/*
 * Copyright (C) 2009, 2010  Daniel Borkmann <daniel@netsniff-ng.org> and 
 *                           Emmanuel Roullit <emmanuel@netsniff-ng.org>
 *
 * This program is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or (at 
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 51 Franklin St, Fifth Floor, Boston, MA 02110, USA
 */

#ifndef _NET_OUI_H_
#define _NET_OUI_H_

#include <stdint.h>

struct vendor_id {
	uintptr_t id;
	char *vendor;
};

/* Taken from IEEE oui vendor list. */
static const struct vendor_id vendor_db[] = {
	{0x000000, "XEROX CORPORATION"},
	{0x000001, "XEROX CORPORATION"},
	{0x000002, "XEROX CORPORATION"},
	{0x000003, "XEROX CORPORATION"},
	{0x000004, "XEROX CORPORATION"},
	{0x000005, "XEROX CORPORATION"},
	{0x000006, "XEROX CORPORATION"},
	{0x000007, "XEROX CORPORATION"},
	{0x000008, "XEROX CORPORATION"},
	{0x000009, "XEROX CORPORATION"},
	{0x00000A, "OMRON TATEISI ELECTRONICS CO."},
	{0x00000B, "MATRIX CORPORATION"},
	{0x00000C, "CISCO SYSTEMS, INC."},
	{0x00000D, "FIBRONICS LTD."},
	{0x00000E, "FUJITSU LIMITED"},
	{0x00000F, "NEXT, INC."},
	{0x000010, "SYTEK INC."},
	{0x000011, "NORMEREL SYSTEMES"},
	{0x000012, "INFORMATION TECHNOLOGY LIMITED"},
	{0x000013, "CAMEX"},
	{0x000014, "NETRONIX"},
	{0x000015, "DATAPOINT CORPORATION"},
	{0x000016, "DU PONT PIXEL SYSTEMS     ."},
	{0x000017, "TEKELEC"},
	{0x000018, "WEBSTER COMPUTER CORPORATION"},
	{0x000019, "APPLIED DYNAMICS INTERNATIONAL"},
	{0x00001A, "ADVANCED MICRO DEVICES"},
	{0x00001B, "NOVELL INC."},
	{0x00001C, "BELL TECHNOLOGIES"},
	{0x00001D, "CABLETRON SYSTEMS, INC."},
	{0x00001E, "TELSIST INDUSTRIA ELECTRONICA"},
	{0x00001F, "Telco Systems, Inc."},
	{0x000020, "DATAINDUSTRIER DIAB AB"},
	{0x000021, "SUREMAN COMP. & COMMUN. CORP."},
	{0x000022, "VISUAL TECHNOLOGY INC."},
	{0x000023, "ABB INDUSTRIAL SYSTEMS AB"},
	{0x000024, "CONNECT AS"},
	{0x000025, "RAMTEK CORP."},
	{0x000026, "SHA-KEN CO., LTD."},
	{0x000027, "JAPAN RADIO COMPANY"},
	{0x000028, "PRODIGY SYSTEMS CORPORATION"},
	{0x000029, "IMC NETWORKS CORP."},
	{0x00002A, "TRW - SEDD/INP"},
	{0x00002B, "CRISP AUTOMATION, INC"},
	{0x00002C, "AUTOTOTE LIMITED"},
	{0x00002D, "CHROMATICS INC"},
	{0x00002E, "SOCIETE EVIRA"},
	{0x00002F, "TIMEPLEX INC."},
	{0x000030, "VG LABORATORY SYSTEMS LTD"},
	{0x000031, "QPSX COMMUNICATIONS PTY LTD"},
	{0x000032, "Marconi plc"},
	{0x000033, "EGAN MACHINERY COMPANY"},
	{0x000034, "NETWORK RESOURCES CORPORATION"},
	{0x000035, "SPECTRAGRAPHICS CORPORATION"},
	{0x000036, "ATARI CORPORATION"},
	{0x000037, "OXFORD METRICS LIMITED"},
	{0x000038, "CSS LABS"},
	{0x000039, "TOSHIBA CORPORATION"},
	{0x00003A, "CHYRON CORPORATION"},
	{0x00003B, "i Controls, Inc."},
	{0x00003C, "AUSPEX SYSTEMS INC."},
	{0x00003D, "UNISYS"},
	{0x00003E, "SIMPACT"},
	{0x00003F, "SYNTREX, INC."},
	{0x000040, "APPLICON, INC."},
	{0x000041, "ICE CORPORATION"},
	{0x000042, "METIER MANAGEMENT SYSTEMS LTD."},
	{0x000043, "MICRO TECHNOLOGY"},
	{0x000044, "CASTELLE CORPORATION"},
	{0x000045, "FORD AEROSPACE & COMM. CORP."},
	{0x000046, "OLIVETTI NORTH AMERICA"},
	{0x000047, "NICOLET INSTRUMENTS CORP."},
	{0x000048, "SEIKO EPSON CORPORATION"},
	{0x000049, "APRICOT COMPUTERS, LTD"},
	{0x00004A, "ADC CODENOLL TECHNOLOGY CORP."},
	{0x00004B, "ICL DATA OY"},
	{0x00004C, "NEC CORPORATION"},
	{0x00004D, "DCI CORPORATION"},
	{0x00004E, "AMPEX CORPORATION"},
	{0x00004F, "LOGICRAFT, INC."},
	{0x000050, "RADISYS CORPORATION"},
	{0x000051, "HOB ELECTRONIC GMBH & CO. KG"},
	{0x000052, "Intrusion.com, Inc."},
	{0x000053, "COMPUCORP"},
	{0x000054, "MODICON, INC."},
	{0x000055, "COMMISSARIAT A L`ENERGIE ATOM."},
	{0x000056, "DR. B. STRUCK"},
	{0x000057, "SCITEX CORPORATION LTD."},
	{0x000058, "RACORE COMPUTER PRODUCTS INC."},
	{0x000059, "HELLIGE GMBH"},
	{0x00005A, "SysKonnect GmbH"},
	{0x00005B, "ELTEC ELEKTRONIK AG"},
	{0x00005C, "TELEMATICS INTERNATIONAL INC."},
	{0x00005D, "CS TELECOM"},
	{0x00005E, "USC INFORMATION SCIENCES INST"},
	{0x00005F, "SUMITOMO ELECTRIC IND., LTD."},
	{0x000060, "KONTRON ELEKTRONIK GMBH"},
	{0x000061, "GATEWAY COMMUNICATIONS"},
	{0x000062, "BULL HN INFORMATION SYSTEMS"},
	{0x000063, "BARCO CONTROL ROOMS GMBH"},
	{0x000064, "YOKOGAWA DIGITAL COMPUTER CORP"},
	{0x000065, "Network General Corporation"},
	{0x000066, "TALARIS SYSTEMS, INC."},
	{0x000067, "SOFT * RITE, INC."},
	{0x000068, "ROSEMOUNT CONTROLS"},
	{0x000069, "CONCORD COMMUNICATIONS INC"},
	{0x00006A, "COMPUTER CONSOLES INC."},
	{0x00006B, "SILICON GRAPHICS INC./MIPS"},
	{0x00006D, "CRAY COMMUNICATIONS, LTD."},
	{0x00006E, "ARTISOFT, INC."},
	{0x00006F, "Madge Ltd."},
	{0x000070, "HCL LIMITED"},
	{0x000071, "ADRA SYSTEMS INC."},
	{0x000072, "MINIWARE TECHNOLOGY"},
	{0x000073, "SIECOR CORPORATION"},
	{0x000074, "RICOH COMPANY LTD."},
	{0x000075, "Nortel Networks"},
	{0x000076, "ABEKAS VIDEO SYSTEM"},
	{0x000077, "INTERPHASE CORPORATION"},
	{0x000078, "LABTAM LIMITED"},
	{0x000079, "NETWORTH INCORPORATED"},
	{0x00007A, "DANA COMPUTER INC."},
	{0x00007B, "RESEARCH MACHINES"},
	{0x00007C, "AMPERE INCORPORATED"},
	{0x00007D, "SUN MICROSYSTEMS, INC."},
	{0x00007E, "CLUSTRIX CORPORATION"},
	{0x00007F, "LINOTYPE-HELL AG"},
	{0x000080, "CRAY COMMUNICATIONS A/S"},
	{0x000081, "BAY NETWORKS"},
	{0x000082, "LECTRA SYSTEMES SA"},
	{0x000083, "TADPOLE TECHNOLOGY PLC"},
	{0x000084, "SUPERNET"},
	{0x000085, "CANON INC."},
	{0x000086, "MEGAHERTZ CORPORATION"},
	{0x000087, "HITACHI, LTD."},
	{0x000088, "Brocade Communications Systems, Inc."},
	{0x000089, "CAYMAN SYSTEMS INC."},
	{0x00008A, "DATAHOUSE INFORMATION SYSTEMS"},
	{0x00008B, "INFOTRON"},
	{0x00008C, "Alloy Computer Products (Australia) Pty Ltd"},
	{0x00008D, "Cryptek Inc."},
	{0x00008E, "SOLBOURNE COMPUTER, INC."},
	{0x00008F, "Raytheon"},
	{0x000090, "MICROCOM"},
	{0x000091, "ANRITSU CORPORATION"},
	{0x000092, "COGENT DATA TECHNOLOGIES"},
	{0x000093, "PROTEON INC."},
	{0x000094, "ASANTE TECHNOLOGIES"},
	{0x000095, "SONY TEKTRONIX CORP."},
	{0x000096, "MARCONI ELECTRONICS LTD."},
	{0x000097, "EMC Corporation"},
	{0x000098, "CROSSCOMM CORPORATION"},
	{0x000099, "MTX, INC."},
	{0x00009A, "RC COMPUTER A/S"},
	{0x00009B, "INFORMATION INTERNATIONAL, INC"},
	{0x00009C, "ROLM MIL-SPEC COMPUTERS"},
	{0x00009D, "LOCUS COMPUTING CORPORATION"},
	{0x00009E, "MARLI S.A."},
	{0x00009F, "AMERISTAR TECHNOLOGIES INC."},
	{0x0000A0, "SANYO Electric Co., Ltd."},
	{0x0000A1, "MARQUETTE ELECTRIC CO."},
	{0x0000A2, "BAY NETWORKS"},
	{0x0000A3, "NETWORK APPLICATION TECHNOLOGY"},
	{0x0000A4, "ACORN COMPUTERS LIMITED"},
	{0x0000A5, "COMPATIBLE SYSTEMS CORP."},
	{0x0000A6, "NETWORK GENERAL CORPORATION"},
	{0x0000A7, "NETWORK COMPUTING DEVICES INC."},
	{0x0000A8, "STRATUS COMPUTER INC."},
	{0x0000A9, "NETWORK SYSTEMS CORP."},
	{0x0000AA, "XEROX CORPORATION"},
	{0x0000AB, "LOGIC MODELING CORPORATION"},
	{0x0000AC, "CONWARE COMPUTER CONSULTING"},
	{0x0000AD, "BRUKER INSTRUMENTS INC."},
	{0x0000AE, "DASSAULT ELECTRONIQUE"},
	{0x0000AF, "NUCLEAR DATA INSTRUMENTATION"},
	{0x0000B0, "RND-RAD NETWORK DEVICES"},
	{0x0000B1, "ALPHA MICROSYSTEMS INC."},
	{0x0000B2, "TELEVIDEO SYSTEMS, INC."},
	{0x0000B3, "CIMLINC INCORPORATED"},
	{0x0000B4, "EDIMAX COMPUTER COMPANY"},
	{0x0000B5, "DATABILITY SOFTWARE SYS. INC."},
	{0x0000B6, "MICRO-MATIC RESEARCH"},
	{0x0000B7, "DOVE COMPUTER CORPORATION"},
	{0x0000B8, "SEIKOSHA CO., LTD."},
	{0x0000B9, "MCDONNELL DOUGLAS COMPUTER SYS"},
	{0x0000BA, "SIIG, INC."},
	{0x0000BB, "TRI-DATA"},
	{0x0000BC, "Rockwell Automation"},
	{0x0000BD, "MITSUBISHI CABLE COMPANY"},
	{0x0000BE, "THE NTI GROUP"},
	{0x0000BF, "SYMMETRIC COMPUTER SYSTEMS"},
	{0x0000C0, "WESTERN DIGITAL CORPORATION"},
	{0x0000C1, "Madge Ltd."},
	{0x0000C2, "INFORMATION PRESENTATION TECH."},
	{0x0000C3, "HARRIS CORP COMPUTER SYS DIV"},
	{0x0000C4, "WATERS DIV. OF MILLIPORE"},
	{0x0000C5, "FARALLON COMPUTING/NETOPIA"},
	{0x0000C6, "EON SYSTEMS"},
	{0x0000C7, "ARIX CORPORATION"},
	{0x0000C8, "ALTOS COMPUTER SYSTEMS"},
	{0x0000C9, "Emulex Corporation"},
	{0x0000CA, "ARRIS International"},
	{0x0000CB, "COMPU-SHACK ELECTRONIC GMBH"},
	{0x0000CC, "DENSAN CO., LTD."},
	{0x0000CD, "Allied Telesis Labs Ltd"},
	{0x0000CE, "MEGADATA CORP."},
	{0x0000CF, "HAYES MICROCOMPUTER PRODUCTS"},
	{0x0000D0, "DEVELCON ELECTRONICS LTD."},
	{0x0000D1, "ADAPTEC INCORPORATED"},
	{0x0000D2, "SBE, INC."},
	{0x0000D3, "WANG LABORATORIES INC."},
	{0x0000D4, "PURE DATA LTD."},
	{0x0000D5, "MICROGNOSIS INTERNATIONAL"},
	{0x0000D6, "PUNCH LINE HOLDING"},
	{0x0000D7, "DARTMOUTH COLLEGE"},
	{0x0000D8, "NOVELL, INC."},
	{0x0000D9, "NIPPON TELEGRAPH & TELEPHONE"},
	{0x0000DA, "ATEX"},
	{0x0000DB, "BRITISH TELECOMMUNICATIONS PLC"},
	{0x0000DC, "HAYES MICROCOMPUTER PRODUCTS"},
	{0x0000DD, "TCL INCORPORATED"},
	{0x0000DE, "CETIA"},
	{0x0000DF, "BELL & HOWELL PUB SYS DIV"},
	{0x0000E0, "QUADRAM CORP."},
	{0x0000E1, "GRID SYSTEMS"},
	{0x0000E2, "ACER TECHNOLOGIES CORP."},
	{0x0000E3, "INTEGRATED MICRO PRODUCTS LTD"},
	{0x0000E4, "IN2 GROUPE INTERTECHNIQUE"},
	{0x0000E5, "SIGMEX LTD."},
	{0x0000E6, "APTOR PRODUITS DE COMM INDUST"},
	{0x0000E7, "STAR GATE TECHNOLOGIES"},
	{0x0000E8, "ACCTON TECHNOLOGY CORP."},
	{0x0000E9, "ISICAD, INC."},
	{0x0000EA, "UPNOD AB"},
	{0x0000EB, "MATSUSHITA COMM. IND. CO. LTD."},
	{0x0000EC, "MICROPROCESS"},
	{0x0000ED, "APRIL"},
	{0x0000EE, "NETWORK DESIGNERS, LTD."},
	{0x0000EF, "KTI"},
	{0x0000F0, "SAMSUNG ELECTRONICS CO., LTD."},
	{0x0000F1, "MAGNA COMPUTER CORPORATION"},
	{0x0000F2, "SPIDER COMMUNICATIONS"},
	{0x0000F3, "GANDALF DATA LIMITED"},
	{0x0000F4, "Allied Telesis"},
	{0x0000F5, "DIAMOND SALES LIMITED"},
	{0x0000F6, "APPLIED MICROSYSTEMS CORP."},
	{0x0000F7, "YOUTH KEEP ENTERPRISE CO LTD"},
	{0x0000F8, "DIGITAL EQUIPMENT CORPORATION"},
	{0x0000F9, "QUOTRON SYSTEMS INC."},
	{0x0000FA, "MICROSAGE COMPUTER SYSTEMS INC"},
	{0x0000FB, "RECHNER ZUR KOMMUNIKATION"},
	{0x0000FC, "MEIKO"},
	{0x0000FD, "HIGH LEVEL HARDWARE"},
	{0x0000FE, "ANNAPOLIS MICRO SYSTEMS"},
	{0x0000FF, "CAMTEC ELECTRONICS LTD."},
	{0x000100, "EQUIP'TRANS"},
	{0x000102, "3COM CORPORATION"},
	{0x000103, "3COM CORPORATION"},
	{0x000104, "DVICO Co., Ltd."},
	{0x000105, "Beckhoff Automation GmbH"},
	{0x000106, "Tews Datentechnik GmbH"},
	{0x000107, "Leiser GmbH"},
	{0x000108, "AVLAB Technology, Inc."},
	{0x000109, "Nagano Japan Radio Co., Ltd."},
	{0x00010A, "CIS TECHNOLOGY INC."},
	{0x00010B, "Space CyberLink, Inc."},
	{0x00010C, "System Talks Inc."},
	{0x00010D, "CORECO, INC."},
	{0x00010E, "Bri-Link Technologies Co., Ltd"},
	{0x00010F, "Brocade Communications Systems, Inc."},
	{0x000110, "Gotham Networks"},
	{0x000111, "iDigm Inc."},
	{0x000112, "Shark Multimedia Inc."},
	{0x000113, "OLYMPUS CORPORATION"},
	{0x000114, "KANDA TSUSHIN KOGYO CO., LTD."},
	{0x000115, "EXTRATECH CORPORATION"},
	{0x000116, "Netspect Technologies, Inc."},
	{0x000117, "CANAL +"},
	{0x000118, "EZ Digital Co., Ltd."},
	{0x000119, "RTUnet (Australia)"},
	{0x00011A, "EEH DataLink GmbH"},
	{0x00011B, "Unizone Technologies, Inc."},
	{0x00011C, "Universal Talkware Corporation"},
	{0x00011D, "Centillium Communications"},
	{0x00011E, "Precidia Technologies, Inc."},
	{0x00011F, "RC Networks, Inc."},
	{0x000120, "OSCILLOQUARTZ S.A."},
	{0x000121, "Watchguard Technologies, Inc."},
	{0x000122, "Trend Communications, Ltd."},
	{0x000123, "DIGITAL ELECTRONICS CORP."},
	{0x000124, "Acer Incorporated"},
	{0x000125, "YAESU MUSEN CO., LTD."},
	{0x000126, "PAC Labs"},
	{0x000127, "OPEN Networks Pty Ltd"},
	{0x000128, "EnjoyWeb, Inc."},
	{0x000129, "DFI Inc."},
	{0x00012A, "Telematica Sistems Inteligente"},
	{0x00012B, "TELENET Co., Ltd."},
	{0x00012C, "Aravox Technologies, Inc."},
	{0x00012D, "Komodo Technology"},
	{0x00012E, "PC Partner Ltd."},
	{0x00012F, "Twinhead International Corp"},
	{0x000130, "Extreme Networks"},
	{0x000131, "Detection Systems, Inc."},
	{0x000132, "Dranetz - BMI"},
	{0x000133, "KYOWA Electronic Instruments C"},
	{0x000134, "Selectron Systems AG"},
	{0x000135, "KDC Corp."},
	{0x000136, "CyberTAN Technology, Inc."},
	{0x000137, "IT Farm Corporation"},
	{0x000138, "XAVi Technologies Corp."},
	{0x000139, "Point Multimedia Systems"},
	{0x00013A, "SHELCAD COMMUNICATIONS, LTD."},
	{0x00013B, "BNA SYSTEMS"},
	{0x00013C, "TIW SYSTEMS"},
	{0x00013D, "RiscStation Ltd."},
	{0x00013E, "Ascom Tateco AB"},
	{0x00013F, "Neighbor World Co., Ltd."},
	{0x000140, "Sendtek Corporation"},
	{0x000141, "CABLE PRINT"},
	{0x000142, "Cisco Systems, Inc."},
	{0x000143, "Cisco Systems, Inc."},
	{0x000144, "EMC Corporation"},
	{0x000145, "WINSYSTEMS, INC."},
	{0x000146, "Tesco Controls, Inc."},
	{0x000147, "Zhone Technologies"},
	{0x000148, "X-traWeb Inc."},
	{0x000149, "T.D.T. Transfer Data Test GmbH"},
	{0x00014A, "Sony Corporation"},
	{0x00014B, "Ennovate Networks, Inc."},
	{0x00014C, "Berkeley Process Control"},
	{0x00014D, "Shin Kin Enterprises Co., Ltd"},
	{0x00014E, "WIN Enterprises, Inc."},
	{0x00014F, "ADTRAN INC"},
	{0x000150, "GILAT COMMUNICATIONS, LTD."},
	{0x000151, "Ensemble Communications"},
	{0x000152, "CHROMATEK INC."},
	{0x000153, "ARCHTEK TELECOM CORPORATION"},
	{0x000154, "G3M Corporation"},
	{0x000155, "Promise Technology, Inc."},
	{0x000156, "FIREWIREDIRECT.COM, INC."},
	{0x000157, "SYSWAVE CO., LTD"},
	{0x000158, "Electro Industries/Gauge Tech"},
	{0x000159, "S1 Corporation"},
	{0x00015A, "Digital Video Broadcasting"},
	{0x00015B, "ITALTEL S.p.A/RF-UP-I"},
	{0x00015C, "CADANT INC."},
	{0x00015D, "Sun Microsystems, Inc"},
	{0x00015E, "BEST TECHNOLOGY CO., LTD."},
	{0x00015F, "DIGITAL DESIGN GmbH"},
	{0x000160, "ELMEX Co., LTD."},
	{0x000161, "Meta Machine Technology"},
	{0x000162, "Cygnet Technologies, Inc."},
	{0x000163, "Cisco Systems, Inc."},
	{0x000164, "Cisco Systems, Inc."},
	{0x000165, "AirSwitch Corporation"},
	{0x000166, "TC GROUP A/S"},
	{0x000167, "HIOKI E.E. CORPORATION"},
	{0x000168, "VITANA CORPORATION"},
	{0x000169, "Celestix Networks Pte Ltd."},
	{0x00016A, "ALITEC"},
	{0x00016B, "LightChip, Inc."},
	{0x00016C, "FOXCONN"},
	{0x00016D, "CarrierComm Inc."},
	{0x00016E, "Conklin Corporation"},
	{0x00016F, "Inkel Corp."},
	{0x000170, "ESE Embedded System Engineer'g"},
	{0x000171, "Allied Data Technologies"},
	{0x000172, "TechnoLand Co., LTD."},
	{0x000173, "AMCC"},
	{0x000174, "CyberOptics Corporation"},
	{0x000175, "Radiant Communications Corp."},
	{0x000176, "Orient Silver Enterprises"},
	{0x000177, "EDSL"},
	{0x000178, "MARGI Systems, Inc."},
	{0x000179, "WIRELESS TECHNOLOGY, INC."},
	{0x00017A, "Chengdu Maipu Electric Industrial Co., Ltd."},
	{0x00017B, "Heidelberger Druckmaschinen AG"},
	{0x00017C, "AG-E GmbH"},
	{0x00017D, "ThermoQuest"},
	{0x00017E, "ADTEK System Science Co., Ltd."},
	{0x00017F, "Experience Music Project"},
	{0x000180, "AOpen, Inc."},
	{0x000181, "Nortel Networks"},
	{0x000182, "DICA TECHNOLOGIES AG"},
	{0x000183, "ANITE TELECOMS"},
	{0x000184, "SIEB & MEYER AG"},
	{0x000185, "Aloka Co., Ltd."},
	{0x000186, "Uwe Disch"},
	{0x000187, "i2SE GmbH"},
	{0x000188, "LXCO Technologies ag"},
	{0x000189, "Refraction Technology, Inc."},
	{0x00018A, "ROI COMPUTER AG"},
	{0x00018B, "NetLinks Co., Ltd."},
	{0x00018C, "Mega Vision"},
	{0x00018D, "AudeSi Technologies"},
	{0x00018E, "Logitec Corporation"},
	{0x00018F, "Kenetec, Inc."},
	{0x000190, "SMK-M"},
	{0x000191, "SYRED Data Systems"},
	{0x000192, "Texas Digital Systems"},
	{0x000193, "Hanbyul Telecom Co., Ltd."},
	{0x000194, "Capital Equipment Corporation"},
	{0x000195, "Sena Technologies, Inc."},
	{0x000196, "Cisco Systems, Inc."},
	{0x000197, "Cisco Systems, Inc."},
	{0x000198, "Darim Vision"},
	{0x000199, "HeiSei Electronics"},
	{0x00019A, "LEUNIG GmbH"},
	{0x00019B, "Kyoto Microcomputer Co., Ltd."},
	{0x00019C, "JDS Uniphase Inc."},
	{0x00019D, "E-Control Systems, Inc."},
	{0x00019E, "ESS Technology, Inc."},
	{0x00019F, "Phonex Broadband"},
	{0x0001A0, "Infinilink Corporation"},
	{0x0001A1, "Mag-Tek, Inc."},
	{0x0001A2, "Logical Co., Ltd."},
	{0x0001A3, "GENESYS LOGIC, INC."},
	{0x0001A4, "Microlink Corporation"},
	{0x0001A5, "Nextcomm, Inc."},
	{0x0001A6, "Scientific-Atlanta Arcodan A/S"},
	{0x0001A7, "UNEX TECHNOLOGY CORPORATION"},
	{0x0001A8, "Welltech Computer Co., Ltd."},
	{0x0001A9, "BMW AG"},
	{0x0001AA, "Airspan Communications, Ltd."},
	{0x0001AB, "Main Street Networks"},
	{0x0001AC, "Sitara Networks, Inc."},
	{0x0001AD, "Coach Master International  d.b.a. CMI Worldwide, Inc."},
	{0x0001AE, "Trex Enterprises"},
	{0x0001AF, "Emerson Network Power"},
	{0x0001B0, "Fulltek Technology Co., Ltd."},
	{0x0001B1, "General Bandwidth"},
	{0x0001B2, "Digital Processing Systems, Inc."},
	{0x0001B3, "Precision Electronic Manufacturing"},
	{0x0001B4, "Wayport, Inc."},
	{0x0001B5, "Turin Networks, Inc."},
	{0x0001B6, "SAEJIN T&M Co., Ltd."},
	{0x0001B7, "Centos, Inc."},
	{0x0001B8, "Netsensity, Inc."},
	{0x0001B9, "SKF Condition Monitoring"},
	{0x0001BA, "IC-Net, Inc."},
	{0x0001BB, "Frequentis"},
	{0x0001BC, "Brains Corporation"},
	{0x0001BD, "Peterson Electro-Musical Products, Inc."},
	{0x0001BE, "Gigalink Co., Ltd."},
	{0x0001BF, "Teleforce Co., Ltd."},
	{0x0001C0, "CompuLab, Ltd."},
	{0x0001C1, "Vitesse Semiconductor Corporation"},
	{0x0001C2, "ARK Research Corp."},
	{0x0001C3, "Acromag, Inc."},
	{0x0001C4, "NeoWave, Inc."},
	{0x0001C5, "Simpler Networks"},
	{0x0001C6, "Quarry Technologies"},
	{0x0001C7, "Cisco Systems, Inc."},
	{0x0001C8, "THOMAS CONRAD CORP."},
	{0x0001C8, "CONRAD CORP."},
	{0x0001C9, "Cisco Systems, Inc."},
	{0x0001CA, "Geocast Network Systems, Inc."},
	{0x0001CB, "EVR"},
	{0x0001CC, "Japan Total Design Communication Co., Ltd."},
	{0x0001CD, "ARtem"},
	{0x0001CE, "Custom Micro Products, Ltd."},
	{0x0001CF, "Alpha Data Parallel Systems, Ltd."},
	{0x0001D0, "VitalPoint, Inc."},
	{0x0001D1, "CoNet Communications, Inc."},
	{0x0001D2, "MacPower Peripherals, Ltd."},
	{0x0001D3, "PAXCOMM, Inc."},
	{0x0001D4, "Leisure Time, Inc."},
	{0x0001D5, "HAEDONG INFO & COMM CO., LTD"},
	{0x0001D6, "manroland AG"},
	{0x0001D7, "F5 Networks, Inc."},
	{0x0001D8, "Teltronics, Inc."},
	{0x0001D9, "Sigma, Inc."},
	{0x0001DA, "WINCOMM Corporation"},
	{0x0001DB, "Freecom Technologies GmbH"},
	{0x0001DC, "Activetelco"},
	{0x0001DD, "Avail Networks"},
	{0x0001DE, "Trango Systems, Inc."},
	{0x0001DF, "ISDN Communications, Ltd."},
	{0x0001E0, "Fast Systems, Inc."},
	{0x0001E1, "Kinpo Electronics, Inc."},
	{0x0001E2, "Ando Electric Corporation"},
	{0x0001E3, "Siemens AG"},
	{0x0001E4, "Sitera, Inc."},
	{0x0001E5, "Supernet, Inc."},
	{0x0001E6, "Hewlett-Packard Company"},
	{0x0001E7, "Hewlett-Packard Company"},
	{0x0001E8, "Force10 Networks, Inc."},
	{0x0001E9, "Litton Marine Systems B.V."},
	{0x0001EA, "Cirilium Corp."},
	{0x0001EB, "C-COM Corporation"},
	{0x0001EC, "Ericsson Group"},
	{0x0001ED, "SETA Corp."},
	{0x0001EE, "Comtrol Europe, Ltd."},
	{0x0001EF, "Camtel Technology Corp."},
	{0x0001F0, "Tridium, Inc."},
	{0x0001F1, "Innovative Concepts, Inc."},
	{0x0001F2, "Mark of the Unicorn, Inc."},
	{0x0001F3, "QPS, Inc."},
	{0x0001F4, "Enterasys Networks"},
	{0x0001F5, "ERIM S.A."},
	{0x0001F6, "Association of Musical Electronics Industry"},
	{0x0001F7, "Image Display Systems, Inc."},
	{0x0001F8, "Adherent Systems, Ltd."},
	{0x0001F9, "TeraGlobal Communications Corp."},
	{0x0001FA, "HOROSCAS"},
	{0x0001FB, "DoTop Technology, Inc."},
	{0x0001FC, "Keyence Corporation"},
	{0x0001FD, "Digital Voice Systems, Inc."},
	{0x0001FE, "DIGITAL EQUIPMENT CORPORATION"},
	{0x0001FF, "Data Direct Networks, Inc."},
	{0x000200, "Net & Sys Co., Ltd."},
	{0x000201, "IFM Electronic gmbh"},
	{0x000202, "Amino Communications, Ltd."},
	{0x000203, "Woonsang Telecom, Inc."},
	{0x000204, "Bodmann Industries Elektronik GmbH"},
	{0x000205, "Hitachi Denshi, Ltd."},
	{0x000206, "Telital R&D Denmark A/S"},
	{0x000207, "VisionGlobal Network Corp."},
	{0x000208, "Unify Networks, Inc."},
	{0x000209, "Shenzhen SED Information Technology Co., Ltd."},
	{0x00020A, "Gefran Spa"},
	{0x00020B, "Native Networks, Inc."},
	{0x00020C, "Metro-Optix"},
	{0x00020D, "Micronpc.com"},
	{0x00020E, "ECI Telecom, Ltd., NSD-US"},
	{0x00020F, "AATR"},
	{0x000210, "Fenecom"},
	{0x000211, "Nature Worldwide Technology Corp."},
	{0x000212, "SierraCom"},
	{0x000213, "S.D.E.L."},
	{0x000214, "DTVRO"},
	{0x000215, "Cotas Computer Technology A/B"},
	{0x000216, "Cisco Systems, Inc."},
	{0x000217, "Cisco Systems, Inc."},
	{0x000218, "Advanced Scientific Corp"},
	{0x000219, "Paralon Technologies"},
	{0x00021A, "Zuma Networks"},
	{0x00021B, "Kollmorgen-Servotronix"},
	{0x00021C, "Network Elements, Inc."},
	{0x00021D, "Data General Communication Ltd."},
	{0x00021E, "SIMTEL S.R.L."},
	{0x00021F, "Aculab PLC"},
	{0x000220, "Canon Aptex, Inc."},
	{0x000221, "DSP Application, Ltd."},
	{0x000222, "Chromisys, Inc."},
	{0x000223, "ClickTV"},
	{0x000224, "C-COR"},
	{0x000225, "One Stop Systems"},
	{0x000226, "XESystems, Inc."},
	{0x000227, "ESD Electronic System Design GmbH"},
	{0x000228, "Necsom, Ltd."},
	{0x000229, "Adtec Corporation"},
	{0x00022A, "Asound Electronic"},
	{0x00022B, "SAXA, Inc."},
	{0x00022C, "ABB Bomem, Inc."},
	{0x00022D, "Agere Systems"},
	{0x00022E, "TEAC Corp. R& D"},
	{0x00022F, "P-Cube, Ltd."},
	{0x000230, "Intersoft Electronics"},
	{0x000231, "Ingersoll-Rand"},
	{0x000232, "Avision, Inc."},
	{0x000233, "Mantra Communications, Inc."},
	{0x000234, "Imperial Technology, Inc."},
	{0x000235, "Paragon Networks International"},
	{0x000236, "INIT GmbH"},
	{0x000237, "Cosmo Research Corp."},
	{0x000238, "Serome Technology, Inc."},
	{0x000239, "Visicom"},
	{0x00023A, "ZSK Stickmaschinen GmbH"},
	{0x00023B, "Redback Networks"},
	{0x00023C, "Creative Technology, Ltd."},
	{0x00023D, "NuSpeed, Inc."},
	{0x00023E, "Selta Telematica S.p.a"},
	{0x00023F, "Compal Electronics, Inc."},
	{0x000240, "Seedek Co., Ltd."},
	{0x000241, "Amer.com"},
	{0x000242, "Videoframe Systems"},
	{0x000243, "Raysis Co., Ltd."},
	{0x000244, "SURECOM Technology Co."},
	{0x000245, "Lampus Co, Ltd."},
	{0x000246, "All-Win Tech Co., Ltd."},
	{0x000247, "Great Dragon Information Technology (Group) Co., Ltd."},
	{0x000248, "Pilz GmbH & Co."},
	{0x000249, "Aviv Infocom Co, Ltd."},
	{0x00024A, "Cisco Systems, Inc."},
	{0x00024B, "Cisco Systems, Inc."},
	{0x00024C, "SiByte, Inc."},
	{0x00024D, "Mannesman Dematic Colby Pty. Ltd."},
	{0x00024E, "Datacard Group"},
	{0x00024F, "IPM Datacom S.R.L."},
	{0x000250, "Geyser Networks, Inc."},
	{0x000251, "Soma Networks, Inc."},
	{0x000252, "Carrier Corporation"},
	{0x000253, "Televideo, Inc."},
	{0x000254, "WorldGate"},
	{0x000255, "IBM Corporation"},
	{0x000256, "Alpha Processor, Inc."},
	{0x000257, "Microcom Corp."},
	{0x000258, "Flying Packets Communications"},
	{0x000259, "Tsann Kuen China (Shanghai)Enterprise Co., Ltd. IT Group"},
	{0x00025A, "Catena Networks"},
	{0x00025B, "Cambridge Silicon Radio"},
	{0x00025C, "SCI Systems (Kunshan) Co., Ltd."},
	{0x00025D, "Calix Networks"},
	{0x00025E, "High Technology Ltd"},
	{0x00025F, "Nortel Networks"},
	{0x000260, "Accordion Networks, Inc."},
	{0x000261, "Tilgin AB"},
	{0x000262, "Soyo Group Soyo Com Tech Co., Ltd"},
	{0x000263, "UPS Manufacturing SRL"},
	{0x000264, "AudioRamp.com"},
	{0x000265, "Virditech Co. Ltd."},
	{0x000266, "Thermalogic Corporation"},
	{0x000267, "NODE RUNNER, INC."},
	{0x000268, "Harris Government Communications"},
	{0x000269, "Nadatel Co., Ltd"},
	{0x00026A, "Cocess Telecom Co., Ltd."},
	{0x00026B, "BCM Computers Co., Ltd."},
	{0x00026C, "Philips CFT"},
	{0x00026D, "Adept Telecom"},
	{0x00026E, "NeGeN Access, Inc."},
	{0x00026F, "Senao International Co., Ltd."},
	{0x000270, "Crewave Co., Ltd."},
	{0x000271, "Vpacket Communications"},
	{0x000272, "CC&C Technologies, Inc."},
	{0x000273, "Coriolis Networks"},
	{0x000274, "Tommy Technologies Corp."},
	{0x000275, "SMART Technologies, Inc."},
	{0x000276, "Primax Electronics Ltd."},
	{0x000277, "Cash Systemes Industrie"},
	{0x000278, "Samsung Electro-Mechanics Co., Ltd."},
	{0x000279, "Control Applications, Ltd."},
	{0x00027A, "IOI Technology Corporation"},
	{0x00027B, "Amplify Net, Inc."},
	{0x00027C, "Trilithic, Inc."},
	{0x00027D, "Cisco Systems, Inc."},
	{0x00027E, "Cisco Systems, Inc."},
	{0x00027F, "ask-technologies.com"},
	{0x000280, "Mu Net, Inc."},
	{0x000281, "Madge Ltd."},
	{0x000282, "ViaClix, Inc."},
	{0x000283, "Spectrum Controls, Inc."},
	{0x000284, "AREVA T&D"},
	{0x000285, "Riverstone Networks"},
	{0x000286, "Occam Networks"},
	{0x000287, "Adapcom"},
	{0x000288, "GLOBAL VILLAGE COMMUNICATION"},
	{0x000289, "DNE Technologies"},
	{0x00028A, "Ambit Microsystems Corporation"},
	{0x00028B, "VDSL Systems OY"},
	{0x00028C, "Micrel-Synergy Semiconductor"},
	{0x00028D, "Movita Technologies, Inc."},
	{0x00028E, "Rapid 5 Networks, Inc."},
	{0x00028F, "Globetek, Inc."},
	{0x000290, "Woorigisool, Inc."},
	{0x000291, "Open Network Co., Ltd."},
	{0x000292, "Logic Innovations, Inc."},
	{0x000293, "Solid Data Systems"},
	{0x000294, "Tokyo Sokushin Co., Ltd."},
	{0x000295, "IP.Access Limited"},
	{0x000296, "Lectron Co,. Ltd."},
	{0x000297, "C-COR.net"},
	{0x000298, "Broadframe Corporation"},
	{0x000299, "Apex, Inc."},
	{0x00029A, "Storage Apps"},
	{0x00029B, "Kreatel Communications AB"},
	{0x00029C, "3COM"},
	{0x00029D, "Merix Corp."},
	{0x00029E, "Information Equipment Co., Ltd."},
	{0x00029F, "L-3 Communication Aviation Recorders"},
	{0x0002A0, "Flatstack Ltd."},
	{0x0002A1, "World Wide Packets"},
	{0x0002A2, "Hilscher GmbH"},
	{0x0002A3, "ABB Switzerland Ltd, Power Systems"},
	{0x0002A4, "AddPac Technology Co., Ltd."},
	{0x0002A5, "Hewlett Packard"},
	{0x0002A6, "Effinet Systems Co., Ltd."},
	{0x0002A7, "Vivace Networks"},
	{0x0002A8, "Air Link Technology"},
	{0x0002A9, "RACOM, s.r.o."},
	{0x0002AA, "PLcom Co., Ltd."},
	{0x0002AB, "CTC Union Technologies Co., Ltd."},
	{0x0002AC, "3PAR data"},
	{0x0002AD, "HOYA Corporation"},
	{0x0002AE, "Scannex Electronics Ltd."},
	{0x0002AF, "TeleCruz Technology, Inc."},
	{0x0002B0, "Hokubu Communication & Industrial Co., Ltd."},
	{0x0002B1, "Anritsu, Ltd."},
	{0x0002B2, "Cablevision"},
	{0x0002B3, "Intel Corporation"},
	{0x0002B4, "DAPHNE"},
	{0x0002B5, "Avnet, Inc."},
	{0x0002B6, "Acrosser Technology Co., Ltd."},
	{0x0002B7, "Watanabe Electric Industry Co., Ltd."},
	{0x0002B8, "WHI KONSULT AB"},
	{0x0002B9, "Cisco Systems, Inc."},
	{0x0002BA, "Cisco Systems, Inc."},
	{0x0002BB, "Continuous Computing Corp"},
	{0x0002BC, "LVL 7 Systems, Inc."},
	{0x0002BD, "Bionet Co., Ltd."},
	{0x0002BE, "Totsu Engineering, Inc."},
	{0x0002BF, "dotRocket, Inc."},
	{0x0002C0, "Bencent Tzeng Industry Co., Ltd."},
	{0x0002C1, "Innovative Electronic Designs, Inc."},
	{0x0002C2, "Net Vision Telecom"},
	{0x0002C3, "Arelnet Ltd."},
	{0x0002C4, "Vector International BVBA"},
	{0x0002C5, "Evertz Microsystems Ltd."},
	{0x0002C6, "Data Track Technology PLC"},
	{0x0002C7, "ALPS ELECTRIC Co., Ltd."},
	{0x0002C8, "Technocom Communications Technology (pte) Ltd"},
	{0x0002C9, "Mellanox Technologies"},
	{0x0002CA, "EndPoints, Inc."},
	{0x0002CB, "TriState Ltd."},
	{0x0002CC, "M.C.C.I"},
	{0x0002CD, "TeleDream, Inc."},
	{0x0002CE, "FoxJet, Inc."},
	{0x0002CF, "ZyGate Communications, Inc."},
	{0x0002D0, "Comdial Corporation"},
	{0x0002D1, "Vivotek, Inc."},
	{0x0002D2, "Workstation AG"},
	{0x0002D3, "NetBotz, Inc."},
	{0x0002D4, "PDA Peripherals, Inc."},
	{0x0002D5, "ACR"},
	{0x0002D6, "NICE Systems"},
	{0x0002D7, "EMPEG Ltd"},
	{0x0002D8, "BRECIS Communications Corporation"},
	{0x0002D9, "Reliable Controls"},
	{0x0002DA, "ExiO Communications, Inc."},
	{0x0002DB, "NETSEC"},
	{0x0002DC, "Fujitsu General Limited"},
	{0x0002DD, "Bromax Communications, Ltd."},
	{0x0002DE, "Astrodesign, Inc."},
	{0x0002DF, "Net Com Systems, Inc."},
	{0x0002E0, "ETAS GmbH"},
	{0x0002E1, "Integrated Network Corporation"},
	{0x0002E2, "NDC Infared Engineering"},
	{0x0002E3, "LITE-ON Communications, Inc."},
	{0x0002E4, "JC HYUN Systems, Inc."},
	{0x0002E5, "Timeware Ltd."},
	{0x0002E6, "Gould Instrument Systems, Inc."},
	{0x0002E7, "CAB GmbH & Co KG"},
	{0x0002E8, "E.D.&A."},
	{0x0002E9, "CS Systemes De Securite - C3S"},
	{0x0002EA, "Focus Enhancements"},
	{0x0002EB, "Pico Communications"},
	{0x0002EC, "Maschoff Design Engineering"},
	{0x0002ED, "DXO Telecom Co., Ltd."},
	{0x0002EE, "Nokia Danmark A/S"},
	{0x0002EF, "CCC Network Systems Group Ltd."},
	{0x0002F0, "AME Optimedia Technology Co., Ltd."},
	{0x0002F1, "Pinetron Co., Ltd."},
	{0x0002F2, "eDevice, Inc."},
	{0x0002F3, "Media Serve Co., Ltd."},
	{0x0002F4, "PCTEL, Inc."},
	{0x0002F5, "VIVE Synergies, Inc."},
	{0x0002F6, "Equipe Communications"},
	{0x0002F7, "ARM"},
	{0x0002F8, "SEAKR Engineering, Inc."},
	{0x0002F9, "Mimos Semiconductor SDN BHD"},
	{0x0002FA, "DX Antenna Co., Ltd."},
	{0x0002FB, "Baumuller Aulugen-Systemtechnik GmbH"},
	{0x0002FC, "Cisco Systems, Inc."},
	{0x0002FD, "Cisco Systems, Inc."},
	{0x0002FE, "Viditec, Inc."},
	{0x0002FF, "Handan BroadInfoCom"},
	{0x000300, "NetContinuum, Inc."},
	{0x000301, "Avantas Networks Corporation"},
	{0x000302, "Charles Industries, Ltd."},
	{0x000303, "JAMA Electronics Co., Ltd."},
	{0x000304, "Pacific Broadband Communications"},
	{0x000305, "MSC Vertriebs GmbH"},
	{0x000306, "Fusion In Tech Co., Ltd."},
	{0x000307, "Secure Works, Inc."},
	{0x000308, "AM Communications, Inc."},
	{0x000309, "Texcel Technology PLC"},
	{0x00030A, "Argus Technologies"},
	{0x00030B, "Hunter Technology, Inc."},
	{0x00030C, "Telesoft Technologies Ltd."},
	{0x00030D, "Uniwill Computer Corp."},
	{0x00030E, "Core Communications Co., Ltd."},
	{0x00030F, "Digital China (Shanghai) Networks Ltd."},
	{0x000310, "ITX E-Globaledge Corporation"},
	{0x000311, "Micro Technology Co., Ltd."},
	{0x000312, "TR-Systemtechnik GmbH"},
	{0x000313, "Access Media SPA"},
	{0x000314, "Teleware Network Systems"},
	{0x000315, "Cidco Incorporated"},
	{0x000316, "Nobell Communications, Inc."},
	{0x000317, "Merlin Systems, Inc."},
	{0x000318, "Cyras Systems, Inc."},
	{0x000319, "Infineon AG"},
	{0x00031A, "Beijing Broad Telecom Ltd., China"},
	{0x00031B, "Cellvision Systems, Inc."},
	{0x00031C, "Svenska Hardvarufabriken AB"},
	{0x00031D, "Taiwan Commate Computer, Inc."},
	{0x00031E, "Optranet, Inc."},
	{0x00031F, "Condev Ltd."},
	{0x000320, "Xpeed, Inc."},
	{0x000321, "Reco Research Co., Ltd."},
	{0x000322, "IDIS Co., Ltd."},
	{0x000323, "Cornet Technology, Inc."},
	{0x000324, "SANYO Consumer Electronics Co., Ltd."},
	{0x000325, "Arima Computer Corp."},
	{0x000326, "Iwasaki Information Systems Co., Ltd."},
	{0x000327, "ACT'L"},
	{0x000328, "Mace Group, Inc."},
	{0x000329, "F3, Inc."},
	{0x00032A, "UniData Communication Systems, Inc."},
	{0x00032B, "GAI Datenfunksysteme GmbH"},
	{0x00032C, "ABB Switzerland Ltd"},
	{0x00032D, "IBASE Technology, Inc."},
	{0x00032E, "Scope Information Management, Ltd."},
	{0x00032F, "Global Sun Technology, Inc."},
	{0x000330, "Imagenics, Co., Ltd."},
	{0x000331, "Cisco Systems, Inc."},
	{0x000332, "Cisco Systems, Inc."},
	{0x000333, "Digitel Co., Ltd."},
	{0x000334, "Newport Electronics"},
	{0x000335, "Mirae Technology"},
	{0x000336, "Zetes Technologies"},
	{0x000337, "Vaone, Inc."},
	{0x000338, "Oak Technology"},
	{0x000339, "Eurologic Systems, Ltd."},
	{0x00033A, "Silicon Wave, Inc."},
	{0x00033B, "TAMI Tech Co., Ltd."},
	{0x00033C, "Daiden Co., Ltd."},
	{0x00033D, "ILSHin Lab"},
	{0x00033E, "Tateyama System Laboratory Co., Ltd."},
	{0x00033F, "BigBand Networks, Ltd."},
	{0x000340, "Floware Wireless Systems, Ltd."},
	{0x000341, "Axon Digital Design"},
	{0x000342, "Nortel Networks"},
	{0x000343, "Martin Professional A/S"},
	{0x000344, "Tietech.Co., Ltd."},
	{0x000345, "Routrek Networks Corporation"},
	{0x000346, "Hitachi Kokusai Electric, Inc."},
	{0x000347, "Intel Corporation"},
	{0x000348, "Norscan Instruments, Ltd."},
	{0x000349, "Vidicode Datacommunicatie B.V."},
	{0x00034A, "RIAS Corporation"},
	{0x00034B, "Nortel Networks"},
	{0x00034C, "Shanghai DigiVision Technology Co., Ltd."},
	{0x00034D, "Chiaro Networks, Ltd."},
	{0x00034E, "Pos Data Company, Ltd."},
	{0x00034F, "Sur-Gard Security"},
	{0x000350, "BTICINO SPA"},
	{0x000351, "Diebold, Inc."},
	{0x000352, "Colubris Networks"},
	{0x000353, "Mitac, Inc."},
	{0x000354, "Fiber Logic Communications"},
	{0x000355, "TeraBeam Internet Systems"},
	{0x000356, "Wincor Nixdorf International GmbH"},
	{0x000357, "Intervoice-Brite, Inc."},
	{0x000358, "Hanyang Digitech Co., Ltd."},
	{0x000359, "DigitalSis"},
	{0x00035A, "Photron Limited"},
	{0x00035B, "BridgeWave Communications"},
	{0x00035C, "Saint Song Corp."},
	{0x00035D, "Bosung Hi-Net Co., Ltd."},
	{0x00035E, "Metropolitan Area Networks, Inc."},
	{0x00035F, "Prueftechnik Condition Monitoring GmbH & Co. KG"},
	{0x000360, "PAC Interactive Technology, Inc."},
	{0x000361, "Widcomm, Inc."},
	{0x000362, "Vodtel Communications, Inc."},
	{0x000363, "Miraesys Co., Ltd."},
	{0x000364, "Scenix Semiconductor, Inc."},
	{0x000365, "Kira Information & Communications, Ltd."},
	{0x000366, "ASM Pacific Technology"},
	{0x000367, "Jasmine Networks, Inc."},
	{0x000368, "Embedone Co., Ltd."},
	{0x000369, "Nippon Antenna Co., Ltd."},
	{0x00036A, "Mainnet, Ltd."},
	{0x00036B, "Cisco Systems, Inc."},
	{0x00036C, "Cisco Systems, Inc."},
	{0x00036D, "Runtop, Inc."},
	{0x00036E, "Nicon Systems (Pty) Limited"},
	{0x00036F, "Telsey SPA"},
	{0x000370, "NXTV, Inc."},
	{0x000371, "Acomz Networks Corp."},
	{0x000372, "ULAN"},
	{0x000373, "Aselsan A.S"},
	{0x000374, "Control Microsystems"},
	{0x000375, "NetMedia, Inc."},
	{0x000376, "Graphtec Technology, Inc."},
	{0x000377, "Gigabit Wireless"},
	{0x000378, "HUMAX Co., Ltd."},
	{0x000379, "Proscend Communications, Inc."},
	{0x00037A, "Taiyo Yuden Co., Ltd."},
	{0x00037B, "IDEC IZUMI Corporation"},
	{0x00037C, "Coax Media"},
	{0x00037D, "Stellcom"},
	{0x00037E, "PORTech Communications, Inc."},
	{0x00037F, "Atheros Communications, Inc."},
	{0x000380, "SSH Communications Security Corp."},
	{0x000381, "Ingenico International"},
	{0x000382, "A-One Co., Ltd."},
	{0x000383, "Metera Networks, Inc."},
	{0x000384, "AETA"},
	{0x000385, "Actelis Networks, Inc."},
	{0x000386, "Ho Net, Inc."},
	{0x000387, "Blaze Network Products"},
	{0x000388, "Fastfame Technology Co., Ltd."},
	{0x000389, "Plantronics"},
	{0x00038A, "America Online, Inc."},
	{0x00038B, "PLUS-ONE I&T, Inc."},
	{0x00038C, "Total Impact"},
	{0x00038D, "PCS Revenue Control Systems, Inc."},
	{0x00038E, "Atoga Systems, Inc."},
	{0x00038F, "Weinschel Corporation"},
	{0x000390, "Digital Video Communications, Inc."},
	{0x000391, "Advanced Digital Broadcast, Ltd."},
	{0x000392, "Hyundai Teletek Co., Ltd."},
	{0x000393, "Apple Computer, Inc."},
	{0x000394, "Connect One"},
	{0x000395, "California Amplifier"},
	{0x000396, "EZ Cast Co., Ltd."},
	{0x000397, "Watchfront Limited"},
	{0x000398, "WISI"},
	{0x000399, "Dongju Informations & Communications Co., Ltd."},
	{0x00039A, "SiConnect"},
	{0x00039B, "NetChip Technology, Inc."},
	{0x00039C, "OptiMight Communications, Inc."},
	{0x00039D, "Qisda Corporation"},
	{0x00039E, "Tera System Co., Ltd."},
	{0x00039F, "Cisco Systems, Inc."},
	{0x0003A0, "Cisco Systems, Inc."},
	{0x0003A1, "HIPER Information & Communication, Inc."},
	{0x0003A2, "Catapult Communications"},
	{0x0003A3, "MAVIX, Ltd."},
	{0x0003A4, "Imation Corp."},
	{0x0003A5, "Medea Corporation"},
	{0x0003A6, "Traxit Technology, Inc."},
	{0x0003A7, "Unixtar Technology, Inc."},
	{0x0003A8, "IDOT Computers, Inc."},
	{0x0003A9, "AXCENT Media AG"},
	{0x0003AA, "Watlow"},
	{0x0003AB, "Bridge Information Systems"},
	{0x0003AC, "Fronius Schweissmaschinen"},
	{0x0003AD, "Emerson Energy Systems AB"},
	{0x0003AE, "Allied Advanced Manufacturing Pte, Ltd."},
	{0x0003AF, "Paragea Communications"},
	{0x0003B0, "Xsense Technology Corp."},
	{0x0003B1, "Hospira Inc."},
	{0x0003B2, "Radware"},
	{0x0003B3, "IA Link Systems Co., Ltd."},
	{0x0003B4, "Macrotek International Corp."},
	{0x0003B5, "Entra Technology Co."},
	{0x0003B6, "QSI Corporation"},
	{0x0003B7, "ZACCESS Systems"},
	{0x0003B8, "NetKit Solutions, LLC"},
	{0x0003B9, "Hualong Telecom Co., Ltd."},
	{0x0003BA, "Sun Microsystems Inc."},
	{0x0003BB, "Signal Communications Limited"},
	{0x0003BC, "COT GmbH"},
	{0x0003BD, "OmniCluster Technologies, Inc."},
	{0x0003BE, "Netility"},
	{0x0003BF, "Centerpoint Broadband Technologies, Inc."},
	{0x0003C0, "RFTNC Co., Ltd."},
	{0x0003C1, "Packet Dynamics Ltd"},
	{0x0003C2, "Solphone K.K."},
	{0x0003C3, "Micronik Multimedia"},
	{0x0003C4, "Tomra Systems ASA"},
	{0x0003C5, "Mobotix AG"},
	{0x0003C6, "ICUE Systems, Inc."},
	{0x0003C7, "hopf Elektronik GmbH"},
	{0x0003C8, "CML Emergency Services"},
	{0x0003C9, "TECOM Co., Ltd."},
	{0x0003CA, "MTS Systems Corp."},
	{0x0003CB, "Nippon Systems Development Co., Ltd."},
	{0x0003CC, "Momentum Computer, Inc."},
	{0x0003CD, "Clovertech, Inc."},
	{0x0003CE, "ETEN Technologies, Inc."},
	{0x0003CF, "Muxcom, Inc."},
	{0x0003D0, "KOANKEISO Co., Ltd."},
	{0x0003D1, "Takaya Corporation"},
	{0x0003D2, "Crossbeam Systems, Inc."},
	{0x0003D3, "Internet Energy Systems, Inc."},
	{0x0003D4, "Alloptic, Inc."},
	{0x0003D5, "Advanced Communications Co., Ltd."},
	{0x0003D6, "RADVision, Ltd."},
	{0x0003D7, "NextNet Wireless, Inc."},
	{0x0003D8, "iMPath Networks, Inc."},
	{0x0003D9, "Secheron SA"},
	{0x0003DA, "Takamisawa Cybernetics Co., Ltd."},
	{0x0003DB, "Apogee Electronics Corp."},
	{0x0003DC, "Lexar Media, Inc."},
	{0x0003DD, "Comark Corp."},
	{0x0003DE, "OTC Wireless"},
	{0x0003DF, "Desana Systems"},
	{0x0003E0, "RadioFrame Networks, Inc."},
	{0x0003E1, "Winmate Communication, Inc."},
	{0x0003E2, "Comspace Corporation"},
	{0x0003E3, "Cisco Systems, Inc."},
	{0x0003E4, "Cisco Systems, Inc."},
	{0x0003E5, "Hermstedt SG"},
	{0x0003E6, "Entone, Inc."},
	{0x0003E7, "Logostek Co. Ltd."},
	{0x0003E8, "Wavelength Digital Limited"},
	{0x0003E9, "Akara Canada, Inc."},
	{0x0003EA, "Mega System Technologies, Inc."},
	{0x0003EB, "Atrica"},
	{0x0003EC, "ICG Research, Inc."},
	{0x0003ED, "Shinkawa Electric Co., Ltd."},
	{0x0003EE, "MKNet Corporation"},
	{0x0003EF, "Oneline AG"},
	{0x0003F0, "Redfern Broadband Networks"},
	{0x0003F1, "Cicada Semiconductor, Inc."},
	{0x0003F2, "Seneca Networks"},
	{0x0003F3, "Dazzle Multimedia, Inc."},
	{0x0003F4, "NetBurner"},
	{0x0003F5, "Chip2Chip"},
	{0x0003F6, "Allegro Networks, Inc."},
	{0x0003F7, "Plast-Control GmbH"},
	{0x0003F8, "SanCastle Technologies, Inc."},
	{0x0003F9, "Pleiades Communications, Inc."},
	{0x0003FA, "TiMetra Networks"},
	{0x0003FB, "ENEGATE Co.,Ltd."},
	{0x0003FC, "Intertex Data AB"},
	{0x0003FD, "Cisco Systems, Inc."},
	{0x0003FE, "Cisco Systems, Inc."},
	{0x0003FF, "Microsoft Corporation"},
	{0x000400, "LEXMARK INTERNATIONAL, INC."},
	{0x000401, "Osaki Electric Co., Ltd."},
	{0x000402, "Nexsan Technologies, Ltd."},
	{0x000403, "Nexsi Corporation"},
	{0x000404, "Makino Milling Machine Co., Ltd."},
	{0x000405, "ACN Technologies"},
	{0x000406, "Fa. Metabox AG"},
	{0x000407, "Topcon Positioning Systems, Inc."},
	{0x000408, "Sanko Electronics Co., Ltd."},
	{0x000409, "Cratos Networks"},
	{0x00040A, "Sage Systems"},
	{0x00040B, "3com Europe Ltd."},
	{0x00040C, "KANNO Work's Ltd."},
	{0x00040D, "Avaya, Inc."},
	{0x00040E, "AVM GmbH"},
	{0x00040F, "Asus Network Technologies, Inc."},
	{0x000410, "Spinnaker Networks, Inc."},
	{0x000411, "Inkra Networks, Inc."},
	{0x000412, "WaveSmith Networks, Inc."},
	{0x000413, "SNOM Technology AG"},
	{0x000414, "Umezawa Musen Denki Co., Ltd."},
	{0x000415, "Rasteme Systems Co., Ltd."},
	{0x000416, "Parks S/A Comunicacoes Digitais"},
	{0x000417, "ELAU AG"},
	{0x000418, "Teltronic S.A.U."},
	{0x000419, "Fibercycle Networks, Inc."},
	{0x00041A, "Ines Test and Measurement GmbH & CoKG"},
	{0x00041B, "Bridgeworks Ltd."},
	{0x00041C, "ipDialog, Inc."},
	{0x00041D, "Corega of America"},
	{0x00041E, "Shikoku Instrumentation Co., Ltd."},
	{0x00041F, "Sony Computer Entertainment, Inc."},
	{0x000420, "Slim Devices, Inc."},
	{0x000421, "Ocular Networks"},
	{0x000422, "Gordon Kapes, Inc."},
	{0x000423, "Intel Corporation"},
	{0x000424, "TMC s.r.l."},
	{0x000425, "Atmel Corporation"},
	{0x000426, "Autosys"},
	{0x000427, "Cisco Systems, Inc."},
	{0x000428, "Cisco Systems, Inc."},
	{0x000429, "Pixord Corporation"},
	{0x00042A, "Wireless Networks, Inc."},
	{0x00042B, "IT Access Co., Ltd."},
	{0x00042C, "Minet, Inc."},
	{0x00042D, "Sarian Systems, Ltd."},
	{0x00042E, "Netous Technologies, Ltd."},
	{0x00042F, "International Communications Products, Inc."},
	{0x000430, "Netgem"},
	{0x000431, "GlobalStreams, Inc."},
	{0x000432, "Voyetra Turtle Beach, Inc."},
	{0x000433, "Cyberboard A/S"},
	{0x000434, "Accelent Systems, Inc."},
	{0x000435, "Comptek International, Inc."},
	{0x000436, "ELANsat Technologies, Inc."},
	{0x000437, "Powin Information Technology, Inc."},
	{0x000438, "Nortel Networks"},
	{0x000439, "Rosco Entertainment Technology, Inc."},
	{0x00043A, "Intelligent Telecommunications, Inc."},
	{0x00043B, "Lava Computer Mfg., Inc."},
	{0x00043C, "SONOS Co., Ltd."},
	{0x00043D, "INDEL AG"},
	{0x00043E, "Telencomm"},
	{0x00043F, "ESTeem Wireless Modems, Inc"},
	{0x000440, "cyberPIXIE, Inc."},
	{0x000441, "Half Dome Systems, Inc."},
	{0x000442, "NACT"},
	{0x000443, "Agilent Technologies, Inc."},
	{0x000444, "Western Multiplex Corporation"},
	{0x000445, "LMS Skalar Instruments GmbH"},
	{0x000446, "CYZENTECH Co., Ltd."},
	{0x000447, "Acrowave Systems Co., Ltd."},
	{0x000448, "Polaroid Corporation"},
	{0x000449, "Mapletree Networks"},
	{0x00044A, "iPolicy Networks, Inc."},
	{0x00044B, "NVIDIA"},
	{0x00044C, "JENOPTIK"},
	{0x00044D, "Cisco Systems, Inc."},
	{0x00044E, "Cisco Systems, Inc."},
	{0x00044F, "Leukhardt Systemelektronik GmbH"},
	{0x000450, "DMD Computers SRL"},
	{0x000451, "Medrad, Inc."},
	{0x000452, "RocketLogix, Inc."},
	{0x000453, "YottaYotta, Inc."},
	{0x000454, "Quadriga UK"},
	{0x000455, "ANTARA.net"},
	{0x000456, "Motorola PTP Inc"},
	{0x000457, "Universal Access Technology, Inc."},
	{0x000458, "Fusion X Co., Ltd."},
	{0x000459, "Veristar Corporation"},
	{0x00045A, "The Linksys Group, Inc."},
	{0x00045B, "Techsan Electronics Co., Ltd."},
	{0x00045C, "Mobiwave Pte Ltd"},
	{0x00045D, "BEKA Elektronik"},
	{0x00045E, "PolyTrax Information Technology AG"},
	{0x00045F, "Evalue Technology, Inc."},
	{0x000460, "Knilink Technology, Inc."},
	{0x000461, "EPOX Computer Co., Ltd."},
	{0x000462, "DAKOS Data & Communication Co., Ltd."},
	{0x000463, "Bosch Security Systems"},
	{0x000464, "Fantasma Networks, Inc."},
	{0x000465, "i.s.t isdn-support technik GmbH"},
	{0x000466, "ARMITEL Co."},
	{0x000467, "Wuhan Research Institute of MII"},
	{0x000468, "Vivity, Inc."},
	{0x000469, "Innocom, Inc."},
	{0x00046A, "Navini Networks"},
	{0x00046B, "Palm Wireless, Inc."},
	{0x00046C, "Cyber Technology Co., Ltd."},
	{0x00046D, "Cisco Systems, Inc."},
	{0x00046E, "Cisco Systems, Inc."},
	{0x00046F, "Digitel S/A Industria Eletronica"},
	{0x000470, "ipUnplugged AB"},
	{0x000471, "IPrad"},
	{0x000472, "Telelynx, Inc."},
	{0x000473, "Photonex Corporation"},
	{0x000474, "LEGRAND"},
	{0x000475, "3 Com Corporation"},
	{0x000476, "3 Com Corporation"},
	{0x000477, "Scalant Systems, Inc."},
	{0x000478, "G. Star Technology Corporation"},
	{0x000479, "Radius Co., Ltd."},
	{0x00047A, "AXXESSIT ASA"},
	{0x00047B, "Schlumberger"},
	{0x00047C, "Skidata AG"},
	{0x00047D, "Pelco"},
	{0x00047E, "Optelecom=NKF"},
	{0x00047F, "Chr. Mayr GmbH & Co. KG"},
	{0x000480, "Brocade Communications Systems, Inc"},
	{0x000481, "Econolite Control Products, Inc."},
	{0x000482, "Medialogic Corp."},
	{0x000483, "Deltron Technology, Inc."},
	{0x000484, "Amann GmbH"},
	{0x000485, "PicoLight"},
	{0x000486, "ITTC, University of Kansas"},
	{0x000487, "Cogency Semiconductor, Inc."},
	{0x000488, "Eurotherm Controls"},
	{0x000489, "YAFO Networks, Inc."},
	{0x00048A, "Temia Vertriebs GmbH"},
	{0x00048B, "Poscon Corporation"},
	{0x00048C, "Nayna Networks, Inc."},
	{0x00048D, "Tone Commander Systems, Inc."},
	{0x00048E, "Ohm Tech Labs, Inc."},
	{0x00048F, "TD Systems Corporation"},
	{0x000490, "Optical Access"},
	{0x000491, "Technovision, Inc."},
	{0x000492, "Hive Internet, Ltd."},
	{0x000493, "Tsinghua Unisplendour Co., Ltd."},
	{0x000494, "Breezecom, Ltd."},
	{0x000495, "Tejas Networks India Limited"},
	{0x000496, "Extreme Networks"},
	{0x000497, "MacroSystem Digital Video AG"},
	{0x000498, "Mahi Networks"},
	{0x000499, "Chino Corporation"},
	{0x00049A, "Cisco Systems, Inc."},
	{0x00049B, "Cisco Systems, Inc."},
	{0x00049C, "Surgient Networks, Inc."},
	{0x00049D, "Ipanema Technologies"},
	{0x00049E, "Wirelink Co., Ltd."},
	{0x00049F, "Freescale Semiconductor"},
	{0x0004A0, "Verity Instruments, Inc."},
	{0x0004A1, "Pathway Connectivity"},
	{0x0004A2, "L.S.I. Japan Co., Ltd."},
	{0x0004A3, "Microchip Technology, Inc."},
	{0x0004A4, "NetEnabled, Inc."},
	{0x0004A5, "Barco Projection Systems NV"},
	{0x0004A6, "SAF Tehnika Ltd."},
	{0x0004A7, "FabiaTech Corporation"},
	{0x0004A8, "Broadmax Technologies, Inc."},
	{0x0004A9, "SandStream Technologies, Inc."},
	{0x0004AA, "Jetstream Communications"},
	{0x0004AB, "Comverse Network Systems, Inc."},
	{0x0004AC, "IBM CORP."},
	{0x0004AD, "Malibu Networks"},
	{0x0004AE, "Sullair Corporation"},
	{0x0004AF, "Digital Fountain, Inc."},
	{0x0004B0, "ELESIGN Co., Ltd."},
	{0x0004B1, "Signal Technology, Inc."},
	{0x0004B2, "ESSEGI SRL"},
	{0x0004B3, "Videotek, Inc."},
	{0x0004B4, "CIAC"},
	{0x0004B5, "Equitrac Corporation"},
	{0x0004B6, "Stratex Networks, Inc."},
	{0x0004B7, "AMB i.t. Holding"},
	{0x0004B8, "Kumahira Co., Ltd."},
	{0x0004B9, "S.I. Soubou, Inc."},
	{0x0004BA, "KDD Media Will Corporation"},
	{0x0004BB, "Bardac Corporation"},
	{0x0004BC, "Giantec, Inc."},
	{0x0004BD, "Motorola BCS"},
	{0x0004BE, "OptXCon, Inc."},
	{0x0004BF, "VersaLogic Corp."},
	{0x0004C0, "Cisco Systems, Inc."},
	{0x0004C1, "Cisco Systems, Inc."},
	{0x0004C2, "Magnipix, Inc."},
	{0x0004C3, "CASTOR Informatique"},
	{0x0004C4, "Allen & Heath Limited"},
	{0x0004C5, "ASE Technologies, USA"},
	{0x0004C6, "Yamaha Motor Co., Ltd."},
	{0x0004C7, "NetMount"},
	{0x0004C8, "LIBA Maschinenfabrik GmbH"},
	{0x0004C9, "Micro Electron Co., Ltd."},
	{0x0004CA, "FreeMs Corp."},
	{0x0004CB, "Tdsoft Communication, Ltd."},
	{0x0004CC, "Peek Traffic B.V."},
	{0x0004CD, "Informedia Research Group"},
	{0x0004CE, "Patria Ailon"},
	{0x0004CF, "Seagate Technology"},
	{0x0004D0, "Softlink s.r.o."},
	{0x0004D1, "Drew Technologies, Inc."},
	{0x0004D2, "Adcon Telemetry GmbH"},
	{0x0004D3, "Toyokeiki Co., Ltd."},
	{0x0004D4, "Proview Electronics Co., Ltd."},
	{0x0004D5, "Hitachi Information & Communication Engineering, Ltd."},
	{0x0004D6, "Takagi Industrial Co., Ltd."},
	{0x0004D7, "Omitec Instrumentation Ltd."},
	{0x0004D8, "IPWireless, Inc."},
	{0x0004D9, "Titan Electronics, Inc."},
	{0x0004DA, "Relax Technology, Inc."},
	{0x0004DB, "Tellus Group Corp."},
	{0x0004DC, "Nortel Networks"},
	{0x0004DD, "Cisco Systems, Inc."},
	{0x0004DE, "Cisco Systems, Inc."},
	{0x0004DF, "Teracom Telematica Ltda."},
	{0x0004E0, "Procket Networks"},
	{0x0004E1, "Infinior Microsystems"},
	{0x0004E2, "SMC Networks, Inc."},
	{0x0004E3, "Accton Technology Corp."},
	{0x0004E4, "Daeryung Ind., Inc."},
	{0x0004E5, "Glonet Systems, Inc."},
	{0x0004E6, "Banyan Network Private Limited"},
	{0x0004E7, "Lightpointe Communications, Inc"},
	{0x0004E8, "IER, Inc."},
	{0x0004E9, "Infiniswitch Corporation"},
	{0x0004EA, "Hewlett-Packard Company"},
	{0x0004EB, "Paxonet Communications, Inc."},
	{0x0004EC, "Memobox SA"},
	{0x0004ED, "Billion Electric Co., Ltd."},
	{0x0004EE, "Lincoln Electric Company"},
	{0x0004EF, "Polestar Corp."},
	{0x0004F0, "International Computers, Ltd"},
	{0x0004F1, "WhereNet"},
	{0x0004F2, "Polycom"},
	{0x0004F3, "FS FORTH-SYSTEME GmbH"},
	{0x0004F4, "Infinite Electronics Inc."},
	{0x0004F5, "SnowShore Networks, Inc."},
	{0x0004F6, "Amphus"},
	{0x0004F7, "Omega Band, Inc."},
	{0x0004F8, "QUALICABLE TV Industria E Com., Ltda"},
	{0x0004F9, "Xtera Communications, Inc."},
	{0x0004FA, "NBS Technologies Inc."},
	{0x0004FB, "Commtech, Inc."},
	{0x0004FC, "Stratus Computer (DE), Inc."},
	{0x0004FD, "Japan Control Engineering Co., Ltd."},
	{0x0004FE, "Pelago Networks"},
	{0x0004FF, "Acronet Co., Ltd."},
	{0x000500, "Cisco Systems, Inc."},
	{0x000501, "Cisco Systems, Inc."},
	{0x000502, "APPLE COMPUTER"},
	{0x000503, "ICONAG"},
	{0x000504, "Naray Information & Communication Enterprise"},
	{0x000505, "Systems Integration Solutions, Inc."},
	{0x000506, "Reddo Networks AB"},
	{0x000507, "Fine Appliance Corp."},
	{0x000508, "Inetcam, Inc."},
	{0x000509, "AVOC Nishimura Ltd."},
	{0x00050A, "ICS Spa"},
	{0x00050B, "SICOM Systems, Inc."},
	{0x00050C, "Network Photonics, Inc."},
	{0x00050D, "Midstream Technologies, Inc."},
	{0x00050E, "3ware, Inc."},
	{0x00050F, "Tanaka S/S Ltd."},
	{0x000510, "Infinite Shanghai Communication Terminals Ltd."},
	{0x000511, "Complementary Technologies Ltd"},
	{0x000512, "MeshNetworks, Inc."},
	{0x000513, "VTLinx Multimedia Systems, Inc."},
	{0x000514, "KDT Systems Co., Ltd."},
	{0x000515, "Nuark Co., Ltd."},
	{0x000516, "SMART Modular Technologies"},
	{0x000517, "Shellcomm, Inc."},
	{0x000518, "Jupiters Technology"},
	{0x000519, "Siemens Building Technologies AG,"},
	{0x00051A, "3Com Europe Ltd."},
	{0x00051B, "Magic Control Technology Corporation"},
	{0x00051C, "Xnet Technology Corp."},
	{0x00051D, "Airocon, Inc."},
	{0x00051E, "Brocade Communications Systems, Inc."},
	{0x00051F, "Taijin Media Co., Ltd."},
	{0x000520, "Smartronix, Inc."},
	{0x000521, "Control Microsystems"},
	{0x000522, "LEA*D Corporation, Inc."},
	{0x000523, "AVL List GmbH"},
	{0x000524, "BTL System (HK) Limited"},
	{0x000525, "Puretek Industrial Co., Ltd."},
	{0x000526, "IPAS GmbH"},
	{0x000527, "SJ Tek Co. Ltd"},
	{0x000528, "New Focus, Inc."},
	{0x000529, "Shanghai Broadan Communication Technology Co., Ltd"},
	{0x00052A, "Ikegami Tsushinki Co., Ltd."},
	{0x00052B, "HORIBA, Ltd."},
	{0x00052C, "Supreme Magic Corporation"},
	{0x00052D, "Zoltrix International Limited"},
	{0x00052E, "Cinta Networks"},
	{0x00052F, "Leviton Network Solutions"},
	{0x000530, "Andiamo Systems, Inc."},
	{0x000531, "Cisco Systems, Inc."},
	{0x000532, "Cisco Systems, Inc."},
	{0x000533, "Brocade Communications Systems, Inc."},
	{0x000534, "Northstar Engineering Ltd."},
	{0x000535, "Chip PC Ltd."},
	{0x000536, "Danam Communications, Inc."},
	{0x000537, "Nets Technology Co., Ltd."},
	{0x000538, "Merilus, Inc."},
	{0x000539, "A Brand New World in Sweden AB"},
	{0x00053A, "Willowglen Services Pte Ltd"},
	{0x00053B, "Harbour Networks Ltd., Co. Beijing"},
	{0x00053C, "Xircom"},
	{0x00053D, "Agere Systems"},
	{0x00053E, "KID Systeme GmbH"},
	{0x00053F, "VisionTek, Inc."},
	{0x000540, "FAST Corporation"},
	{0x000541, "Advanced Systems Co., Ltd."},
	{0x000542, "Otari, Inc."},
	{0x000543, "IQ Wireless GmbH"},
	{0x000544, "Valley Technologies, Inc."},
	{0x000545, "Internet Photonics"},
	{0x000546, "KDDI Network & Solultions Inc."},
	{0x000547, "Starent Networks"},
	{0x000548, "Disco Corporation"},
	{0x000549, "Salira Optical Network Systems"},
	{0x00054A, "Ario Data Networks, Inc."},
	{0x00054B, "Micro Innovation AG"},
	{0x00054C, "RF Innovations Pty Ltd"},
	{0x00054D, "Brans Technologies, Inc."},
	{0x00054E, "Philips"},
	{0x000550, "Vcomms Connect Limited"},
	{0x000551, "F & S Elektronik Systeme GmbH"},
	{0x000552, "Xycotec Computer GmbH"},
	{0x000553, "DVC Company, Inc."},
	{0x000554, "Rangestar Wireless"},
	{0x000555, "Japan Cash Machine Co., Ltd."},
	{0x000556, "360 Systems"},
	{0x000557, "Agile TV Corporation"},
	{0x000558, "Synchronous, Inc."},
	{0x000559, "Intracom S.A."},
	{0x00055A, "Power Dsine Ltd."},
	{0x00055B, "Charles Industries, Ltd."},
	{0x00055C, "Kowa Company, Ltd."},
	{0x00055D, "D-Link Systems, Inc."},
	{0x00055E, "Cisco Systems, Inc."},
	{0x00055F, "Cisco Systems, Inc."},
	{0x000560, "LEADER COMM.CO., LTD"},
	{0x000561, "nac Image Technology, Inc."},
	{0x000562, "Digital View Limited"},
	{0x000563, "J-Works, Inc."},
	{0x000564, "Tsinghua Bitway Co., Ltd."},
	{0x000565, "Tailyn Communication Company Ltd."},
	{0x000566, "Secui.com Corporation"},
	{0x000567, "Etymonic Design, Inc."},
	{0x000568, "Piltofish Networks AB"},
	{0x000569, "VMware, Inc."},
	{0x00056A, "Heuft Systemtechnik GmbH"},
	{0x00056B, "C.P. Technology Co., Ltd."},
	{0x00056C, "Hung Chang Co., Ltd."},
	{0x00056D, "Pacific Corporation"},
	{0x00056E, "National Enhance Technology, Inc."},
	{0x00056F, "Innomedia Technologies Pvt. Ltd."},
	{0x000570, "Baydel Ltd."},
	{0x000571, "Seiwa Electronics Co."},
	{0x000572, "Deonet Co., Ltd."},
	{0x000573, "Cisco Systems, Inc."},
	{0x000574, "Cisco Systems, Inc."},
	{0x000575, "CDS-Electronics BV"},
	{0x000576, "NSM Technology Ltd."},
	{0x000577, "SM Information & Communication"},
	{0x000579, "Universal Control Solution Corp."},
	{0x00057A, "Hatteras Networks"},
	{0x00057B, "Chung Nam Electronic Co., Ltd."},
	{0x00057C, "RCO Security AB"},
	{0x00057D, "Sun Communications, Inc."},
	{0x00057E, "Eckelmann Steuerungstechnik GmbH"},
	{0x00057F, "Acqis Technology"},
	{0x000580, "Fibrolan Ltd."},
	{0x000581, "Snell & Wilcox Ltd."},
	{0x000582, "ClearCube Technology"},
	{0x000583, "ImageCom Limited"},
	{0x000584, "AbsoluteValue Systems, Inc."},
	{0x000585, "Juniper Networks, Inc."},
	{0x000586, "Lucent Technologies"},
	{0x000587, "Locus, Incorporated"},
	{0x000588, "Sensoria Corp."},
	{0x000589, "National Datacomputer"},
	{0x00058A, "Netcom Co., Ltd."},
	{0x00058B, "IPmental, Inc."},
	{0x00058C, "Opentech Inc."},
	{0x00058D, "Lynx Photonic Networks, Inc."},
	{0x00058E, "Flextronics International GmbH & Co. Nfg. KG"},
	{0x00058F, "CLCsoft co."},
	{0x000590, "Swissvoice Ltd."},
	{0x000591, "Active Silicon Ltd."},
	{0x000592, "Pultek Corp."},
	{0x000593, "Grammar Engine Inc."},
	{0x000594, "IXXAT Automation GmbH"},
	{0x000595, "Alesis Corporation"},
	{0x000596, "Genotech Co., Ltd."},
	{0x000597, "Eagle Traffic Control Systems"},
	{0x000598, "CRONOS S.r.l."},
	{0x000599, "DRS Test and Energy Management or DRS-TEM"},
	{0x00059A, "Cisco Systems, Inc."},
	{0x00059B, "Cisco Systems, Inc."},
	{0x00059C, "Kleinknecht GmbH, Ing. Buero"},
	{0x00059D, "Daniel Computing Systems, Inc."},
	{0x00059E, "Zinwell Corporation"},
	{0x00059F, "Yotta Networks, Inc."},
	{0x0005A0, "MOBILINE Kft."},
	{0x0005A1, "Zenocom"},
	{0x0005A2, "CELOX Networks"},
	{0x0005A3, "QEI, Inc."},
	{0x0005A4, "Lucid Voice Ltd."},
	{0x0005A5, "KOTT"},
	{0x0005A6, "Extron Electronics"},
	{0x0005A7, "Hyperchip, Inc."},
	{0x0005A8, "WYLE ELECTRONICS"},
	{0x0005A9, "Princeton Networks, Inc."},
	{0x0005AA, "Moore Industries International Inc."},
	{0x0005AB, "Cyber Fone, Inc."},
	{0x0005AC, "Northern Digital, Inc."},
	{0x0005AD, "Topspin Communications, Inc."},
	{0x0005AE, "Mediaport USA"},
	{0x0005AF, "InnoScan Computing A/S"},
	{0x0005B0, "Korea Computer Technology Co., Ltd."},
	{0x0005B1, "ASB Technology BV"},
	{0x0005B2, "Medison Co., Ltd."},
	{0x0005B3, "Asahi-Engineering Co., Ltd."},
	{0x0005B4, "Aceex Corporation"},
	{0x0005B5, "Broadcom Technologies"},
	{0x0005B6, "INSYS Microelectronics GmbH"},
	{0x0005B7, "Arbor Technology Corp."},
	{0x0005B8, "Electronic Design Associates, Inc."},
	{0x0005B9, "Airvana, Inc."},
	{0x0005BA, "Area Netwoeks, Inc."},
	{0x0005BB, "Myspace AB"},
	{0x0005BC, "Resorsys Ltd."},
	{0x0005BD, "ROAX BV"},
	{0x0005BE, "Kongsberg Seatex AS"},
	{0x0005BF, "JustEzy Technology, Inc."},
	{0x0005C0, "Digital Network Alacarte Co., Ltd."},
	{0x0005C1, "A-Kyung Motion, Inc."},
	{0x0005C2, "Soronti, Inc."},
	{0x0005C3, "Pacific Instruments, Inc."},
	{0x0005C4, "Telect, Inc."},
	{0x0005C5, "Flaga HF"},
	{0x0005C6, "Triz Communications"},
	{0x0005C7, "I/F-COM A/S"},
	{0x0005C8, "VERYTECH"},
	{0x0005C9, "LG Innotek Co., Ltd."},
	{0x0005CA, "Hitron Technology, Inc."},
	{0x0005CB, "ROIS Technologies, Inc."},
	{0x0005CC, "Sumtel Communications, Inc."},
	{0x0005CD, "Denon, Ltd."},
	{0x0005CE, "Prolink Microsystems Corporation"},
	{0x0005CF, "Thunder River Technologies, Inc."},
	{0x0005D0, "Solinet Systems"},
	{0x0005D1, "Metavector Technologies"},
	{0x0005D2, "DAP Technologies"},
	{0x0005D3, "eProduction Solutions, Inc."},
	{0x0005D4, "FutureSmart Networks, Inc."},
	{0x0005D5, "Speedcom Wireless"},
	{0x0005D6, "Titan Wireless"},
	{0x0005D7, "Vista Imaging, Inc."},
	{0x0005D8, "Arescom, Inc."},
	{0x0005D9, "Techno Valley, Inc."},
	{0x0005DA, "Apex Automationstechnik"},
	{0x0005DB, "NENTEC Netzwerktechnologie GmbH"},
	{0x0005DC, "Cisco Systems, Inc."},
	{0x0005DD, "Cisco Systems, Inc."},
	{0x0005DE, "Gi Fone Korea, Inc."},
	{0x0005DF, "Electronic Innovation, Inc."},
	{0x0005E0, "Empirix Corp."},
	{0x0005E1, "Trellis Photonics, Ltd."},
	{0x0005E2, "Creativ Network Technologies"},
	{0x0005E3, "LightSand Communications, Inc."},
	{0x0005E4, "Red Lion Controls Inc."},
	{0x0005E5, "Renishaw PLC"},
	{0x0005E6, "Egenera, Inc."},
	{0x0005E7, "Netrake an AudioCodes Company"},
	{0x0005E8, "TurboWave, Inc."},
	{0x0005E9, "Unicess Network, Inc."},
	{0x0005EA, "Rednix"},
	{0x0005EB, "Blue Ridge Networks, Inc."},
	{0x0005EC, "Mosaic Systems Inc."},
	{0x0005ED, "Technikum Joanneum GmbH"},
	{0x0005EE, "BEWATOR Group"},
	{0x0005EF, "ADOIR Digital Technology"},
	{0x0005F0, "SATEC"},
	{0x0005F1, "Vrcom, Inc."},
	{0x0005F2, "Power R, Inc."},
	{0x0005F3, "Weboyn"},
	{0x0005F4, "System Base Co., Ltd."},
	{0x0005F5, "OYO Geospace"},
	{0x0005F6, "Young Chang Co. Ltd."},
	{0x0005F7, "Analog Devices, Inc."},
	{0x0005F8, "Real Time Access, Inc."},
	{0x0005F9, "TOA Corporation"},
	{0x0005FA, "IPOptical, Inc."},
	{0x0005FB, "ShareGate, Inc."},
	{0x0005FC, "Schenck Pegasus Corp."},
	{0x0005FD, "PacketLight Networks Ltd."},
	{0x0005FE, "Traficon N.V."},
	{0x0005FF, "SNS Solutions, Inc."},
	{0x000600, "Toshiba Teli Corporation"},
	{0x000601, "Otanikeiki Co., Ltd."},
	{0x000602, "Cirkitech Electronics Co."},
	{0x000603, "Baker Hughes Inc."},
	{0x000604, "@Track Communications, Inc."},
	{0x000605, "Inncom International, Inc."},
	{0x000606, "RapidWAN, Inc."},
	{0x000607, "Omni Directional Control Technology Inc."},
	{0x000608, "At-Sky SAS"},
	{0x000609, "Crossport Systems"},
	{0x00060A, "Blue2space"},
	{0x00060B, "Paceline Systems Corporation"},
	{0x00060C, "Melco Industries, Inc."},
	{0x00060D, "Wave7 Optics"},
	{0x00060E, "IGYS Systems, Inc."},
	{0x00060F, "Narad Networks Inc"},
	{0x000610, "Abeona Networks Inc"},
	{0x000611, "Zeus Wireless, Inc."},
	{0x000612, "Accusys, Inc."},
	{0x000613, "Kawasaki Microelectronics Incorporated"},
	{0x000614, "Prism Holdings"},
	{0x000615, "Kimoto Electric Co., Ltd."},
	{0x000616, "Tel Net Co., Ltd."},
	{0x000617, "Redswitch Inc."},
	{0x000618, "DigiPower Manufacturing Inc."},
	{0x000619, "Connection Technology Systems"},
	{0x00061A, "Zetari Inc."},
	{0x00061B, "Notebook Development Lab.  Lenovo Japan Ltd."},
	{0x00061C, "Hoshino Metal Industries, Ltd."},
	{0x00061D, "MIP Telecom, Inc."},
	{0x00061E, "Maxan Systems"},
	{0x00061F, "Vision Components GmbH"},
	{0x000620, "Serial System Ltd."},
	{0x000621, "Hinox, Co., Ltd."},
	{0x000622, "Chung Fu Chen Yeh Enterprise Corp."},
	{0x000623, "MGE UPS Systems France"},
	{0x000624, "Gentner Communications Corp."},
	{0x000625, "The Linksys Group, Inc."},
	{0x000626, "MWE GmbH"},
	{0x000627, "Uniwide Technologies, Inc."},
	{0x000628, "Cisco Systems, Inc."},
	{0x000629, "IBM CORPORATION"},
	{0x00062A, "Cisco Systems, Inc."},
	{0x00062B, "INTRASERVER TECHNOLOGY"},
	{0x00062C, "Bivio Networks"},
	{0x00062D, "TouchStar Technologies, L.L.C."},
	{0x00062E, "Aristos Logic Corp."},
	{0x00062F, "Pivotech Systems Inc."},
	{0x000630, "Adtranz Sweden"},
	{0x000631, "Optical Solutions, Inc."},
	{0x000632, "Mesco Engineering GmbH"},
	{0x000633, "Cross Match Technologies GmbH"},
	{0x000634, "GTE Airfone Inc."},
	{0x000635, "PacketAir Networks, Inc."},
	{0x000636, "Jedai Broadband Networks"},
	{0x000637, "Toptrend-Meta Information (ShenZhen) Inc."},
	{0x000638, "Sungjin C&C Co., Ltd."},
	{0x000639, "Newtec"},
	{0x00063A, "Dura Micro, Inc."},
	{0x00063B, "Arcturus Networks, Inc."},
	{0x00063C, "Intrinsyc Europe Ltd"},
	{0x00063D, "Microwave Data Systems Inc."},
	{0x00063E, "Opthos Inc."},
	{0x00063F, "Everex Communications Inc."},
	{0x000640, "White Rock Networks"},
	{0x000641, "ITCN"},
	{0x000642, "Genetel Systems Inc."},
	{0x000643, "SONO Computer Co., Ltd."},
	{0x000644, "Neix,Inc"},
	{0x000645, "Meisei Electric Co. Ltd."},
	{0x000646, "ShenZhen XunBao Network Technology Co Ltd"},
	{0x000647, "Etrali S.A."},
	{0x000648, "Seedsware, Inc."},
	{0x000649, "3M Deutschland GmbH"},
	{0x00064A, "Honeywell Co., Ltd. (KOREA)"},
	{0x00064B, "Alexon Co., Ltd."},
	{0x00064C, "Invicta Networks, Inc."},
	{0x00064D, "Sencore"},
	{0x00064E, "Broad Net Technology Inc."},
	{0x00064F, "PRO-NETS Technology Corporation"},
	{0x000650, "Tiburon Networks, Inc."},
	{0x000651, "Aspen Networks Inc."},
	{0x000652, "Cisco Systems, Inc."},
	{0x000653, "Cisco Systems, Inc."},
	{0x000654, "Winpresa Building Automation Technologies GmbH"},
	{0x000655, "Yipee, Inc."},
	{0x000656, "Tactel AB"},
	{0x000657, "Market Central, Inc."},
	{0x000658,
	 "Helmut Fischer GmbH Institut fr Elektronik und Messtechnik"},
	{0x000659, "EAL (Apeldoorn) B.V."},
	{0x00065A, "Strix Systems"},
	{0x00065B, "Dell Computer Corp."},
	{0x00065C, "Malachite Technologies, Inc."},
	{0x00065D, "Heidelberg Web Systems"},
	{0x00065E, "Photuris, Inc."},
	{0x00065F, "ECI Telecom - NGTS Ltd."},
	{0x000660, "NADEX Co., Ltd."},
	{0x000661, "NIA Home Technologies Corp."},
	{0x000662, "MBM Technology Ltd."},
	{0x000663, "Human Technology Co., Ltd."},
	{0x000664, "Fostex Corporation"},
	{0x000665, "Sunny Giken, Inc."},
	{0x000666, "Roving Networks"},
	{0x000667, "Tripp Lite"},
	{0x000668, "Vicon Industries Inc."},
	{0x000669, "Datasound Laboratories Ltd"},
	{0x00066A, "InfiniCon Systems, Inc."},
	{0x00066B, "Sysmex Corporation"},
	{0x00066C, "Robinson Corporation"},
	{0x00066D, "Compuprint S.P.A."},
	{0x00066E, "Delta Electronics, Inc."},
	{0x00066F, "Korea Data Systems"},
	{0x000670, "Upponetti Oy"},
	{0x000671, "Softing AG"},
	{0x000672, "Netezza"},
	{0x000673, "Optelecom-nkf"},
	{0x000674, "Spectrum Control, Inc."},
	{0x000675, "Banderacom, Inc."},
	{0x000676, "Novra Technologies Inc."},
	{0x000677, "SICK AG"},
	{0x000678, "Marantz Brand Company"},
	{0x000679, "Konami Corporation"},
	{0x00067A, "JMP Systems"},
	{0x00067B, "Toplink C&C Corporation"},
	{0x00067C, "CISCO SYSTEMS, INC."},
	{0x00067D, "Takasago Ltd."},
	{0x00067E, "WinCom Systems, Inc."},
	{0x00067F, "Digeo, Inc."},
	{0x000680, "Card Access, Inc."},
	{0x000681, "Goepel Electronic GmbH"},
	{0x000682, "Convedia"},
	{0x000683, "Bravara Communications, Inc."},
	{0x000684, "Biacore AB"},
	{0x000685, "NetNearU Corporation"},
	{0x000686, "ZARDCOM Co., Ltd."},
	{0x000687, "Omnitron Systems Technology, Inc."},
	{0x000688, "Telways Communication Co., Ltd."},
	{0x000689, "yLez Technologies Pte Ltd"},
	{0x00068A, "NeuronNet Co. Ltd. R&D Center"},
	{0x00068B, "AirRunner Technologies, Inc."},
	{0x00068C, "3Com Corporation"},
	{0x00068D, "SEPATON, Inc."},
	{0x00068E, "HID Corporation"},
	{0x00068F, "Telemonitor, Inc."},
	{0x000690, "Euracom Communication GmbH"},
	{0x000691, "PT Inovacao"},
	{0x000692, "Intruvert Networks, Inc."},
	{0x000693, "Flexus Computer Technology, Inc."},
	{0x000694, "Mobillian Corporation"},
	{0x000695, "Ensure Technologies, Inc."},
	{0x000696, "Advent Networks"},
	{0x000697, "R & D Center"},
	{0x000698, "egnite Software GmbH"},
	{0x000699, "Vida Design Co."},
	{0x00069A, "e & Tel"},
	{0x00069B, "AVT Audio Video Technologies GmbH"},
	{0x00069C, "Transmode Systems AB"},
	{0x00069D, "Petards Mobile Intelligence"},
	{0x00069E, "UNIQA, Inc."},
	{0x00069F, "Kuokoa Networks"},
	{0x0006A0, "Mx Imaging"},
	{0x0006A1, "Celsian Technologies, Inc."},
	{0x0006A2, "Microtune, Inc."},
	{0x0006A3, "Bitran Corporation"},
	{0x0006A4, "INNOWELL Corp."},
	{0x0006A5, "PINON Corp."},
	{0x0006A6, "Artistic Licence (UK) Ltd"},
	{0x0006A7, "Primarion"},
	{0x0006A8, "KC Technology, Inc."},
	{0x0006A9, "Universal Instruments Corp."},
	{0x0006AA, "VT Miltope"},
	{0x0006AB, "W-Link Systems, Inc."},
	{0x0006AC, "Intersoft Co."},
	{0x0006AD, "KB Electronics Ltd."},
	{0x0006AE, "Himachal Futuristic Communications Ltd"},
	{0x0006AF, "Xalted Networks"},
	{0x0006B0, "Comtech EF Data Corp."},
	{0x0006B1, "Sonicwall"},
	{0x0006B2, "Linxtek Co."},
	{0x0006B3, "Diagraph Corporation"},
	{0x0006B4, "Vorne Industries, Inc."},
	{0x0006B5, "Luminent, Inc."},
	{0x0006B6, "Nir-Or Israel Ltd."},
	{0x0006B7, "TELEM GmbH"},
	{0x0006B8, "Bandspeed Pty Ltd"},
	{0x0006B9, "A5TEK Corp."},
	{0x0006BA, "Westwave Communications"},
	{0x0006BB, "ATI Technologies Inc."},
	{0x0006BC, "Macrolink, Inc."},
	{0x0006BD, "BNTECHNOLOGY Co., Ltd."},
	{0x0006BE, "Baumer Optronic GmbH"},
	{0x0006BF, "Accella Technologies Co., Ltd."},
	{0x0006C0, "United Internetworks, Inc."},
	{0x0006C1, "CISCO SYSTEMS, INC."},
	{0x0006C2, "Smartmatic Corporation"},
	{0x0006C3, "Schindler Elevator Ltd."},
	{0x0006C4, "Piolink Inc."},
	{0x0006C5, "INNOVI Technologies Limited"},
	{0x0006C6, "lesswire AG"},
	{0x0006C7, "RFNET Technologies Pte Ltd (S)"},
	{0x0006C8, "Sumitomo Metal Micro Devices, Inc."},
	{0x0006C9, "Technical Marketing Research, Inc."},
	{0x0006CA, "American Computer & Digital Components, Inc. (ACDC)"},
	{0x0006CB, "Jotron Electronics A/S"},
	{0x0006CC, "JMI Electronics Co., Ltd."},
	{0x0006CD, "Leaf Imaging Ltd."},
	{0x0006CE, "DATENO"},
	{0x0006CF, "Thales Avionics In-Flight Systems, LLC"},
	{0x0006D0, "Elgar Electronics Corp."},
	{0x0006D1, "Tahoe Networks, Inc."},
	{0x0006D2, "Tundra Semiconductor Corp."},
	{0x0006D3, "Alpha Telecom, Inc. U.S.A."},
	{0x0006D4, "Interactive Objects, Inc."},
	{0x0006D5, "Diamond Systems Corp."},
	{0x0006D6, "Cisco Systems, Inc."},
	{0x0006D7, "Cisco Systems, Inc."},
	{0x0006D8, "Maple Optical Systems"},
	{0x0006D9, "IPM-Net S.p.A."},
	{0x0006DA, "ITRAN Communications Ltd."},
	{0x0006DB, "ICHIPS Co., Ltd."},
	{0x0006DC, "Syabas Technology (Amquest)"},
	{0x0006DD, "AT & T Laboratories - Cambridge Ltd"},
	{0x0006DE, "Flash Technology"},
	{0x0006DF, "AIDONIC Corporation"},
	{0x0006E0, "MAT Co., Ltd."},
	{0x0006E1, "Techno Trade s.a"},
	{0x0006E2, "Ceemax Technology Co., Ltd."},
	{0x0006E3, "Quantitative Imaging Corporation"},
	{0x0006E4, "Citel Technologies Ltd."},
	{0x0006E5, "Fujian Newland Computer Ltd. Co."},
	{0x0006E6, "DongYang Telecom Co., Ltd."},
	{0x0006E7, "Bit Blitz Communications Inc."},
	{0x0006E8, "Optical Network Testing, Inc."},
	{0x0006E9, "Intime Corp."},
	{0x0006EA, "ELZET80 Mikrocomputer GmbH&Co. KG"},
	{0x0006EB, "Global Data"},
	{0x0006EC, "Harris Corporation"},
	{0x0006ED, "Inara Networks"},
	{0x0006EE, "Shenyang Neu-era Information & Technology Stock Co., Ltd"},
	{0x0006EF, "Maxxan Systems, Inc."},
	{0x0006F0, "Digeo, Inc."},
	{0x0006F1, "Optillion"},
	{0x0006F2, "Platys Communications"},
	{0x0006F3, "AcceLight Networks"},
	{0x0006F4, "Prime Electronics & Satellitics Inc."},
	{0x0006F8, "CPU Technology, Inc."},
	{0x0006F9, "Mitsui Zosen Systems Research Inc."},
	{0x0006FA, "IP SQUARE Co, Ltd."},
	{0x0006FB, "Hitachi Printing Solutions, Ltd."},
	{0x0006FC, "Fnet Co., Ltd."},
	{0x0006FD, "Comjet Information Systems Corp."},
	{0x0006FE, "Ambrado, Inc"},
	{0x0006FF, "Sheba Systems Co., Ltd."},
	{0x000700, "Zettamedia Korea"},
	{0x000701, "RACAL-DATACOM"},
	{0x000702, "Varian Medical Systems"},
	{0x000703, "CSEE Transport"},
	{0x000705, "Endress & Hauser GmbH & Co"},
	{0x000706, "Sanritz Corporation"},
	{0x000707, "Interalia Inc."},
	{0x000708, "Bitrage Inc."},
	{0x000709, "Westerstrand Urfabrik AB"},
	{0x00070A, "Unicom Automation Co., Ltd."},
	{0x00070B, "Novabase SGPS, SA"},
	{0x00070C, "SVA-Intrusion.com Co. Ltd."},
	{0x00070D, "Cisco Systems Inc."},
	{0x00070E, "Cisco Systems Inc."},
	{0x00070F, "Fujant, Inc."},
	{0x000710, "Adax, Inc."},
	{0x000711, "Acterna"},
	{0x000712, "JAL Information Technology"},
	{0x000713, "IP One, Inc."},
	{0x000714, "Brightcom"},
	{0x000715, "General Research of Electronics, Inc."},
	{0x000716, "J & S Marine Ltd."},
	{0x000717, "Wieland Electric GmbH"},
	{0x000718, "iCanTek Co., Ltd."},
	{0x000719, "Mobiis Co., Ltd."},
	{0x00071A, "Finedigital Inc."},
	{0x00071B, "CDV Americas Ltd"},
	{0x00071C, "AT&T Fixed Wireless Services"},
	{0x00071D,
	 "Satelsa Sistemas Y Aplicaciones De Telecomunicaciones, S.A."},
	{0x00071E, "Tri-M Engineering / Nupak Dev. Corp."},
	{0x00071F, "European Systems Integration"},
	{0x000720, "Trutzschler GmbH & Co. KG"},
	{0x000721, "Formac Elektronik GmbH"},
	{0x000722, "The Nielsen Company"},
	{0x000723, "ELCON Systemtechnik GmbH"},
	{0x000724, "Telemax Co., Ltd."},
	{0x000725, "Bematech International Corp."},
	{0x000727, "Zi Corporation (HK) Ltd."},
	{0x000728, "Neo Telecom"},
	{0x000729, "Kistler Instrumente AG"},
	{0x00072A, "Innovance Networks"},
	{0x00072B, "Jung Myung Telecom Co., Ltd."},
	{0x00072C, "Fabricom"},
	{0x00072D, "CNSystems"},
	{0x00072E, "North Node AB"},
	{0x00072F, "Intransa, Inc."},
	{0x000730, "Hutchison OPTEL Telecom Technology Co., Ltd."},
	{0x000731, "Ophir-Spiricon Inc"},
	{0x000732, "AAEON Technology Inc."},
	{0x000733, "DANCONTROL Engineering"},
	{0x000734, "ONStor, Inc."},
	{0x000735, "Flarion Technologies, Inc."},
	{0x000736, "Data Video Technologies Co., Ltd."},
	{0x000737, "Soriya Co. Ltd."},
	{0x000738, "Young Technology Co., Ltd."},
	{0x000739, "Scotty Group Austria Gmbh"},
	{0x00073A, "Inventel Systemes"},
	{0x00073B, "Tenovis GmbH & Co KG"},
	{0x00073C, "Telecom Design"},
	{0x00073D, "Nanjing Postel Telecommunications Co., Ltd."},
	{0x00073E, "China Great-Wall Computer Shenzhen Co., Ltd."},
	{0x00073F, "Woojyun Systec Co., Ltd."},
	{0x000740, "Buffalo, Inc"},
	{0x000741, "Sierra Automated Systems"},
	{0x000742, "Current Technologies, LLC"},
	{0x000743, "Chelsio Communications"},
	{0x000744, "Unico, Inc."},
	{0x000745, "Radlan Computer Communications Ltd."},
	{0x000746, "TURCK, Inc."},
	{0x000747, "Mecalc"},
	{0x000748, "The Imaging Source Europe"},
	{0x000749, "CENiX Inc."},
	{0x00074A, "Carl Valentin GmbH"},
	{0x00074B, "Daihen Corporation"},
	{0x00074C, "Beicom Inc."},
	{0x00074D, "Zebra Technologies Corp."},
	{0x00074E, "Naughty boy co., Ltd."},
	{0x00074F, "Cisco Systems, Inc."},
	{0x000750, "Cisco Systems, Inc."},
	{0x000751, "mut AG"},
	{0x000752, "Rhythm Watch Co., Ltd."},
	{0x000753, "Beijing Qxcomm Technology Co., Ltd."},
	{0x000754, "Xyterra Computing, Inc."},
	{0x000755, "Lafon SA"},
	{0x000756, "Juyoung Telecom"},
	{0x000757, "Topcall International AG"},
	{0x000758, "Dragonwave"},
	{0x000759, "Boris Manufacturing Corp."},
	{0x00075A, "Air Products and Chemicals, Inc."},
	{0x00075B, "Gibson Guitars"},
	{0x00075C, "Eastman Kodak Company"},
	{0x00075D, "Celleritas Inc."},
	{0x00075E, "Ametek Power Instruments"},
	{0x00075F, "VCS Video Communication Systems AG"},
	{0x000760, "TOMIS Information & Telecom Corp."},
	{0x000761, "Logitech SA"},
	{0x000762, "Group Sense Limited"},
	{0x000763, "Sunniwell Cyber Tech. Co., Ltd."},
	{0x000764, "YoungWoo Telecom Co. Ltd."},
	{0x000765, "Jade Quantum Technologies, Inc."},
	{0x000766, "Chou Chin Industrial Co., Ltd."},
	{0x000767, "Yuxing Electronics Company Limited"},
	{0x000768, "Danfoss A/S"},
	{0x000769, "Italiana Macchi SpA"},
	{0x00076A, "NEXTEYE Co., Ltd."},
	{0x00076B, "Stralfors AB"},
	{0x00076C, "Daehanet, Inc."},
	{0x00076D, "Flexlight Networks"},
	{0x00076E, "Sinetica Corporation Limited"},
	{0x00076F, "Synoptics Limited"},
	{0x000770, "Locusnetworks Corporation"},
	{0x000771, "Embedded System Corporation"},
	{0x000772, "Alcatel Shanghai Bell Co., Ltd."},
	{0x000773, "Ascom Powerline Communications Ltd."},
	{0x000774, "GuangZhou Thinker Technology Co. Ltd."},
	{0x000775, "Valence Semiconductor, Inc."},
	{0x000776, "Federal APD"},
	{0x000777, "Motah Ltd."},
	{0x000778, "GERSTEL GmbH & Co. KG"},
	{0x000779, "Sungil Telecom Co., Ltd."},
	{0x00077A, "Infoware System Co., Ltd."},
	{0x00077B, "Millimetrix Broadband Networks"},
	{0x00077C, "Westermo Teleindustri AB"},
	{0x00077E, "Elrest GmbH"},
	{0x00077F, "J Communications Co., Ltd."},
	{0x000780, "Bluegiga Technologies OY"},
	{0x000781, "Itron Inc."},
	{0x000782, "Sun Microsystems, Inc."},
	{0x000783, "SynCom Network, Inc."},
	{0x000784, "Cisco Systems Inc."},
	{0x000785, "Cisco Systems Inc."},
	{0x000786, "Wireless Networks Inc."},
	{0x000787, "Idea System Co., Ltd."},
	{0x000788, "Clipcomm, Inc."},
	{0x000789, "Eastel Systems Corporation"},
	{0x00078A, "Mentor Data System Inc."},
	{0x00078B, "Wegener Communications, Inc."},
	{0x00078C, "Elektronikspecialisten i Borlange AB"},
	{0x00078D, "NetEngines Ltd."},
	{0x00078E, "Garz & Friche GmbH"},
	{0x00078F, "Emkay Innovative Products"},
	{0x000790, "Tri-M Technologies (s) Limited"},
	{0x000791, "International Data Communications, Inc."},
	{0x000792, "Suetron Electronic GmbH"},
	{0x000793, "Shin Satellite Public Company Limited"},
	{0x000794, "Simple Devices, Inc."},
	{0x000795, "Elitegroup Computer System Co. (ECS)"},
	{0x000796, "LSI Systems, Inc."},
	{0x000797, "Netpower Co., Ltd."},
	{0x000798, "Selea SRL"},
	{0x000799, "Tipping Point Technologies, Inc."},
	{0x00079A, "Verint Systems Inc"},
	{0x00079B, "Aurora Networks"},
	{0x00079C, "Golden Electronics Technology Co., Ltd."},
	{0x00079D, "Musashi Co., Ltd."},
	{0x00079E, "Ilinx Co., Ltd."},
	{0x00079F, "Action Digital Inc."},
	{0x0007A0, "e-Watch Inc."},
	{0x0007A1, "VIASYS Healthcare GmbH"},
	{0x0007A2, "Opteon Corporation"},
	{0x0007A3, "Ositis Software, Inc."},
	{0x0007A4, "GN Netcom Ltd."},
	{0x0007A5, "Y.D.K Co. Ltd."},
	{0x0007A6, "Home Automation, Inc."},
	{0x0007A7, "A-Z Inc."},
	{0x0007A8, "Haier Group Technologies Ltd."},
	{0x0007A9, "Novasonics"},
	{0x0007AA, "Quantum Data Inc."},
	{0x0007AC, "Eolring"},
	{0x0007AD, "Pentacon GmbH Foto-und Feinwerktechnik"},
	{0x0007AE, "Britestream Networks, Inc."},
	{0x0007AF, "N-Tron Corp."},
	{0x0007B0, "Office Details, Inc."},
	{0x0007B1, "Equator Technologies"},
	{0x0007B2, "Transaccess S.A."},
	{0x0007B3, "Cisco Systems Inc."},
	{0x0007B4, "Cisco Systems Inc."},
	{0x0007B5, "Any One Wireless Ltd."},
	{0x0007B6, "Telecom Technology Ltd."},
	{0x0007B7, "Samurai Ind. Prods Eletronicos Ltda"},
	{0x0007B8, "Corvalent Corporation"},
	{0x0007B9, "Ginganet Corporation"},
	{0x0007BA, "UTStarcom, Inc."},
	{0x0007BB, "Candera Inc."},
	{0x0007BC, "Identix Inc."},
	{0x0007BD, "Radionet Ltd."},
	{0x0007BE, "DataLogic SpA"},
	{0x0007BF, "Armillaire Technologies, Inc."},
	{0x0007C0, "NetZerver Inc."},
	{0x0007C1, "Overture Networks, Inc."},
	{0x0007C2, "Netsys Telecom"},
	{0x0007C3, "Thomson"},
	{0x0007C4, "JEAN Co. Ltd."},
	{0x0007C5, "Gcom, Inc."},
	{0x0007C6, "VDS Vosskuhler GmbH"},
	{0x0007C7, "Synectics Systems Limited"},
	{0x0007C8, "Brain21, Inc."},
	{0x0007C9, "Technol Seven Co., Ltd."},
	{0x0007CA, "Creatix Polymedia Ges Fur Kommunikaitonssysteme"},
	{0x0007CB, "Freebox SA"},
	{0x0007CC, "Kaba Benzing GmbH"},
	{0x0007CD, "NMTEL Co., Ltd."},
	{0x0007CE, "Cabletime Limited"},
	{0x0007CF, "Anoto AB"},
	{0x0007D0, "Automat Engenharia de Automaoa Ltda."},
	{0x0007D1, "Spectrum Signal Processing Inc."},
	{0x0007D2, "Logopak Systeme"},
	{0x0007D3, "Stork Digital Imaging B.V."},
	{0x0007D4, "Zhejiang Yutong Network Communication Co Ltd."},
	{0x0007D5, "3e Technologies Int;., Inc."},
	{0x0007D6, "Commil Ltd."},
	{0x0007D7, "Caporis Networks AG"},
	{0x0007D8, "Hitron Systems Inc."},
	{0x0007D9, "Splicecom"},
	{0x0007DA, "Neuro Telecom Co., Ltd."},
	{0x0007DB, "Kirana Networks, Inc."},
	{0x0007DC, "Atek Co, Ltd."},
	{0x0007DD, "Cradle Technologies"},
	{0x0007DE, "eCopilt AB"},
	{0x0007DF, "Vbrick Systems Inc."},
	{0x0007E0, "Palm Inc."},
	{0x0007E1, "WIS Communications Co. Ltd."},
	{0x0007E2, "Bitworks, Inc."},
	{0x0007E3, "Navcom Technology, Inc."},
	{0x0007E4, "SoftRadio Co., Ltd."},
	{0x0007E5, "Coup Corporation"},
	{0x0007E6, "edgeflow Canada Inc."},
	{0x0007E7, "FreeWave Technologies"},
	{0x0007E8, "St. Bernard Software"},
	{0x0007E9, "Intel Corporation"},
	{0x0007EA, "Massana, Inc."},
	{0x0007EB, "Cisco Systems Inc."},
	{0x0007EC, "Cisco Systems Inc."},
	{0x0007ED, "Altera Corporation"},
	{0x0007EE, "telco Informationssysteme GmbH"},
	{0x0007EF, "Lockheed Martin Tactical Systems"},
	{0x0007F0, "Beckett LogiSync LLC"},
	{0x0007F1, "TeraBurst Networks Inc."},
	{0x0007F2, "IOA Corporation"},
	{0x0007F3, "Thinkengine Networks"},
	{0x0007F4, "Eletex Co., Ltd."},
	{0x0007F5, "Bridgeco Co AG"},
	{0x0007F6, "Qqest Software Systems"},
	{0x0007F7, "Galtronics"},
	{0x0007F8, "ITDevices, Inc."},
	{0x0007F9, "Phonetics, Inc."},
	{0x0007FA, "ITT Co., Ltd."},
	{0x0007FB, "Giga Stream UMTS Technologies GmbH"},
	{0x0007FC, "Adept Systems Inc."},
	{0x0007FD, "LANergy Ltd."},
	{0x0007FE, "Rigaku Corporation"},
	{0x0007FF, "Gluon Networks"},
	{0x000800, "MULTITECH SYSTEMS, INC."},
	{0x000801, "HighSpeed Surfing Inc."},
	{0x000802, "Hewlett Packard"},
	{0x000803, "Cos Tron"},
	{0x000804, "ICA Inc."},
	{0x000805, "Techno-Holon Corporation"},
	{0x000806, "Raonet Systems, Inc."},
	{0x000807, "Access Devices Limited"},
	{0x000808, "PPT Vision, Inc."},
	{0x000809, "Systemonic AG"},
	{0x00080A, "Espera-Werke GmbH"},
	{0x00080B, "Birka BPA Informationssystem AB"},
	{0x00080C, "VDA Elettronica spa"},
	{0x00080D, "Toshiba"},
	{0x00080E, "Motorola, BCS"},
	{0x00080F, "Proximion Fiber Optics AB"},
	{0x000810, "Key Technology, Inc."},
	{0x000811, "VOIX Corporation"},
	{0x000812, "GM-2 Corporation"},
	{0x000813, "Diskbank, Inc."},
	{0x000814, "TIL Technologies"},
	{0x000815, "CATS Co., Ltd."},
	{0x000816, "Bluetags A/S"},
	{0x000817, "EmergeCore Networks LLC"},
	{0x000818, "Pixelworks, Inc."},
	{0x000819, "Banksys"},
	{0x00081A, "Sanrad Intelligence Storage Communications (2000) Ltd."},
	{0x00081B, "Windigo Systems"},
	{0x00081C, "@pos.com"},
	{0x00081D, "Ipsil, Incorporated"},
	{0x00081E, "Repeatit AB"},
	{0x00081F, "Pou Yuen Tech Corp. Ltd."},
	{0x000820, "Cisco Systems Inc."},
	{0x000821, "Cisco Systems Inc."},
	{0x000822, "InPro Comm"},
	{0x000823, "Texa Corp."},
	{0x000824, "Copitrak Inc"},
	{0x000825, "Acme Packet"},
	{0x000826, "Colorado Med Tech"},
	{0x000827, "Pirelli Broadband Solutions"},
	{0x000828, "Koei Engineering Ltd."},
	{0x000829, "Aval Nagasaki Corporation"},
	{0x00082A, "Powerwallz Network Security"},
	{0x00082B, "Wooksung Electronics, Inc."},
	{0x00082C, "Homag AG"},
	{0x00082D, "Indus Teqsite Private Limited"},
	{0x00082E, "Multitone Electronics PLC"},
	{0x00084E, "DivergeNet, Inc."},
	{0x00084F, "Qualstar Corporation"},
	{0x000850, "Arizona Instrument Corp."},
	{0x000851, "Canadian Bank Note Company, Ltd."},
	{0x000852, "Davolink Co. Inc."},
	{0x000853, "Schleicher GmbH & Co. Relaiswerke KG"},
	{0x000854, "Netronix, Inc."},
	{0x000855, "NASA-Goddard Space Flight Center"},
	{0x000856, "Gamatronic Electronic Industries Ltd."},
	{0x000857, "Polaris Networks, Inc."},
	{0x000858, "Novatechnology Inc."},
	{0x000859, "ShenZhen Unitone Electronics Co., Ltd."},
	{0x00085A, "IntiGate Inc."},
	{0x00085B, "Hanbit Electronics Co., Ltd."},
	{0x00085C, "Shanghai Dare Technologies Co. Ltd."},
	{0x00085D, "Aastra"},
	{0x00085E, "PCO AG"},
	{0x00085F, "Picanol N.V."},
	{0x000860, "LodgeNet Entertainment Corp."},
	{0x000861, "SoftEnergy Co., Ltd."},
	{0x000862, "NEC Eluminant Technologies, Inc."},
	{0x000863, "Entrisphere Inc."},
	{0x000864, "Fasy S.p.A."},
	{0x000865, "JASCOM CO., LTD"},
	{0x000866, "DSX Access Systems, Inc."},
	{0x000867, "Uptime Devices"},
	{0x000868, "PurOptix"},
	{0x000869, "Command-e Technology Co.,Ltd."},
	{0x00086A, "Industrie Technik IPS GmbH"},
	{0x00086B, "MIPSYS"},
	{0x00086C, "Plasmon LMS"},
	{0x00086D, "Missouri FreeNet"},
	{0x00086E, "Hyglo AB"},
	{0x00086F, "Resources Computer Network Ltd."},
	{0x000870, "Rasvia Systems, Inc."},
	{0x000871, "NORTHDATA Co., Ltd."},
	{0x000872, "Sorenson Communications"},
	{0x000873, "DAP Design B.V."},
	{0x000874, "Dell Computer Corp."},
	{0x000875, "Acorp Electronics Corp."},
	{0x000876, "SDSystem"},
	{0x000877, "Liebert-Hiross Spa"},
	{0x000878, "Benchmark Storage Innovations"},
	{0x000879, "CEM Corporation"},
	{0x00087A, "Wipotec GmbH"},
	{0x00087B, "RTX Telecom A/S"},
	{0x00087C, "Cisco Systems, Inc."},
	{0x00087D, "Cisco Systems Inc."},
	{0x00087E, "Bon Electro-Telecom Inc."},
	{0x00087F, "SPAUN electronic GmbH & Co. KG"},
	{0x000880, "BroadTel Canada Communications inc."},
	{0x000881, "DIGITAL HANDS CO.,LTD."},
	{0x000882, "SIGMA CORPORATION"},
	{0x000883, "Hewlett-Packard Company"},
	{0x000884, "Index Braille AB"},
	{0x000885, "EMS Dr. Thomas Wuensche"},
	{0x000886, "Hansung Teliann, Inc."},
	{0x000887, "Maschinenfabrik Reinhausen GmbH"},
	{0x000888, "OULLIM Information Technology Inc,."},
	{0x000889, "Echostar Technologies Corp"},
	{0x00088A, "Minds@Work"},
	{0x00088B, "Tropic Networks Inc."},
	{0x00088C, "Quanta Network Systems Inc."},
	{0x00088D, "Sigma-Links Inc."},
	{0x00088E, "Nihon Computer Co., Ltd."},
	{0x00088F, "ADVANCED DIGITAL TECHNOLOGY"},
	{0x000890, "AVILINKS SA"},
	{0x000891, "Lyan Inc."},
	{0x000892, "EM Solutions"},
	{0x000893, "LE INFORMATION COMMUNICATION INC."},
	{0x000894, "InnoVISION Multimedia Ltd."},
	{0x000895, "DIRC Technologie GmbH & Co.KG"},
	{0x000896, "Printronix, Inc."},
	{0x000897, "Quake Technologies"},
	{0x000898, "Gigabit Optics Corporation"},
	{0x000899, "Netbind, Inc."},
	{0x00089A, "Alcatel Microelectronics"},
	{0x00089B, "ICP Electronics Inc."},
	{0x00089C, "Elecs Industry Co., Ltd."},
	{0x00089D, "UHD-Elektronik"},
	{0x00089E, "Beijing Enter-Net co.LTD"},
	{0x00089F, "EFM Networks"},
	{0x0008A0, "Stotz Feinmesstechnik GmbH"},
	{0x0008A1, "CNet Technology Inc."},
	{0x0008A2, "ADI Engineering, Inc."},
	{0x0008A3, "Cisco Systems"},
	{0x0008A4, "Cisco Systems"},
	{0x0008A5, "Peninsula Systems Inc."},
	{0x0008A6, "Multiware & Image Co., Ltd."},
	{0x0008A7, "iLogic Inc."},
	{0x0008A8, "Systec Co., Ltd."},
	{0x0008A9, "SangSang Technology, Inc."},
	{0x0008AA, "KARAM"},
	{0x0008AB, "EnerLinx.com, Inc."},
	{0x0008AC, "Eltromat GmbH"},
	{0x0008AD, "Toyo-Linx Co., Ltd."},
	{0x0008AE, "PacketFront Sweden AB"},
	{0x0008AF, "Novatec Corporation"},
	{0x0008B0, "BKtel communications GmbH"},
	{0x0008B1, "ProQuent Systems"},
	{0x0008B2, "SHENZHEN COMPASS TECHNOLOGY DEVELOPMENT CO.,LTD"},
	{0x0008B3, "Fastwel"},
	{0x0008B4, "SYSPOL"},
	{0x0008B5, "TAI GUEN ENTERPRISE CO., LTD"},
	{0x0008B6, "RouteFree, Inc."},
	{0x0008B7, "HIT Incorporated"},
	{0x0008B8, "E.F. Johnson"},
	{0x0008B9, "KAON MEDIA Co., Ltd."},
	{0x0008BA, "Erskine Systems Ltd"},
	{0x0008BB, "NetExcell"},
	{0x0008BC, "Ilevo AB"},
	{0x0008BD, "TEPG-US"},
	{0x0008BE, "XENPAK MSA Group"},
	{0x0008BF, "Aptus Elektronik AB"},
	{0x0008C0, "ASA SYSTEMS"},
	{0x0008C1, "Avistar Communications Corporation"},
	{0x0008C2, "Cisco Systems"},
	{0x0008C3, "Contex A/S"},
	{0x0008C4, "Hikari Co.,Ltd."},
	{0x0008C5, "Liontech Co., Ltd."},
	{0x0008C6, "Philips Consumer Communications"},
	{0x0008C7, "Hewlett Packard"},
	{0x0008C8, "Soneticom, Inc."},
	{0x0008C9, "TechniSat Digital GmbH"},
	{0x0008CA, "TwinHan Technology Co.,Ltd"},
	{0x0008CB, "Zeta Broadband Inc."},
	{0x0008CC, "Remotec, Inc."},
	{0x0008CD, "With-Net Inc"},
	{0x0008CE, "IPMobileNet Inc."},
	{0x0008CF, "Nippon Koei Power Systems Co., Ltd."},
	{0x0008D0, "Musashi Engineering Co., LTD."},
	{0x0008D1, "KAREL INC."},
	{0x0008D2, "ZOOM Networks Inc."},
	{0x0008D3, "Hercules Technologies S.A."},
	{0x0008D4, "IneoQuest Technologies, Inc"},
	{0x0008D5, "Vanguard Networks Solutions, LLC"},
	{0x0008D6, "HASSNET Inc."},
	{0x0008D7, "HOW CORPORATION"},
	{0x0008D8, "Dowkey Microwave"},
	{0x0008D9, "Mitadenshi Co.,LTD"},
	{0x0008DA, "SofaWare Technologies Ltd."},
	{0x0008DB, "Corrigent Systems"},
	{0x0008DC, "Wiznet"},
	{0x0008DD, "Telena Communications, Inc."},
	{0x0008DE, "3UP Systems"},
	{0x0008DF, "Alistel Inc."},
	{0x0008E0, "ATO Technology Ltd."},
	{0x0008E1, "Barix AG"},
	{0x0008E2, "Cisco Systems"},
	{0x0008E3, "Cisco Systems"},
	{0x0008E4, "Envenergy Inc"},
	{0x0008E5, "IDK Corporation"},
	{0x0008E6, "Littlefeet"},
	{0x0008E7, "SHI ControlSystems,Ltd."},
	{0x0008E8, "Excel Master Ltd."},
	{0x0008E9, "NextGig"},
	{0x0008EA, "Motion Control Engineering, Inc"},
	{0x0008EB, "ROMWin Co.,Ltd."},
	{0x0008EC, "Zonu, Inc."},
	{0x0008ED, "ST&T Instrument Corp."},
	{0x0008EE, "Logic Product Development"},
	{0x0008EF, "DIBAL,S.A."},
	{0x0008F0, "Next Generation Systems, Inc."},
	{0x0008F1, "Voltaire"},
	{0x0008F2, "C&S Technology"},
	{0x0008F3, "WANY"},
	{0x0008F4, "Bluetake Technology Co., Ltd."},
	{0x0008F5, "YESTECHNOLOGY Co.,Ltd."},
	{0x0008F6, "Sumitomo Electric System Solutions Co.,Ltd."},
	{0x0008F7, "Hitachi Ltd, Semiconductor &amp; Integrated Circuits Gr"},
	{0x0008F8, "Guardall Ltd"},
	{0x0008F9, "Padcom, Inc."},
	{0x0008FA, "Karl E.Brinkmann GmbH"},
	{0x0008FB, "SonoSite, Inc."},
	{0x0008FC, "Gigaphoton Inc."},
	{0x0008FD, "BlueKorea Co., Ltd."},
	{0x0008FE, "UNIK C&C Co.,Ltd."},
	{0x0008FF, "Trilogy Communications Ltd"},
	{0x000900, "TMT"},
	{0x000901, "Shenzhen Shixuntong Information & Technoligy Co"},
	{0x000902, "Redline Communications Inc."},
	{0x000903, "Panasas, Inc"},
	{0x000904, "MONDIAL electronic"},
	{0x000905, "iTEC Technologies Ltd."},
	{0x000906, "Esteem Networks"},
	{0x000907, "Chrysalis Development"},
	{0x000908, "VTech Technology Corp."},
	{0x000909, "Telenor Connect A/S"},
	{0x00090A, "SnedFar Technology Co., Ltd."},
	{0x00090B, "MTL  Instruments PLC"},
	{0x00090C, "Mayekawa Mfg. Co. Ltd."},
	{0x00090D, "LEADER ELECTRONICS CORP."},
	{0x00090E, "Helix Technology Inc."},
	{0x00090F, "Fortinet Inc."},
	{0x000910, "Simple Access Inc."},
	{0x000911, "Cisco Systems"},
	{0x000912, "Cisco Systems"},
	{0x000913, "SystemK Corporation"},
	{0x000914, "COMPUTROLS INC."},
	{0x000915, "CAS Corp."},
	{0x000916, "Listman Home Technologies, Inc."},
	{0x000917, "WEM Technology Inc"},
	{0x000918, "SAMSUNG TECHWIN CO.,LTD"},
	{0x000919, "MDS Gateways"},
	{0x00091A, "Macat Optics & Electronics Co., Ltd."},
	{0x00091B, "Digital Generation Inc."},
	{0x00091C, "CacheVision, Inc"},
	{0x00091D, "Proteam Computer Corporation"},
	{0x00091E, "Firstech Technology Corp."},
	{0x00091F, "A&amp;D Co., Ltd."},
	{0x000920, "EpoX COMPUTER CO.,LTD."},
	{0x000921, "Planmeca Oy"},
	{0x000922, "TST Biometrics GmbH"},
	{0x000923, "Heaman System Co., Ltd"},
	{0x000924, "Telebau GmbH"},
	{0x000925, "VSN Systemen BV"},
	{0x000926, "YODA COMMUNICATIONS, INC."},
	{0x000927, "TOYOKEIKI CO.,LTD."},
	{0x000928, "Telecore"},
	{0x000929, "Sanyo Industries (UK) Limited"},
	{0x00092A, "MYTECS Co.,Ltd."},
	{0x00092B, "iQstor Networks, Inc."},
	{0x00092C, "Hitpoint Inc."},
	{0x00092D, "HTC Corporation"},
	{0x00092E, "B&Tech System Inc."},
	{0x00092F, "Akom Technology Corporation"},
	{0x000930, "AeroConcierge Inc."},
	{0x000931, "Future Internet, Inc."},
	{0x000932, "Omnilux"},
	{0x000933, "OPTOVALLEY Co. Ltd."},
	{0x000934, "Dream-Multimedia-Tv GmbH"},
	{0x000935, "Sandvine Incorporated"},
	{0x000936, "Ipetronik GmbH & Co.KG"},
	{0x000937, "Inventec Appliance Corp"},
	{0x000938, "Allot Communications"},
	{0x000939, "ShibaSoku Co.,Ltd."},
	{0x00093A, "Molex Fiber Optics"},
	{0x00093B, "HYUNDAI NETWORKS INC."},
	{0x00093C, "Jacques Technologies P/L"},
	{0x00093D, "Newisys,Inc."},
	{0x00093E, "C&I Technologies"},
	{0x00093F, "Double-Win Enterpirse CO., LTD"},
	{0x000940, "AGFEO GmbH & Co. KG"},
	{0x000941, "Allied Telesis K.K."},
	{0x000942, "CRESCO, LTD."},
	{0x000943, "Cisco Systems"},
	{0x000944, "Cisco Systems"},
	{0x000945, "Palmmicro Communications Inc"},
	{0x000946, "Cluster Labs GmbH"},
	{0x000947, "Aztek, Inc."},
	{0x000948, "Vista Control Systems, Corp."},
	{0x000949, "Glyph Technologies Inc."},
	{0x00094A, "Homenet Communications"},
	{0x00094B, "FillFactory NV"},
	{0x00094C, "Communication Weaver Co.,Ltd."},
	{0x00094D, "Braintree Communications Pty Ltd"},
	{0x00094E, "BARTECH SYSTEMS INTERNATIONAL, INC"},
	{0x00094F, "elmegt GmbH & Co. KG"},
	{0x000950, "Independent Storage Corporation"},
	{0x000951, "Apogee Instruments, Inc"},
	{0x000952, "Auerswald GmbH & Co. KG"},
	{0x000953, "Linkage System Integration Co.Ltd."},
	{0x000954, "AMiT spol. s. r. o."},
	{0x000955, "Young Generation International Corp."},
	{0x000956, "Network Systems Group, Ltd. (NSG)"},
	{0x000957, "Supercaller, Inc."},
	{0x000958, "INTELNET S.A."},
	{0x000959, "Sitecsoft"},
	{0x00095A, "RACEWOOD TECHNOLOGY"},
	{0x00095B, "Netgear, Inc."},
	{0x00095C,
	 "Philips Medical Systems - Cardiac and Monitoring Systems (CM"},
	{0x00095D, "Dialogue Technology Corp."},
	{0x00095E, "Masstech Group Inc."},
	{0x00095F, "Telebyte, Inc."},
	{0x000960, "YOZAN Inc."},
	{0x000961, "Switchgear and Instrumentation Ltd"},
	{0x000962, "Sonitor Technologies AS"},
	{0x000963, "Dominion Lasercom Inc."},
	{0x000964, "Hi-Techniques, Inc."},
	{0x000965, "HyunJu Computer Co., Ltd."},
	{0x000966, "Thales Navigation"},
	{0x000967, "Tachyon, Inc"},
	{0x000968, "TECHNOVENTURE, INC."},
	{0x000969, "Meret Optical Communications"},
	{0x00096A, "Cloverleaf Communications Inc."},
	{0x00096B, "IBM Corporation"},
	{0x00096C, "Imedia Semiconductor Corp."},
	{0x00096D, "Powernet Technologies Corp."},
	{0x00096E, "GIANT ELECTRONICS LTD."},
	{0x00096F, "Beijing Zhongqing Elegant Tech. Corp.,Limited"},
	{0x000970, "Vibration Research Corporation"},
	{0x000971, "Time Management, Inc."},
	{0x000972, "Securebase,Inc"},
	{0x000973, "Lenten Technology Co., Ltd."},
	{0x000974, "Innopia Technologies, Inc."},
	{0x000975, "fSONA Communications Corporation"},
	{0x000976, "Datasoft ISDN Systems GmbH"},
	{0x000977, "Brunner Elektronik AG"},
	{0x000978, "AIJI System Co., Ltd."},
	{0x000979, "Advanced Television Systems Committee, Inc."},
	{0x00097A, "Louis Design Labs."},
	{0x00097B, "Cisco Systems"},
	{0x00097C, "Cisco Systems"},
	{0x00097D, "SecWell Networks Oy"},
	{0x00097E, "IMI TECHNOLOGY CO., LTD"},
	{0x00097F, "Vsecure 2000 LTD."},
	{0x000980, "Power Zenith Inc."},
	{0x000981, "Newport Networks"},
	{0x000982, "Loewe Opta GmbH"},
	{0x000983, "Gvision Incorporated"},
	{0x000984, "MyCasa Network Inc."},
	{0x000985, "Auto Telecom Company"},
	{0x000986, "Metalink LTD."},
	{0x000987, "NISHI NIPPON ELECTRIC WIRE & CABLE CO.,LTD."},
	{0x000988, "Nudian Electron Co., Ltd."},
	{0x000989, "VividLogic Inc."},
	{0x00098A, "EqualLogic Inc"},
	{0x00098B, "Entropic Communications, Inc."},
	{0x00098C, "Option Wireless Sweden"},
	{0x00098D, "Velocity Semiconductor"},
	{0x00098E, "ipcas GmbH"},
	{0x00098F, "Cetacean Networks"},
	{0x000990, "ACKSYS Communications & systems"},
	{0x000991, "GE Fanuc Automation Manufacturing, Inc."},
	{0x000992, "InterEpoch Technology,INC."},
	{0x000993, "Visteon Corporation"},
	{0x000994, "Cronyx Engineering"},
	{0x000995, "Castle Technology Ltd"},
	{0x000996, "RDI"},
	{0x000997, "Nortel Networks"},
	{0x000998, "Capinfo Company Limited"},
	{0x000999, "CP GEORGES RENAULT"},
	{0x00099A, "ELMO COMPANY, LIMITED"},
	{0x00099B, "Western Telematic Inc."},
	{0x00099C, "Naval Research Laboratory"},
	{0x00099D, "Haliplex Communications"},
	{0x00099E, "Testech, Inc."},
	{0x00099F, "VIDEX INC."},
	{0x0009A0, "Microtechno Corporation"},
	{0x0009A1, "Telewise Communications, Inc."},
	{0x0009A2, "Interface Co., Ltd."},
	{0x0009A3, "Leadfly Techologies Corp. Ltd."},
	{0x0009A4, "HARTEC Corporation"},
	{0x0009A5, "HANSUNG ELETRONIC INDUSTRIES DEVELOPMENT CO., LTD"},
	{0x0009A6, "Ignis Optics, Inc."},
	{0x0009A7, "Bang & Olufsen A/S"},
	{0x0009A8, "Eastmode Pte Ltd"},
	{0x0009A9, "Ikanos Communications"},
	{0x0009AA, "Data Comm for Business, Inc."},
	{0x0009AB, "Netcontrol Oy"},
	{0x0009AC, "LANVOICE"},
	{0x0009AD, "HYUNDAI SYSCOMM, INC."},
	{0x0009AE, "OKANO ELECTRIC CO.,LTD"},
	{0x0009AF, "e-generis"},
	{0x0009B0, "Onkyo Corporation"},
	{0x0009B1, "Kanematsu Electronics, Ltd."},
	{0x0009B2, "L&F Inc."},
	{0x0009B3, "MCM Systems Ltd"},
	{0x0009B4, "KISAN TELECOM CO., LTD."},
	{0x0009B5, "3J Tech. Co., Ltd."},
	{0x0009B6, "Cisco Systems"},
	{0x0009B7, "Cisco Systems"},
	{0x0009B8, "Entise Systems"},
	{0x0009B9, "Action Imaging Solutions"},
	{0x0009BA, "MAKU Informationstechik GmbH"},
	{0x0009BB, "MathStar, Inc."},
	{0x0009BC, "Digital Safety Technologies, Inc"},
	{0x0009BD, "Epygi Technologies, Ltd."},
	{0x0009BE, "Mamiya-OP Co.,Ltd."},
	{0x0009BF, "Nintendo Co.,Ltd."},
	{0x0009C0, "6WIND"},
	{0x0009C1, "PROCES-DATA A/S"},
	{0x0009C2, "Onity, Inc."},
	{0x0009C3, "NETAS"},
	{0x0009C4, "Medicore Co., Ltd"},
	{0x0009C5, "KINGENE Technology Corporation"},
	{0x0009C6, "Visionics Corporation"},
	{0x0009C7, "Movistec"},
	{0x0009C8, "SINAGAWA TSUSHIN KEISOU SERVICE"},
	{0x0009C9, "BlueWINC Co., Ltd."},
	{0x0009CA, "iMaxNetworks(Shenzhen)Limited."},
	{0x0009CB, "HBrain"},
	{0x0009CC, "Moog GmbH"},
	{0x0009CD, "HUDSON SOFT CO.,LTD."},
	{0x0009CE, "SpaceBridge Semiconductor Corp."},
	{0x0009CF, "iAd GmbH"},
	{0x0009D0, "Solacom Technologies Inc."},
	{0x0009D1, "SERANOA NETWORKS INC"},
	{0x0009D2, "Mai Logic Inc."},
	{0x0009D3, "Western DataCom Co., Inc."},
	{0x0009D4, "Transtech Networks"},
	{0x0009D5, "Signal Communication, Inc."},
	{0x0009D6, "KNC One GmbH"},
	{0x0009D7, "DC Security Products"},
	{0x0009D8, "Flt Communications AB"},
	{0x0009D9, "Neoscale Systems, Inc"},
	{0x0009DA, "Control Module Inc."},
	{0x0009DB, "eSpace"},
	{0x0009DC, "Galaxis Technology AG"},
	{0x0009DD, "Mavin Technology Inc."},
	{0x0009DE, "Samjin Information & Communications Co., Ltd."},
	{0x0009DF, "Vestel Komunikasyon Sanayi ve Ticaret A.S."},
	{0x0009E0, "XEMICS S.A."},
	{0x0009E1, "Gemtek Technology Co., Ltd."},
	{0x0009E2, "Sinbon Electronics Co., Ltd."},
	{0x0009E3, "Angel Iglesias S.A."},
	{0x0009E4, "K Tech Infosystem Inc."},
	{0x0009E5, "Hottinger Baldwin Messtechnik GmbH"},
	{0x0009E6, "Cyber Switching Inc."},
	{0x0009E7, "ADC Techonology"},
	{0x0009E8, "Cisco Systems"},
	{0x0009E9, "Cisco Systems"},
	{0x0009EA, "YEM Inc."},
	{0x0009EB, "HuMANDATA LTD."},
	{0x0009EC, "Daktronics, Inc."},
	{0x0009ED, "CipherOptics"},
	{0x0009EE, "MEIKYO ELECTRIC CO.,LTD"},
	{0x0009EF, "Vocera Communications"},
	{0x0009F0, "Shimizu Technology Inc."},
	{0x0009F1, "Yamaki Electric Corporation"},
	{0x0009F2, "Cohu, Inc., Electronics Division"},
	{0x0009F3, "WELL Communication Corp."},
	{0x0009F4, "Alcon Laboratories, Inc."},
	{0x0009F5, "Emerson Network Power Co.,Ltd"},
	{0x0009F6, "Shenzhen Eastern Digital Tech Ltd."},
	{0x0009F7, "SED, a division of Calian"},
	{0x0009F8, "UNIMO TECHNOLOGY CO., LTD."},
	{0x0009F9, "ART JAPAN CO., LTD."},
	{0x0009FB, "Philips Patient Monitoring"},
	{0x0009FC, "IPFLEX Inc."},
	{0x0009FD, "Ubinetics Limited"},
	{0x0009FE, "Daisy Technologies, Inc."},
	{0x0009FF, "X.net 2000 GmbH"},
	{0x000A00, "Mediatek Corp."},
	{0x000A01, "SOHOware, Inc."},
	{0x000A02, "ANNSO CO., LTD."},
	{0x000A03, "ENDESA SERVICIOS, S.L."},
	{0x000A04, "3Com Ltd"},
	{0x000A05, "Widax Corp."},
	{0x000A06, "Teledex LLC"},
	{0x000A07, "WebWayOne Ltd"},
	{0x000A08, "ALPINE ELECTRONICS, INC."},
	{0x000A09, "TaraCom Integrated Products, Inc."},
	{0x000A0A, "SUNIX Co., Ltd."},
	{0x000A0B, "Sealevel Systems, Inc."},
	{0x000A0C, "Scientific Research Corporation"},
	{0x000A0D, "MergeOptics GmbH"},
	{0x000A0E, "Invivo Research Inc."},
	{0x000A0F, "Ilryung Telesys, Inc"},
	{0x000A10, "FAST media integrations AG"},
	{0x000A11, "ExPet Technologies, Inc"},
	{0x000A12, "Azylex Technology, Inc"},
	{0x000A13, "Honeywell Video Systems"},
	{0x000A14, "TECO a.s."},
	{0x000A15, "Silicon Data, Inc"},
	{0x000A16, "Lassen Research"},
	{0x000A17, "NESTAR COMMUNICATIONS, INC"},
	{0x000A18, "Vichel Inc."},
	{0x000A19, "Valere Power, Inc."},
	{0x000A1A, "Imerge Ltd"},
	{0x000A1B, "Stream Labs"},
	{0x000A1C, "Bridge Information Co., Ltd."},
	{0x000A1D, "Optical Communications Products Inc."},
	{0x000A1E, "Red-M Products Limited"},
	{0x000A1F, "ART WARE Telecommunication Co., Ltd."},
	{0x000A20, "SVA Networks, Inc."},
	{0x000A21, "Integra Telecom Co. Ltd"},
	{0x000A22, "Amperion Inc"},
	{0x000A23, "Parama Networks Inc"},
	{0x000A24, "Octave Communications"},
	{0x000A25, "CERAGON NETWORKS"},
	{0x000A26, "CEIA S.p.A."},
	{0x000A27, "Apple Computer, Inc."},
	{0x000A28, "Motorola"},
	{0x000A29, "Pan Dacom Networking AG"},
	{0x000A2A, "QSI Systems Inc."},
	{0x000A2B, "Etherstuff"},
	{0x000A2C, "Active Tchnology Corporation"},
	{0x000A2D, "Cabot Communications Limited"},
	{0x000A2E, "MAPLE NETWORKS CO., LTD"},
	{0x000A2F, "Artnix Inc."},
	{0x000A30, "Johnson Controls-ASG"},
	{0x000A31, "HCV Wireless"},
	{0x000A32, "Xsido Corporation"},
	{0x000A33, "Emulex Corporation"},
	{0x000A34, "Identicard Systems Incorporated"},
	{0x000A35, "Xilinx"},
	{0x000A36, "Synelec Telecom Multimedia"},
	{0x000A37, "Procera Networks, Inc."},
	{0x000A38, "Apani Networks"},
	{0x000A39, "LoPA Information Technology"},
	{0x000A3A, "J-THREE INTERNATIONAL Holding Co., Ltd."},
	{0x000A3B, "GCT Semiconductor, Inc"},
	{0x000A3C, "Enerpoint Ltd."},
	{0x000A3D, "Elo Sistemas Eletronicos S.A."},
	{0x000A3E, "EADS Telecom"},
	{0x000A3F, "Data East Corporation"},
	{0x000A40, "Crown Audio -- Harmanm International"},
	{0x000A41, "Cisco Systems"},
	{0x000A42, "Cisco Systems"},
	{0x000A43, "Chunghwa Telecom Co., Ltd."},
	{0x000A44, "Avery Dennison Deutschland GmbH"},
	{0x000A45, "Audio-Technica Corp."},
	{0x000A46, "ARO Controls SAS"},
	{0x000A47, "Allied Vision Technologies"},
	{0x000A48, "Albatron Technology"},
	{0x000A49, "F5 Networks, Inc."},
	{0x000A4A, "Targa Systems Ltd."},
	{0x000A4B, "DataPower Technology, Inc."},
	{0x000A4C, "Molecular Devices Corporation"},
	{0x000A4D, "Noritz Corporation"},
	{0x000A4E, "UNITEK Electronics INC."},
	{0x000A4F, "Brain Boxes Limited"},
	{0x000A50, "REMOTEK CORPORATION"},
	{0x000A51, "GyroSignal Technology Co., Ltd."},
	{0x000A52, "AsiaRF Ltd."},
	{0x000A53, "Intronics, Incorporated"},
	{0x000A54, "Laguna Hills, Inc."},
	{0x000A55, "MARKEM Corporation"},
	{0x000A56, "HITACHI Maxell Ltd."},
	{0x000A57, "Hewlett-Packard Company - Standards"},
	{0x000A58, "Ingenieur-Buero Freyer & Siegel"},
	{0x000A59, "HW server"},
	{0x000A5A, "GreenNET Technologies Co.,Ltd."},
	{0x000A5B, "Power-One as"},
	{0x000A5C, "Carel s.p.a."},
	{0x000A5D, "PUC Founder (MSC) Berhad"},
	{0x000A5E, "3COM Corporation"},
	{0x000A5F, "almedio inc."},
	{0x000A60, "Autostar Technology Pte Ltd"},
	{0x000A61, "Cellinx Systems Inc."},
	{0x000A62, "Crinis Networks, Inc."},
	{0x000A63, "DHD GmbH"},
	{0x000A64, "Eracom Technologies"},
	{0x000A65, "GentechMedia.co.,ltd."},
	{0x000A66, "MITSUBISHI ELECTRIC SYSTEM & SERVICE CO.,LTD."},
	{0x000A67, "OngCorp"},
	{0x000A68, "SolarFlare Communications, Inc."},
	{0x000A69, "SUNNY bell Technology Co., Ltd."},
	{0x000A6A, "SVM Microwaves s.r.o."},
	{0x000A6B, "Tadiran Telecom Business Systems LTD"},
	{0x000A6C, "Walchem Corporation"},
	{0x000A6D, "EKS Elektronikservice GmbH"},
	{0x000A6E, "Broadcast Technology Limited"},
	{0x000A6F, "ZyFLEX Technologies Inc"},
	{0x000A70, "MPLS Forum"},
	{0x000A71, "Avrio Technologies, Inc"},
	{0x000A72, "STEC, INC."},
	{0x000A73, "Scientific Atlanta"},
	{0x000A74, "Manticom Networks Inc."},
	{0x000A75, "Caterpillar, Inc"},
	{0x000A76, "Beida Jade Bird Huaguang Technology Co.,Ltd"},
	{0x000A77, "Bluewire Technologies LLC"},
	{0x000A78, "OLITEC"},
	{0x000A79, "Allied Telesis K.K. corega division"},
	{0x000A7A, "Kyoritsu Electric Co., Ltd."},
	{0x000A7B, "Cornelius Consult"},
	{0x000A7C, "Tecton Ltd"},
	{0x000A7D, "Valo, Inc."},
	{0x000A7E, "The Advantage Group"},
	{0x000A7F, "Teradon Industries, Inc"},
	{0x000A80, "Telkonet Inc."},
	{0x000A81, "TEIMA Audiotex S.L."},
	{0x000A82, "TATSUTA SYSTEM ELECTRONICS CO.,LTD."},
	{0x000A83, "SALTO SYSTEMS S.L."},
	{0x000A84, "Rainsun Enterprise Co., Ltd."},
	{0x000A85, "PLAT'C2,Inc"},
	{0x000A86, "Lenze"},
	{0x000A87, "Integrated Micromachines Inc."},
	{0x000A88, "InCypher S.A."},
	{0x000A89, "Creval Systems, Inc."},
	{0x000A8A, "Cisco Systems"},
	{0x000A8B, "Cisco Systems"},
	{0x000A8C, "Guardware Systems Ltd."},
	{0x000A8D, "EUROTHERM LIMITED"},
	{0x000A8E, "Invacom Ltd"},
	{0x000A8F, "Aska International Inc."},
	{0x000A90, "Bayside Interactive, Inc."},
	{0x000A91, "HemoCue AB"},
	{0x000A92, "Presonus Corporation"},
	{0x000A93, "W2 Networks, Inc."},
	{0x000A94, "ShangHai cellink CO., LTD"},
	{0x000A95, "Apple Computer, Inc."},
	{0x000A96, "MEWTEL TECHNOLOGY INC."},
	{0x000A97, "SONICblue, Inc."},
	{0x000A98, "M+F Gwinner GmbH & Co"},
	{0x000A99, "Dataradio Inc."},
	{0x000A9A, "Aiptek International Inc"},
	{0x000A9B, "Towa Meccs Corporation"},
	{0x000A9C, "Server Technology, Inc."},
	{0x000A9D, "King Young Technology Co. Ltd."},
	{0x000A9E, "BroadWeb Corportation"},
	{0x000A9F, "Pannaway Technologies, Inc."},
	{0x000AA0, "Cedar Point Communications"},
	{0x000AA1, "V V S Limited"},
	{0x000AA2, "SYSTEK INC."},
	{0x000AA3, "SHIMAFUJI ELECTRIC CO.,LTD."},
	{0x000AA4, "SHANGHAI SURVEILLANCE TECHNOLOGY CO,LTD"},
	{0x000AA5, "MAXLINK INDUSTRIES LIMITED"},
	{0x000AA6, "Hochiki Corporation"},
	{0x000AA7, "FEI Electron Optics"},
	{0x000AA8, "ePipe Pty. Ltd."},
	{0x000AA9, "Brooks Automation GmbH"},
	{0x000AAA, "AltiGen Communications Inc."},
	{0x000AAB, "Toyota Technical Development Corporation"},
	{0x000AAC, "TerraTec Electronic GmbH"},
	{0x000AAD, "Stargames Corporation"},
	{0x000AAE, "Rosemount Process Analytical"},
	{0x000AAF, "Pipal Systems"},
	{0x000AB0, "LOYTEC electronics GmbH"},
	{0x000AB1, "GENETEC Corporation"},
	{0x000AB2, "Fresnel Wireless Systems"},
	{0x000AB3, "Fa. GIRA"},
	{0x000AB4, "ETIC Telecommunications"},
	{0x000AB5, "Digital Electronic Network"},
	{0x000AB6, "COMPUNETIX, INC"},
	{0x000AB7, "Cisco Systems"},
	{0x000AB8, "Cisco Systems"},
	{0x000AB9, "Astera Technologies Corp."},
	{0x000ABA, "Arcon Technology Limited"},
	{0x000ABB, "Taiwan Secom Co,. Ltd"},
	{0x000ABC, "Seabridge Ltd."},
	{0x000ABD, "Rupprecht & Patashnick Co."},
	{0x000ABE, "OPNET Technologies CO., LTD."},
	{0x000ABF, "HIROTA SS"},
	{0x000AC0, "Fuyoh Video Industry CO., LTD."},
	{0x000AC1, "Futuretel"},
	{0x000AC2, "FiberHome Telecommunication Technologies CO.,LTD"},
	{0x000AC3, "eM Technics Co., Ltd."},
	{0x000AC4, "Daewoo Teletech Co., Ltd"},
	{0x000AC5, "Color Kinetics"},
	{0x000AC6, "Ceterus Networks, Inc."},
	{0x000AC7, "Unication Group"},
	{0x000AC8, "ZPSYS CO.,LTD. (Planning&Management)"},
	{0x000AC9, "Zambeel Inc"},
	{0x000ACA, "YOKOYAMA SHOKAI CO.,Ltd."},
	{0x000ACB, "XPAK MSA Group"},
	{0x000ACC, "Winnow Networks, Inc."},
	{0x000ACD, "Sunrich Technology Limited"},
	{0x000ACE, "RADIANTECH, INC."},
	{0x000ACF, "PROVIDEO Multimedia Co. Ltd."},
	{0x000AD0, "Niigata Develoment Center,  F.I.T. Co., Ltd."},
	{0x000AD1, "MWS"},
	{0x000AD2, "JEPICO Corporation"},
	{0x000AD3, "INITECH Co., Ltd"},
	{0x000AD4, "CoreBell Systems Inc."},
	{0x000AD5, "Brainchild Electronic Co., Ltd."},
	{0x000AD6, "BeamReach Networks"},
	{0x000AD7, "Origin ELECTRIC CO.,LTD."},
	{0x000AD8, "IPCserv Technology Corp."},
	{0x000AD9, "Sony Ericsson Mobile Communications AB"},
	{0x000ADA, "Vindicator Technologies"},
	{0x000ADB, "SkyPilot Network, Inc"},
	{0x000ADC, "RuggedCom Inc."},
	{0x000ADD, "Allworx Corp."},
	{0x000ADE, "Happy Communication Co., Ltd."},
	{0x000ADF, "Gennum Corporation"},
	{0x000AE0, "Fujitsu Softek"},
	{0x000AE1, "EG Technology"},
	{0x000AE2, "Binatone Electronics International, Ltd"},
	{0x000AE3, "YANG MEI TECHNOLOGY CO., LTD"},
	{0x000AE4, "Wistron Corp."},
	{0x000AE5, "ScottCare Corporation"},
	{0x000AE6, "Elitegroup Computer System Co. (ECS)"},
	{0x000AE7, "ELIOP S.A."},
	{0x000AE8, "Cathay Roxus Information Technology Co. LTD"},
	{0x000AE9, "AirVast Technology Inc."},
	{0x000AEA, "ADAM ELEKTRONIK LTD.STI."},
	{0x000AEB, "Shenzhen Tp-Link Technology Co; Ltd."},
	{0x000AEC, "Koatsu Gas Kogyo Co., Ltd."},
	{0x000AED, "HARTING Systems GmbH & Co KG"},
	{0x000AEE, "GCD Hard- & Software GmbH"},
	{0x000AEF, "OTRUM ASA"},
	{0x000AF0, "SHIN-OH ELECTRONICS CO., LTD. R&D"},
	{0x000AF1, "Clarity Design, Inc."},
	{0x000AF2, "NeoAxiom Corp."},
	{0x000AF3, "Cisco Systems"},
	{0x000AF4, "Cisco Systems"},
	{0x000AF5, "Airgo Networks, Inc."},
	{0x000AF6, "Emerson Climate Technologies Retail Solutions, Inc."},
	{0x000AF7, "Broadcom Corp."},
	{0x000AF8, "American Telecare Inc."},
	{0x000AF9, "HiConnect, Inc."},
	{0x000AFA, "Traverse Technologies Australia"},
	{0x000AFB, "Ambri Limited"},
	{0x000AFC, "Core Tec Communications, LLC"},
	{0x000AFD, "Viking Electronic Services"},
	{0x000AFE, "NovaPal Ltd"},
	{0x000AFF, "Kilchherr Elektronik AG"},
	{0x000B00, "FUJIAN START COMPUTER EQUIPMENT CO.,LTD"},
	{0x000B01, "DAIICHI ELECTRONICS CO., LTD."},
	{0x000B02, "Dallmeier electronic"},
	{0x000B03, "Taekwang Industrial Co., Ltd"},
	{0x000B04, "Volktek Corporation"},
	{0x000B05, "Pacific Broadband Networks"},
	{0x000B06, "Motorola BCS"},
	{0x000B07, "Voxpath Networks"},
	{0x000B08, "Pillar Data Systems"},
	{0x000B09, "Ifoundry Systems Singapore"},
	{0x000B0A, "dBm Optics"},
	{0x000B0B, "Corrent Corporation"},
	{0x000B0C, "Agile Systems Inc."},
	{0x000B0D, "Air2U, Inc."},
	{0x000B0E, "Trapeze Networks"},
	{0x000B0F, "Nyquist Industrial Control BV"},
	{0x000B10, "11wave Technonlogy Co.,Ltd"},
	{0x000B11, "HIMEJI ABC TRADING CO.,LTD."},
	{0x000B12, "NURI Telecom Co., Ltd."},
	{0x000B13, "ZETRON INC"},
	{0x000B14, "ViewSonic Corporation"},
	{0x000B15, "Platypus Technology"},
	{0x000B16, "Communication Machinery Corporation"},
	{0x000B17, "MKS Instruments"},
	{0x000B19, "Vernier Networks, Inc."},
	{0x000B1A, "Industrial Defender, Inc."},
	{0x000B1B, "Systronix, Inc."},
	{0x000B1C, "SIBCO bv"},
	{0x000B1D, "LayerZero Power Systems, Inc."},
	{0x000B1E, "KAPPA opto-electronics GmbH"},
	{0x000B1F, "I CON Computer Co."},
	{0x000B20, "Hirata corporation"},
	{0x000B21, "G-Star Communications Inc."},
	{0x000B22, "Environmental Systems and Services"},
	{0x000B23, "Siemens Subscriber Networks"},
	{0x000B24, "AirLogic"},
	{0x000B25, "Aeluros"},
	{0x000B26, "Wetek Corporation"},
	{0x000B27, "Scion Corporation"},
	{0x000B28, "Quatech Inc."},
	{0x000B29, "LS(LG) Industrial Systems co.,Ltd"},
	{0x000B2A, "HOWTEL Co., Ltd."},
	{0x000B2B, "HOSTNET CORPORATION"},
	{0x000B2C, "Eiki Industrial Co. Ltd."},
	{0x000B2D, "Danfoss Inc."},
	{0x000B2E,
	 "Cal-Comp Electronics (Thailand) Public Company Limited Taipe"},
	{0x000B2F, "bplan GmbH"},
	{0x000B30, "Beijing Gongye Science & Technology Co.,Ltd"},
	{0x000B31,
	 "Yantai ZhiYang Scientific and technology industry CO., LTD"},
	{0x000B32, "VORMETRIC, INC."},
	{0x000B33, "Vivato"},
	{0x000B34, "ShangHai Broadband Technologies CO.LTD"},
	{0x000B35, "Quad Bit System co., Ltd."},
	{0x000B36, "Productivity Systems, Inc."},
	{0x000B37, "MANUFACTURE DES MONTRES ROLEX SA"},
	{0x000B38, "Knuerr AG"},
	{0x000B39, "Keisoku Giken Co.,Ltd."},
	{0x000B3A, "QuStream Corporation"},
	{0x000B3B, "devolo AG"},
	{0x000B3C, "Cygnal Integrated Products, Inc."},
	{0x000B3D, "CONTAL OK Ltd."},
	{0x000B3E, "BittWare, Inc"},
	{0x000B3F, "Anthology Solutions Inc."},
	{0x000B40, "OpNext Inc."},
	{0x000B41, "Ing. Buero Dr. Beutlhauser"},
	{0x000B42, "commax Co., Ltd."},
	{0x000B43, "Microscan Systems, Inc."},
	{0x000B44, "Concord IDea Corp."},
	{0x000B45, "Cisco"},
	{0x000B46, "Cisco"},
	{0x000B47, "Advanced Energy"},
	{0x000B48, "sofrel"},
	{0x000B49, "RF-Link System Inc."},
	{0x000B4A, "Visimetrics (UK) Ltd"},
	{0x000B4B, "VISIOWAVE SA"},
	{0x000B4C, "Clarion (M) Sdn Bhd"},
	{0x000B4D, "Emuzed"},
	{0x000B4E, "VertexRSI, General Dynamics SatCOM Technologies, Inc."},
	{0x000B4F, "Verifone, INC."},
	{0x000B50, "Oxygnet"},
	{0x000B51, "Micetek International Inc."},
	{0x000B52, "JOYMAX ELECTRONICS CORP."},
	{0x000B53, "INITIUM Co., Ltd."},
	{0x000B54, "BiTMICRO Networks, Inc."},
	{0x000B55, "ADInstruments"},
	{0x000B56, "Cybernetics"},
	{0x000B57, "Silicon Laboratories"},
	{0x000B58, "Astronautics C.A  LTD"},
	{0x000B59, "ScriptPro, LLC"},
	{0x000B5A, "HyperEdge"},
	{0x000B5B, "Rincon Research Corporation"},
	{0x000B5C, "Newtech Co.,Ltd"},
	{0x000B5D, "FUJITSU LIMITED"},
	{0x000B5E, "Audio Engineering Society Inc."},
	{0x000B5F, "Cisco Systems"},
	{0x000B60, "Cisco Systems"},
	{0x000B61, "Friedrich Ltze GmbH &Co."},
	{0x000B62, "Ingenieurbuero fuer Elektronikdesign Ingo Mohnen"},
	{0x000B63, "Kaleidescape"},
	{0x000B64, "Kieback & Peter GmbH & Co KG"},
	{0x000B65, "Sy.A.C. srl"},
	{0x000B66, "Teralink Communications"},
	{0x000B67, "Topview Technology Corporation"},
	{0x000B68, "Addvalue Communications Pte Ltd"},
	{0x000B69, "Franke Finland Oy"},
	{0x000B6A, "Asiarock Incorporation"},
	{0x000B6B, "Wistron Neweb Corp."},
	{0x000B6C, "Sychip Inc."},
	{0x000B6D, "SOLECTRON JAPAN NAKANIIDA"},
	{0x000B6E, "Neff Instrument Corp."},
	{0x000B6F, "Media Streaming Networks Inc"},
	{0x000B70, "Load Technology, Inc."},
	{0x000B71, "Litchfield Communications Inc."},
	{0x000B72, "Lawo AG"},
	{0x000B73, "Kodeos Communications"},
	{0x000B74, "Kingwave Technology Co., Ltd."},
	{0x000B75, "Iosoft Ltd."},
	{0x000B76, "ET&T Technology Co. Ltd."},
	{0x000B77, "Cogent Systems, Inc."},
	{0x000B78, "TAIFATECH INC."},
	{0x000B79, "X-COM, Inc."},
	{0x000B7A, "Wave Science Inc."},
	{0x000B7B, "Test-Um Inc."},
	{0x000B7C, "Telex Communications"},
	{0x000B7D, "SOLOMON EXTREME INTERNATIONAL LTD."},
	{0x000B7E, "SAGINOMIYA Seisakusho Inc."},
	{0x000B7F, "OmniWerks"},
	{0x000B80, "Lycium Networks"},
	{0x000B81, "Kaparel Corporation"},
	{0x000B82, "Grandstream Networks, Inc."},
	{0x000B83, "DATAWATT B.V."},
	{0x000B84, "BODET"},
	{0x000B85, "Cisco Systems"},
	{0x000B86, "Aruba Networks"},
	{0x000B87, "American Reliance Inc."},
	{0x000B88, "Vidisco ltd."},
	{0x000B89, "Top Global Technology, Ltd."},
	{0x000B8A, "MITEQ Inc."},
	{0x000B8B, "KERAJET, S.A."},
	{0x000B8C, "Flextronics"},
	{0x000B8D, "Avvio Networks"},
	{0x000B8E, "Ascent Corporation"},
	{0x000B8F, "AKITA ELECTRONICS SYSTEMS CO.,LTD."},
	{0x000B90, "Adva Optical Networking Inc."},
	{0x000B91,
	 "Aglaia Gesellschaft fr Bildverarbeitung und Kommunikation m"},
	{0x000B92, "Ascom Danmark A/S"},
	{0x000B93, "Ritter Elektronik"},
	{0x000B94, "Digital Monitoring Products, Inc."},
	{0x000B95, "eBet Gaming Systems Pty Ltd"},
	{0x000B96, "Innotrac Diagnostics Oy"},
	{0x000B97, "Matsushita Electric Industrial Co.,Ltd."},
	{0x000B98, "NiceTechVision"},
	{0x000B99, "SensAble Technologies, Inc."},
	{0x000B9A, "Shanghai Ulink Telecom Equipment Co. Ltd."},
	{0x000B9B, "Sirius System Co, Ltd."},
	{0x000B9C, "TriBeam Technologies, Inc."},
	{0x000B9D, "TwinMOS Technologies Inc."},
	{0x000B9E, "Yasing Technology Corp."},
	{0x000B9F, "Neue ELSA GmbH"},
	{0x000BA0, "T&L Information Inc."},
	{0x000BA1, "SYSCOM Ltd."},
	{0x000BA2, "Sumitomo Electric Networks, Inc"},
	{0x000BA3, "Siemens AG, I&S"},
	{0x000BA4, "Shiron Satellite Communications Ltd. (1996)"},
	{0x000BA5, "Quasar Cipta Mandiri, PT"},
	{0x000BA6, "Miyakawa Electric Works Ltd."},
	{0x000BA7, "Maranti Networks"},
	{0x000BA8, "HANBACK ELECTRONICS CO., LTD."},
	{0x000BA9, "CloudShield Technologies, Inc."},
	{0x000BAA, "Aiphone co.,Ltd"},
	{0x000BAB, "Advantech Technology (CHINA) Co., Ltd."},
	{0x000BAC, "3Com Ltd"},
	{0x000BAD, "PC-PoS Inc."},
	{0x000BAE, "Vitals System Inc."},
	{0x000BAF, "WOOJU COMMUNICATIONS Co,.Ltd"},
	{0x000BB0, "Sysnet Telematica srl"},
	{0x000BB1, "Super Star Technology Co., Ltd."},
	{0x000BB2, "SMALLBIG TECHNOLOGY"},
	{0x000BB3, "RiT technologies Ltd."},
	{0x000BB4, "RDC Semiconductor Inc.,"},
	{0x000BB5, "nStor Technologies, Inc."},
	{0x000BB6, "Mototech Inc."},
	{0x000BB7, "Micro Systems Co.,Ltd."},
	{0x000BB8, "Kihoku Electronic Co."},
	{0x000BB9, "Imsys AB"},
	{0x000BBA, "Harmonic Broadband Access Networks"},
	{0x000BBB, "Etin Systems Co., Ltd"},
	{0x000BBC, "En Garde Systems, Inc."},
	{0x000BBD, "Connexionz Limited"},
	{0x000BBE, "Cisco Systems"},
	{0x000BBF, "Cisco Systems"},
	{0x000BC0, "China IWNComm Co., Ltd."},
	{0x000BC1, "Bay Microsystems, Inc."},
	{0x000BC2, "Corinex Communication Corp."},
	{0x000BC3, "Multiplex, Inc."},
	{0x000BC4, "BIOTRONIK GmbH & Co"},
	{0x000BC5, "SMC Networks, Inc."},
	{0x000BC6, "ISAC, Inc."},
	{0x000BC7, "ICET S.p.A."},
	{0x000BC8, "AirFlow Networks"},
	{0x000BC9, "Electroline Equipment"},
	{0x000BCA, "DATAVAN International Corporation"},
	{0x000BCB, "Fagor Automation , S. Coop"},
	{0x000BCC, "JUSAN, S.A."},
	{0x000BCD, "Hewlett Packard"},
	{0x000BCE, "Free2move AB"},
	{0x000BCF, "AGFA NDT INC."},
	{0x000BD0, "XiMeta Technology Americas Inc."},
	{0x000BD1, "Aeronix, Inc."},
	{0x000BD2, "Remopro Technology Inc."},
	{0x000BD3, "cd3o"},
	{0x000BD4, "Beijing Wise Technology & Science Development Co.Ltd"},
	{0x000BD5, "Nvergence, Inc."},
	{0x000BD6, "Paxton Access Ltd"},
	{0x000BD7, "DORMA Time + Access GmbH"},
	{0x000BD8, "Industrial Scientific Corp."},
	{0x000BD9, "General Hydrogen"},
	{0x000BDA, "EyeCross Co.,Inc."},
	{0x000BDB, "Dell ESG PCBA Test"},
	{0x000BDC, "AKCP"},
	{0x000BDD, "TOHOKU RICOH Co., LTD."},
	{0x000BDE, "TELDIX GmbH"},
	{0x000BDF, "Shenzhen RouterD Networks Limited"},
	{0x000BE0, "SercoNet Ltd."},
	{0x000BE1, "Nokia NET Product Operations"},
	{0x000BE2, "Lumenera Corporation"},
	{0x000BE3, "Key Stream Co., Ltd."},
	{0x000BE4, "Hosiden Corporation"},
	{0x000BE5, "HIMS Korea Co., Ltd."},
	{0x000BE6, "Datel Electronics"},
	{0x000BE7, "COMFLUX TECHNOLOGY INC."},
	{0x000BE8, "AOIP"},
	{0x000BE9, "Actel Corporation"},
	{0x000BEA, "Zultys Technologies"},
	{0x000BEB, "Systegra AG"},
	{0x000BEC, "NIPPON ELECTRIC INSTRUMENT, INC."},
	{0x000BED, "ELM Inc."},
	{0x000BEE, "inc.jet, Incorporated"},
	{0x000BEF, "Code Corporation"},
	{0x000BF0, "MoTEX Products Co., Ltd."},
	{0x000BF1, "LAP Laser Applikations"},
	{0x000BF2, "Chih-Kan Technology Co., Ltd."},
	{0x000BF3, "BAE SYSTEMS"},
	{0x000BF5, "Shanghai Sibo Telecom Technology Co.,Ltd"},
	{0x000BF6, "Nitgen Co., Ltd"},
	{0x000BF7, "NIDEK CO.,LTD"},
	{0x000BF8, "Infinera"},
	{0x000BF9, "Gemstone communications, Inc."},
	{0x000BFA, "EXEMYS SRL"},
	{0x000BFB, "D-NET International Corporation"},
	{0x000BFC, "Cisco Systems"},
	{0x000BFD, "Cisco Systems"},
	{0x000BFE, "CASTEL Broadband Limited"},
	{0x000BFF, "Berkeley Camera Engineering"},
	{0x000C00, "BEB Industrie-Elektronik AG"},
	{0x000C01, "Abatron AG"},
	{0x000C02, "ABB Oy"},
	{0x000C03, "HDMI Licensing, LLC"},
	{0x000C04, "Tecnova"},
	{0x000C05, "RPA Reserch Co., Ltd."},
	{0x000C06, "Nixvue Systems  Pte Ltd"},
	{0x000C07, "Iftest AG"},
	{0x000C08, "HUMEX Technologies Corp."},
	{0x000C09, "Hitachi IE Systems Co., Ltd"},
	{0x000C0A,
	 "Guangdong Province Electronic Technology Research Institute"},
	{0x000C0B, "Broadbus Technologies"},
	{0x000C0C, "APPRO TECHNOLOGY INC."},
	{0x000C0D, "Communications & Power Industries / Satcom Division"},
	{0x000C0E, "XtremeSpectrum, Inc."},
	{0x000C0F, "Techno-One Co., Ltd"},
	{0x000C10, "PNI Corporation"},
	{0x000C11, "NIPPON DEMPA CO.,LTD."},
	{0x000C12, "Micro-Optronic-Messtechnik GmbH"},
	{0x000C13, "MediaQ"},
	{0x000C14, "Diagnostic Instruments, Inc."},
	{0x000C15, "CyberPower Systems, Inc."},
	{0x000C16, "Concorde Microsystems Inc."},
	{0x000C17, "AJA Video Systems Inc"},
	{0x000C18, "Zenisu Keisoku Inc."},
	{0x000C19, "Telio Communications GmbH"},
	{0x000C1A, "Quest Technical Solutions Inc."},
	{0x000C1B, "ORACOM Co, Ltd."},
	{0x000C1C, "MicroWeb Co., Ltd."},
	{0x000C1D, "Mettler & Fuchs AG"},
	{0x000C1E, "Global Cache"},
	{0x000C1F, "Glimmerglass Networks"},
	{0x000C20, "Fi WIn, Inc."},
	{0x000C21, "Faculty of Science and Technology, Keio University"},
	{0x000C22, "Double D Electronics Ltd"},
	{0x000C23, "Beijing Lanchuan Tech. Co., Ltd."},
	{0x000C24, "ANATOR"},
	{0x000C25, "Allied Telesyn Networks"},
	{0x000C26, "Weintek Labs. Inc."},
	{0x000C27, "Sammy Corporation"},
	{0x000C28, "RIFATRON"},
	{0x000C29, "VMware, Inc."},
	{0x000C2A, "OCTTEL Communication Co., Ltd."},
	{0x000C2B, "ELIAS Technology, Inc."},
	{0x000C2C, "Enwiser Inc."},
	{0x000C2D, "FullWave Technology Co., Ltd."},
	{0x000C2E, "Openet information technology(shenzhen) Co., Ltd."},
	{0x000C2F, "SeorimTechnology Co.,Ltd."},
	{0x000C30, "Cisco"},
	{0x000C31, "Cisco"},
	{0x000C32, "Avionic Design Development GmbH"},
	{0x000C33, "Compucase Enterprise Co. Ltd."},
	{0x000C34, "Vixen Co., Ltd."},
	{0x000C35, "KaVo Dental GmbH & Co. KG"},
	{0x000C36, "SHARP TAKAYA ELECTRONICS INDUSTRY CO.,LTD."},
	{0x000C37, "Geomation, Inc."},
	{0x000C38, "TelcoBridges Inc."},
	{0x000C39, "Sentinel Wireless Inc."},
	{0x000C3A, "Oxance"},
	{0x000C3B, "Orion Electric Co., Ltd."},
	{0x000C3C, "MediaChorus, Inc."},
	{0x000C3D, "Glsystech Co., Ltd."},
	{0x000C3E, "Crest Audio"},
	{0x000C3F, "Cogent Defence & Security Networks,"},
	{0x000C40, "Altech Controls"},
	{0x000C41, "Cisco-Linksys"},
	{0x000C42, "Routerboard.com"},
	{0x000C43, "Ralink Technology, Corp."},
	{0x000C44, "Automated Interfaces, Inc."},
	{0x000C45, "Animation Technologies Inc."},
	{0x000C46, "Allied Telesyn Inc."},
	{0x000C47, "SK Teletech(R&D Planning Team)"},
	{0x000C48, "QoStek Corporation"},
	{0x000C49, "Dangaard Telecom RTC Division A/S"},
	{0x000C4A, "Cygnus Microsystems (P) Limited"},
	{0x000C4B, "Cheops Elektronik"},
	{0x000C4C, "Arcor AG&Co."},
	{0x000C4D, "ACRA CONTROL"},
	{0x000C4E, "Winbest Technology CO,LT"},
	{0x000C4F, "UDTech Japan Corporation"},
	{0x000C50, "Seagate Technology"},
	{0x000C51, "Scientific Technologies Inc."},
	{0x000C52, "Roll Systems Inc."},
	{0x000C54, "Pedestal Networks, Inc"},
	{0x000C55, "Microlink Communications Inc."},
	{0x000C56, "Megatel Computer (1986) Corp."},
	{0x000C57, "MACKIE Engineering Services Belgium BVBA"},
	{0x000C58, "M&S Systems"},
	{0x000C59, "Indyme Electronics, Inc."},
	{0x000C5A, "IBSmm Industrieelektronik Multimedia"},
	{0x000C5B, "HANWANG TECHNOLOGY CO.,LTD"},
	{0x000C5C, "GTN Systems B.V."},
	{0x000C5D, "CHIC TECHNOLOGY (CHINA) CORP."},
	{0x000C5E, "Calypso Medical"},
	{0x000C5F, "Avtec, Inc."},
	{0x000C60, "ACM Systems"},
	{0x000C61, "AC Tech corporation DBA Advanced Digital"},
	{0x000C62, "ABB Automation Technology Products AB, Control"},
	{0x000C63, "Zenith Electronics Corporation"},
	{0x000C64, "X2 MSA Group"},
	{0x000C65, "Sunin Telecom"},
	{0x000C66, "Pronto Networks Inc"},
	{0x000C67, "OYO ELECTRIC CO.,LTD"},
	{0x000C68, "SigmaTel, Inc."},
	{0x000C69, "National Radio Astronomy Observatory"},
	{0x000C6A, "MBARI"},
	{0x000C6B, "Kurz Industrie-Elektronik GmbH"},
	{0x000C6C, "Elgato Systems LLC"},
	{0x000C6D, "Edwards Ltd."},
	{0x000C6E, "ASUSTEK COMPUTER INC."},
	{0x000C6F, "Amtek system co.,LTD."},
	{0x000C70, "ACC GmbH"},
	{0x000C71, "Wybron, Inc"},
	{0x000C72, "Tempearl Industrial Co., Ltd."},
	{0x000C73, "TELSON ELECTRONICS CO., LTD"},
	{0x000C74, "RIVERTEC CORPORATION"},
	{0x000C75, "Oriental integrated electronics. LTD"},
	{0x000C76, "MICRO-STAR INTERNATIONAL CO., LTD."},
	{0x000C77, "Life Racing Ltd"},
	{0x000C78, "In-Tech Electronics Limited"},
	{0x000C79, "Extel Communications P/L"},
	{0x000C7A, "DaTARIUS Technologies GmbH"},
	{0x000C7B, "ALPHA PROJECT Co.,Ltd."},
	{0x000C7C, "Internet Information Image Inc."},
	{0x000C7D, "TEIKOKU ELECTRIC MFG. CO., LTD"},
	{0x000C7E, "Tellium Incorporated"},
	{0x000C7F, "synertronixx GmbH"},
	{0x000C80, "Opelcomm Inc."},
	{0x000C81, "Nulec Industries Pty Ltd"},
	{0x000C82, "NETWORK TECHNOLOGIES INC"},
	{0x000C83, "Logical Solutions"},
	{0x000C84, "Eazix, Inc."},
	{0x000C85, "Cisco Systems"},
	{0x000C86, "Cisco Systems"},
	{0x000C87, "AMD"},
	{0x000C88, "Apache Micro Peripherals, Inc."},
	{0x000C89, "AC Electric Vehicles, Ltd."},
	{0x000C8A, "Bose Corporation"},
	{0x000C8B, "Connect Tech Inc"},
	{0x000C8C, "KODICOM CO.,LTD."},
	{0x000C8D, "MATRIX VISION GmbH"},
	{0x000C8E, "Mentor Engineering Inc"},
	{0x000C8F, "Nergal s.r.l."},
	{0x000C90, "Octasic Inc."},
	{0x000C91, "Riverhead Networks Inc."},
	{0x000C92, "WolfVision Gmbh"},
	{0x000C93, "Xeline Co., Ltd."},
	{0x000C94, "United Electronic Industries, Inc. (EUI)"},
	{0x000C95, "PrimeNet"},
	{0x000C96, "OQO, Inc."},
	{0x000C97, "NV ADB TTV Technologies SA"},
	{0x000C98, "LETEK Communications Inc."},
	{0x000C99, "HITEL LINK Co.,Ltd"},
	{0x000C9A, "Hitech Electronics Corp."},
	{0x000C9B, "EE Solutions, Inc"},
	{0x000C9C, "Chongho information & communications"},
	{0x000C9D, "AirWalk Communications, Inc."},
	{0x000C9E, "MemoryLink Corp."},
	{0x000C9F, "NKE Corporation"},
	{0x000CA0, "StorCase Technology, Inc."},
	{0x000CA1, "SIGMACOM Co., LTD."},
	{0x000CA2, "Scopus Network Technologies Ltd"},
	{0x000CA3, "Rancho Technology, Inc."},
	{0x000CA4, "Prompttec Product Management GmbH"},
	{0x000CA5, "Naman NZ LTd"},
	{0x000CA6, "Mintera Corporation"},
	{0x000CA7, "Metro (Suzhou) Technologies Co., Ltd."},
	{0x000CA8, "Garuda Networks Corporation"},
	{0x000CA9, "Ebtron Inc."},
	{0x000CAA, "Cubic Transportation Systems Inc"},
	{0x000CAB, "COMMEND International"},
	{0x000CAC, "Citizen Watch Co., Ltd."},
	{0x000CAD, "BTU International"},
	{0x000CAE, "Ailocom Oy"},
	{0x000CAF, "TRI TERM CO.,LTD."},
	{0x000CB0, "Star Semiconductor Corporation"},
	{0x000CB1, "Salland Engineering (Europe) BV"},
	{0x000CB2, "Comstar Co., Ltd."},
	{0x000CB3, "ROUND Co.,Ltd."},
	{0x000CB4, "AutoCell Laboratories, Inc."},
	{0x000CB5, "Premier Technolgies, Inc"},
	{0x000CB6, "NANJING SEU MOBILE & INTERNET TECHNOLOGY CO.,LTD"},
	{0x000CB7, "Nanjing Huazhuo Electronics Co., Ltd."},
	{0x000CB8, "MEDION AG"},
	{0x000CB9, "LEA"},
	{0x000CBA, "Jamex, Inc."},
	{0x000CBB, "ISKRAEMECO"},
	{0x000CBC, "Iscutum"},
	{0x000CBD, "Interface Masters, Inc"},
	{0x000CBE, "Innominate Security Technologies AG"},
	{0x000CBF, "Holy Stone Ent. Co., Ltd."},
	{0x000CC0, "Genera Oy"},
	{0x000CC1, "Cooper Industries Inc."},
	{0x000CC2, "ControlNet (India) Private Limited"},
	{0x000CC3, "BeWAN systems"},
	{0x000CC4, "Tiptel AG"},
	{0x000CC5, "Nextlink Co., Ltd."},
	{0x000CC6, "Ka-Ro electronics GmbH"},
	{0x000CC7, "Intelligent Computer Solutions Inc."},
	{0x000CC8, "Xytronix Research & Design, Inc."},
	{0x000CC9, "ILWOO DATA & TECHNOLOGY CO.,LTD"},
	{0x000CCA, "Hitachi Global Storage Technologies"},
	{0x000CCB, "Design Combus Ltd"},
	{0x000CCC, "Aeroscout Ltd."},
	{0x000CCD, "IEC - TC57"},
	{0x000CCE, "Cisco Systems"},
	{0x000CCF, "Cisco Systems"},
	{0x000CD0, "Symetrix"},
	{0x000CD1, "SFOM Technology Corp."},
	{0x000CD2, "Schaffner EMV AG"},
	{0x000CD3, "Prettl Elektronik Radeberg GmbH"},
	{0x000CD4, "Positron Public Safety Systems inc."},
	{0x000CD5, "Passave Inc."},
	{0x000CD6, "PARTNER TECH"},
	{0x000CD7, "Nallatech Ltd"},
	{0x000CD8, "M. K. Juchheim GmbH & Co"},
	{0x000CD9, "Itcare Co., Ltd"},
	{0x000CDA, "FreeHand Systems, Inc."},
	{0x000CDB, "Brocade Communications Systems, Inc"},
	{0x000CDC, "BECS Technology, Inc"},
	{0x000CDD, "AOS Technologies AG"},
	{0x000CDE, "ABB STOTZ-KONTAKT GmbH"},
	{0x000CDF, "PULNiX America, Inc"},
	{0x000CE0, "Trek Diagnostics Inc."},
	{0x000CE1, "The Open Group"},
	{0x000CE2, "Rolls-Royce"},
	{0x000CE3, "Option International N.V."},
	{0x000CE4, "NeuroCom International, Inc."},
	{0x000CE5, "Motorola BCS"},
	{0x000CE6, "Meru Networks Inc"},
	{0x000CE7, "MediaTek Inc."},
	{0x000CE8, "GuangZhou AnJuBao Co., Ltd"},
	{0x000CE9, "BLOOMBERG L.P."},
	{0x000CEA, "aphona Kommunikationssysteme"},
	{0x000CEB, "CNMP Networks, Inc."},
	{0x000CEC, "Spectracom Corp."},
	{0x000CED, "Real Digital Media"},
	{0x000CEE, "jp-embedded"},
	{0x000CEF, "Open Networks Engineering Ltd"},
	{0x000CF0, "M & N GmbH"},
	{0x000CF1, "Intel Corporation"},
	{0x000CF2, "GAMESA ELICA"},
	{0x000CF3, "CALL IMAGE SA"},
	{0x000CF4, "AKATSUKI ELECTRIC MFG.CO.,LTD."},
	{0x000CF5, "InfoExpress"},
	{0x000CF6, "Sitecom Europe BV"},
	{0x000CF7, "Nortel Networks"},
	{0x000CF8, "Nortel Networks"},
	{0x000CF9, "ITT Flygt AB"},
	{0x000CFA, "Digital Systems Corp"},
	{0x000CFB, "Korea Network Systems"},
	{0x000CFC, "S2io Technologies Corp"},
	{0x000CFD, "Hyundai ImageQuest Co.,Ltd."},
	{0x000CFE, "Grand Electronic Co., Ltd"},
	{0x000CFF, "MRO-TEK LIMITED"},
	{0x000D00, "Seaway Networks Inc."},
	{0x000D01, "P&E Microcomputer Systems, Inc."},
	{0x000D02, "NEC AccessTechnica,Ltd"},
	{0x000D03, "Matrics, Inc."},
	{0x000D04, "Foxboro Eckardt Development GmbH"},
	{0x000D05, "cybernet manufacturing inc."},
	{0x000D06, "Compulogic Limited"},
	{0x000D07, "Calrec Audio Ltd"},
	{0x000D08, "AboveCable, Inc."},
	{0x000D09, "Yuehua(Zhuhai) Electronic CO. LTD"},
	{0x000D0A, "Projectiondesign as"},
	{0x000D0B, "Buffalo Inc."},
	{0x000D0C, "MDI Security Systems"},
	{0x000D0D, "ITSupported, LLC"},
	{0x000D0E, "Inqnet Systems, Inc."},
	{0x000D0F, "Finlux Ltd"},
	{0x000D10, "Embedtronics Oy"},
	{0x000D11, "DENTSPLY - Gendex"},
	{0x000D12, "AXELL Corporation"},
	{0x000D13, "Wilhelm Rutenbeck GmbH&Co."},
	{0x000D14, "Vtech Innovation LP dba Advanced American Telephones"},
	{0x000D15, "Voipac s.r.o."},
	{0x000D16, "UHS Systems Pty Ltd"},
	{0x000D17, "Turbo Networks Co.Ltd"},
	{0x000D18, "Mega-Trend Electronics CO., LTD."},
	{0x000D19, "ROBE Show lighting"},
	{0x000D1A, "Mustek System Inc."},
	{0x000D1B, "Kyoto Electronics Manufacturing Co., Ltd."},
	{0x000D1C, "Amesys Defense"},
	{0x000D1D, "HIGH-TEK HARNESS ENT. CO., LTD."},
	{0x000D1E, "Control Techniques"},
	{0x000D1F, "AV Digital"},
	{0x000D20, "ASAHIKASEI TECHNOSYSTEM CO.,LTD."},
	{0x000D21, "WISCORE Inc."},
	{0x000D22, "Unitronics LTD"},
	{0x000D23, "Smart Solution, Inc"},
	{0x000D24, "SENTEC E&E CO., LTD."},
	{0x000D25, "SANDEN CORPORATION"},
	{0x000D26, "Primagraphics Limited"},
	{0x000D27, "MICROPLEX Printware AG"},
	{0x000D28, "Cisco"},
	{0x000D29, "Cisco"},
	{0x000D2A, "Scanmatic AS"},
	{0x000D2B, "Racal Instruments"},
	{0x000D2C, "Patapsco Designs Ltd"},
	{0x000D2D, "NCT Deutschland GmbH"},
	{0x000D2E, "Matsushita Avionics Systems Corporation"},
	{0x000D2F, "AIN Comm.Tech.Co., LTD"},
	{0x000D30, "IceFyre Semiconductor"},
	{0x000D31, "Compellent Technologies, Inc."},
	{0x000D32, "DispenseSource, Inc."},
	{0x000D33, "Prediwave Corp."},
	{0x000D34, "Shell International Exploration and Production, Inc."},
	{0x000D35, "PAC International Ltd"},
	{0x000D36, "Wu Han Routon Electronic Co., Ltd"},
	{0x000D37, "WIPLUG"},
	{0x000D38, "NISSIN INC."},
	{0x000D39, "Network Electronics"},
	{0x000D3A, "Microsoft Corp."},
	{0x000D3B, "Microelectronics Technology Inc."},
	{0x000D3C, "i.Tech Dynamic Ltd"},
	{0x000D3D, "Hammerhead Systems, Inc."},
	{0x000D3E, "APLUX Communications Ltd."},
	{0x000D3F, "VTI Instruments Corporation"},
	{0x000D40, "Verint Loronix Video Solutions"},
	{0x000D41, "Siemens AG ICM MP UC RD IT KLF1"},
	{0x000D42, "Newbest Development Limited"},
	{0x000D43, "DRS Tactical Systems Inc."},
	{0x000D44, "Audio BU - Logitech"},
	{0x000D45, "Tottori SANYO Electric Co., Ltd."},
	{0x000D46, "Parker SSD Drives"},
	{0x000D47, "Collex"},
	{0x000D48, "AEWIN Technologies Co., Ltd."},
	{0x000D49, "Triton Systems of Delaware, Inc."},
	{0x000D4A, "Steag ETA-Optik"},
	{0x000D4B, "Roku, LLC"},
	{0x000D4C, "Outline Electronics Ltd."},
	{0x000D4D, "Ninelanes"},
	{0x000D4E, "NDR Co.,LTD."},
	{0x000D4F, "Kenwood Corporation"},
	{0x000D50, "Galazar Networks"},
	{0x000D51, "DIVR Systems, Inc."},
	{0x000D52, "Comart system"},
	{0x000D53, "Beijing 5w Communication Corp."},
	{0x000D54, "3Com Ltd"},
	{0x000D55, "SANYCOM Technology Co.,Ltd"},
	{0x000D56, "Dell PCBA Test"},
	{0x000D57, "Fujitsu I-Network Systems Limited."},
	{0x000D59, "Amity Systems, Inc."},
	{0x000D5A, "Tiesse SpA"},
	{0x000D5B, "Smart Empire Investments Limited"},
	{0x000D5C, "Robert Bosch GmbH, VT-ATMO"},
	{0x000D5D, "Raritan Computer, Inc"},
	{0x000D5E, "NEC Personal Products"},
	{0x000D5F, "Minds Inc"},
	{0x000D60, "IBM Corporation"},
	{0x000D61, "Giga-Byte Technology Co., Ltd."},
	{0x000D62, "Funkwerk Dabendorf GmbH"},
	{0x000D63, "DENT Instruments, Inc."},
	{0x000D64, "COMAG Handels AG"},
	{0x000D65, "Cisco Systems"},
	{0x000D66, "Cisco Systems"},
	{0x000D67, "BelAir Networks Inc."},
	{0x000D68, "Vinci Systems, Inc."},
	{0x000D69, "TMT&D Corporation"},
	{0x000D6A, "Redwood Technologies LTD"},
	{0x000D6B, "Mita-Teknik A/S"},
	{0x000D6C, "M-Audio"},
	{0x000D6D, "K-Tech Devices Corp."},
	{0x000D6E, "K-Patents Oy"},
	{0x000D6F, "Ember Corporation"},
	{0x000D70, "Datamax Corporation"},
	{0x000D71, "boca systems"},
	{0x000D72, "2Wire, Inc"},
	{0x000D73, "Technical Support, Inc."},
	{0x000D74, "Sand Network Systems, Inc."},
	{0x000D75, "Kobian Pte Ltd - Taiwan Branch"},
	{0x000D76, "Hokuto Denshi Co,. Ltd."},
	{0x000D77, "FalconStor Software"},
	{0x000D78, "Engineering & Security"},
	{0x000D79, "Dynamic Solutions Co,.Ltd."},
	{0x000D7A, "DiGATTO Asia Pacific Pte Ltd"},
	{0x000D7B, "Consensys Computers Inc."},
	{0x000D7C, "Codian Ltd"},
	{0x000D7D, "Afco Systems"},
	{0x000D7E, "Axiowave Networks, Inc."},
	{0x000D7F,
	 "MIDAS  COMMUNICATION TECHNOLOGIES PTE LTD ( Foreign Branch)"},
	{0x000D80, "Online Development Inc"},
	{0x000D81, "Pepperl+Fuchs GmbH"},
	{0x000D82, "PHS srl"},
	{0x000D83, "Sanmina-SCI Hungary  Ltd."},
	{0x000D84, "Makus Inc."},
	{0x000D85, "Tapwave, Inc."},
	{0x000D86, "Huber + Suhner AG"},
	{0x000D87, "Elitegroup Computer System Co. (ECS)"},
	{0x000D88, "D-Link Corporation"},
	{0x000D89, "Bils Technology Inc"},
	{0x000D8A, "Winners Electronics Co., Ltd."},
	{0x000D8B, "T&D Corporation"},
	{0x000D8C, "Shanghai Wedone Digital Ltd. CO."},
	{0x000D8D, "ProLinx Communication Gateways, Inc."},
	{0x000D8E, "Koden Electronics Co., Ltd."},
	{0x000D8F, "King Tsushin Kogyo Co., LTD."},
	{0x000D90, "Factum Electronics AB"},
	{0x000D91, "Eclipse (HQ Espana) S.L."},
	{0x000D92, "Arima Communication Corporation"},
	{0x000D93, "Apple Computer"},
	{0x000D94, "AFAR Communications,Inc"},
	{0x000D95, "Opti-cell, Inc."},
	{0x000D96, "Vtera Technology Inc."},
	{0x000D97, "Tropos Networks, Inc."},
	{0x000D98, "S.W.A.C. Schmitt-Walter Automation Consult GmbH"},
	{0x000D99, "Orbital Sciences Corp.; Launch Systems Group"},
	{0x000D9A, "INFOTEC LTD"},
	{0x000D9B, "Heraeus Electro-Nite International N.V."},
	{0x000D9C, "Elan GmbH & Co KG"},
	{0x000D9D, "Hewlett Packard"},
	{0x000D9E, "TOKUDEN OHIZUMI SEISAKUSYO Co.,Ltd."},
	{0x000D9F, "RF Micro Devices"},
	{0x000DA0, "NEDAP N.V."},
	{0x000DA1, "MIRAE ITS Co.,LTD."},
	{0x000DA2, "Infrant Technologies, Inc."},
	{0x000DA3, "Emerging Technologies Limited"},
	{0x000DA4, "DOSCH & AMAND SYSTEMS AG"},
	{0x000DA5, "Fabric7 Systems, Inc"},
	{0x000DA6, "Universal Switching Corporation"},
	{0x000DA8, "Teletronics Technology Corporation"},
	{0x000DA9, "T.E.A.M. S.L."},
	{0x000DAA, "S.A.Tehnology co.,Ltd."},
	{0x000DAB, "Parker Hannifin GmbH Electromechanical Division Europe"},
	{0x000DAC, "Japan CBM Corporation"},
	{0x000DAD, "Dataprobe Inc"},
	{0x000DAE, "SAMSUNG HEAVY INDUSTRIES CO., LTD."},
	{0x000DAF, "Plexus Corp (UK) Ltd"},
	{0x000DB0, "Olym-tech Co.,Ltd."},
	{0x000DB1, "Japan Network Service Co., Ltd."},
	{0x000DB2, "Ammasso, Inc."},
	{0x000DB3, "SDO Communication Corperation"},
	{0x000DB4, "NETASQ"},
	{0x000DB5, "GLOBALSAT TECHNOLOGY CORPORATION"},
	{0x000DB6, "Teknovus, Inc."},
	{0x000DB7, "SANKO ELECTRIC CO,.LTD"},
	{0x000DB8, "SCHILLER AG"},
	{0x000DB9, "PC Engines GmbH"},
	{0x000DBA, "Oc Document Technologies GmbH"},
	{0x000DBB, "Nippon Dentsu Co.,Ltd."},
	{0x000DBC, "Cisco Systems"},
	{0x000DBD, "Cisco Systems"},
	{0x000DBE, "Bel Fuse Europe Ltd.,UK"},
	{0x000DBF, "TekTone Sound & Signal Mfg., Inc."},
	{0x000DC0, "Spagat AS"},
	{0x000DC1, "SafeWeb Inc"},
	{0x000DC3, "First Communication, Inc."},
	{0x000DC4, "Emcore Corporation"},
	{0x000DC5, "EchoStar International Corporation"},
	{0x000DC6, "DigiRose Technology Co., Ltd."},
	{0x000DC7, "COSMIC ENGINEERING INC."},
	{0x000DC8, "AirMagnet, Inc"},
	{0x000DC9, "THALES Elektronik Systeme GmbH"},
	{0x000DCA, "Tait Electronics"},
	{0x000DCB, "Petcomkorea Co., Ltd."},
	{0x000DCC, "NEOSMART Corp."},
	{0x000DCD, "GROUPE TXCOM"},
	{0x000DCE, "Dynavac Technology Pte Ltd"},
	{0x000DCF, "Cidra Corp."},
	{0x000DD0, "TetraTec Instruments GmbH"},
	{0x000DD1, "Stryker Corporation"},
	{0x000DD2, "Simrad Optronics ASA"},
	{0x000DD3, "SAMWOO Telecommunication Co.,Ltd."},
	{0x000DD4, "Symantec Corporation"},
	{0x000DD5, "O'RITE TECHNOLOGY CO.,LTD"},
	{0x000DD6, "ITI    LTD"},
	{0x000DD7, "Bright"},
	{0x000DD8, "BBN"},
	{0x000DD9, "Anton Paar GmbH"},
	{0x000DDA, "ALLIED TELESIS K.K."},
	{0x000DDB, "AIRWAVE TECHNOLOGIES INC."},
	{0x000DDC, "VAC"},
	{0x000DDD, "PROFLO TELRA ELEKTRONK SANAY VE TCARET A.."},
	{0x000DDE, "Joyteck Co., Ltd."},
	{0x000DDF, "Japan Image & Network Inc."},
	{0x000DE0, "ICPDAS Co.,LTD"},
	{0x000DE1, "Control Products, Inc."},
	{0x000DE2, "CMZ Sistemi Elettronici"},
	{0x000DE3, "AT Sweden AB"},
	{0x000DE4, "DIGINICS, Inc."},
	{0x000DE5, "Samsung Thales"},
	{0x000DE6, "YOUNGBO ENGINEERING CO.,LTD"},
	{0x000DE7, "Snap-on OEM Group"},
	{0x000DE8, "Nasaco Electronics Pte. Ltd"},
	{0x000DE9, "Napatech Aps"},
	{0x000DEA, "Kingtel Telecommunication Corp."},
	{0x000DEB, "CompXs Limited"},
	{0x000DEC, "Cisco Systems"},
	{0x000DED, "Cisco Systems"},
	{0x000DEE, "Andrew RF Power Amplifier Group"},
	{0x000DEF, "Soc. Coop. Bilanciai"},
	{0x000DF0, "QCOM TECHNOLOGY INC."},
	{0x000DF1, "IONIX INC."},
	{0x000DF3, "Asmax Solutions"},
	{0x000DF4, "Watertek Co."},
	{0x000DF5, "Teletronics International Inc."},
	{0x000DF6, "Technology Thesaurus Corp."},
	{0x000DF7, "Space Dynamics Lab"},
	{0x000DF8, "ORGA Kartensysteme GmbH"},
	{0x000DF9, "NDS Limited"},
	{0x000DFA, "Micro Control Systems Ltd."},
	{0x000DFB, "Komax AG"},
	{0x000DFC, "ITFOR Inc."},
	{0x000DFD, "Huges Hi-Tech Inc.,"},
	{0x000DFE, "Hauppauge Computer Works, Inc."},
	{0x000DFF, "CHENMING MOLD INDUSTRY CORP."},
	{0x000E00, "Atrie"},
	{0x000E01, "ASIP Technologies Inc."},
	{0x000E02, "Advantech AMT Inc."},
	{0x000E03, "Emulex"},
	{0x000E04, "CMA/Microdialysis AB"},
	{0x000E05, "WIRELESS MATRIX CORP."},
	{0x000E06, "Team Simoco Ltd"},
	{0x000E07, "Sony Ericsson Mobile Communications AB"},
	{0x000E08, "Cisco Linksys LLC"},
	{0x000E09, "Shenzhen Coship Software Co.,LTD."},
	{0x000E0A, "SAKUMA DESIGN OFFICE"},
	{0x000E0B, "Netac Technology Co., Ltd."},
	{0x000E0C, "Intel Corporation"},
	{0x000E0D, "HESCH Schrder GmbH"},
	{0x000E0E, "ESA elettronica S.P.A."},
	{0x000E0F, "ERMME"},
	{0x000E10, "C-guys, Inc."},
	{0x000E11, "BDT Bro- und Datentechnik GmbH & Co. KG"},
	{0x000E12, "Adaptive Micro Systems Inc."},
	{0x000E13, "Accu-Sort Systems inc."},
	{0x000E14, "Visionary Solutions, Inc."},
	{0x000E15, "Tadlys LTD"},
	{0x000E16, "SouthWing S.L."},
	{0x000E18, "MyA Technology"},
	{0x000E19, "LogicaCMG Pty Ltd"},
	{0x000E1A, "JPS Communications"},
	{0x000E1B, "IAV GmbH"},
	{0x000E1C, "Hach Company"},
	{0x000E1D, "ARION Technology Inc."},
	{0x000E1E, "NetXen, Inc."},
	{0x000E1F, "TCL Networks Equipment Co., Ltd."},
	{0x000E20, "ACCESS Systems Americas, Inc."},
	{0x000E21, "MTU Friedrichshafen GmbH"},
	{0x000E23, "Incipient, Inc."},
	{0x000E24, "Huwell Technology Inc."},
	{0x000E25, "Hannae Technology Co., Ltd"},
	{0x000E26, "Gincom Technology Corp."},
	{0x000E27, "Crere Networks, Inc."},
	{0x000E28, "Dynamic Ratings P/L"},
	{0x000E29, "Shester Communications Inc"},
	{0x000E2B, "Safari Technologies"},
	{0x000E2C, "Netcodec co."},
	{0x000E2D, "Hyundai Digital Technology Co.,Ltd."},
	{0x000E2E, "Edimax Technology Co., Ltd."},
	{0x000E2F, "Disetronic Medical Systems AG"},
	{0x000E30, "AERAS Networks, Inc."},
	{0x000E31, "Olympus Soft Imaging Solutions GmbH"},
	{0x000E32, "Kontron Medical"},
	{0x000E33, "Shuko Electronics Co.,Ltd"},
	{0x000E34, "NexGen City, LP"},
	{0x000E35, "Intel Corp"},
	{0x000E36, "HEINESYS, Inc."},
	{0x000E37, "Harms & Wende GmbH & Co.KG"},
	{0x000E38, "Cisco Systems"},
	{0x000E39, "Cisco Systems"},
	{0x000E3A, "Cirrus Logic"},
	{0x000E3B, "Hawking Technologies, Inc."},
	{0x000E3C, "Transact Technologies Inc"},
	{0x000E3D, "Televic N.V."},
	{0x000E3E, "Sun Optronics Inc"},
	{0x000E3F, "Soronti, Inc."},
	{0x000E40, "Nortel Networks"},
	{0x000E41, "NIHON MECHATRONICS CO.,LTD."},
	{0x000E42, "Motic Incoporation Ltd."},
	{0x000E43, "G-Tek Electronics Sdn. Bhd."},
	{0x000E44, "Digital 5, Inc."},
	{0x000E45, "Beijing Newtry Electronic Technology Ltd"},
	{0x000E46, "Niigata Seimitsu Co.,Ltd."},
	{0x000E47, "NCI System Co.,Ltd."},
	{0x000E48, "Lipman TransAction Solutions"},
	{0x000E49, "Forsway Scandinavia AB"},
	{0x000E4A, "Changchun Huayu WEBPAD Co.,LTD"},
	{0x000E4B, "atrium c and i"},
	{0x000E4C, "Bermai Inc."},
	{0x000E4D, "Numesa Inc."},
	{0x000E4E, "Waveplus Technology Co., Ltd."},
	{0x000E4F, "Trajet GmbH"},
	{0x000E50, "Thomson Telecom Belgium"},
	{0x000E51, "tecna elettronica srl"},
	{0x000E52, "Optium Corporation"},
	{0x000E53, "AV TECH CORPORATION"},
	{0x000E54, "AlphaCell Wireless Ltd."},
	{0x000E55, "AUVITRAN"},
	{0x000E56, "4G Systems GmbH & Co. KG"},
	{0x000E57, "Iworld Networking, Inc."},
	{0x000E58, "Sonos, Inc."},
	{0x000E59, "SAGEM SA"},
	{0x000E5A, "TELEFIELD inc."},
	{0x000E5B, "ParkerVision - Direct2Data"},
	{0x000E5C, "Motorola BCS"},
	{0x000E5D, "Triple Play Technologies A/S"},
	{0x000E5E, "Raisecom Technology"},
	{0x000E5F, "activ-net GmbH & Co. KG"},
	{0x000E60, "360SUN Digital Broadband Corporation"},
	{0x000E61, "MICROTROL LIMITED"},
	{0x000E62, "Nortel Networks"},
	{0x000E63, "Lemke Diagnostics GmbH"},
	{0x000E64, "Elphel, Inc"},
	{0x000E65, "TransCore"},
	{0x000E66, "Hitachi Advanced Digital, Inc."},
	{0x000E67, "Eltis Microelectronics Ltd."},
	{0x000E68, "E-TOP Network Technology Inc."},
	{0x000E69, "China Electric Power Research Institute"},
	{0x000E6A, "3Com Ltd"},
	{0x000E6B, "Janitza electronics GmbH"},
	{0x000E6C, "Device Drivers Limited"},
	{0x000E6D, "Murata Manufacturing Co., Ltd."},
	{0x000E6E, "MICRELEC  ELECTRONICS S.A"},
	{0x000E6F, "IRIS Corporation Berhad"},
	{0x000E70, "in2 Networks"},
	{0x000E71, "Gemstar Technology Development Ltd."},
	{0x000E72, "CTS electronics"},
	{0x000E73, "Tpack A/S"},
	{0x000E74, "Solar Telecom. Tech"},
	{0x000E75, "New York Air Brake Corp."},
	{0x000E76, "GEMSOC INNOVISION INC."},
	{0x000E77, "Decru, Inc."},
	{0x000E78, "Amtelco"},
	{0x000E79, "Ample Communications Inc."},
	{0x000E7A, "GemWon Communications Co., Ltd."},
	{0x000E7B, "Toshiba"},
	{0x000E7C, "Televes S.A."},
	{0x000E7D, "Electronics Line 3000 Ltd."},
	{0x000E7E, "ionSign Oy"},
	{0x000E7F, "Hewlett Packard"},
	{0x000E80, "Thomson Technology Inc"},
	{0x000E81, "Devicescape Software, Inc."},
	{0x000E82, "Commtech Wireless"},
	{0x000E83, "Cisco Systems"},
	{0x000E84, "Cisco Systems"},
	{0x000E85, "Catalyst Enterprises, Inc."},
	{0x000E86, "Alcatel North America"},
	{0x000E87, "adp Gauselmann GmbH"},
	{0x000E88, "VIDEOTRON CORP."},
	{0x000E89, "CLEMATIC"},
	{0x000E8A, "Avara Technologies Pty. Ltd."},
	{0x000E8B, "Astarte Technology Co, Ltd."},
	{0x000E8C, "Siemens AG A&D ET"},
	{0x000E8D, "Systems in Progress Holding GmbH"},
	{0x000E8E, "SparkLAN Communications, Inc."},
	{0x000E8F, "Sercomm Corp."},
	{0x000E90, "PONICO CORP."},
	{0x000E91, "Navico Auckland Ltd"},
	{0x000E92, "Millinet Co., Ltd."},
	{0x000E93, "Milnio 3 Sistemas Electrnicos, Lda."},
	{0x000E94, "Maas International BV"},
	{0x000E95, "Fujiya Denki Seisakusho Co.,Ltd."},
	{0x000E96, "Cubic Defense Applications, Inc."},
	{0x000E97, "Ultracker Technology CO., Inc"},
	{0x000E98, "Vitec CC, INC."},
	{0x000E99, "Spectrum Digital, Inc"},
	{0x000E9A, "BOE TECHNOLOGY GROUP CO.,LTD"},
	{0x000E9B, "Ambit Microsystems Corporation"},
	{0x000E9C, "Pemstar"},
	{0x000E9D, "Tiscali UK Ltd"},
	{0x000E9E, "Topfield Co., Ltd"},
	{0x000E9F, "TEMIC SDS GmbH"},
	{0x000EA0, "NetKlass Technology Inc."},
	{0x000EA1, "Formosa Teletek Corporation"},
	{0x000EA2, "McAfee, Inc"},
	{0x000EA3, "CNCR-IT CO.,LTD,HangZhou P.R.CHINA"},
	{0x000EA4, "Certance Inc."},
	{0x000EA5, "BLIP Systems"},
	{0x000EA6, "ASUSTEK COMPUTER INC."},
	{0x000EA7, "Endace Technology"},
	{0x000EA8, "United Technologists Europe Limited"},
	{0x000EA9, "Shanghai Xun Shi Communications Equipment Ltd. Co."},
	{0x000EAA, "Scalent Systems, Inc."},
	{0x000EAB, "Cray Inc"},
	{0x000EAC, "MINTRON ENTERPRISE CO., LTD."},
	{0x000EAD, "Metanoia Technologies, Inc."},
	{0x000EAE, "GAWELL TECHNOLOGIES CORP."},
	{0x000EAF, "CASTEL"},
	{0x000EB0, "Solutions Radio BV"},
	{0x000EB1, "Newcotech,Ltd"},
	{0x000EB2, "Micro-Research Finland Oy"},
	{0x000EB3, "Hewlett-Packard"},
	{0x000EB4, "GUANGZHOU GAOKE COMMUNICATIONS TECHNOLOGY CO.LTD."},
	{0x000EB5, "Ecastle Electronics Co., Ltd."},
	{0x000EB6, "Riverbed Technology, Inc."},
	{0x000EB7, "Knovative, Inc."},
	{0x000EB8, "Iiga co.,Ltd"},
	{0x000EB9, "HASHIMOTO Electronics Industry Co.,Ltd."},
	{0x000EBA, "HANMI SEMICONDUCTOR CO., LTD."},
	{0x000EBB, "Everbee Networks"},
	{0x000EBC, "Paragon Fidelity GmbH"},
	{0x000EBD, "Burdick, a Quinton Compny"},
	{0x000EBE, "B&B Electronics Manufacturing Co."},
	{0x000EBF, "Remsdaq Limited"},
	{0x000EC0, "Nortel Networks"},
	{0x000EC1, "MYNAH Technologies"},
	{0x000EC2, "Lowrance Electronics, Inc."},
	{0x000EC3, "Logic Controls, Inc."},
	{0x000EC4, "Iskra Transmission d.d."},
	{0x000EC5, "Digital Multitools Inc"},
	{0x000EC6, "ASIX ELECTRONICS CORP."},
	{0x000EC7, "Motorola Korea"},
	{0x000EC8, "Zoran Corporation"},
	{0x000EC9, "YOKO Technology Corp."},
	{0x000ECA, "WTSS Inc"},
	{0x000ECB, "VineSys Technology"},
	{0x000ECC, "Tableau, LLC"},
	{0x000ECD, "SKOV A/S"},
	{0x000ECE, "S.I.T.T.I. S.p.A."},
	{0x000ECF, "PROFIBUS Nutzerorganisation e.V."},
	{0x000ED0, "Privaris, Inc."},
	{0x000ED1, "Osaka Micro Computer."},
	{0x000ED2, "Filtronic plc"},
	{0x000ED3, "Epicenter, Inc."},
	{0x000ED4, "CRESITT INDUSTRIE"},
	{0x000ED5, "COPAN Systems Inc."},
	{0x000ED6, "Cisco Systems"},
	{0x000ED7, "Cisco Systems"},
	{0x000ED8, "Aktino, Inc."},
	{0x000ED9, "Aksys, Ltd."},
	{0x000EDA, "C-TECH UNITED CORP."},
	{0x000EDB, "XiNCOM Corp."},
	{0x000EDC, "Tellion INC."},
	{0x000EDD, "SHURE INCORPORATED"},
	{0x000EDE, "REMEC, Inc."},
	{0x000EDF, "PLX Technology"},
	{0x000EE0, "Mcharge"},
	{0x000EE1, "ExtremeSpeed Inc."},
	{0x000EE2, "Custom Engineering S.p.A."},
	{0x000EE3, "Chiyu Technology Co.,Ltd"},
	{0x000EE4, "BOE TECHNOLOGY GROUP CO.,LTD"},
	{0x000EE5, "bitWallet, Inc."},
	{0x000EE6, "Adimos Systems LTD"},
	{0x000EE7, "AAC ELECTRONICS CORP."},
	{0x000EE8, "zioncom"},
	{0x000EE9, "WayTech Development, Inc."},
	{0x000EEA, "Shadong Luneng Jicheng Electronics,Co.,Ltd"},
	{0x000EEB, "Sandmartin(zhong shan)Electronics Co.,Ltd"},
	{0x000EEC, "Orban"},
	{0x000EED, "Nokia Danmark A/S"},
	{0x000EEE, "Muco Industrie BV"},
	{0x000EF0, "Festo AG & Co. KG"},
	{0x000EF1, "EZQUEST INC."},
	{0x000EF2, "Infinico Corporation"},
	{0x000EF3, "Smarthome"},
	{0x000EF4, "Kasda Digital Technology Co.,Ltd"},
	{0x000EF5, "iPAC Technology Co., Ltd."},
	{0x000EF6, "E-TEN Information Systems Co., Ltd."},
	{0x000EF7, "Vulcan Portals Inc"},
	{0x000EF8, "SBC ASI"},
	{0x000EF9, "REA Elektronik GmbH"},
	{0x000EFA, "Optoway Technology Incorporation"},
	{0x000EFB, "Macey Enterprises"},
	{0x000EFC, "JTAG Technologies B.V."},
	{0x000EFD, "FUJINON CORPORATION"},
	{0x000EFE, "EndRun Technologies LLC"},
	{0x000EFF, "Megasolution,Inc."},
	{0x000F00, "Legra Systems, Inc."},
	{0x000F01, "DIGITALKS INC"},
	{0x000F02, "Digicube Technology Co., Ltd"},
	{0x000F03, "COM&C CO., LTD"},
	{0x000F04, "cim-usa inc"},
	{0x000F05, "3B SYSTEM INC."},
	{0x000F06, "Nortel Networks"},
	{0x000F07, "Mangrove Systems, Inc."},
	{0x000F08, "Indagon Oy"},
	{0x000F0A, "Clear Edge Networks"},
	{0x000F0B, "Kentima Technologies AB"},
	{0x000F0C, "SYNCHRONIC ENGINEERING"},
	{0x000F0D, "Hunt Electronic Co., Ltd."},
	{0x000F0E, "WaveSplitter Technologies, Inc."},
	{0x000F0F, "Real ID Technology Co., Ltd."},
	{0x000F10, "RDM Corporation"},
	{0x000F11, "Prodrive B.V."},
	{0x000F12, "Panasonic Europe Ltd."},
	{0x000F13, "Nisca corporation"},
	{0x000F14, "Mindray Co., Ltd."},
	{0x000F15, "Kjaerulff1 A/S"},
	{0x000F16, "JAY HOW TECHNOLOGY CO.,"},
	{0x000F17, "Insta Elektro GmbH"},
	{0x000F18, "Industrial Control Systems"},
	{0x000F19, "Boston Scientific"},
	{0x000F1A, "Gaming Support B.V."},
	{0x000F1B, "Ego Systems Inc."},
	{0x000F1C, "DigitAll World Co., Ltd"},
	{0x000F1D, "Cosmo Techs Co., Ltd."},
	{0x000F1E, "Chengdu KT Electric Co.of High & New Technology"},
	{0x000F1F, "WW PCBA Test"},
	{0x000F20, "Hewlett Packard"},
	{0x000F21, "Scientific Atlanta, Inc"},
	{0x000F22, "Helius, Inc."},
	{0x000F23, "Cisco Systems"},
	{0x000F24, "Cisco Systems"},
	{0x000F25, "AimValley B.V."},
	{0x000F26, "WorldAccxx  LLC"},
	{0x000F27, "TEAL Electronics, Inc."},
	{0x000F28, "Itronix Corporation"},
	{0x000F29, "Augmentix Corporation"},
	{0x000F2A, "Cableware Electronics"},
	{0x000F2B, "GREENBELL SYSTEMS"},
	{0x000F2C, "Uplogix, Inc."},
	{0x000F2D, "CHUNG-HSIN ELECTRIC & MACHINERY MFG.CORP."},
	{0x000F2E, "Megapower International Corp."},
	{0x000F2F, "W-LINX TECHNOLOGY CO., LTD."},
	{0x000F30, "Raza Microelectronics Inc"},
	{0x000F31, "Allied Vision Technologies Canada Inc"},
	{0x000F32, "LuTong Electronic Technology Co.,Ltd"},
	{0x000F33, "DUALi Inc."},
	{0x000F34, "Cisco Systems"},
	{0x000F35, "Cisco Systems"},
	{0x000F36, "Accurate Techhnologies, Inc."},
	{0x000F37, "Xambala Incorporated"},
	{0x000F38, "Netstar"},
	{0x000F39, "IRIS SENSORS"},
	{0x000F3A, "HISHARP"},
	{0x000F3B, "Fuji System Machines Co., Ltd."},
	{0x000F3C, "Endeleo Limited"},
	{0x000F3D, "D-Link Corporation"},
	{0x000F3E, "CardioNet, Inc"},
	{0x000F3F, "Big Bear Networks"},
	{0x000F40, "Optical Internetworking Forum"},
	{0x000F41, "Zipher Ltd"},
	{0x000F42, "Xalyo Systems"},
	{0x000F43, "Wasabi Systems Inc."},
	{0x000F44, "Tivella Inc."},
	{0x000F45, "Stretch, Inc."},
	{0x000F46, "SINAR AG"},
	{0x000F47, "ROBOX SPA"},
	{0x000F48, "Polypix Inc."},
	{0x000F49, "Northover Solutions Limited"},
	{0x000F4A, "Kyushu-kyohan co.,ltd"},
	{0x000F4B, "Virtual Iron Software, Inc."},
	{0x000F4C, "Elextech INC"},
	{0x000F4D, "TalkSwitch"},
	{0x000F4E, "Cellink"},
	{0x000F4F, "Cadmus Technology Ltd"},
	{0x000F50, "StreamScale Limited"},
	{0x000F51, "Azul Systems, Inc."},
	{0x000F52, "YORK Refrigeration, Marine & Controls"},
	{0x000F53, "Solarflare Communications Inc"},
	{0x000F54, "Entrelogic Corporation"},
	{0x000F55, "Datawire Communication Networks Inc."},
	{0x000F56, "Continuum Photonics Inc"},
	{0x000F57, "CABLELOGIC Co., Ltd."},
	{0x000F58, "Adder Technology Limited"},
	{0x000F59, "Phonak Communications AG"},
	{0x000F5A, "Peribit Networks"},
	{0x000F5B, "Delta Information Systems, Inc."},
	{0x000F5C, "Day One Digital Media Limited"},
	{0x000F5D, "42Networks AB"},
	{0x000F5E, "Veo"},
	{0x000F5F, "Nicety Technologies Inc. (NTS)"},
	{0x000F60, "Lifetron Co.,Ltd"},
	{0x000F61, "Hewlett Packard"},
	{0x000F62, "Alcatel Bell Space N.V."},
	{0x000F63, "Obzerv Technologies"},
	{0x000F64, "D&R Electronica Weesp BV"},
	{0x000F65, "icube Corp."},
	{0x000F66, "Cisco-Linksys"},
	{0x000F67, "West Instruments"},
	{0x000F68, "Vavic Network Technology, Inc."},
	{0x000F69, "SEW Eurodrive GmbH & Co. KG"},
	{0x000F6A, "Nortel Networks"},
	{0x000F6B, "GateWare Communications GmbH"},
	{0x000F6C, "ADDI-DATA GmbH"},
	{0x000F6D, "Midas Engineering"},
	{0x000F6E, "BBox"},
	{0x000F6F, "FTA Communication Technologies"},
	{0x000F70, "Wintec Industries, inc."},
	{0x000F71, "Sanmei Electronics Co.,Ltd"},
	{0x000F72, "Sandburst"},
	{0x000F73, "Rockwell  Automation Korea"},
	{0x000F74, "Qamcom Technology AB"},
	{0x000F75, "First Silicon Solutions"},
	{0x000F76, "Digital Keystone, Inc."},
	{0x000F77, "DENTUM CO.,LTD"},
	{0x000F78, "Datacap Systems Inc"},
	{0x000F79, "Bluetooth Interest Group Inc."},
	{0x000F7A, "BeiJing NuQX Technology CO.,LTD"},
	{0x000F7B, "Arce Sistemas, S.A."},
	{0x000F7C, "ACTi Corporation"},
	{0x000F7D, "Xirrus"},
	{0x000F7E, "Ablerex Electronics Co., LTD"},
	{0x000F7F, "UBSTORAGE Co.,Ltd."},
	{0x000F80, "Trinity Security Systems,Inc."},
	{0x000F81, "Secure Info Imaging"},
	{0x000F82, "Mortara Instrument, Inc."},
	{0x000F83, "Brainium Technologies Inc."},
	{0x000F84, "Astute Networks, Inc."},
	{0x000F85, "ADDO-Japan Corporation"},
	{0x000F86, "Research In Motion Limited"},
	{0x000F87, "Maxcess International"},
	{0x000F88, "AMETEK, Inc."},
	{0x000F89, "Winnertec System Co., Ltd."},
	{0x000F8A, "WideView"},
	{0x000F8B, "Orion MultiSystems Inc"},
	{0x000F8C, "Gigawavetech Pte Ltd"},
	{0x000F8D, "FAST TV-Server AG"},
	{0x000F8E, "DONGYANG TELECOM CO.,LTD."},
	{0x000F8F, "Cisco Systems"},
	{0x000F90, "Cisco Systems"},
	{0x000F91, "Aerotelecom Co.,Ltd."},
	{0x000F92, "Microhard Systems Inc."},
	{0x000F93, "Landis+Gyr Ltd."},
	{0x000F94, "Genexis"},
	{0x000F95, "ELECOM Co.,LTD Laneed Division"},
	{0x000F96, "Critical Telecom Corp."},
	{0x000F97, "Avanex Corporation"},
	{0x000F98, "Avamax Co. Ltd."},
	{0x000F99, "APAC opto Electronics Inc."},
	{0x000F9A, "Synchrony, Inc."},
	{0x000F9B, "Ross Video Limited"},
	{0x000F9C, "Panduit Corp"},
	{0x000F9D, "DisplayLink (UK) Ltd"},
	{0x000F9E, "Murrelektronik GmbH"},
	{0x000F9F, "Motorola BCS"},
	{0x000FA0, "CANON KOREA BUSINESS SOLUTIONS INC."},
	{0x000FA1, "Gigabit Systems Inc."},
	{0x000FA2, "Digital Path Networks"},
	{0x000FA3, "Alpha Networks Inc."},
	{0x000FA4, "Sprecher Automation GmbH"},
	{0x000FA5, "SMP / BWA Technology GmbH"},
	{0x000FA6, "S2 Security Corporation"},
	{0x000FA7, "Raptor Networks Technology"},
	{0x000FA8, "Photometrics, Inc."},
	{0x000FA9, "PC Fabrik"},
	{0x000FAA, "Nexus Technologies"},
	{0x000FAB, "Kyushu Electronics Systems Inc."},
	{0x000FAC, "IEEE 802.11"},
	{0x000FAD, "FMN communications GmbH"},
	{0x000FAE, "E2O Communications"},
	{0x000FAF, "Dialog Inc."},
	{0x000FB0, "Compal Electronics,INC."},
	{0x000FB1, "Cognio Inc."},
	{0x000FB2, "Broadband Pacenet (India) Pvt. Ltd."},
	{0x000FB3, "Actiontec Electronics, Inc"},
	{0x000FB4, "Timespace Technology"},
	{0x000FB5, "NETGEAR Inc"},
	{0x000FB6, "Europlex Technologies"},
	{0x000FB7, "Cavium Networks"},
	{0x000FB8, "CallURL Inc."},
	{0x000FB9, "Adaptive Instruments"},
	{0x000FBA, "Tevebox AB"},
	{0x000FBB, "Nokia Siemens Networks GmbH & Co. KG"},
	{0x000FBC, "Onkey Technologies, Inc."},
	{0x000FBD, "MRV Communications (Networks) LTD"},
	{0x000FBE, "e-w/you Inc."},
	{0x000FBF, "DGT Sp. z o.o."},
	{0x000FC0, "DELCOMp"},
	{0x000FC1, "WAVE Corporation"},
	{0x000FC2, "Uniwell Corporation"},
	{0x000FC3, "PalmPalm Technology, Inc."},
	{0x000FC4, "NST co.,LTD."},
	{0x000FC5, "KeyMed Ltd"},
	{0x000FC6, "Eurocom Industries A/S"},
	{0x000FC7, "Dionica R&D Ltd."},
	{0x000FC8, "Chantry Networks"},
	{0x000FC9, "Allnet GmbH"},
	{0x000FCA, "A-JIN TECHLINE CO, LTD"},
	{0x000FCB, "3Com Ltd"},
	{0x000FCC, "Netopia, Inc."},
	{0x000FCD, "Nortel Networks"},
	{0x000FCE, "Kikusui Electronics Corp."},
	{0x000FCF, "Datawind Research"},
	{0x000FD0, "ASTRI"},
	{0x000FD1, "Applied Wireless Identifications Group, Inc."},
	{0x000FD2, "EWA Technologies, Inc."},
	{0x000FD3, "Digium"},
	{0x000FD4, "Soundcraft"},
	{0x000FD5, "Schwechat - RISE"},
	{0x000FD6, "Sarotech Co., Ltd"},
	{0x000FD7, "Harman Music Group"},
	{0x000FD8, "Force, Inc."},
	{0x000FD9, "FlexDSL Telecommunications AG"},
	{0x000FDA, "YAZAKI CORPORATION"},
	{0x000FDB, "Westell Technologies"},
	{0x000FDC, "Ueda Japan  Radio Co., Ltd."},
	{0x000FDD, "SORDIN AB"},
	{0x000FDE, "Sony Ericsson Mobile Communications AB"},
	{0x000FDF, "SOLOMON Technology Corp."},
	{0x000FE0, "NComputing Co.,Ltd."},
	{0x000FE1, "ID DIGITAL CORPORATION"},
	{0x000FE2, "Hangzhou H3C Technologies Co., Ltd."},
	{0x000FE3, "Damm Cellular Systems A/S"},
	{0x000FE4, "Pantech Co.,Ltd"},
	{0x000FE5, "MERCURY SECURITY CORPORATION"},
	{0x000FE6, "MBTech Systems, Inc."},
	{0x000FE7, "Lutron Electronics Co., Inc."},
	{0x000FE8, "Lobos, Inc."},
	{0x000FE9, "GW TECHNOLOGIES CO.,LTD."},
	{0x000FEA, "Giga-Byte Technology Co.,LTD."},
	{0x000FEB, "Cylon Controls"},
	{0x000FEC, "Arkus Inc."},
	{0x000FED, "Anam Electronics Co., Ltd"},
	{0x000FEE, "XTec, Incorporated"},
	{0x000FEF, "Thales e-Transactions GmbH"},
	{0x000FF0, "Sunray Co. Ltd."},
	{0x000FF1, "nex-G Systems Pte.Ltd"},
	{0x000FF2, "Loud Technologies Inc."},
	{0x000FF3, "Jung Myoung Communications&Technology"},
	{0x000FF4, "Guntermann & Drunck GmbH"},
	{0x000FF5, "GN&S company"},
	{0x000FF6, "Darfon Electronics Corp."},
	{0x000FF7, "Cisco Systems"},
	{0x000FF8, "Cisco  Systems"},
	{0x000FF9, "Valcretec, Inc."},
	{0x000FFA, "Optinel Systems, Inc."},
	{0x000FFB, "Nippon Denso Industry Co., Ltd."},
	{0x000FFC, "Merit Li-Lin Ent."},
	{0x000FFD, "Glorytek Network Inc."},
	{0x000FFE, "G-PRO COMPUTER"},
	{0x000FFF, "Control4"},
	{0x001000, "CABLE TELEVISION LABORATORIES, INC."},
	{0x001001, "Citel"},
	{0x001002, "ACTIA"},
	{0x001003, "IMATRON, INC."},
	{0x001004, "THE BRANTLEY COILE COMPANY,INC"},
	{0x001005, "UEC COMMERCIAL"},
	{0x001006, "Thales Contact Solutions Ltd."},
	{0x001007, "CISCO SYSTEMS, INC."},
	{0x001008, "VIENNA SYSTEMS CORPORATION"},
	{0x001009, "HORO QUARTZ"},
	{0x00100A, "WILLIAMS COMMUNICATIONS GROUP"},
	{0x00100B, "CISCO SYSTEMS, INC."},
	{0x00100C, "ITO CO., LTD."},
	{0x00100D, "CISCO SYSTEMS, INC."},
	{0x00100E, "MICRO LINEAR COPORATION"},
	{0x00100F, "INDUSTRIAL CPU SYSTEMS"},
	{0x001010, "INITIO CORPORATION"},
	{0x001011, "CISCO SYSTEMS, INC."},
	{0x001012, "PROCESSOR SYSTEMS (I) PVT LTD"},
	{0x001013, "Kontron America, Inc."},
	{0x001014, "CISCO SYSTEMS, INC."},
	{0x001015, "OOmon Inc."},
	{0x001016, "T.SQWARE"},
	{0x001017, "Bosch Access Systems GmbH"},
	{0x001018, "BROADCOM CORPORATION"},
	{0x001019, "SIRONA DENTAL SYSTEMS GmbH & Co. KG"},
	{0x00101A, "PictureTel Corp."},
	{0x00101B, "CORNET TECHNOLOGY, INC."},
	{0x00101C, "OHM TECHNOLOGIES INTL, LLC"},
	{0x00101D, "WINBOND ELECTRONICS CORP."},
	{0x00101E, "MATSUSHITA ELECTRONIC INSTRUMENTS CORP."},
	{0x00101F, "CISCO SYSTEMS, INC."},
	{0x001020, "Hand Held Products Inc"},
	{0x001021, "ENCANTO NETWORKS, INC."},
	{0x001022, "SatCom Media Corporation"},
	{0x001023, "Network Equipment Technologies"},
	{0x001024, "NAGOYA ELECTRIC WORKS CO., LTD"},
	{0x001025, "Grayhill, Inc"},
	{0x001026, "ACCELERATED NETWORKS, INC."},
	{0x001027, "L-3 COMMUNICATIONS EAST"},
	{0x001028, "COMPUTER TECHNICA, INC."},
	{0x001029, "CISCO SYSTEMS, INC."},
	{0x00102A, "ZF MICROSYSTEMS, INC."},
	{0x00102B, "UMAX DATA SYSTEMS, INC."},
	{0x00102C, "Lasat Networks A/S"},
	{0x00102D, "HITACHI SOFTWARE ENGINEERING"},
	{0x00102E, "NETWORK SYSTEMS & TECHNOLOGIES PVT. LTD."},
	{0x00102F, "CISCO SYSTEMS, INC."},
	{0x001030, "EION Inc."},
	{0x001031, "OBJECTIVE COMMUNICATIONS, INC."},
	{0x001032, "ALTA TECHNOLOGY"},
	{0x001033, "ACCESSLAN COMMUNICATIONS, INC."},
	{0x001034, "GNP Computers"},
	{0x001035, "ELITEGROUP COMPUTER SYSTEMS CO., LTD"},
	{0x001036, "INTER-TEL INTEGRATED SYSTEMS"},
	{0x001037, "CYQ've Technology Co., Ltd."},
	{0x001038, "MICRO RESEARCH INSTITUTE, INC."},
	{0x001039, "Vectron Systems AG"},
	{0x00103A, "DIAMOND NETWORK TECH"},
	{0x00103B, "HIPPI NETWORKING FORUM"},
	{0x00103C, "IC ENSEMBLE, INC."},
	{0x00103D, "PHASECOM, LTD."},
	{0x00103E, "NETSCHOOLS CORPORATION"},
	{0x00103F, "TOLLGRADE COMMUNICATIONS, INC."},
	{0x001040, "INTERMEC CORPORATION"},
	{0x001041, "BRISTOL BABCOCK, INC."},
	{0x001042, "Alacritech, Inc."},
	{0x001043, "A2 CORPORATION"},
	{0x001044, "InnoLabs Corporation"},
	{0x001045, "Nortel Networks"},
	{0x001046, "ALCORN MCBRIDE INC."},
	{0x001047, "ECHO ELETRIC CO. LTD."},
	{0x001048, "HTRC AUTOMATION, INC."},
	{0x001049, "ShoreTel, Inc"},
	{0x00104A, "The Parvus Corporation"},
	{0x00104B, "3COM CORPORATION"},
	{0x00104C, "LeCroy Corporation"},
	{0x00104D, "SURTEC INDUSTRIES, INC."},
	{0x00104E, "CEOLOGIC"},
	{0x00104F, "Sun Microsystems, Inc."},
	{0x001050, "RION CO., LTD."},
	{0x001051, "CMICRO CORPORATION"},
	{0x001052, "METTLER-TOLEDO (ALBSTADT) GMBH"},
	{0x001053, "COMPUTER TECHNOLOGY CORP."},
	{0x001054, "CISCO SYSTEMS, INC."},
	{0x001055, "FUJITSU MICROELECTRONICS, INC."},
	{0x001056, "SODICK CO., LTD."},
	{0x001057, "Rebel.com, Inc."},
	{0x001058, "ArrowPoint Communications"},
	{0x001059, "DIABLO RESEARCH CO. LLC"},
	{0x00105A, "3COM CORPORATION"},
	{0x00105B, "NET INSIGHT AB"},
	{0x00105C, "QUANTUM DESIGNS (H.K.) LTD."},
	{0x00105D, "Draeger Medical"},
	{0x00105E, "HEKIMIAN LABORATORIES, INC."},
	{0x00105F, "IN-SNEC"},
	{0x001060, "BILLIONTON SYSTEMS, INC."},
	{0x001061, "HOSTLINK CORP."},
	{0x001062, "NX SERVER, ILNC."},
	{0x001063, "STARGUIDE DIGITAL NETWORKS"},
	{0x001064, "DNPG, LLC"},
	{0x001065, "RADYNE CORPORATION"},
	{0x001066, "ADVANCED CONTROL SYSTEMS, INC."},
	{0x001067, "REDBACK NETWORKS, INC."},
	{0x001068, "COMOS TELECOM"},
	{0x001069, "HELIOSS COMMUNICATIONS, INC."},
	{0x00106A, "DIGITAL MICROWAVE CORPORATION"},
	{0x00106B, "SONUS NETWORKS, INC."},
	{0x00106C, "Infratec AG"},
	{0x00106D, "Axxcelera Broadband Wireless"},
	{0x00106E, "TADIRAN COM. LTD."},
	{0x00106F, "TRENTON TECHNOLOGY INC."},
	{0x001070, "CARADON TREND LTD."},
	{0x001071, "ADVANET INC."},
	{0x001072, "GVN TECHNOLOGIES, INC."},
	{0x001073, "Technobox, Inc."},
	{0x001074, "ATEN INTERNATIONAL CO., LTD."},
	{0x001075, "Maxtor Corporation"},
	{0x001076, "EUREM GmbH"},
	{0x001077, "SAF DRIVE SYSTEMS, LTD."},
	{0x001078, "NUERA COMMUNICATIONS, INC."},
	{0x001079, "CISCO SYSTEMS, INC."},
	{0x00107A, "AmbiCom, Inc."},
	{0x00107B, "CISCO SYSTEMS, INC."},
	{0x00107C, "P-COM, INC."},
	{0x00107D, "AURORA COMMUNICATIONS, LTD."},
	{0x00107E, "BACHMANN ELECTRONIC GmbH"},
	{0x00107F, "CRESTRON ELECTRONICS, INC."},
	{0x001080, "METAWAVE COMMUNICATIONS"},
	{0x001081, "DPS, INC."},
	{0x001082, "JNA TELECOMMUNICATIONS LIMITED"},
	{0x001083, "HEWLETT-PACKARD COMPANY"},
	{0x001084, "K-BOT COMMUNICATIONS"},
	{0x001085, "POLARIS COMMUNICATIONS, INC."},
	{0x001086, "ATTO Technology, Inc."},
	{0x001087, "Xstreamis PLC"},
	{0x001088, "AMERICAN NETWORKS INC."},
	{0x001089, "WebSonic"},
	{0x00108A, "TeraLogic, Inc."},
	{0x00108B, "LASERANIMATION SOLLINGER GmbH"},
	{0x00108C, "FUJITSU TELECOMMUNICATIONS EUROPE, LTD."},
	{0x00108D, "Johnson Controls, Inc."},
	{0x00108E, "HUGH SYMONS CONCEPT Technologies Ltd."},
	{0x00108F, "RAPTOR SYSTEMS"},
	{0x001090, "CIMETRICS, INC."},
	{0x001091, "NO WIRES NEEDED BV"},
	{0x001092, "NETCORE INC."},
	{0x001093, "CMS COMPUTERS, LTD."},
	{0x001094, "Performance Analysis Broadband, Spirent plc"},
	{0x001095, "Thomson Inc."},
	{0x001096, "TRACEWELL SYSTEMS, INC."},
	{0x001097, "WinNet Metropolitan Communications Systems, Inc."},
	{0x001098, "STARNET TECHNOLOGIES, INC."},
	{0x001099, "InnoMedia, Inc."},
	{0x00109A, "NETLINE"},
	{0x00109B, "Emulex Corporation"},
	{0x00109C, "M-SYSTEM CO., LTD."},
	{0x00109D, "CLARINET SYSTEMS, INC."},
	{0x00109E, "AWARE, INC."},
	{0x00109F, "PAVO, INC."},
	{0x0010A0, "INNOVEX TECHNOLOGIES, INC."},
	{0x0010A1, "KENDIN SEMICONDUCTOR, INC."},
	{0x0010A2, "TNS"},
	{0x0010A3, "OMNITRONIX, INC."},
	{0x0010A4, "XIRCOM"},
	{0x0010A5, "OXFORD INSTRUMENTS"},
	{0x0010A6, "CISCO SYSTEMS, INC."},
	{0x0010A7, "UNEX TECHNOLOGY CORPORATION"},
	{0x0010A8, "RELIANCE COMPUTER CORP."},
	{0x0010A9, "ADHOC TECHNOLOGIES"},
	{0x0010AA, "MEDIA4, INC."},
	{0x0010AB, "KOITO INDUSTRIES, LTD."},
	{0x0010AC, "IMCI TECHNOLOGIES"},
	{0x0010AD, "SOFTRONICS USB, INC."},
	{0x0010AE, "SHINKO ELECTRIC INDUSTRIES CO."},
	{0x0010AF, "TAC SYSTEMS, INC."},
	{0x0010B0, "MERIDIAN TECHNOLOGY CORP."},
	{0x0010B1, "FOR-A CO., LTD."},
	{0x0010B2, "COACTIVE AESTHETICS"},
	{0x0010B3, "NOKIA MULTIMEDIA TERMINALS"},
	{0x0010B4, "ATMOSPHERE NETWORKS"},
	{0x0010B5, "ACCTON TECHNOLOGY CORPORATION"},
	{0x0010B6, "ENTRATA COMMUNICATIONS CORP."},
	{0x0010B7, "COYOTE TECHNOLOGIES, LLC"},
	{0x0010B8, "ISHIGAKI COMPUTER SYSTEM CO."},
	{0x0010B9, "MAXTOR CORP."},
	{0x0010BA, "MARTINHO-DAVIS SYSTEMS, INC."},
	{0x0010BB, "DATA & INFORMATION TECHNOLOGY"},
	{0x0010BC, "Aastra Telecom"},
	{0x0010BD, "THE TELECOMMUNICATION TECHNOLOGY COMMITTEE"},
	{0x0010BE, "TELEXIS CORP."},
	{0x0010BF, "InterAir Wireless"},
	{0x0010C0, "ARMA, Inc."},
	{0x0010C1, "OI ELECTRIC CO., LTD."},
	{0x0010C2, "WILLNET, INC."},
	{0x0010C3, "CSI-CONTROL SYSTEMS"},
	{0x0010C4, "MEDIA LINKS CO., LTD."},
	{0x0010C5, "PROTOCOL TECHNOLOGIES, INC."},
	{0x0010C6, "USI"},
	{0x0010C7, "DATA TRANSMISSION NETWORK"},
	{0x0010C8, "COMMUNICATIONS ELECTRONICS SECURITY GROUP"},
	{0x0010C9, "MITSUBISHI ELECTRONICS LOGISTIC SUPPORT CO."},
	{0x0010CA, "INTEGRAL ACCESS"},
	{0x0010CB, "FACIT K.K."},
	{0x0010CC, "CLP COMPUTER LOGISTIK PLANUNG GmbH"},
	{0x0010CD, "INTERFACE CONCEPT"},
	{0x0010CE, "VOLAMP, LTD."},
	{0x0010CF, "FIBERLANE COMMUNICATIONS"},
	{0x0010D0, "WITCOM, LTD."},
	{0x0010D1, "Top Layer Networks, Inc."},
	{0x0010D2, "NITTO TSUSHINKI CO., LTD"},
	{0x0010D3, "GRIPS ELECTRONIC GMBH"},
	{0x0010D4, "STORAGE COMPUTER CORPORATION"},
	{0x0010D5, "IMASDE CANARIAS, S.A."},
	{0x0010D6, "ITT - A/CD"},
	{0x0010D7, "ARGOSY RESEARCH INC."},
	{0x0010D8, "CALISTA"},
	{0x0010D9, "IBM JAPAN, FUJISAWA MT+D"},
	{0x0010DA, "MOTION ENGINEERING, INC."},
	{0x0010DB, "Juniper Networks, Inc."},
	{0x0010DC, "MICRO-STAR INTERNATIONAL CO., LTD."},
	{0x0010DD, "ENABLE SEMICONDUCTOR, INC."},
	{0x0010DE, "INTERNATIONAL DATACASTING CORPORATION"},
	{0x0010DF, "RISE COMPUTER INC."},
	{0x0010E0, "Sun Microsystems, Inc."},
	{0x0010E1, "S.I. TECH, INC."},
	{0x0010E2, "ArrayComm, Inc."},
	{0x0010E3, "Hewlett Packard"},
	{0x0010E4, "NSI CORPORATION"},
	{0x0010E5, "SOLECTRON TEXAS"},
	{0x0010E6, "APPLIED INTELLIGENT SYSTEMS, INC."},
	{0x0010E7, "BreezeCom"},
	{0x0010E8, "TELOCITY, INCORPORATED"},
	{0x0010E9, "RAIDTEC LTD."},
	{0x0010EA, "ADEPT TECHNOLOGY"},
	{0x0010EB, "SELSIUS SYSTEMS, INC."},
	{0x0010EC, "RPCG, LLC"},
	{0x0010ED, "SUNDANCE TECHNOLOGY, INC."},
	{0x0010EE, "CTI PRODUCTS, INC."},
	{0x0010EF, "DBTEL INCORPORATED"},
	{0x0010F1, "I-O CORPORATION"},
	{0x0010F2, "ANTEC"},
	{0x0010F3, "Nexcom International Co., Ltd."},
	{0x0010F4, "Vertical Communications"},
	{0x0010F5, "AMHERST SYSTEMS, INC."},
	{0x0010F6, "CISCO SYSTEMS, INC."},
	{0x0010F7, "IRIICHI TECHNOLOGIES Inc."},
	{0x0010F8, "Niikke Techno System Co. Ltd"},
	{0x0010F9, "UNIQUE SYSTEMS, INC."},
	{0x0010FA, "Apple Inc"},
	{0x0010FB, "ZIDA TECHNOLOGIES LIMITED"},
	{0x0010FC, "BROADBAND NETWORKS, INC."},
	{0x0010FD, "COCOM A/S"},
	{0x0010FE, "DIGITAL EQUIPMENT CORPORATION"},
	{0x0010FF, "CISCO SYSTEMS, INC."},
	{0x001100, "Schneider Electric"},
	{0x001101, "CET Technologies Pte Ltd"},
	{0x001102, "Aurora Multimedia Corp."},
	{0x001103, "kawamura electric inc."},
	{0x001104, "TELEXY"},
	{0x001105, "Sunplus Technology Co., Ltd."},
	{0x001106, "Siemens NV (Belgium)"},
	{0x001107, "RGB Networks Inc."},
	{0x001108, "Orbital Data Corporation"},
	{0x001109, "Micro-Star International"},
	{0x00110A, "Hewlett Packard"},
	{0x00110B, "Franklin Technology Systems"},
	{0x00110C, "Atmark Techno, Inc."},
	{0x00110D, "SANBlaze Technology, Inc."},
	{0x00110E, "Tsurusaki Sealand Transportation Co. Ltd."},
	{0x00110F, "netplat,Inc."},
	{0x001110, "Maxanna Technology Co., Ltd."},
	{0x001111, "Intel Corporation"},
	{0x001112, "Honeywell CMSS"},
	{0x001113, "Fraunhofer FOKUS"},
	{0x001114, "EverFocus Electronics Corp."},
	{0x001115, "EPIN Technologies, Inc."},
	{0x001116, "COTEAU VERT CO., LTD."},
	{0x001117, "CESNET"},
	{0x001118, "BLX IC Design Corp., Ltd."},
	{0x001119, "Solteras, Inc."},
	{0x00111A, "Motorola BCS"},
	{0x00111B, "Targa Systems Div L-3 Communications Canada"},
	{0x00111C, "Pleora Technologies Inc."},
	{0x00111D, "Hectrix Limited"},
	{0x00111E, "EPSG (Ethernet Powerlink Standardization Group)"},
	{0x00111F, "Doremi Labs, Inc."},
	{0x001120, "Cisco Systems"},
	{0x001121, "Cisco Systems"},
	{0x001122, "CIMSYS Inc"},
	{0x001123, "Appointech, Inc."},
	{0x001124, "Apple Computer"},
	{0x001125, "IBM Corporation"},
	{0x001126, "Venstar Inc."},
	{0x001127, "TASI, Inc"},
	{0x001128, "Streamit"},
	{0x001129, "Paradise Datacom Ltd."},
	{0x00112A, "Niko NV"},
	{0x00112B, "NetModule"},
	{0x00112C, "IZT GmbH"},
	{0x00112D, "iPulse Systems"},
	{0x00112E, "CEICOM"},
	{0x00112F, "ASUSTek Computer Inc."},
	{0x001130, "Allied Telesis (Hong Kong) Ltd."},
	{0x001131, "UNATECH. CO.,LTD"},
	{0x001132, "Synology Incorporated"},
	{0x001133, "Siemens Austria SIMEA"},
	{0x001134, "MediaCell, Inc."},
	{0x001135, "Grandeye Ltd"},
	{0x001136, "Goodrich Sensor Systems"},
	{0x001137, "AICHI ELECTRIC CO., LTD."},
	{0x001138, "TAISHIN CO., LTD."},
	{0x001139, "STOEBER ANTRIEBSTECHNIK GmbH + Co. KG."},
	{0x00113A, "SHINBORAM"},
	{0x00113B, "Micronet Communications Inc."},
	{0x00113C, "Micronas GmbH"},
	{0x00113D, "KN SOLTEC CO.,LTD."},
	{0x00113E, "JL Corporation"},
	{0x00113F, "Alcatel DI"},
	{0x001140, "Nanometrics Inc."},
	{0x001141, "GoodMan Corporation"},
	{0x001142, "e-SMARTCOM  INC."},
	{0x001143, "DELL INC."},
	{0x001144, "Assurance Technology Corp"},
	{0x001145, "ValuePoint Networks"},
	{0x001146, "Telecard-Pribor Ltd"},
	{0x001147, "Secom-Industry co.LTD."},
	{0x001148, "Prolon Control Systems"},
	{0x001149, "Proliphix Inc."},
	{0x00114A, "KAYABA INDUSTRY Co,.Ltd."},
	{0x00114B, "Francotyp-Postalia GmbH"},
	{0x00114C, "caffeina applied research ltd."},
	{0x00114D, "Atsumi Electric Co.,LTD."},
	{0x00114E, "690885 Ontario Inc."},
	{0x00114F, "US Digital Television, Inc"},
	{0x001150, "Belkin Corporation"},
	{0x001151, "Mykotronx"},
	{0x001152, "Eidsvoll Electronics AS"},
	{0x001153, "Trident Tek, Inc."},
	{0x001154, "Webpro Technologies Inc."},
	{0x001155, "Sevis Systems"},
	{0x001156, "Pharos Systems NZ"},
	{0x001157, "OF Networks Co., Ltd."},
	{0x001158, "Nortel Networks"},
	{0x001159, "MATISSE NETWORKS INC"},
	{0x00115A, "Ivoclar Vivadent AG"},
	{0x00115B, "Elitegroup Computer System Co. (ECS)"},
	{0x00115C, "Cisco"},
	{0x00115D, "Cisco"},
	{0x00115E, "ProMinent Dosiertechnik GmbH"},
	{0x00115F, "ITX Security Co., Ltd."},
	{0x001160, "ARTDIO Company Co., LTD"},
	{0x001161, "NetStreams, LLC"},
	{0x001162, "STAR MICRONICS CO.,LTD."},
	{0x001163, "SYSTEM SPA DEPT. ELECTRONICS"},
	{0x001164, "ACARD Technology Corp."},
	{0x001165, "Znyx Networks"},
	{0x001166, "Taelim Electronics Co., Ltd."},
	{0x001167, "Integrated System Solution Corp."},
	{0x001168, "HomeLogic LLC"},
	{0x001169, "EMS Satcom"},
	{0x00116A, "Domo Ltd"},
	{0x00116B, "Digital Data Communications Asia Co.,Ltd"},
	{0x00116C, "Nanwang Multimedia Inc.,Ltd"},
	{0x00116D, "American Time and Signal"},
	{0x00116E, "PePLink Ltd."},
	{0x00116F, "Netforyou Co., LTD."},
	{0x001170, "GSC SRL"},
	{0x001171, "DEXTER Communications, Inc."},
	{0x001172, "COTRON CORPORATION"},
	{0x001173, "SMART Modular Technologies"},
	{0x001174, "Wibhu Technologies, Inc."},
	{0x001175, "PathScale, Inc."},
	{0x001176, "Intellambda Systems, Inc."},
	{0x001177, "Coaxial Networks, Inc."},
	{0x001178, "Chiron Technology Ltd"},
	{0x001179, "Singular Technology Co. Ltd."},
	{0x00117A, "Singim International Corp."},
	{0x00117B, "Bchi Labortechnik AG"},
	{0x00117C, "e-zy.net"},
	{0x00117D, "ZMD America, Inc."},
	{0x00117E, "Progeny Inc."},
	{0x00117F, "Neotune Information Technology Corporation,.LTD"},
	{0x001180, "Motorola BCS"},
	{0x001181, "InterEnergy Co.Ltd,"},
	{0x001182, "IMI Norgren Ltd"},
	{0x001183, "Datalogic Mobile, Inc."},
	{0x001184, "Humo Laboratory,Ltd."},
	{0x001185, "Hewlett Packard"},
	{0x001186, "Prime Systems, Inc."},
	{0x001187, "Category Solutions, Inc"},
	{0x001188, "Enterasys"},
	{0x001189, "Aerotech Inc"},
	{0x00118A, "Viewtran Technology Limited"},
	{0x00118B, "Alcatel-Lucent, Enterprise Business Group"},
	{0x00118C, "Missouri Department of Transportation"},
	{0x00118D, "Hanchang System Corp."},
	{0x00118E, "Halytech Mace"},
	{0x00118F, "EUTECH INSTRUMENTS PTE. LTD."},
	{0x001190, "Digital Design Corporation"},
	{0x001191, "CTS-Clima Temperatur Systeme GmbH"},
	{0x001192, "Cisco Systems"},
	{0x001193, "Cisco Systems"},
	{0x001194, "Chi Mei Communication Systems, Inc."},
	{0x001195, "D-Link Corporation"},
	{0x001196, "Actuality Systems, Inc."},
	{0x001197, "Monitoring Technologies Limited"},
	{0x001198, "Prism Media Products Limited"},
	{0x001199, "2wcom GmbH"},
	{0x00119A, "Alkeria srl"},
	{0x00119B, "Telesynergy Research Inc."},
	{0x00119C, "EP&T Energy"},
	{0x00119D, "Diginfo Technology Corporation"},
	{0x00119E, "Solectron Brazil"},
	{0x00119F, "Nokia Danmark A/S"},
	{0x0011A0, "Vtech Engineering Canada Ltd"},
	{0x0011A1, "VISION NETWARE CO.,LTD"},
	{0x0011A2, "Manufacturing Technology Inc"},
	{0x0011A3, "LanReady Technologies Inc."},
	{0x0011A4, "JStream Technologies Inc."},
	{0x0011A5, "Fortuna Electronic Corp."},
	{0x0011A6, "Sypixx Networks"},
	{0x0011A7, "Infilco Degremont Inc."},
	{0x0011A8, "Quest Technologies"},
	{0x0011A9, "MOIMSTONE Co., LTD"},
	{0x0011AA, "Uniclass Technology, Co., LTD"},
	{0x0011AB, "TRUSTABLE TECHNOLOGY CO.,LTD."},
	{0x0011AC, "Simtec Electronics"},
	{0x0011AD, "Shanghai Ruijie Technology"},
	{0x0011AE, "Motorola BCS"},
	{0x0011AF, "Medialink-i,Inc"},
	{0x0011B0, "Fortelink Inc."},
	{0x0011B1, "BlueExpert Technology Corp."},
	{0x0011B2, "2001 Technology Inc."},
	{0x0011B3, "YOSHIMIYA CO.,LTD."},
	{0x0011B4, "Westermo Teleindustri AB"},
	{0x0011B5, "Shenzhen Powercom Co.,Ltd"},
	{0x0011B6, "Open Systems International"},
	{0x0011B7, "Octalix B.V."},
	{0x0011B8, "Liebherr - Elektronik GmbH"},
	{0x0011B9, "Inner Range Pty. Ltd."},
	{0x0011BA, "Elexol Pty Ltd"},
	{0x0011BB, "Cisco Systems"},
	{0x0011BC, "Cisco Systems"},
	{0x0011BD, "Bombardier Transportation"},
	{0x0011BE, "AGP Telecom Co. Ltd"},
	{0x0011BF, "AESYS S.p.A."},
	{0x0011C0, "Aday Technology Inc"},
	{0x0011C1, "4P MOBILE DATA PROCESSING"},
	{0x0011C2, "United Fiber Optic Communication"},
	{0x0011C3, "Transceiving System Technology Corporation"},
	{0x0011C4, "Terminales de Telecomunicacion Terrestre, S.L."},
	{0x0011C5, "TEN Technology"},
	{0x0011C6, "Seagate Technology LLC"},
	{0x0011C7, "Raymarine UK Ltd"},
	{0x0011C8, "Powercom Co., Ltd."},
	{0x0011C9, "MTT Corporation"},
	{0x0011CA, "Long Range Systems, Inc."},
	{0x0011CB, "Jacobsons AB"},
	{0x0011CC, "Guangzhou Jinpeng Group Co.,Ltd."},
	{0x0011CD, "Axsun Technologies"},
	{0x0011CE, "Ubisense Limited"},
	{0x0011CF, "Thrane & Thrane A/S"},
	{0x0011D0, "Tandberg Data ASA"},
	{0x0011D1, "Soft Imaging System GmbH"},
	{0x0011D2, "Perception Digital Ltd"},
	{0x0011D3, "NextGenTel Holding ASA"},
	{0x0011D4, "NetEnrich, Inc"},
	{0x0011D5, "Hangzhou Sunyard System Engineering Co.,Ltd."},
	{0x0011D6, "HandEra, Inc."},
	{0x0011D7, "eWerks Inc"},
	{0x0011D8, "ASUSTek Computer Inc."},
	{0x0011D9, "TiVo"},
	{0x0011DA, "Vivaas Technology Inc."},
	{0x0011DB, "Land-Cellular Corporation"},
	{0x0011DC, "Glunz & Jensen"},
	{0x0011DD, "FROMUS TEC. Co., Ltd."},
	{0x0011DE, "EURILOGIC"},
	{0x0011DF, "Current Energy"},
	{0x0011E0, "U-MEDIA Communications, Inc."},
	{0x0011E1, "BEKO Electronics Co."},
	{0x0011E2, "Hua Jung Components Co., Ltd."},
	{0x0011E3, "Thomson, Inc."},
	{0x0011E4, "Danelec Electronics A/S"},
	{0x0011E5, "KCodes Corporation"},
	{0x0011E6, "Scientific Atlanta"},
	{0x0011E7, "WORLDSAT - Texas de France"},
	{0x0011E8, "Tixi.Com"},
	{0x0011E9, "STARNEX CO., LTD."},
	{0x0011EA, "IWICS Inc."},
	{0x0011EB, "Innovative Integration"},
	{0x0011EC, "AVIX INC."},
	{0x0011ED, "802 Global"},
	{0x0011EE, "Estari, Inc."},
	{0x0011EF, "Conitec Datensysteme GmbH"},
	{0x0011F0, "Wideful Limited"},
	{0x0011F1, "QinetiQ Ltd"},
	{0x0011F2, "Institute of Network Technologies"},
	{0x0011F3, "NeoMedia Europe AG"},
	{0x0011F4, "woori-net"},
	{0x0011F5, "ASKEY COMPUTER CORP."},
	{0x0011F6, "Asia Pacific Microsystems , Inc."},
	{0x0011F7, "Shenzhen Forward Industry Co., Ltd"},
	{0x0011F8, "AIRAYA Corp"},
	{0x0011F9, "Nortel Networks"},
	{0x0011FA, "Rane Corporation"},
	{0x0011FB, "Heidelberg Engineering GmbH"},
	{0x0011FC, "HARTING Electric Gmbh & Co.KG"},
	{0x0011FD, "KORG INC."},
	{0x0011FE, "Keiyo System Research, Inc."},
	{0x0011FF, "Digitro Tecnologia Ltda"},
	{0x001200, "Cisco"},
	{0x001201, "Cisco"},
	{0x001202, "Decrane Aerospace - Audio International Inc."},
	{0x001203, "Activ Networks"},
	{0x001204, "u10 Networks, Inc."},
	{0x001205, "Terrasat Communications, Inc."},
	{0x001206, "iQuest (NZ) Ltd"},
	{0x001207, "Head Strong International Limited"},
	{0x001208, "Gantner Instruments GmbH"},
	{0x001209, "Fastrax Ltd"},
	{0x00120A, "Emerson Electric GmbH & Co. OHG"},
	{0x00120B, "Chinasys Technologies Limited"},
	{0x00120C, "CE-Infosys Pte Ltd"},
	{0x00120D, "Advanced Telecommunication Technologies, Inc."},
	{0x00120E, "AboCom"},
	{0x00120F, "IEEE 802.3"},
	{0x001210, "WideRay Corp"},
	{0x001211, "Protechna Herbst GmbH & Co. KG"},
	{0x001212, "PLUS  Corporation"},
	{0x001213, "Metrohm AG"},
	{0x001214, "Koenig & Bauer AG"},
	{0x001215, "iStor Networks, Inc."},
	{0x001216, "ICP Internet Communication Payment AG"},
	{0x001217, "Cisco-Linksys, LLC"},
	{0x001218, "ARUZE Corporation"},
	{0x001219, "Ahead Communication Systems Inc"},
	{0x00121A, "Techno Soft Systemnics Inc."},
	{0x00121B, "Sound Devices, LLC"},
	{0x00121C, "PARROT S.A."},
	{0x00121D, "Netfabric Corporation"},
	{0x00121E, "Juniper Networks, Inc."},
	{0x00121F, "Harding Intruments"},
	{0x001220, "Cadco Systems"},
	{0x001221, "B.Braun Melsungen AG"},
	{0x001222, "Skardin (UK) Ltd"},
	{0x001223, "Pixim"},
	{0x001224, "NexQL Corporation"},
	{0x001225, "Motorola BCS"},
	{0x001226, "Japan Direx Corporation"},
	{0x001227, "Franklin Electric Co., Inc."},
	{0x001228, "Data Ltd."},
	{0x001229, "BroadEasy Technologies Co.,Ltd"},
	{0x00122A, "VTech Telecommunications Ltd."},
	{0x00122B, "Virbiage Pty Ltd"},
	{0x00122C, "Soenen Controls N.V."},
	{0x00122D, "SiNett Corporation"},
	{0x00122E, "Signal Technology - AISD"},
	{0x00122F, "Sanei Electric Inc."},
	{0x001230, "Picaso Infocommunication CO., LTD."},
	{0x001231, "Motion Control Systems, Inc."},
	{0x001232, "LeWiz Communications Inc."},
	{0x001233, "JRC TOKKI Co.,Ltd."},
	{0x001234, "Camille Bauer"},
	{0x001235, "Andrew Corporation"},
	{0x001236, "ConSentry Networks"},
	{0x001237, "Texas Instruments"},
	{0x001238, "SetaBox Technology Co., Ltd."},
	{0x001239, "S Net Systems Inc."},
	{0x00123A, "Posystech Inc., Co."},
	{0x00123B, "KeRo Systems ApS"},
	{0x00123C, "Second Rule LLC"},
	{0x00123D, "GES"},
	{0x00123E, "ERUNE technology Co., Ltd."},
	{0x00123F, "Dell Inc"},
	{0x001240, "AMOI ELECTRONICS CO.,LTD"},
	{0x001241, "a2i marketing center"},
	{0x001242, "Millennial Net"},
	{0x001243, "Cisco"},
	{0x001244, "Cisco"},
	{0x001245, "Zellweger Analytics, Inc."},
	{0x001246, "T.O.M TECHNOLOGY INC.."},
	{0x001247, "Samsung Electronics Co., Ltd."},
	{0x001248, "EMC Corporation (Kashya)"},
	{0x001249, "Delta Elettronica S.p.A."},
	{0x00124A, "Dedicated Devices, Inc."},
	{0x00124B, "Texas Instruments"},
	{0x00124C, "BBWM Corporation"},
	{0x00124D, "Inducon BV"},
	{0x00124E, "XAC AUTOMATION CORP."},
	{0x00124F, "Tyco Thermal Controls LLC."},
	{0x001250, "Tokyo Aircaft Instrument Co., Ltd."},
	{0x001251, "SILINK"},
	{0x001252, "Citronix, LLC"},
	{0x001253, "AudioDev AB"},
	{0x001254, "Spectra Technologies Holdings Company Ltd"},
	{0x001255, "NetEffect Incorporated"},
	{0x001256, "LG INFORMATION & COMM."},
	{0x001257, "LeapComm Communication Technologies Inc."},
	{0x001258, "Activis Polska"},
	{0x001259, "THERMO ELECTRON KARLSRUHE"},
	{0x00125A, "Microsoft Corporation"},
	{0x00125B, "KAIMEI ELECTRONI"},
	{0x00125C, "Green Hills Software, Inc."},
	{0x00125D, "CyberNet Inc."},
	{0x00125E, "CAEN"},
	{0x00125F, "AWIND Inc."},
	{0x001260, "Stanton Magnetics,inc."},
	{0x001261, "Adaptix, Inc"},
	{0x001262, "Nokia Danmark A/S"},
	{0x001263, "Data Voice Technologies GmbH"},
	{0x001264, "daum electronic gmbh"},
	{0x001265, "Enerdyne Technologies, Inc."},
	{0x001266, "Swisscom Hospitality Services SA"},
	{0x001267, "Matsushita Electronic Components Co., Ltd."},
	{0x001268, "IPS d.o.o."},
	{0x001269, "Value Electronics"},
	{0x00126A, "OPTOELECTRONICS Co., Ltd."},
	{0x00126B, "Ascalade Communications Limited"},
	{0x00126C, "Visonic Ltd."},
	{0x00126D, "University of California, Berkeley"},
	{0x00126E, "Seidel Elektronik GmbH Nfg.KG"},
	{0x00126F, "Rayson Technology Co., Ltd."},
	{0x001270, "NGES Denro Systems"},
	{0x001271, "Measurement Computing Corp"},
	{0x001272, "Redux Communications Ltd."},
	{0x001273, "Stoke Inc"},
	{0x001274, "NIT lab"},
	{0x001275, "Sentilla Corporation"},
	{0x001276, "Microsol Holdings Ltd."},
	{0x001277, "Korenix Technologies Co., Ltd."},
	{0x001278, "International Bar Code"},
	{0x001279, "Hewlett Packard"},
	{0x00127A, "Sanyu Industry Co.,Ltd."},
	{0x00127B, "VIA Networking Technologies, Inc."},
	{0x00127C, "SWEGON AB"},
	{0x00127D, "MobileAria"},
	{0x00127E, "Digital Lifestyles Group, Inc."},
	{0x00127F, "Cisco"},
	{0x001280, "Cisco"},
	{0x001281, "CIEFFE srl"},
	{0x001282, "Qovia"},
	{0x001283, "Nortel Networks"},
	{0x001284, "Lab33 Srl"},
	{0x001285, "Gizmondo Europe Ltd"},
	{0x001286, "ENDEVCO CORP"},
	{0x001287, "Digital Everywhere Unterhaltungselektronik GmbH"},
	{0x001288, "2Wire, Inc"},
	{0x001289, "Advance Sterilization Products"},
	{0x00128A, "Motorola PCS"},
	{0x00128B, "Sensory Networks Inc"},
	{0x00128C, "Woodward Governor"},
	{0x00128D, "STB Datenservice GmbH"},
	{0x00128E, "Q-Free ASA"},
	{0x00128F, "Montilio"},
	{0x001290, "KYOWA Electric & Machinery Corp."},
	{0x001291, "KWS Computersysteme GmbH"},
	{0x001292, "Griffin Technology"},
	{0x001293, "GE Energy"},
	{0x001294, "SUMITOMO ELECTRIC DEVICE INNOVATIONS, INC"},
	{0x001295, "Aiware Inc."},
	{0x001296, "Addlogix"},
	{0x001297, "O2Micro, Inc."},
	{0x001298, "MICO ELECTRIC(SHENZHEN) LIMITED"},
	{0x001299, "Ktech Telecommunications Inc"},
	{0x00129A, "IRT Electronics Pty Ltd"},
	{0x00129B, "E2S Electronic Engineering Solutions, S.L."},
	{0x00129C, "Yulinet"},
	{0x00129D, "First International Computer do Brasil"},
	{0x00129E, "Surf Communications Inc."},
	{0x00129F, "RAE Systems, Inc."},
	{0x0012A0, "NeoMeridian Sdn Bhd"},
	{0x0012A1, "BluePacket Communications Co., Ltd."},
	{0x0012A2, "VITA"},
	{0x0012A3, "Trust International B.V."},
	{0x0012A4, "ThingMagic, LLC"},
	{0x0012A5, "Stargen, Inc."},
	{0x0012A6, "Dolby Australia"},
	{0x0012A7, "ISR TECHNOLOGIES Inc"},
	{0x0012A8, "intec GmbH"},
	{0x0012A9, "3Com Ltd"},
	{0x0012AA, "IEE, Inc."},
	{0x0012AB, "WiLife, Inc."},
	{0x0012AC, "ONTIMETEK INC."},
	{0x0012AD, "IDS GmbH"},
	{0x0012AE, "HLS HARD-LINE Solutions Inc."},
	{0x0012AF, "ELPRO Technologies"},
	{0x0012B0, "Efore Oyj   (Plc)"},
	{0x0012B1, "Dai Nippon Printing Co., Ltd"},
	{0x0012B2, "AVOLITES LTD."},
	{0x0012B3, "Advance Wireless Technology Corp."},
	{0x0012B4, "Work Microwave GmbH"},
	{0x0012B5, "Vialta, Inc."},
	{0x0012B6, "Santa Barbara Infrared, Inc."},
	{0x0012B7, "PTW Freiburg"},
	{0x0012B8, "G2 Microsystems"},
	{0x0012B9, "Fusion Digital Technology"},
	{0x0012BA, "FSI Systems, Inc."},
	{0x0012BB, "Telecommunications Industry Association TR-41 Committee"},
	{0x0012BC, "Echolab LLC"},
	{0x0012BD, "Avantec Manufacturing Limited"},
	{0x0012BE, "Astek Corporation"},
	{0x0012BF, "Arcadyan Technology Corporation"},
	{0x0012C0, "HotLava Systems, Inc."},
	{0x0012C1, "Check Point Software Technologies"},
	{0x0012C2, "Apex Electronics Factory"},
	{0x0012C3, "WIT S.A."},
	{0x0012C4, "Viseon, Inc."},
	{0x0012C5, "V-Show  Technology (China) Co.,Ltd"},
	{0x0012C6, "TGC America, Inc"},
	{0x0012C7, "SECURAY Technologies Ltd.Co."},
	{0x0012C8, "Perfect tech"},
	{0x0012C9, "Motorola BCS"},
	{0x0012CA, "Mechatronic Brick Aps"},
	{0x0012CB, "CSS Inc."},
	{0x0012CC, "Bitatek CO., LTD"},
	{0x0012CD, "ASEM SpA"},
	{0x0012CE, "Advanced Cybernetics Group"},
	{0x0012CF, "Accton Technology Corporation"},
	{0x0012D0, "Gossen-Metrawatt-GmbH"},
	{0x0012D1, "Texas Instruments Inc"},
	{0x0012D2, "Texas Instruments"},
	{0x0012D3, "Zetta Systems, Inc."},
	{0x0012D4, "Princeton Technology, Ltd"},
	{0x0012D5, "Motion Reality Inc."},
	{0x0012D6, "Jiangsu Yitong High-Tech Co.,Ltd"},
	{0x0012D7, "Invento Networks, Inc."},
	{0x0012D8, "International Games System Co., Ltd."},
	{0x0012D9, "Cisco Systems"},
	{0x0012DA, "Cisco Systems"},
	{0x0012DB, "ZIEHL industrie-elektronik GmbH + Co KG"},
	{0x0012DC, "SunCorp Industrial Limited"},
	{0x0012DD, "Shengqu Information Technology (Shanghai) Co., Ltd."},
	{0x0012DE, "Radio Components Sweden AB"},
	{0x0012DF, "Novomatic AG"},
	{0x0012E0, "Codan Limited"},
	{0x0012E1, "Alliant Networks, Inc"},
	{0x0012E2, "ALAXALA Networks Corporation"},
	{0x0012E3, "Agat-RT, Ltd."},
	{0x0012E4, "ZIEHL industrie-electronik GmbH + Co KG"},
	{0x0012E5, "Time America, Inc."},
	{0x0012E6, "SPECTEC COMPUTER CO., LTD."},
	{0x0012E7, "Projectek Networking Electronics Corp."},
	{0x0012E8, "Fraunhofer IMS"},
	{0x0012E9, "Abbey Systems Ltd"},
	{0x0012EA, "Trane"},
	{0x0012EB, "R2DI, LLC"},
	{0x0012EC, "Movacolor b.v."},
	{0x0012ED, "AVG Advanced Technologies"},
	{0x0012EE, "Sony Ericsson Mobile Communications AB"},
	{0x0012EF, "OneAccess SA"},
	{0x0012F0, "Intel Corporate"},
	{0x0012F1, "IFOTEC"},
	{0x0012F2, "Brocade Communications Systems, Inc"},
	{0x0012F3, "connectBlue AB"},
	{0x0012F4, "Belco International Co.,Ltd."},
	{0x0012F5, "Imarda New Zealand Limited"},
	{0x0012F6, "MDK CO.,LTD."},
	{0x0012F7, "Xiamen Xinglian Electronics Co., Ltd."},
	{0x0012F8, "WNI Resources, LLC"},
	{0x0012F9, "URYU SEISAKU, LTD."},
	{0x0012FA, "THX LTD"},
	{0x0012FB, "Samsung Electronics"},
	{0x0012FC, "PLANET System Co.,LTD"},
	{0x0012FD, "OPTIMUS IC S.A."},
	{0x0012FE, "Lenovo Mobile Communication Technology Ltd."},
	{0x0012FF, "Lely Industries N.V."},
	{0x001300, "IT-FACTORY, INC."},
	{0x001301, "IronGate S.L."},
	{0x001302, "Intel Corporate"},
	{0x001303, "GateConnect Technologies GmbH"},
	{0x001304, "Flaircomm Technologies Co. LTD"},
	{0x001305, "Epicom, Inc."},
	{0x001306, "Always On Wireless"},
	{0x001307, "Paravirtual Corporation"},
	{0x001308, "Nuvera Fuel Cells"},
	{0x001309, "Ocean Broadband Networks"},
	{0x00130A, "Nortel"},
	{0x00130B, "Mextal B.V."},
	{0x00130C, "HF System Corporation"},
	{0x00130D, "GALILEO AVIONICA"},
	{0x00130E, "Focusrite Audio Engineering Limited"},
	{0x00130F, "EGEMEN Bilgisayar Muh San ve Tic LTD STI"},
	{0x001310, "Cisco-Linksys, LLC"},
	{0x001311, "ARRIS International"},
	{0x001312, "Amedia Networks Inc."},
	{0x001313, "GuangZhou Post & Telecom Equipment ltd"},
	{0x001314, "Asiamajor Inc."},
	{0x001315, "SONY Computer Entertainment inc,"},
	{0x001316, "L-S-B Broadcast Technologies GmbH"},
	{0x001317, "GN Netcom as"},
	{0x001318, "DGSTATION Co., Ltd."},
	{0x001319, "Cisco Systems"},
	{0x00131A, "Cisco Systems"},
	{0x00131B, "BeCell Innovations Corp."},
	{0x00131C, "LiteTouch, Inc."},
	{0x00131D, "Scanvaegt International A/S"},
	{0x00131E, "Peiker acustic GmbH & Co. KG"},
	{0x00131F, "NxtPhase T&D, Corp."},
	{0x001320, "Intel Corporate"},
	{0x001321, "Hewlett Packard"},
	{0x001322, "DAQ Electronics, Inc."},
	{0x001323, "Cap Co., Ltd."},
	{0x001324, "Schneider Electric Ultra Terminal"},
	{0x001325, "Cortina Systems Inc"},
	{0x001326, "ECM Systems Ltd"},
	{0x001327, "Data Acquisitions limited"},
	{0x001328, "Westech Korea Inc.,"},
	{0x001329, "VSST Co., LTD"},
	{0x00132A, "Sitronics Telecom Solutions"},
	{0x00132B, "Phoenix Digital"},
	{0x00132C, "MAZ Brandenburg GmbH"},
	{0x00132D, "iWise Communications"},
	{0x00132E, "ITian Coporation"},
	{0x00132F, "Interactek"},
	{0x001330, "EURO PROTECTION SURVEILLANCE"},
	{0x001331, "CellPoint Connect"},
	{0x001332, "Beijing Topsec Network Security Technology Co., Ltd."},
	{0x001333, "BaudTec Corporation"},
	{0x001334, "Arkados, Inc."},
	{0x001335, "VS Industry Berhad"},
	{0x001336, "Tianjin 712 Communication Broadcasting co., ltd."},
	{0x001337, "Orient Power Home Network Ltd."},
	{0x001338, "FRESENIUS-VIAL"},
	{0x001339, "EL-ME AG"},
	{0x00133A, "VadaTech Inc."},
	{0x00133B, "Speed Dragon Multimedia Limited"},
	{0x00133C, "QUINTRON SYSTEMS INC."},
	{0x00133D, "Micro Memory Curtiss Wright Co"},
	{0x00133E, "MetaSwitch"},
	{0x00133F, "Eppendorf Instrumente GmbH"},
	{0x001340, "AD.EL s.r.l."},
	{0x001341, "Shandong New Beiyang Information Technology Co.,Ltd"},
	{0x001342, "Vision Research, Inc."},
	{0x001343, "Matsushita Electronic Components (Europe) GmbH"},
	{0x001344, "Fargo Electronics Inc."},
	{0x001345, "Eaton Corporation"},
	{0x001346, "D-Link Corporation"},
	{0x001347, "BlueTree Wireless Data Inc."},
	{0x001348, "Artila Electronics Co., Ltd."},
	{0x001349, "ZyXEL Communications Corporation"},
	{0x00134A, "Engim, Inc."},
	{0x00134B, "ToGoldenNet Technology Inc."},
	{0x00134C, "YDT Technology International"},
	{0x00134D, "IPC systems"},
	{0x00134E, "Valox Systems, Inc."},
	{0x00134F, "Tranzeo Wireless Technologies Inc."},
	{0x001350, "Silver Spring Networks, Inc"},
	{0x001351, "Niles Audio Corporation"},
	{0x001352, "Naztec, Inc."},
	{0x001353, "HYDAC Filtertechnik GMBH"},
	{0x001354, "Zcomax Technologies, Inc."},
	{0x001355, "TOMEN Cyber-business Solutions, Inc."},
	{0x001356, "target systemelectronic gmbh"},
	{0x001357, "Soyal Technology Co., Ltd."},
	{0x001358, "Realm Systems, Inc."},
	{0x001359, "ProTelevision Technologies A/S"},
	{0x00135A, "Project T&E Limited"},
	{0x00135B, "PanelLink Cinema, LLC"},
	{0x00135C, "OnSite Systems, Inc."},
	{0x00135D, "NTTPC Communications, Inc."},
	{0x00135E, "EAB/RWI/K"},
	{0x00135F, "Cisco Systems"},
	{0x001360, "Cisco Systems"},
	{0x001361, "Biospace Co., Ltd."},
	{0x001362, "ShinHeung Precision Co., Ltd."},
	{0x001363, "Verascape, Inc."},
	{0x001364, "Paradigm Technology Inc.."},
	{0x001365, "Nortel"},
	{0x001366, "Neturity Technologies Inc."},
	{0x001367, "Narayon. Co., Ltd."},
	{0x001368, "Maersk Data Defence"},
	{0x001369, "Honda Electron Co., LED."},
	{0x00136A, "Hach Lange SA"},
	{0x00136B, "E-TEC"},
	{0x00136C, "TomTom"},
	{0x00136D, "Tentaculus AB"},
	{0x00136E, "Techmetro Corp."},
	{0x00136F, "PacketMotion, Inc."},
	{0x001370, "Nokia Danmark A/S"},
	{0x001371, "Motorola CHS"},
	{0x001372, "Dell Inc."},
	{0x001373, "BLwave Electronics Co., Ltd"},
	{0x001374, "Atheros Communications, Inc."},
	{0x001375, "American Security Products Co."},
	{0x001376, "Tabor Electronics Ltd."},
	{0x001377, "Samsung Electronics CO., LTD"},
	{0x001378, "QSAN Technology, Inc."},
	{0x001379, "PONDER INFORMATION INDUSTRIES LTD."},
	{0x00137A, "Netvox Technology Co., Ltd."},
	{0x00137B, "Movon Corporation"},
	{0x00137C, "Kaicom co., Ltd."},
	{0x00137D, "Dynalab, Inc."},
	{0x00137E, "CorEdge Networks, Inc."},
	{0x00137F, "Cisco Systems"},
	{0x001380, "Cisco Systems"},
	{0x001381, "CHIPS & Systems, Inc."},
	{0x001382, "Cetacea Networks Corporation"},
	{0x001383,
	 "Application Technologies and Engineering Research Laboratory"},
	{0x001384, "Advanced Motion Controls"},
	{0x001385, "Add-On Technology Co., LTD."},
	{0x001386, "ABB Inc./Totalflow"},
	{0x001387, "27M Technologies AB"},
	{0x001388, "WiMedia Alliance"},
	{0x001389, "Redes de Telefona Mvil S.A."},
	{0x00138A, "QINGDAO GOERTEK ELECTRONICS CO.,LTD."},
	{0x00138B, "Phantom Technologies LLC"},
	{0x00138C, "Kumyoung.Co.Ltd"},
	{0x00138D, "Kinghold"},
	{0x00138E, "FOAB Elektronik AB"},
	{0x00138F, "Asiarock Incorporation"},
	{0x001390, "Termtek Computer Co., Ltd"},
	{0x001391, "OUEN CO.,LTD."},
	{0x001392, "Ruckus Wireless"},
	{0x001393, "Panta Systems, Inc."},
	{0x001394, "Infohand Co.,Ltd"},
	{0x001395, "congatec AG"},
	{0x001396, "Acbel Polytech Inc."},
	{0x001397, "Xsigo Systems, Inc."},
	{0x001398, "TrafficSim Co.,Ltd"},
	{0x001399, "STAC Corporation."},
	{0x00139A, "K-ubique ID Corp."},
	{0x00139B, "ioIMAGE Ltd."},
	{0x00139C, "Exavera Technologies, Inc."},
	{0x00139D, "Design of Systems on Silicon S.A."},
	{0x00139E, "Ciara Technologies Inc."},
	{0x00139F, "Electronics Design Services, Co., Ltd."},
	{0x0013A0, "ALGOSYSTEM Co., Ltd."},
	{0x0013A1, "Crow Electronic Engeneering"},
	{0x0013A2, "MaxStream, Inc"},
	{0x0013A3, "Siemens Com CPE Devices"},
	{0x0013A4, "KeyEye Communications"},
	{0x0013A5, "General Solutions, LTD."},
	{0x0013A6, "Extricom Ltd"},
	{0x0013A7, "BATTELLE MEMORIAL INSTITUTE"},
	{0x0013A8, "Tanisys Technology"},
	{0x0013A9, "Sony Corporation"},
	{0x0013AA, "ALS  & TEC Ltd."},
	{0x0013AB, "Telemotive AG"},
	{0x0013AC, "Sunmyung Electronics Co., LTD"},
	{0x0013AD, "Sendo Ltd"},
	{0x0013AE, "Radiance Technologies, Inc."},
	{0x0013AF, "NUMA Technology,Inc."},
	{0x0013B0, "Jablotron"},
	{0x0013B1, "Intelligent Control Systems (Asia) Pte Ltd"},
	{0x0013B2, "Carallon Limited"},
	{0x0013B3, "Ecom Communications Technology Co., Ltd."},
	{0x0013B4, "Appear TV"},
	{0x0013B5, "Wavesat"},
	{0x0013B6, "Sling Media, Inc."},
	{0x0013B7, "Scantech ID"},
	{0x0013B8, "RyCo Electronic Systems Limited"},
	{0x0013B9, "BM SPA"},
	{0x0013BA, "ReadyLinks Inc"},
	{0x0013BB, "Smartvue Corporation"},
	{0x0013BC, "Artimi Ltd"},
	{0x0013BD, "HYMATOM SA"},
	{0x0013BE, "Virtual Conexions"},
	{0x0013BF, "Media System Planning Corp."},
	{0x0013C0, "Trix Tecnologia Ltda."},
	{0x0013C1, "Asoka USA Corporation"},
	{0x0013C2, "WACOM Co.,Ltd"},
	{0x0013C3, "Cisco Systems"},
	{0x0013C4, "Cisco Systems"},
	{0x0013C5, "LIGHTRON FIBER-OPTIC DEVICES INC."},
	{0x0013C6, "OpenGear, Inc"},
	{0x0013C7, "IONOS Co.,Ltd."},
	{0x0013C8, "PIRELLI BROADBAND SOLUTIONS S.P.A."},
	{0x0013C9, "Beyond Achieve Enterprises Ltd."},
	{0x0013CA, "X-Digital Systems, Inc."},
	{0x0013CB, "Zenitel Norway AS"},
	{0x0013CC, "Tall Maple Systems"},
	{0x0013CD, "MTI co. LTD"},
	{0x0013CE, "Intel Corporate"},
	{0x0013CF, "4Access Communications"},
	{0x0013D0, "t+ Medical Ltd"},
	{0x0013D1, "KIRK telecom A/S"},
	{0x0013D2, "PAGE IBERICA, S.A."},
	{0x0013D3, "MICRO-STAR INTERNATIONAL CO., LTD."},
	{0x0013D4, "ASUSTek COMPUTER INC."},
	{0x0013D5, "WiNetworks LTD"},
	{0x0013D6, "TII NETWORK TECHNOLOGIES, INC."},
	{0x0013D7, "SPIDCOM Technologies SA"},
	{0x0013D8, "Princeton Instruments"},
	{0x0013D9, "Matrix Product Development, Inc."},
	{0x0013DA, "Diskware Co., Ltd"},
	{0x0013DB, "SHOEI Electric Co.,Ltd"},
	{0x0013DC, "IBTEK INC."},
	{0x0013DD, "Abbott Diagnostics"},
	{0x0013DE, "Adapt4, LLC"},
	{0x0013DF, "Ryvor Corp."},
	{0x0013E0, "Murata Manufacturing Co., Ltd."},
	{0x0013E1, "Iprobe AB"},
	{0x0013E2, "GeoVision Inc."},
	{0x0013E3, "CoVi Technologies, Inc."},
	{0x0013E4, "YANGJAE SYSTEMS CORP."},
	{0x0013E5, "TENOSYS, INC."},
	{0x0013E6, "Technolution"},
	{0x0013E7, "Halcro"},
	{0x0013E8, "Intel Corporate"},
	{0x0013E9, "VeriWave, Inc."},
	{0x0013EA, "Kamstrup A/S"},
	{0x0013EB, "Sysmaster Corporation"},
	{0x0013EC, "Sunbay Software AG"},
	{0x0013ED, "PSIA"},
	{0x0013EE, "JBX Designs Inc."},
	{0x0013EF, "Kingjon Digital Technology Co.,Ltd"},
	{0x0013F0, "Wavefront Semiconductor"},
	{0x0013F1, "AMOD Technology Co., Ltd."},
	{0x0013F2, "Klas Ltd"},
	{0x0013F3, "Giga-byte Communications Inc."},
	{0x0013F4, "Psitek (Pty) Ltd"},
	{0x0013F5, "Akimbi Systems"},
	{0x0013F6, "Cintech"},
	{0x0013F7, "SMC Networks, Inc."},
	{0x0013F8, "Dex Security Solutions"},
	{0x0013F9, "Cavera Systems"},
	{0x0013FA, "LifeSize Communications, Inc"},
	{0x0013FB, "RKC INSTRUMENT INC."},
	{0x0013FC, "SiCortex, Inc"},
	{0x0013FD, "Nokia Danmark A/S"},
	{0x0013FE, "GRANDTEC ELECTRONIC CORP."},
	{0x0013FF, "Dage-MTI of MC, Inc."},
	{0x001400, "MINERVA KOREA CO., LTD"},
	{0x001401, "Rivertree Networks Corp."},
	{0x001402, "kk-electronic a/s"},
	{0x001403, "Renasis, LLC"},
	{0x001404, "Motorola CHS"},
	{0x001405, "OpenIB, Inc."},
	{0x001406, "Go Networks"},
	{0x001407, "Sperian Protection Instrumentation"},
	{0x001408, "Eka Systems Inc."},
	{0x001409, "MAGNETI MARELLI   S.E. S.p.A."},
	{0x00140A, "WEPIO Co., Ltd."},
	{0x00140B, "FIRST INTERNATIONAL COMPUTER, INC."},
	{0x00140C, "GKB CCTV CO., LTD."},
	{0x00140D, "Nortel"},
	{0x00140E, "Nortel"},
	{0x00140F,
	 "Federal State Unitary Enterprise Leningrad R&D Institute of"},
	{0x001410, "Suzhou Keda Technology CO.,Ltd"},
	{0x001411, "Deutschmann Automation GmbH & Co. KG"},
	{0x001412, "S-TEC electronics AG"},
	{0x001413, "Trebing & Himstedt Prozessautomation GmbH & Co. KG"},
	{0x001414, "Jumpnode Systems LLC."},
	{0x001415, "Intec Automation Inc."},
	{0x001416, "Scosche Industries, Inc."},
	{0x001417, "RSE Informations Technologie GmbH"},
	{0x001418, "C4Line"},
	{0x001419, "SIDSA"},
	{0x00141A, "DEICY CORPORATION"},
	{0x00141B, "Cisco Systems"},
	{0x00141C, "Cisco Systems"},
	{0x00141D, "Lust Antriebstechnik GmbH"},
	{0x00141E, "P.A. Semi, Inc."},
	{0x00141F, "SunKwang Electronics Co., Ltd"},
	{0x001420, "G-Links networking company"},
	{0x001421, "Total Wireless Technologies Pte. Ltd."},
	{0x001422, "Dell Inc."},
	{0x001423, "J-S Co. NEUROCOM"},
	{0x001424, "Merry Electrics CO., LTD."},
	{0x001425, "Galactic Computing Corp."},
	{0x001426, "NL Technology"},
	{0x001427, "JazzMutant"},
	{0x001428, "Vocollect, Inc"},
	{0x001429, "V Center Technologies Co., Ltd."},
	{0x00142A, "Elitegroup Computer System Co., Ltd"},
	{0x00142B, "Edata Communication Inc."},
	{0x00142C, "Koncept International, Inc."},
	{0x00142D, "Toradex AG"},
	{0x00142E, "77 Elektronika Kft."},
	{0x00142F, "WildPackets"},
	{0x001430, "ViPowER, Inc"},
	{0x001431, "PDL Electronics Ltd"},
	{0x001432, "Tarallax Wireless, Inc."},
	{0x001433, "Empower Technologies(Canada) Inc."},
	{0x001434, "Keri Systems, Inc"},
	{0x001435, "CityCom Corp."},
	{0x001436, "Qwerty Elektronik AB"},
	{0x001437, "GSTeletech Co.,Ltd."},
	{0x001438, "Hewlett Packard"},
	{0x001439, "Blonder Tongue Laboratories, Inc."},
	{0x00143A, "RAYTALK INTERNATIONAL SRL"},
	{0x00143B, "Sensovation AG"},
	{0x00143C, "Rheinmetall Canada Inc."},
	{0x00143D, "Aevoe Inc."},
	{0x00143E, "AirLink Communications, Inc."},
	{0x00143F, "Hotway Technology Corporation"},
	{0x001440, "ATOMIC Corporation"},
	{0x001441, "Innovation Sound Technology Co., LTD."},
	{0x001442, "ATTO CORPORATION"},
	{0x001443, "Consultronics Europe Ltd"},
	{0x001444, "Grundfos Electronics"},
	{0x001445, "Telefon-Gradnja d.o.o."},
	{0x001446, "SuperVision Solutions LLC"},
	{0x001447, "BOAZ Inc."},
	{0x001448, "Inventec Multimedia & Telecom Corporation"},
	{0x001449, "Sichuan Changhong Electric Ltd."},
	{0x00144A, "Taiwan Thick-Film Ind. Corp."},
	{0x00144B, "Hifn, Inc."},
	{0x00144C, "General Meters Corp."},
	{0x00144D, "Intelligent Systems"},
	{0x00144E, "SRISA"},
	{0x00144F, "Sun Microsystems, Inc."},
	{0x001450, "Heim Systems GmbH"},
	{0x001451, "Apple Computer Inc."},
	{0x001452, "CALCULEX,INC."},
	{0x001453, "ADVANTECH TECHNOLOGIES CO.,LTD"},
	{0x001454, "Symwave"},
	{0x001455, "Coder Electronics Corporation"},
	{0x001456, "Edge Products"},
	{0x001457, "T-VIPS AS"},
	{0x001458, "HS Automatic ApS"},
	{0x001459, "Moram Co., Ltd."},
	{0x00145A, "Neratec AG"},
	{0x00145B, "SeekerNet Inc."},
	{0x00145C, "Intronics B.V."},
	{0x00145D, "WJ Communications, Inc."},
	{0x00145E, "IBM"},
	{0x00145F, "ADITEC CO. LTD"},
	{0x001460, "Kyocera Wireless Corp."},
	{0x001461, "CORONA CORPORATION"},
	{0x001462, "Digiwell Technology, inc"},
	{0x001463, "IDCS N.V."},
	{0x001464, "Cryptosoft"},
	{0x001465, "Novo Nordisk A/S"},
	{0x001466, "Kleinhenz Elektronik GmbH"},
	{0x001467, "ArrowSpan Inc."},
	{0x001468, "CelPlan International, Inc."},
	{0x001469, "Cisco Systems"},
	{0x00146A, "Cisco Systems"},
	{0x00146B, "Anagran, Inc."},
	{0x00146C, "Netgear Inc."},
	{0x00146D, "RF Technologies"},
	{0x00146E, "H. Stoll GmbH & Co. KG"},
	{0x00146F, "Kohler Co"},
	{0x001470, "Prokom Software SA"},
	{0x001471, "Eastern Asia Technology Limited"},
	{0x001472, "China Broadband Wireless IP Standard Group"},
	{0x001473, "Bookham Inc"},
	{0x001474, "K40 Electronics"},
	{0x001475, "Wiline Networks, Inc."},
	{0x001476, "MultiCom Industries Limited"},
	{0x001477, "Nertec  Inc."},
	{0x001478, "ShenZhen TP-LINK Technologies Co., Ltd."},
	{0x001479, "NEC Magnus Communications,Ltd."},
	{0x00147A, "Eubus GmbH"},
	{0x00147B, "Iteris, Inc."},
	{0x00147C, "3Com Ltd"},
	{0x00147D, "Aeon Digital International"},
	{0x00147E, "InnerWireless"},
	{0x00147F, "Thomson Telecom Belgium"},
	{0x001480, "Hitachi-LG Data Storage Korea, Inc"},
	{0x001481, "Multilink Inc"},
	{0x001482, "GoBackTV, Inc"},
	{0x001483, "eXS Inc."},
	{0x001484, "Cermate Technologies Inc."},
	{0x001485, "Giga-Byte"},
	{0x001486, "Echo Digital Audio Corporation"},
	{0x001487, "American Technology Integrators"},
	{0x001488, "Akorri"},
	{0x001489, "B15402100 - JANDEI, S.L."},
	{0x00148A, "Elin Ebg Traction Gmbh"},
	{0x00148B, "Globo Electronic GmbH & Co. KG"},
	{0x00148C, "Fortress Technologies"},
	{0x00148D, "Cubic Defense Simulation Systems"},
	{0x00148E, "Tele Power Inc."},
	{0x00148F, "Protronic (Far East) Ltd."},
	{0x001490, "ASP Corporation"},
	{0x001491, "Daniels Electronics Ltd."},
	{0x001492, "Liteon, Mobile Media Solution SBU"},
	{0x001493, "Systimax Solutions"},
	{0x001494, "ESU AG"},
	{0x001495, "2Wire, Inc."},
	{0x001496, "Phonic Corp."},
	{0x001497, "ZHIYUAN Eletronics co.,ltd."},
	{0x001498, "Viking Design Technology"},
	{0x001499, "Helicomm Inc"},
	{0x00149A, "Motorola Mobile Devices Business"},
	{0x00149B, "Nokota Communications, LLC"},
	{0x00149C, "HF Company"},
	{0x00149D, "Sound ID Inc."},
	{0x00149E, "UbONE Co., Ltd"},
	{0x00149F, "System and Chips, Inc."},
	{0x0014A0, "Accsense, Inc."},
	{0x0014A1, "Synchronous Communication Corp"},
	{0x0014A2, "Core Micro Systems Inc."},
	{0x0014A3, "Vitelec BV"},
	{0x0014A4, "Hon Hai Precision Ind. Co., Ltd."},
	{0x0014A5, "Gemtek Technology Co., Ltd."},
	{0x0014A6, "Teranetics, Inc."},
	{0x0014A7, "Nokia Danmark A/S"},
	{0x0014A8, "Cisco Systems"},
	{0x0014A9, "Cisco Systems"},
	{0x0014AA, "Ashly Audio, Inc."},
	{0x0014AB, "Senhai Electronic Technology Co., Ltd."},
	{0x0014AC, "Bountiful WiFi"},
	{0x0014AD, "Gassner Wiege- u. Metechnik GmbH"},
	{0x0014AE, "Wizlogics Co., Ltd."},
	{0x0014AF, "Datasym Inc."},
	{0x0014B0, "Naeil Community"},
	{0x0014B1, "Avitec AB"},
	{0x0014B2, "mCubelogics Corporation"},
	{0x0014B3, "CoreStar International Corp"},
	{0x0014B4, "General Dynamics United Kingdom Ltd"},
	{0x0014B5, "PHYSIOMETRIX,INC"},
	{0x0014B6, "Enswer Technology Inc."},
	{0x0014B7, "AR Infotek Inc."},
	{0x0014B8, "Hill-Rom"},
	{0x0014B9, "MSTAR SEMICONDUCTOR"},
	{0x0014BA, "Carvers SA de CV"},
	{0x0014BB, "Open Interface North America"},
	{0x0014BC, "SYNECTIC TELECOM EXPORTS PVT. LTD."},
	{0x0014BD, "incNETWORKS, Inc"},
	{0x0014BE, "Wink communication technology CO.LTD"},
	{0x0014BF, "Cisco-Linksys LLC"},
	{0x0014C0, "Symstream Technology Group Ltd"},
	{0x0014C1, "U.S. Robotics Corporation"},
	{0x0014C2, "Hewlett Packard"},
	{0x0014C3, "Seagate Technology LLC"},
	{0x0014C4, "Vitelcom Mobile Technology"},
	{0x0014C5, "Alive Technologies Pty Ltd"},
	{0x0014C6, "Quixant Ltd"},
	{0x0014C7, "Nortel"},
	{0x0014C8, "Contemporary Research Corp"},
	{0x0014C9, "Brocade Communications Systems, Inc."},
	{0x0014CA, "Key Radio Systems Limited"},
	{0x0014CB, "LifeSync Corporation"},
	{0x0014CC, "Zetec, Inc."},
	{0x0014CD, "DigitalZone Co., Ltd."},
	{0x0014CE, "NF CORPORATION"},
	{0x0014CF, "Nextlink.to A/S"},
	{0x0014D0, "BTI Systems Inc."},
	{0x0014D1, "TRENDnet"},
	{0x0014D2, "KYUKI CORPORATION"},
	{0x0014D3, "SEPSA"},
	{0x0014D4, "K Technology Corporation"},
	{0x0014D5,
	 "Datang Telecom Technology CO. , LCD,Optical Communication Br"},
	{0x0014D6, "Jeongmin Electronics Co.,Ltd."},
	{0x0014D7, "Datastore Technology Corp"},
	{0x0014D8, "bio-logic SA"},
	{0x0014D9, "IP Fabrics, Inc."},
	{0x0014DA, "Huntleigh Healthcare"},
	{0x0014DB, "Elma Trenew Electronic GmbH"},
	{0x0014DC, "Communication System Design & Manufacturing (CSDM)"},
	{0x0014DD, "Covergence Inc."},
	{0x0014DE, "Sage Instruments Inc."},
	{0x0014DF, "HI-P Tech Corporation"},
	{0x0014E0, "LET'S Corporation"},
	{0x0014E1, "Data Display AG"},
	{0x0014E2, "datacom systems inc."},
	{0x0014E3, "mm-lab GmbH"},
	{0x0014E4, "Integral Technologies"},
	{0x0014E5, "Alticast"},
	{0x0014E6, "AIM Infrarotmodule GmbH"},
	{0x0014E7, "Stolinx,. Inc"},
	{0x0014E8, "Motorola CHS"},
	{0x0014E9, "Nortech International"},
	{0x0014EA, "S Digm Inc. (Safe Paradigm Inc.)"},
	{0x0014EB, "AwarePoint Corporation"},
	{0x0014EC, "Acro Telecom"},
	{0x0014ED, "Airak, Inc."},
	{0x0014EE, "Western Digital Technologies, Inc."},
	{0x0014EF, "TZero Technologies, Inc."},
	{0x0014F0, "Business Security OL AB"},
	{0x0014F1, "Cisco Systems"},
	{0x0014F2, "Cisco Systems"},
	{0x0014F3, "ViXS Systems Inc"},
	{0x0014F4, "DekTec Digital Video B.V."},
	{0x0014F5, "OSI Security Devices"},
	{0x0014F6, "Juniper Networks, Inc."},
	{0x0014F7, "Crevis"},
	{0x0014F8, "Scientific Atlanta"},
	{0x0014F9, "Vantage Controls"},
	{0x0014FA, "AsGa S.A."},
	{0x0014FB, "Technical Solutions Inc."},
	{0x0014FC, "Extandon, Inc."},
	{0x0014FD, "Thecus Technology Corp."},
	{0x0014FE, "Artech Electronics"},
	{0x0014FF, "Precise Automation, Inc."},
	{0x001500, "Intel Corporate"},
	{0x001501, "LexBox"},
	{0x001502, "BETA tech"},
	{0x001503, "PROFIcomms s.r.o."},
	{0x001504, "GAME PLUS CO., LTD."},
	{0x001505, "Actiontec Electronics, Inc"},
	{0x001506, "Neo Photonics"},
	{0x001507, "Renaissance Learning Inc"},
	{0x001508, "Global Target Enterprise Inc"},
	{0x001509, "Plus Technology Co., Ltd"},
	{0x00150A, "Sonoa Systems, Inc"},
	{0x00150B, "SAGE INFOTECH LTD."},
	{0x00150C, "AVM GmbH"},
	{0x00150D, "Hoana Medical, Inc."},
	{0x00150E, "OPENBRAIN TECHNOLOGIES CO., LTD."},
	{0x00150F, "mingjong"},
	{0x001510, "Techsphere Co., Ltd"},
	{0x001511, "Data Center Systems"},
	{0x001512, "Zurich University of Applied Sciences"},
	{0x001513, "EFS sas"},
	{0x001514, "Hu Zhou NAVA Networks&Electronics Ltd."},
	{0x001515, "Leipold+Co.GmbH"},
	{0x001516, "URIEL SYSTEMS INC."},
	{0x001517, "Intel Corporate"},
	{0x001518, "Shenzhen 10MOONS Technology Development CO.,Ltd"},
	{0x001519, "StoreAge Networking Technologies"},
	{0x00151A, "Hunter Engineering Company"},
	{0x00151B, "Isilon Systems Inc."},
	{0x00151C, "LENECO"},
	{0x00151D, "M2I CORPORATION"},
	{0x00151E, "Ethernet Powerlink Standardization Group (EPSG)"},
	{0x00151F, "Multivision Intelligent Surveillance (Hong Kong) Ltd"},
	{0x001520, "Radiocrafts AS"},
	{0x001521, "Horoquartz"},
	{0x001522, "Dea Security"},
	{0x001523, "Meteor Communications Corporation"},
	{0x001524, "Numatics, Inc."},
	{0x001525, "Chamberlain Access Solutions"},
	{0x001526, "Remote Technologies Inc"},
	{0x001527, "Balboa Instruments"},
	{0x001528, "Beacon Medical Products LLC d.b.a. BeaconMedaes"},
	{0x001529, "N3 Corporation"},
	{0x00152A, "Nokia GmbH"},
	{0x00152B, "Cisco Systems"},
	{0x00152C, "Cisco Systems"},
	{0x00152D, "TenX Networks, LLC"},
	{0x00152E, "PacketHop, Inc."},
	{0x00152F, "Motorola CHS"},
	{0x001530, "Bus-Tech, Inc."},
	{0x001531, "KOCOM"},
	{0x001532, "Consumer Technologies Group, LLC"},
	{0x001533, "NADAM.CO.,LTD"},
	{0x001534, "A BELTRNICA, Companhia de Comunicaes, Lda"},
	{0x001535, "OTE Spa"},
	{0x001536, "Powertech co.,Ltd"},
	{0x001537, "Ventus Networks"},
	{0x001538, "RFID, Inc."},
	{0x001539, "Technodrive SRL"},
	{0x00153A, "Shenzhen Syscan Technology Co.,Ltd."},
	{0x00153B, "EMH Elektrizittszhler GmbH & CoKG"},
	{0x00153C, "Kprotech Co., Ltd."},
	{0x00153D, "ELIM PRODUCT CO."},
	{0x00153E, "Q-Matic Sweden AB"},
	{0x00153F, "Alcatel Alenia Space Italia"},
	{0x001540, "Nortel"},
	{0x001541, "StrataLight Communications, Inc."},
	{0x001542, "MICROHARD S.R.L."},
	{0x001543, "Aberdeen Test Center"},
	{0x001544, "coM.s.a.t. AG"},
	{0x001545, "SEECODE Co., Ltd."},
	{0x001546, "ITG Worldwide Sdn Bhd"},
	{0x001547, "AiZen Solutions Inc."},
	{0x001548, "CUBE TECHNOLOGIES"},
	{0x001549, "Dixtal Biomedica Ind. Com. Ltda"},
	{0x00154A, "WANSHIH ELECTRONIC CO., LTD"},
	{0x00154B, "Wonde Proud Technology Co., Ltd"},
	{0x00154C, "Saunders Electronics"},
	{0x00154D, "Netronome Systems, Inc."},
	{0x00154E, "IEC"},
	{0x00154F, "one RF Technology"},
	{0x001550, "Nits Technology Inc"},
	{0x001551, "RadioPulse Inc."},
	{0x001552, "Wi-Gear Inc."},
	{0x001553, "Cytyc Corporation"},
	{0x001554, "Atalum Wireless S.A."},
	{0x001555, "DFM GmbH"},
	{0x001556, "SAGEM COMMUNICATION"},
	{0x001557, "Olivetti"},
	{0x001558, "FOXCONN"},
	{0x001559, "Securaplane Technologies, Inc."},
	{0x00155A, "DAINIPPON PHARMACEUTICAL CO., LTD."},
	{0x00155B, "Sampo Corporation"},
	{0x00155C, "Dresser Wayne"},
	{0x00155D, "Microsoft Corporation"},
	{0x00155E, "Morgan Stanley"},
	{0x00155F, "GreenPeak Technologies"},
	{0x001560, "Hewlett Packard"},
	{0x001561, "JJPlus Corporation"},
	{0x001562, "Cisco Systems"},
	{0x001563, "Cisco Systems"},
	{0x001564, "BEHRINGER Spezielle Studiotechnik GmbH"},
	{0x001565, "XIAMEN YEALINK NETWORK TECHNOLOGY CO.,LTD"},
	{0x001566, "A-First Technology Co., Ltd."},
	{0x001567, "RADWIN Inc."},
	{0x001568, "Dilithium Networks"},
	{0x001569, "PECO II, Inc."},
	{0x00156A, "DG2L Technologies Pvt. Ltd."},
	{0x00156B, "Perfisans Networks Corp."},
	{0x00156C, "SANE SYSTEM CO., LTD"},
	{0x00156D, "Ubiquiti Networks Inc."},
	{0x00156E, "A. W. Communication Systems Ltd"},
	{0x00156F, "Xiranet Communications GmbH"},
	{0x001570, "Symbol TechnologiesWholly owned Subsidiary of Motorola"},
	{0x001571, "Nolan Systems"},
	{0x001572, "Red-Lemon"},
	{0x001573, "NewSoft  Technology Corporation"},
	{0x001574, "Horizon Semiconductors Ltd."},
	{0x001575, "Nevis Networks Inc."},
	{0x001576, "scil animal care company GmbH"},
	{0x001577, "Allied Telesis"},
	{0x001578, "Audio / Video Innovations"},
	{0x001579, "Lunatone Industrielle Elektronik GmbH"},
	{0x00157A, "Telefin S.p.A."},
	{0x00157B, "Leuze electronic GmbH + Co. KG"},
	{0x00157C, "Dave Networks, Inc."},
	{0x00157D, "POSDATA CO., LTD."},
	{0x00157E, "HEYFRA ELECTRONIC gmbH"},
	{0x00157F, "ChuanG International Holding CO.,LTD."},
	{0x001580, "U-WAY CORPORATION"},
	{0x001581, "MAKUS Inc."},
	{0x001582, "TVonics Ltd"},
	{0x001583, "IVT corporation"},
	{0x001584, "Schenck Process GmbH"},
	{0x001585, "Aonvision Technolopy Corp."},
	{0x001586, "Xiamen Overseas Chinese Electronic Co., Ltd."},
	{0x001587, "Takenaka Seisakusho Co.,Ltd"},
	{0x001588, "Balda-Thong Fook Solutions Sdn. Bhd."},
	{0x001589, "D-MAX Technology Co.,Ltd"},
	{0x00158A, "SURECOM Technology Corp."},
	{0x00158B, "Park Air Systems Ltd"},
	{0x00158C, "Liab ApS"},
	{0x00158D, "Jennic Ltd"},
	{0x00158E, "Plustek.INC"},
	{0x00158F, "NTT Advanced Technology Corporation"},
	{0x001590, "Hectronic GmbH"},
	{0x001591, "RLW Inc."},
	{0x001592, "Facom UK Ltd (Melksham)"},
	{0x001593, "U4EA Technologies Inc."},
	{0x001594, "BIXOLON CO.,LTD"},
	{0x001595, "Quester Tangent Corporation"},
	{0x001596, "ARRIS International"},
	{0x001597, "AETA AUDIO SYSTEMS"},
	{0x001598, "Kolektor group"},
	{0x001599, "Samsung Electronics Co., LTD"},
	{0x00159A, "Motorola CHS"},
	{0x00159B, "Nortel"},
	{0x00159C, "B-KYUNG SYSTEM Co.,Ltd."},
	{0x00159D, "Minicom Advanced Systems ltd"},
	{0x00159E, "Mad Catz Interactive Inc"},
	{0x00159F, "Terascala, Inc."},
	{0x0015A0, "Nokia Danmark A/S"},
	{0x0015A1, "ECA-SINTERS"},
	{0x0015A2, "ARRIS International"},
	{0x0015A3, "ARRIS International"},
	{0x0015A4, "ARRIS International"},
	{0x0015A5, "DCI Co., Ltd."},
	{0x0015A6, "Digital Electronics Products Ltd."},
	{0x0015A7, "Robatech AG"},
	{0x0015A8, "Motorola Mobile Devices"},
	{0x0015A9, "KWANG WOO I&C CO.,LTD"},
	{0x0015AA, "Rextechnik International Co.,"},
	{0x0015AB, "PRO CO SOUND INC"},
	{0x0015AC, "Capelon AB"},
	{0x0015AD, "Accedian Networks"},
	{0x0015AE, "kyung il"},
	{0x0015AF, "AzureWave Technologies, Inc."},
	{0x0015B0, "AUTOTELENET CO.,LTD"},
	{0x0015B1, "Ambient Corporation"},
	{0x0015B2, "Advanced Industrial Computer, Inc."},
	{0x0015B3, "Caretech AB"},
	{0x0015B4, "Polymap  Wireless LLC"},
	{0x0015B5, "CI Network Corp."},
	{0x0015B6, "ShinMaywa Industries, Ltd."},
	{0x0015B7, "Toshiba"},
	{0x0015B8, "Tahoe"},
	{0x0015B9, "Samsung Electronics Co., Ltd."},
	{0x0015BA, "iba AG"},
	{0x0015BB, "SMA Solar Technology AG"},
	{0x0015BC, "Develco"},
	{0x0015BD, "Group 4 Technology Ltd"},
	{0x0015BE, "Iqua Ltd."},
	{0x0015BF, "technicob"},
	{0x0015C0, "DIGITAL TELEMEDIA CO.,LTD."},
	{0x0015C1, "SONY Computer Entertainment inc,"},
	{0x0015C2, "3M Germany"},
	{0x0015C3, "Ruf Telematik AG"},
	{0x0015C4, "FLOVEL CO., LTD."},
	{0x0015C5, "Dell Inc"},
	{0x0015C6, "Cisco Systems"},
	{0x0015C7, "Cisco Systems"},
	{0x0015C8, "FlexiPanel Ltd"},
	{0x0015C9, "Gumstix, Inc"},
	{0x0015CA, "TeraRecon, Inc."},
	{0x0015CB, "Surf Communication Solutions Ltd."},
	{0x0015CC, "TEPCO UQUEST, LTD."},
	{0x0015CD, "Exartech International Corp."},
	{0x0015CE, "ARRIS International"},
	{0x0015CF, "ARRIS International"},
	{0x0015D0, "ARRIS International"},
	{0x0015D1, "ARRIS Group, Inc."},
	{0x0015D2, "Xantech Corporation"},
	{0x0015D3, "Pantech&Curitel Communications, Inc."},
	{0x0015D4, "Emitor AB"},
	{0x0015D5, "NICEVT"},
	{0x0015D6, "OSLiNK Sp. z o.o."},
	{0x0015D7, "Reti Corporation"},
	{0x0015D8, "Interlink Electronics"},
	{0x0015D9, "PKC Electronics Oy"},
	{0x0015DA, "IRITEL A.D."},
	{0x0015DB, "Canesta Inc."},
	{0x0015DC, "KT&C Co., Ltd."},
	{0x0015DD, "IP Control Systems Ltd."},
	{0x0015DE, "Nokia Danmark A/S"},
	{0x0015DF, "Clivet S.p.A."},
	{0x0015E0, "ST-Ericsson"},
	{0x0015E1, "picoChip Designs Ltd"},
	{0x0015E2, "Dr.Ing. Herbert Knauer GmbH"},
	{0x0015E3, "Dream Technologies Corporation"},
	{0x0015E4, "Zimmer Elektromedizin"},
	{0x0015E5, "Cheertek Inc."},
	{0x0015E6, "MOBILE TECHNIKA Inc."},
	{0x0015E7, "Quantec ProAudio"},
	{0x0015E8, "Nortel"},
	{0x0015E9, "D-Link Corporation"},
	{0x0015EA, "Tellumat (Pty) Ltd"},
	{0x0015EB, "ZTE CORPORATION"},
	{0x0015EC, "Boca Devices LLC"},
	{0x0015ED, "Fulcrum Microsystems, Inc."},
	{0x0015EE, "Omnex Control Systems"},
	{0x0015EF, "NEC TOKIN Corporation"},
	{0x0015F0, "EGO BV"},
	{0x0015F1, "KYLINK Communications Corp."},
	{0x0015F2, "ASUSTek COMPUTER INC."},
	{0x0015F3, "PELTOR AB"},
	{0x0015F4, "Eventide"},
	{0x0015F5, "Sustainable Energy Systems"},
	{0x0015F6, "SCIENCE AND ENGINEERING SERVICES, INC."},
	{0x0015F7, "Wintecronics Ltd."},
	{0x0015F8, "Kingtronics Industrial Co. Ltd."},
	{0x0015F9, "Cisco Systems"},
	{0x0015FA, "Cisco Systems"},
	{0x0015FB, "setex schermuly textile computer gmbh"},
	{0x0015FC, "Littelfuse Startco"},
	{0x0015FD, "Complete Media Systems"},
	{0x0015FE, "SCHILLING ROBOTICS LLC"},
	{0x0015FF, "Novatel Wireless, Inc."},
	{0x001600, "CelleBrite Mobile Synchronization"},
	{0x001601, "Buffalo Inc."},
	{0x001602, "CEYON TECHNOLOGY CO.,LTD."},
	{0x001603, "COOLKSKY Co., LTD"},
	{0x001604, "Sigpro"},
	{0x001605, "YORKVILLE SOUND INC."},
	{0x001606, "Ideal Industries"},
	{0x001607, "Curves International Inc."},
	{0x001608, "Sequans Communications"},
	{0x001609, "Unitech electronics co., ltd."},
	{0x00160A, "SWEEX Europe BV"},
	{0x00160B, "TVWorks LLC"},
	{0x00160C, "LPL  DEVELOPMENT S.A. DE C.V"},
	{0x00160D, "Be Here Corporation"},
	{0x00160E, "Optica Technologies Inc."},
	{0x00160F, "BADGER METER INC"},
	{0x001610, "Carina Technology"},
	{0x001611, "Altecon Srl"},
	{0x001612, "Otsuka Electronics Co., Ltd."},
	{0x001613, "LibreStream Technologies Inc."},
	{0x001614, "Picosecond Pulse Labs"},
	{0x001615, "Nittan Company, Limited"},
	{0x001616, "BROWAN COMMUNICATION INC."},
	{0x001617, "MSI"},
	{0x001618, "HIVION Co., Ltd."},
	{0x001619, "La Factora de Comunicaciones Aplicadas,S.L."},
	{0x00161A, "Dametric AB"},
	{0x00161B, "Micronet Corporation"},
	{0x00161C, "e:cue"},
	{0x00161D, "Innovative Wireless Technologies, Inc."},
	{0x00161E, "Woojinnet"},
	{0x00161F, "SUNWAVETEC Co., Ltd."},
	{0x001620, "Sony Ericsson Mobile Communications AB"},
	{0x001621, "Colorado Vnet"},
	{0x001622, "BBH SYSTEMS GMBH"},
	{0x001623, "Interval Media"},
	{0x001624, "Teneros, Inc."},
	{0x001625, "Impinj, Inc."},
	{0x001626, "Motorola CHS"},
	{0x001627, "embedded-logic DESIGN AND MORE GmbH"},
	{0x001628, "Ultra Electronics Manufacturing and Card Systems"},
	{0x001629, "Nivus GmbH"},
	{0x00162A, "Antik computers & communications s.r.o."},
	{0x00162B, "Togami Electric Mfg.co.,Ltd."},
	{0x00162C, "Xanboo"},
	{0x00162D, "STNet Co., Ltd."},
	{0x00162E, "Space Shuttle Hi-Tech Co., Ltd."},
	{0x00162F, "Geutebrck GmbH"},
	{0x001630, "Vativ Technologies"},
	{0x001631, "Xteam"},
	{0x001632, "SAMSUNG ELECTRONICS CO., LTD."},
	{0x001633, "Oxford Diagnostics Ltd."},
	{0x001634, "Mathtech, Inc."},
	{0x001635, "Hewlett Packard"},
	{0x001636, "Quanta Computer Inc."},
	{0x001637, "Citel Srl"},
	{0x001638, "TECOM Co., Ltd."},
	{0x001639, "UBIQUAM Co.,Ltd"},
	{0x00163A, "YVES TECHNOLOGY CO., LTD."},
	{0x00163B, "VertexRSI/General Dynamics"},
	{0x00163C, "Rebox B.V."},
	{0x00163D, "Tsinghua Tongfang Legend Silicon Tech. Co., Ltd."},
	{0x00163E, "Xensource, Inc."},
	{0x00163F, "CReTE SYSTEMS Inc."},
	{0x001640, "Asmobile Communication Inc."},
	{0x001641, "USI"},
	{0x001642, "Pangolin"},
	{0x001643, "Sunhillo Corporation"},
	{0x001644, "LITE-ON Technology Corp."},
	{0x001645, "Power Distribution, Inc."},
	{0x001646, "Cisco Systems"},
	{0x001647, "Cisco Systems"},
	{0x001648, "SSD Company Limited"},
	{0x001649, "SetOne GmbH"},
	{0x00164A, "Vibration Technology Limited"},
	{0x00164B, "Quorion Data Systems GmbH"},
	{0x00164C, "PLANET INT Co., Ltd"},
	{0x00164D, "Alcatel North America IP Division"},
	{0x00164E, "Nokia Danmark A/S"},
	{0x00164F, "World Ethnic Broadcastin Inc."},
	{0x001650, "Herley General Microwave Israel. "},
	{0x001651, "Exeo Systems"},
	{0x001652, "Hoatech Technologies, Inc."},
	{0x001653, "LEGO System A/S IE Electronics Division"},
	{0x001654, "Flex-P Industries Sdn. Bhd."},
	{0x001655, "FUHO TECHNOLOGY Co., LTD"},
	{0x001656, "Nintendo Co., Ltd."},
	{0x001657, "Aegate Ltd"},
	{0x001658, "Fusiontech Technologies Inc."},
	{0x001659, "Z.M.P. RADWAG"},
	{0x00165A, "Harman Specialty Group"},
	{0x00165B, "Grip Audio"},
	{0x00165C, "Trackflow Ltd"},
	{0x00165D, "AirDefense, Inc."},
	{0x00165E, "Precision I/O"},
	{0x00165F, "Fairmount Automation"},
	{0x001660, "Nortel"},
	{0x001661, "Novatium Solutions (P) Ltd"},
	{0x001662, "Liyuh Technology Ltd."},
	{0x001663, "KBT Mobile"},
	{0x001664, "Prod-El SpA"},
	{0x001665, "Cellon France"},
	{0x001666, "Quantier Communication Inc."},
	{0x001667, "A-TEC Subsystem INC."},
	{0x001668, "Eishin Electronics"},
	{0x001669, "MRV Communication (Networks) LTD"},
	{0x00166A, "TPS"},
	{0x00166B, "Samsung Electronics"},
	{0x00166C, "Samsung Electonics Digital Video System Division"},
	{0x00166D,
	 "Yulong Computer Telecommunication Scientific(shenzhen)Co.,Lt"},
	{0x00166E, "Arbitron Inc."},
	{0x00166F, "Intel Corporation"},
	{0x001670, "SKNET Corporation"},
	{0x001671, "Symphox Information Co."},
	{0x001672, "Zenway enterprise ltd"},
	{0x001673, "Bury GmbH & Co. KG"},
	{0x001674, "EuroCB (Phils.), Inc."},
	{0x001675, "Motorola MDb"},
	{0x001676, "Intel Corporation"},
	{0x001677, "Bihl+Wiedemann GmbH"},
	{0x001678, "SHENZHEN BAOAN GAOKE ELECTRONICS CO., LTD"},
	{0x001679, "eOn Communications"},
	{0x00167A, "Skyworth Overseas Dvelopment Ltd."},
	{0x00167B, "Haver&Boecker"},
	{0x00167C, "iRex Technologies BV"},
	{0x00167D, "Sky-Line Information Co., Ltd."},
	{0x00167E, "DIBOSS.CO.,LTD"},
	{0x00167F, "Bluebird Soft Inc."},
	{0x001680, "Bally Gaming + Systems"},
	{0x001681, "Vector Informatik GmbH"},
	{0x001682, "Pro Dex, Inc"},
	{0x001683, "WEBIO International Co.,.Ltd."},
	{0x001684, "Donjin Co.,Ltd."},
	{0x001685, "Elisa Oyj"},
	{0x001686, "Karl Storz Imaging"},
	{0x001687, "Chubb CSC-Vendor AP"},
	{0x001688, "ServerEngines LLC"},
	{0x001689, "Pilkor Electronics Co., Ltd"},
	{0x00168A, "id-Confirm Inc"},
	{0x00168B, "Paralan Corporation"},
	{0x00168C, "DSL Partner AS"},
	{0x00168D, "KORWIN CO., Ltd."},
	{0x00168E, "Vimicro corporation"},
	{0x00168F, "GN Netcom as"},
	{0x001690, "J-TEK INCORPORATION"},
	{0x001691, "Moser-Baer AG"},
	{0x001692, "Scientific-Atlanta, Inc."},
	{0x001693, "PowerLink Technology Inc."},
	{0x001694, "Sennheiser Communications A/S"},
	{0x001695, "AVC Technology Limited"},
	{0x001696, "QDI Technology (H.K.) Limited"},
	{0x001697, "NEC Corporation"},
	{0x001698, "T&A Mobile Phones"},
	{0x001699, "Tonic DVB Marketing Ltd"},
	{0x00169A, "Quadrics Ltd"},
	{0x00169B, "Alstom Transport"},
	{0x00169C, "Cisco Systems"},
	{0x00169D, "Cisco Systems"},
	{0x00169E, "TV One Ltd"},
	{0x00169F, "Vimtron Electronics Co., Ltd."},
	{0x0016A0, "Auto-Maskin"},
	{0x0016A1, "3Leaf Networks"},
	{0x0016A2, "CentraLite Systems, Inc."},
	{0x0016A3, "Ingeteam Transmission&Distribution, S.A."},
	{0x0016A4, "Ezurio Ltd"},
	{0x0016A5, "Tandberg Storage ASA"},
	{0x0016A6, "Dovado FZ-LLC"},
	{0x0016A7, "AWETA G&P"},
	{0x0016A8, "CWT CO., LTD."},
	{0x0016A9, "2EI"},
	{0x0016AA, "Kei Communication Technology Inc."},
	{0x0016AB, "PBI-Dansensor A/S"},
	{0x0016AC, "Toho Technology Corp."},
	{0x0016AD, "BT-Links Company Limited"},
	{0x0016AE, "INVENTEL"},
	{0x0016AF, "Shenzhen Union Networks Equipment Co.,Ltd."},
	{0x0016B0, "VK Corporation"},
	{0x0016B1, "KBS"},
	{0x0016B2, "DriveCam Inc"},
	{0x0016B3, "Photonicbridges (China) Co., Ltd."},
	{0x0016B5, "Motorola CHS"},
	{0x0016B6, "Cisco-Linksys"},
	{0x0016B7, "Seoul Commtech"},
	{0x0016B8, "Sony Ericsson Mobile Communications"},
	{0x0016B9, "ProCurve Networking"},
	{0x0016BA, "WEATHERNEWS INC."},
	{0x0016BB, "Law-Chain Computer Technology Co Ltd"},
	{0x0016BC, "Nokia Danmark A/S"},
	{0x0016BD, "ATI Industrial Automation"},
	{0x0016BE, "INFRANET, Inc."},
	{0x0016BF, "PaloDEx Group Oy"},
	{0x0016C0, "Semtech Corporation"},
	{0x0016C1, "Eleksen Ltd"},
	{0x0016C2, "Avtec Systems Inc"},
	{0x0016C3, "BA Systems Inc"},
	{0x0016C4, "SiRF Technology, Inc."},
	{0x0016C5, "Shenzhen Xing Feng Industry Co.,Ltd"},
	{0x0016C6, "North Atlantic Industries"},
	{0x0016C7, "Cisco Systems"},
	{0x0016C8, "Cisco Systems"},
	{0x0016C9, "NAT Seattle, Inc."},
	{0x0016CA, "Nortel"},
	{0x0016CB, "Apple Computer"},
	{0x0016CC, "Xcute Mobile Corp."},
	{0x0016CD, "HIJI HIGH-TECH CO., LTD."},
	{0x0016CE, "Hon Hai Precision Ind. Co., Ltd."},
	{0x0016CF, "Hon Hai Precision Ind. Co., Ltd."},
	{0x0016D0, "ATech elektronika d.o.o."},
	{0x0016D1, "ZAT a.s."},
	{0x0016D2, "Caspian"},
	{0x0016D3, "Wistron Corporation"},
	{0x0016D4, "Compal Communications, Inc."},
	{0x0016D5, "Synccom Co., Ltd"},
	{0x0016D6, "TDA Tech Pty Ltd"},
	{0x0016D7, "Sunways AG"},
	{0x0016D8, "Senea AB"},
	{0x0016D9, "NINGBO BIRD CO.,LTD."},
	{0x0016DA, "Futronic Technology Co. Ltd."},
	{0x0016DB, "Samsung Electronics Co., Ltd."},
	{0x0016DC, "ARCHOS"},
	{0x0016DD, "Gigabeam Corporation"},
	{0x0016DE, "FAST Inc"},
	{0x0016DF, "Lundinova AB"},
	{0x0016E0, "3Com Ltd"},
	{0x0016E1, "SiliconStor, Inc."},
	{0x0016E2, "American Fibertek, Inc."},
	{0x0016E3, "ASKEY COMPUTER CORP."},
	{0x0016E4, "VANGUARD SECURITY ENGINEERING CORP."},
	{0x0016E5, "FORDLEY DEVELOPMENT LIMITED"},
	{0x0016E6, "GIGA-BYTE TECHNOLOGY CO.,LTD."},
	{0x0016E7, "Dynamix Promotions Limited"},
	{0x0016E8, "Sigma Designs, Inc."},
	{0x0016E9, "Tiba Medical Inc"},
	{0x0016EA, "Intel Corporation"},
	{0x0016EB, "Intel Corporation"},
	{0x0016EC, "Elitegroup Computer Systems Co., Ltd."},
	{0x0016ED, "Digital Safety Technologies, Inc"},
	{0x0016EE, "RoyalDigital Inc."},
	{0x0016EF, "Koko Fitness, Inc."},
	{0x0016F0, "Dell"},
	{0x0016F1, "OmniSense, LLC"},
	{0x0016F2, "Dmobile System Co., Ltd."},
	{0x0016F3, "CAST Information Co., Ltd"},
	{0x0016F4, "Eidicom Co., Ltd."},
	{0x0016F5, "Dalian Golden Hualu Digital Technology Co.,Ltd"},
	{0x0016F6, "Video Products Group"},
	{0x0016F7, "L-3 Communications, Electrodynamics, Inc."},
	{0x0016F8, "AVIQTECH TECHNOLOGY CO., LTD."},
	{0x0016F9, "CETRTA POT, d.o.o., Kranj"},
	{0x0016FA, "ECI Telecom Ltd."},
	{0x0016FB, "SHENZHEN MTC CO.,LTD."},
	{0x0016FC, "TOHKEN CO.,LTD."},
	{0x0016FD, "Jaty Electronics"},
	{0x0016FE, "Alps Electric Co., Ltd"},
	{0x0016FF, "Wamin Optocomm Mfg Corp"},
	{0x001700, "Motorola MDb"},
	{0x001701, "KDE, Inc."},
	{0x001702, "Osung Midicom Co., Ltd"},
	{0x001703, "MOSDAN Internation Co.,Ltd"},
	{0x001704, "Shinco Electronics Group Co.,Ltd"},
	{0x001705, "Methode Electronics"},
	{0x001706, "Techfaith Wireless Communication Technology Limited."},
	{0x001707, "InGrid, Inc"},
	{0x001708, "Hewlett Packard"},
	{0x001709, "Exalt Communications"},
	{0x00170A, "INEW DIGITAL COMPANY"},
	{0x00170B, "Contela, Inc."},
	{0x00170C, "GeoSentric OYj"},
	{0x00170D, "Dust Networks Inc."},
	{0x00170E, "Cisco Systems"},
	{0x00170F, "Cisco Systems"},
	{0x001710, "Casa Systems Inc."},
	{0x001711, "GE Healthcare Bio-Sciences AB"},
	{0x001712, "ISCO International"},
	{0x001713, "Tiger NetCom"},
	{0x001714, "BR Controls Nederland bv"},
	{0x001715, "Qstik"},
	{0x001716, "Qno Technology Inc."},
	{0x001717, "Leica Geosystems AG"},
	{0x001718, "Vansco Electronics Oy"},
	{0x001719, "AudioCodes USA, Inc"},
	{0x00171A, "Winegard Company"},
	{0x00171B, "Innovation Lab Corp."},
	{0x00171C, "NT MicroSystems, Inc."},
	{0x00171D, "DIGIT"},
	{0x00171E, "Theo Benning GmbH & Co. KG"},
	{0x00171F, "IMV Corporation"},
	{0x001720, "Image Sensing Systems, Inc."},
	{0x001721, "FITRE S.p.A."},
	{0x001722, "Hanazeder Electronic GmbH"},
	{0x001723, "Summit Data Communications"},
	{0x001724, "Studer Professional Audio GmbH"},
	{0x001725, "Liquid Computing"},
	{0x001726, "m2c Electronic Technology Ltd."},
	{0x001727, "Thermo Ramsey Italia s.r.l."},
	{0x001728, "Selex Communications"},
	{0x001729, "Ubicod Co.LTD"},
	{0x00172A, "Proware Technology Corp."},
	{0x00172B, "Global Technologies Inc."},
	{0x00172C, "TAEJIN INFOTECH"},
	{0x00172D, "Axcen Photonics Corporation"},
	{0x00172E, "FXC Inc."},
	{0x00172F, "NeuLion Incorporated"},
	{0x001730, "Automation Electronics"},
	{0x001731, "ASUSTek COMPUTER INC."},
	{0x001732, "Science-Technical Center \"RISSA\""},
	{0x001733, "SFR"},
	{0x001734, "ADC Telecommunications"},
	{0x001736, "iiTron Inc."},
	{0x001737, "Industrie Dial Face S.p.A."},
	{0x001738, "International Business Machines"},
	{0x001739, "Bright Headphone Electronics Company"},
	{0x00173A, "Reach Systems Inc."},
	{0x00173B, "Arched Rock Corporation"},
	{0x00173C, "Extreme Engineering Solutions"},
	{0x00173D, "Neology"},
	{0x00173E, "LeucotronEquipamentos Ltda."},
	{0x00173F, "Belkin Corporation"},
	{0x001740, "Technologies Labtronix"},
	{0x001741, "DEFIDEV"},
	{0x001742, "FUJITSU LIMITED"},
	{0x001743, "Deck Srl"},
	{0x001744, "Araneo Ltd."},
	{0x001745, "INNOTZ CO., Ltd"},
	{0x001746, "Freedom9 Inc."},
	{0x001747, "Trimble"},
	{0x001748, "Neokoros Brasil Ltda"},
	{0x001749, "HYUNDAE YONG-O-SA CO.,LTD"},
	{0x00174A, "SOCOMEC"},
	{0x00174B, "Nokia Danmark A/S"},
	{0x00174C, "Millipore"},
	{0x00174D, "DYNAMIC NETWORK FACTORY, INC."},
	{0x00174E, "Parama-tech Co.,Ltd."},
	{0x00174F, "iCatch Inc."},
	{0x001750, "GSI Group, MicroE Systems"},
	{0x001751, "Online Corporation"},
	{0x001752, "DAGS, Inc"},
	{0x001753, "nFore Technology Inc."},
	{0x001754, "Arkino Corporation., Ltd"},
	{0x001755, "GE Security"},
	{0x001756, "Vinci Labs Oy"},
	{0x001757, "RIX TECHNOLOGY LIMITED"},
	{0x001758, "ThruVision Ltd"},
	{0x001759, "Cisco Systems"},
	{0x00175A, "Cisco Systems"},
	{0x00175B, "ACS Solutions Switzerland Ltd."},
	{0x00175C, "SHARP CORPORATION"},
	{0x00175D, "Dongseo system."},
	{0x00175E, "Zed-3"},
	{0x00175F, "XENOLINK Communications Co., Ltd."},
	{0x001760, "Naito Densei Machida MFG.CO.,LTD"},
	{0x001761, "ZKSoftware Inc."},
	{0x001762, "Solar Technology, Inc."},
	{0x001763, "Essentia S.p.A."},
	{0x001764, "ATMedia GmbH"},
	{0x001765, "Nortel"},
	{0x001766, "Accense Technology, Inc."},
	{0x001767, "Earforce AS"},
	{0x001768, "Zinwave Ltd"},
	{0x001769, "Cymphonix Corp"},
	{0x00176A, "Avago Technologies"},
	{0x00176B, "Kiyon, Inc."},
	{0x00176C, "Pivot3, Inc."},
	{0x00176D, "CORE CORPORATION"},
	{0x00176E, "DUCATI SISTEMI"},
	{0x00176F, "PAX Computer Technology(Shenzhen) Ltd."},
	{0x001770, "Arti Industrial Electronics Ltd."},
	{0x001771, "APD Communications Ltd"},
	{0x001772, "ASTRO Strobel Kommunikationssysteme GmbH"},
	{0x001773, "Laketune Technologies Co. Ltd"},
	{0x001774, "Elesta GmbH"},
	{0x001775, "TTE Germany GmbH"},
	{0x001776, "Meso Scale Diagnostics, LLC"},
	{0x001777, "Obsidian Research Corporation"},
	{0x001778, "Central Music Co."},
	{0x001779, "QuickTel"},
	{0x00177A, "ASSA ABLOY AB"},
	{0x00177B, "Azalea Networks inc"},
	{0x00177C, "Smartlink Network Systems Limited"},
	{0x00177D, "IDT International Limited"},
	{0x00177E, "Meshcom Technologies Inc."},
	{0x00177F, "Worldsmart Retech"},
	{0x001780, "Applera Holding B.V. Singapore Operations"},
	{0x001781, "Greystone Data System, Inc."},
	{0x001782, "LoBenn Inc."},
	{0x001783, "Texas Instruments"},
	{0x001784, "Motorola Mobile Devices"},
	{0x001785, "Sparr Electronics Ltd"},
	{0x001786, "wisembed"},
	{0x001787, "Brother, Brother & Sons ApS"},
	{0x001788, "Philips Lighting BV"},
	{0x001789, "Zenitron Corporation"},
	{0x00178A, "DARTS TECHNOLOGIES CORP."},
	{0x00178B, "Teledyne Technologies Incorporated"},
	{0x00178C, "Independent Witness, Inc"},
	{0x00178D, "Checkpoint Systems, Inc."},
	{0x00178E, "Gunnebo Cash Automation AB"},
	{0x00178F, "NINGBO YIDONG ELECTRONIC CO.,LTD."},
	{0x001790, "HYUNDAI DIGITECH Co, Ltd."},
	{0x001791, "LinTech GmbH"},
	{0x001792, "Falcom Wireless Comunications Gmbh"},
	{0x001793, "Tigi Corporation"},
	{0x001794, "Cisco Systems"},
	{0x001795, "Cisco Systems"},
	{0x001796, "Rittmeyer AG"},
	{0x001797, "Telsy Elettronica S.p.A."},
	{0x001798, "Azonic Technology Co., LTD"},
	{0x001799, "SmarTire Systems Inc."},
	{0x00179A, "D-Link Corporation"},
	{0x00179B, "Chant Sincere CO., LTD."},
	{0x00179C, "DEPRAG SCHULZ GMBH u. CO."},
	{0x00179D, "Kelman Limited"},
	{0x00179E, "Sirit Inc"},
	{0x00179F, "Apricorn"},
	{0x0017A0, "RoboTech srl"},
	{0x0017A1, "3soft inc."},
	{0x0017A2, "Camrivox Ltd."},
	{0x0017A3, "MIX s.r.l."},
	{0x0017A4, "Hewlett Packard"},
	{0x0017A5, "TrendChip Technologies Corp."},
	{0x0017A6, "YOSIN ELECTRONICS CO., LTD."},
	{0x0017A7, "Mobile Computing Promotion Consortium"},
	{0x0017A8, "EDM Corporation"},
	{0x0017A9, "Sentivision"},
	{0x0017AA, "elab-experience inc."},
	{0x0017AB, "Nintendo Co., Ltd."},
	{0x0017AC, "O'Neil Product Development Inc."},
	{0x0017AD, "AceNet Corporation"},
	{0x0017AE, "GAI-Tronics"},
	{0x0017AF, "Enermet"},
	{0x0017B0, "Nokia Danmark A/S"},
	{0x0017B1, "ACIST Medical Systems, Inc."},
	{0x0017B2, "SK Telesys"},
	{0x0017B3, "Aftek Infosys Limited"},
	{0x0017B4, "Remote Security Systems, LLC"},
	{0x0017B5, "Peerless Systems Corporation"},
	{0x0017B6, "Aquantia"},
	{0x0017B7, "Tonze Technology Co."},
	{0x0017B8, "NOVATRON CO., LTD."},
	{0x0017B9, "Gambro Lundia AB"},
	{0x0017BA, "SEDO CO., LTD."},
	{0x0017BB, "Syrinx Industrial Electronics"},
	{0x0017BC, "Touchtunes Music Corporation"},
	{0x0017BD, "Tibetsystem"},
	{0x0017BE, "Tratec Telecom B.V."},
	{0x0017BF, "Coherent Research Limited"},
	{0x0017C0, "PureTech Systems, Inc."},
	{0x0017C1, "CM Precision Technology LTD."},
	{0x0017C2, "Pirelli Broadband Solutions"},
	{0x0017C3, "KTF Technologies Inc."},
	{0x0017C4, "Quanta Microsystems, INC."},
	{0x0017C5, "SonicWALL"},
	{0x0017C6, "Cross Match Technologies Inc"},
	{0x0017C7, "MARA Systems Consulting AB"},
	{0x0017C8, "Kyocera Mita Corporation"},
	{0x0017C9, "Samsung Electronics Co., Ltd."},
	{0x0017CA, "Qisda Corporation"},
	{0x0017CB, "Juniper Networks"},
	{0x0017CC, "Alcatel-Lucent"},
	{0x0017CD, "CEC Wireless R&D Ltd."},
	{0x0017CE, "MB International Telecom Labs srl"},
	{0x0017CF, "iMCA-GmbH"},
	{0x0017D0, "Opticom Communications, LLC"},
	{0x0017D1, "Nortel"},
	{0x0017D2, "THINLINX PTY LTD"},
	{0x0017D3, "Etymotic Research, Inc."},
	{0x0017D4, "Monsoon Multimedia, Inc"},
	{0x0017D5, "Samsung Electronics Co., Ltd."},
	{0x0017D6, "Bluechips Microhouse Co.,Ltd."},
	{0x0017D7, "ION Geophysical Corporation Inc."},
	{0x0017D8, "Magnum Semiconductor, Inc."},
	{0x0017D9, "AAI Corporation"},
	{0x0017DA, "Spans Logic"},
	{0x0017DB, "CANKO TECHNOLOGIES INC."},
	{0x0017DC, "DAEMYUNG ZERO1"},
	{0x0017DD, "Clipsal Australia"},
	{0x0017DE, "Advantage Six Ltd"},
	{0x0017DF, "Cisco Systems"},
	{0x0017E0, "Cisco Systems"},
	{0x0017E1, "DACOS Technologies Co., Ltd."},
	{0x0017E2, "Motorola Mobile Devices"},
	{0x0017E3, "Texas Instruments"},
	{0x0017E4, "Texas Instruments"},
	{0x0017E5, "Texas Instruments"},
	{0x0017E6, "Texas Instruments"},
	{0x0017E7, "Texas Instruments"},
	{0x0017E8, "Texas Instruments"},
	{0x0017E9, "Texas Instruments"},
	{0x0017EA, "Texas Instruments"},
	{0x0017EB, "Texas Instruments"},
	{0x0017EC, "Texas Instruments"},
	{0x0017ED, "WooJooIT Ltd."},
	{0x0017EE, "Motorola CHS"},
	{0x0017EF, "Blade Network Technologies, Inc."},
	{0x0017F0, "SZCOM Broadband Network Technology Co.,Ltd"},
	{0x0017F1, "Renu Electronics Pvt Ltd"},
	{0x0017F2, "Apple Computer"},
	{0x0017F3, "Harris Corparation"},
	{0x0017F4, "ZERON ALLIANCE"},
	{0x0017F5, "LIG NEOPTEK"},
	{0x0017F6, "Pyramid Meriden Inc."},
	{0x0017F7, "CEM Solutions Pvt Ltd"},
	{0x0017F8, "Motech Industries Inc."},
	{0x0017F9, "Forcom Sp. z o.o."},
	{0x0017FA, "Microsoft Corporation"},
	{0x0017FB, "FA"},
	{0x0017FC, "Suprema Inc."},
	{0x0017FD, "Amulet Hotkey"},
	{0x0017FE, "TALOS SYSTEM INC."},
	{0x0017FF, "PLAYLINE Co.,Ltd."},
	{0x001800, "UNIGRAND LTD"},
	{0x001801, "Actiontec Electronics, Inc"},
	{0x001802, "Alpha Networks Inc."},
	{0x001803, "ArcSoft Shanghai Co. LTD"},
	{0x001804, "E-TEK DIGITAL TECHNOLOGY LIMITED"},
	{0x001805, "Beijing InHand Networking Technology Co.,Ltd."},
	{0x001806, "Hokkei Industries Co., Ltd."},
	{0x001807, "Fanstel Corp."},
	{0x001808, "SightLogix, Inc."},
	{0x001809, "CRESYN"},
	{0x00180A, "Meraki, Inc."},
	{0x00180B, "Brilliant Telecommunications"},
	{0x00180C, "Optelian Access Networks"},
	{0x00180D, "Terabytes Server Storage Tech Corp"},
	{0x00180E, "Avega Systems"},
	{0x00180F, "Nokia Danmark A/S"},
	{0x001810, "IPTrade S.A."},
	{0x001811, "Neuros Technology International, LLC."},
	{0x001812, "Beijing Xinwei Telecom Technology Co., Ltd."},
	{0x001813, "Sony Ericsson Mobile Communications"},
	{0x001814, "Mitutoyo Corporation"},
	{0x001815, "GZ Technologies, Inc."},
	{0x001816, "Ubixon Co., Ltd."},
	{0x001817, "D. E. Shaw Research, LLC"},
	{0x001818, "Cisco Systems"},
	{0x001819, "Cisco Systems"},
	{0x00181A, "AVerMedia Information Inc."},
	{0x00181B, "TaiJin Metal Co., Ltd."},
	{0x00181C, "Exterity Limited"},
	{0x00181D, "ASIA ELECTRONICS CO.,LTD"},
	{0x00181E, "GDX Technologies Ltd."},
	{0x00181F, "Palmmicro Communications"},
	{0x001820, "w5networks"},
	{0x001821, "SINDORICOH"},
	{0x001822, "CEC TELECOM CO.,LTD."},
	{0x001823, "Delta Electronics, Inc."},
	{0x001824, "Kimaldi Electronics, S.L."},
	{0x001825, "Wavion LTD"},
	{0x001826, "Cale Access AB"},
	{0x001827, "NEC PHILIPS UNIFIED SOLUTIONS NEDERLAND BV"},
	{0x001828, "e2v technologies (UK) ltd."},
	{0x001829, "Gatsometer"},
	{0x00182A, "Taiwan Video & Monitor"},
	{0x00182B, "Softier"},
	{0x00182C, "Ascend Networks, Inc."},
	{0x00182D, "Artec Group O"},
	{0x00182E, "XStreamHD, LLC"},
	{0x00182F, "Texas Instruments"},
	{0x001830, "Texas Instruments"},
	{0x001831, "Texas Instruments"},
	{0x001832, "Texas Instruments"},
	{0x001833, "Texas Instruments"},
	{0x001834, "Texas Instruments"},
	{0x001835, "Thoratec / ITC"},
	{0x001836, "Reliance Electric Limited"},
	{0x001837, "Universal ABIT Co., Ltd."},
	{0x001838, "PanAccess Communications,Inc."},
	{0x001839, "Cisco-Linksys LLC"},
	{0x00183A, "Westell Technologies"},
	{0x00183B, "CENITS Co., Ltd."},
	{0x00183C, "Encore Software Limited"},
	{0x00183D, "Vertex Link Corporation"},
	{0x00183E, "Digilent, Inc"},
	{0x00183F, "2Wire, Inc"},
	{0x001840, "3 Phoenix, Inc."},
	{0x001841, "High Tech Computer Corp"},
	{0x001842, "Nokia Danmark A/S"},
	{0x001843, "Dawevision Ltd"},
	{0x001844, "Heads Up Technologies, Inc."},
	{0x001845, "NPL Pulsar Ltd."},
	{0x001846, "Crypto S.A."},
	{0x001847, "AceNet Technology Inc."},
	{0x001848, "Vecima Networks Inc."},
	{0x001849, "Pigeon Point Systems"},
	{0x00184A, "Catcher, Inc."},
	{0x00184B, "Las Vegas Gaming, Inc."},
	{0x00184C, "Bogen Communications"},
	{0x00184D, "Netgear Inc."},
	{0x00184E, "Lianhe Technologies, Inc."},
	{0x00184F, "8 Ways Technology Corp."},
	{0x001850, "Secfone Kft"},
	{0x001851, "SWsoft"},
	{0x001852, "StorLink Semiconductors, Inc."},
	{0x001853, "Atera Networks LTD."},
	{0x001854, "Argard Co., Ltd"},
	{0x001855, "Aeromaritime Systembau GmbH"},
	{0x001856, "EyeFi, Inc"},
	{0x001857, "Unilever R&D"},
	{0x001858, "TagMaster AB"},
	{0x001859, "Strawberry Linux Co.,Ltd."},
	{0x00185A, "uControl, Inc."},
	{0x00185B, "Network Chemistry, Inc"},
	{0x00185C, "EDS Lab Pte Ltd"},
	{0x00185D, "TAIGUEN TECHNOLOGY (SHEN-ZHEN) CO., LTD."},
	{0x00185E, "Nexterm Inc."},
	{0x00185F, "TAC Inc."},
	{0x001860, "SIM Technology Group Shanghai Simcom Ltd.,"},
	{0x001861, "Ooma, Inc."},
	{0x001862, "Seagate Technology"},
	{0x001863, "Veritech Electronics Limited"},
	{0x001864, "Cybectec Inc."},
	{0x001865, "Siemens Healthcare Diagnostics Manufacturing Ltd"},
	{0x001866, "Leutron Vision"},
	{0x001867, "Evolution Robotics Retail"},
	{0x001868, "Scientific Atlanta, A Cisco Company"},
	{0x001869, "KINGJIM"},
	{0x00186A, "Global Link Digital Technology Co,.LTD"},
	{0x00186B, "Sambu Communics CO., LTD."},
	{0x00186C, "Neonode AB"},
	{0x00186D, "Zhenjiang Sapphire Electronic Industry CO."},
	{0x00186E, "3Com Ltd"},
	{0x00186F, "Setha Industria Eletronica LTDA"},
	{0x001870, "E28 Shanghai Limited"},
	{0x001871, "Hewlett Packard"},
	{0x001872, "Expertise Engineering"},
	{0x001873, "Cisco Systems"},
	{0x001874, "Cisco Systems"},
	{0x001875, "AnaCise Testnology Pte Ltd"},
	{0x001876, "WowWee Ltd."},
	{0x001877, "Amplex A/S"},
	{0x001878, "Mackware GmbH"},
	{0x001879, "dSys"},
	{0x00187A, "Wiremold"},
	{0x00187B, "4NSYS Co. Ltd."},
	{0x00187C, "INTERCROSS, LLC"},
	{0x00187D, "Armorlink shanghai Co. Ltd"},
	{0x00187E, "RGB Spectrum"},
	{0x00187F, "ZODIANET"},
	{0x001880, "Maxim Integrated Circuits"},
	{0x001881, "Buyang Electronics Industrial Co., Ltd"},
	{0x001882, "Huawei Technologies Co., Ltd."},
	{0x001883, "FORMOSA21 INC."},
	{0x001884, "FON"},
	{0x001885, "Avigilon Corporation"},
	{0x001886, "EL-TECH, INC."},
	{0x001887, "Metasystem SpA"},
	{0x001888, "GOTIVE a.s."},
	{0x001889, "WinNet Solutions Limited"},
	{0x00188A, "Infinova LLC"},
	{0x00188B, "Dell"},
	{0x00188C, "Mobile Action Technology Inc."},
	{0x00188D, "Nokia Danmark A/S"},
	{0x00188E, "Ekahau, Inc."},
	{0x00188F, "Montgomery Technology, Inc."},
	{0x001890, "RadioCOM, s.r.o."},
	{0x001891, "Zhongshan General K-mate Electronics Co., Ltd"},
	{0x001892, "ads-tec GmbH"},
	{0x001893, "SHENZHEN PHOTON BROADBAND TECHNOLOGY CO.,LTD"},
	{0x001894, "zimocom"},
	{0x001895, "Hansun Technologies Inc."},
	{0x001896, "Great Well Electronic LTD"},
	{0x001897, "JESS-LINK PRODUCTS Co., LTD"},
	{0x001898, "KINGSTATE ELECTRONICS CORPORATION"},
	{0x001899, "ShenZhen jieshun Science&Technology Industry CO,LTD."},
	{0x00189A, "HANA Micron Inc."},
	{0x00189B, "Thomson Inc."},
	{0x00189C, "Weldex Corporation"},
	{0x00189D, "Navcast Inc."},
	{0x00189E, "OMNIKEY GmbH."},
	{0x00189F, "Lenntek Corporation"},
	{0x0018A0, "Cierma Ascenseurs"},
	{0x0018A1, "Tiqit Computers, Inc."},
	{0x0018A2, "XIP Technology AB"},
	{0x0018A3, "ZIPPY TECHNOLOGY CORP."},
	{0x0018A4, "Motorola Mobile Devices"},
	{0x0018A5, "ADigit Technologies Corp."},
	{0x0018A6, "Persistent Systems, LLC"},
	{0x0018A7, "Yoggie Security Systems LTD."},
	{0x0018A8, "AnNeal Technology Inc."},
	{0x0018A9, "Ethernet Direct Corporation"},
	{0x0018AA, "Protec Fire Detection plc"},
	{0x0018AB, "BEIJING LHWT MICROELECTRONICS INC."},
	{0x0018AC, "Shanghai Jiao Da HISYS Technology Co. Ltd."},
	{0x0018AD, "NIDEC SANKYO CORPORATION"},
	{0x0018AE, "TVT CO.,LTD"},
	{0x0018AF, "Samsung Electronics Co., Ltd."},
	{0x0018B0, "Nortel"},
	{0x0018B1, "Blade Network Technologies"},
	{0x0018B2, "ADEUNIS RF"},
	{0x0018B3, "TEC WizHome Co., Ltd."},
	{0x0018B4, "Dawon Media Inc."},
	{0x0018B5, "Magna Carta"},
	{0x0018B6, "S3C, Inc."},
	{0x0018B7, "D3 LED, LLC"},
	{0x0018B8, "New Voice International AG"},
	{0x0018B9, "Cisco Systems"},
	{0x0018BA, "Cisco Systems"},
	{0x0018BB, "Eliwell Controls srl"},
	{0x0018BC, "ZAO NVP Bolid"},
	{0x0018BD, "SHENZHEN DVBWORLD TECHNOLOGY CO., LTD."},
	{0x0018BE, "ANSA Corporation"},
	{0x0018BF, "Essence Technology Solution, Inc."},
	{0x0018C0, "Motorola CHS"},
	{0x0018C1, "Almitec Informtica e Comrcio Ltda."},
	{0x0018C2, "Firetide, Inc"},
	{0x0018C3, "C&S Microwave"},
	{0x0018C4, "Raba Technologies LLC"},
	{0x0018C5, "Nokia Danmark A/S"},
	{0x0018C6, "OPW Fuel Management Systems"},
	{0x0018C7, "Real Time Automation"},
	{0x0018C8, "ISONAS Inc."},
	{0x0018C9, "EOps Technology Limited"},
	{0x0018CA, "Viprinet GmbH"},
	{0x0018CB, "Tecobest Technology Limited"},
	{0x0018CC, "AXIOHM SAS"},
	{0x0018CD, "Erae Electronics Industry Co., Ltd"},
	{0x0018CE, "Dreamtech Co., Ltd"},
	{0x0018CF, "Baldor Electric Company"},
	{0x0018D0, "AtRoad,  A Trimble Company"},
	{0x0018D1, "Siemens Home & Office Comm. Devices"},
	{0x0018D2, "High-Gain Antennas LLC"},
	{0x0018D3, "TEAMCAST"},
	{0x0018D4, "Unified Display Interface SIG"},
	{0x0018D5, "REIGNCOM"},
	{0x0018D6, "Swirlnet A/S"},
	{0x0018D7, "Javad Navigation Systems Inc."},
	{0x0018D8, "ARCH METER Corporation"},
	{0x0018D9, "Santosha Internatonal, Inc"},
	{0x0018DA, "AMBER wireless GmbH"},
	{0x0018DB, "EPL Technology Ltd"},
	{0x0018DC, "Prostar Co., Ltd."},
	{0x0018DD, "Silicondust Engineering Ltd"},
	{0x0018DE, "Intel Corporation"},
	{0x0018DF, "The Morey Corporation"},
	{0x0018E0, "ANAVEO"},
	{0x0018E1, "Verkerk Service Systemen"},
	{0x0018E2, "Topdata Sistemas de Automacao Ltda"},
	{0x0018E3, "Visualgate Systems, Inc."},
	{0x0018E4, "YIGUANG"},
	{0x0018E5, "Adhoco AG"},
	{0x0018E6, "Computer Hardware Design SIA"},
	{0x0018E7, "Cameo Communications, INC."},
	{0x0018E8, "Hacetron Corporation"},
	{0x0018E9, "Numata Corporation"},
	{0x0018EA, "Alltec GmbH"},
	{0x0018EB, "BroVis Wireless Networks"},
	{0x0018EC, "Welding Technology Corporation"},
	{0x0018ED, "Accutech Ultrasystems Co., Ltd."},
	{0x0018EE, "Videology Imaging Solutions, Inc."},
	{0x0018EF, "Escape Communications, Inc."},
	{0x0018F0, "JOYTOTO Co., Ltd."},
	{0x0018F1, "Chunichi Denshi Co.,LTD."},
	{0x0018F2, "Beijing Tianyu Communication Equipment Co., Ltd"},
	{0x0018F3, "ASUSTek COMPUTER INC."},
	{0x0018F4, "EO TECHNICS Co., Ltd."},
	{0x0018F5, "Shenzhen Streaming Video Technology Company Limited"},
	{0x0018F6, "Thomson Telecom Belgium"},
	{0x0018F7, "Kameleon Technologies"},
	{0x0018F8, "Cisco-Linksys LLC"},
	{0x0018F9, "VVOND, Inc."},
	{0x0018FA, "Yushin Precision Equipment Co.,Ltd."},
	{0x0018FB, "Compro Technology"},
	{0x0018FC, "Altec Electronic AG"},
	{0x0018FD, "Optimal Technologies International Inc."},
	{0x0018FE, "Hewlett Packard"},
	{0x0018FF, "PowerQuattro Co."},
	{0x001900, "Intelliverese - DBA Voicecom"},
	{0x001901, "F1MEDIA"},
	{0x001902, "Cambridge Consultants Ltd"},
	{0x001903, "Bigfoot Networks Inc"},
	{0x001904, "WB Electronics Sp. z o.o."},
	{0x001905, "SCHRACK Seconet AG"},
	{0x001906, "Cisco Systems"},
	{0x001907, "Cisco Systems"},
	{0x001908, "Duaxes Corporation"},
	{0x001909, "Devi A/S"},
	{0x00190A, "HASWARE INC."},
	{0x00190B, "Southern Vision Systems, Inc."},
	{0x00190C, "Encore Electronics, Inc."},
	{0x00190D, "IEEE 1394c"},
	{0x00190E, "Atech Technology Co., Ltd."},
	{0x00190F, "Advansus Corp."},
	{0x001910, "Knick Elektronische Messgeraete GmbH & Co. KG"},
	{0x001911,
	 "Just In Mobile Information Technologies (Shanghai) Co., Ltd."},
	{0x001912, "Welcat Inc"},
	{0x001913, "Chuang-Yi Network Equipment Co.Ltd."},
	{0x001914, "Winix Co., Ltd"},
	{0x001915, "TECOM Co., Ltd."},
	{0x001916, "PayTec AG"},
	{0x001917, "Posiflex Inc."},
	{0x001918, "Interactive Wear AG"},
	{0x001919, "ASTEL Inc."},
	{0x00191A, "IRLINK"},
	{0x00191B, "Sputnik Engineering AG"},
	{0x00191C, "Sensicast Systems"},
	{0x00191D, "Nintendo Co.,Ltd."},
	{0x00191E, "Beyondwiz Co., Ltd."},
	{0x00191F, "Microlink communications Inc."},
	{0x001920, "KUME electric Co.,Ltd."},
	{0x001921, "Elitegroup Computer System Co."},
	{0x001922, "CM Comandos Lineares"},
	{0x001923, "Phonex Korea Co., LTD."},
	{0x001924, "LBNL  Engineering"},
	{0x001925, "Intelicis Corporation"},
	{0x001926, "BitsGen Co., Ltd."},
	{0x001927, "ImCoSys Ltd"},
	{0x001928, "Siemens AG, Transportation Systems"},
	{0x001929, "2M2B Montadora de Maquinas Bahia Brasil LTDA"},
	{0x00192A, "Antiope Associates"},
	{0x00192B, "Aclara RF Systems Inc."},
	{0x00192C, "Motorola Mobile Devices"},
	{0x00192D, "Nokia Corporation"},
	{0x00192E, "Spectral Instruments, Inc."},
	{0x00192F, "Cisco Systems"},
	{0x001930, "Cisco Systems"},
	{0x001931, "Balluff GmbH"},
	{0x001932, "Gude Analog- und Digialsysteme GmbH"},
	{0x001933, "Strix Systems, Inc."},
	{0x001934, "TRENDON TOUCH TECHNOLOGY CORP."},
	{0x001935, "Duerr Dental GmbH & Co. KG"},
	{0x001936, "STERLITE OPTICAL TECHNOLOGIES LIMITED"},
	{0x001937, "CommerceGuard AB"},
	{0x001938, "UMB Communications Co., Ltd."},
	{0x001939, "Gigamips"},
	{0x00193A, "OESOLUTIONS"},
	{0x00193B, "Wilibox Deliberant Group LLC"},
	{0x00193C, "HighPoint Technologies Incorporated"},
	{0x00193D, "GMC Guardian Mobility Corp."},
	{0x00193E, "PIRELLI BROADBAND SOLUTIONS"},
	{0x00193F, "RDI technology(Shenzhen) Co.,LTD"},
	{0x001940, "Rackable Systems"},
	{0x001941, "Pitney Bowes, Inc"},
	{0x001942, "ON SOFTWARE INTERNATIONAL LIMITED"},
	{0x001943, "Belden"},
	{0x001944, "Fossil Partners, L.P."},
	{0x001945, "Ten-Tec Inc."},
	{0x001946, "Cianet Industria e Comercio S/A"},
	{0x001947, "Scientific Atlanta, A Cisco Company"},
	{0x001948, "AireSpider Networks"},
	{0x001949, "TENTEL  COMTECH CO., LTD."},
	{0x00194A, "TESTO AG"},
	{0x00194B, "SAGEM COMMUNICATION"},
	{0x00194C, "Fujian Stelcom information & Technology CO.,Ltd"},
	{0x00194D, "Avago Technologies Sdn Bhd"},
	{0x00194E, "Ultra Electronics - TCS (Tactical Communication Systems)"},
	{0x00194F, "Nokia Danmark A/S"},
	{0x001950, "Harman Multimedia"},
	{0x001951, "NETCONS, s.r.o."},
	{0x001952, "ACOGITO Co., Ltd"},
	{0x001953, "Chainleader Communications Corp."},
	{0x001954, "Leaf Corporation."},
	{0x001955, "Cisco Systems"},
	{0x001956, "Cisco Systems"},
	{0x001957, "Saafnet Canada Inc."},
	{0x001958, "Bluetooth SIG, Inc."},
	{0x001959, "Staccato Communications Inc."},
	{0x00195A, "Jenaer Antriebstechnik GmbH"},
	{0x00195B, "D-Link Corporation"},
	{0x00195C, "Innotech Corporation"},
	{0x00195D, "ShenZhen XinHuaTong Opto Electronics Co.,Ltd"},
	{0x00195E, "Motorola CHS"},
	{0x00195F, "Valemount Networks Corporation"},
	{0x001960, "DoCoMo Systems, Inc."},
	{0x001961, "Blaupunkt GmbH"},
	{0x001962, "Commerciant, LP"},
	{0x001963, "Sony Ericsson Mobile Communications AB"},
	{0x001964, "Doorking Inc."},
	{0x001965, "YuHua TelTech (ShangHai) Co., Ltd."},
	{0x001966, "Asiarock Technology Limited"},
	{0x001967, "TELDAT Sp.J."},
	{0x001968, "Digital Video Networks(Shanghai) CO. LTD."},
	{0x001969, "Nortel"},
	{0x00196A, "MikroM GmbH"},
	{0x00196B, "Danpex Corporation"},
	{0x00196C, "ETROVISION TECHNOLOGY"},
	{0x00196D, "Raybit Systems Korea, Inc"},
	{0x00196E, "Metacom (Pty) Ltd."},
	{0x00196F, "SensoPart GmbH"},
	{0x001970, "Z-Com, Inc."},
	{0x001971, "Guangzhou Unicomp Technology Co.,Ltd"},
	{0x001972, "Plexus (Xiamen) Co.,ltd"},
	{0x001973, "Zeugma Systems"},
	{0x001974, "AboCom Systems, Inc."},
	{0x001975, "Beijing Huisen networks technology Inc"},
	{0x001976, "Xipher Technologies, LLC"},
	{0x001977, "Aerohive Networks, Inc."},
	{0x001978, "Datum Systems, Inc."},
	{0x001979, "Nokia Danmark A/S"},
	{0x00197A, "MAZeT GmbH"},
	{0x00197B, "Picotest Corp."},
	{0x00197C, "Riedel Communications GmbH"},
	{0x00197D, "Hon Hai Precision Ind. Co., Ltd"},
	{0x00197E, "Hon Hai Precision Ind. Co., Ltd"},
	{0x00197F, "PLANTRONICS, INC."},
	{0x001980, "Gridpoint Systems"},
	{0x001981, "Vivox Inc"},
	{0x001982, "SmarDTV"},
	{0x001983, "CCT R&D Limited"},
	{0x001984, "ESTIC Corporation"},
	{0x001985, "IT Watchdogs, Inc"},
	{0x001986, "Cheng Hongjian"},
	{0x001987, "Panasonic Mobile Communications Co., Ltd."},
	{0x001988, "Wi2Wi, Inc"},
	{0x001989, "Sonitrol Corporation"},
	{0x00198A, "Northrop Grumman Systems Corp."},
	{0x00198B, "Novera Optics Korea, Inc."},
	{0x00198C, "iXSea"},
	{0x00198D, "Ocean Optics, Inc."},
	{0x00198E, "Oticon A/S"},
	{0x00198F, "Alcatel Bell N.V."},
	{0x001990, "ELM DATA Co., Ltd."},
	{0x001991, "avinfo"},
	{0x001992, "Bluesocket, Inc"},
	{0x001993,
	 "Changshu Switchgear MFG. Co.,Ltd. (Former Changshu Switchgea"},
	{0x001994, "Jorjin Technologies Inc."},
	{0x001995, "Jurong Hi-Tech (Suzhou)Co.ltd"},
	{0x001996, "TurboChef Technologies Inc."},
	{0x001997, "Soft Device Sdn Bhd"},
	{0x001998, "SATO CORPORATION"},
	{0x001999, "Fujitsu Technology Solutions"},
	{0x00199A, "EDO-EVI"},
	{0x00199B, "Diversified Technical Systems, Inc."},
	{0x00199C, "CTRING"},
	{0x00199D, "VIZIO, Inc."},
	{0x00199E, "SHOWADENSHI ELECTRONICS,INC."},
	{0x00199F, "DKT A/S"},
	{0x0019A0, "NIHON DATA SYSTENS, INC."},
	{0x0019A1, "LG INFORMATION & COMM."},
	{0x0019A2, "ORDYN TECHNOLOGIES"},
	{0x0019A3, "asteel electronique atlantique"},
	{0x0019A4, "Austar Technology (hang zhou) Co.,Ltd"},
	{0x0019A5, "RadarFind Corporation"},
	{0x0019A6, "Motorola CHS"},
	{0x0019A7, "ITU-T"},
	{0x0019A8, "WiQuest Communications"},
	{0x0019A9, "Cisco Systems"},
	{0x0019AA, "Cisco Systems"},
	{0x0019AB, "Raycom CO ., LTD"},
	{0x0019AC, "GSP SYSTEMS Inc."},
	{0x0019AD, "BOBST SA"},
	{0x0019AE, "Hopling Technologies b.v."},
	{0x0019AF, "Rigol Technologies, Inc."},
	{0x0019B0, "HanYang System"},
	{0x0019B1, "Arrow7 Corporation"},
	{0x0019B2, "XYnetsoft Co.,Ltd"},
	{0x0019B3, "Stanford Research Systems"},
	{0x0019B4, "VideoCast Ltd."},
	{0x0019B5, "Famar Fueguina S.A."},
	{0x0019B6, "Euro Emme s.r.l."},
	{0x0019B7, "Nokia Danmark A/S"},
	{0x0019B8, "Boundary Devices"},
	{0x0019B9, "Dell Inc."},
	{0x0019BA, "Paradox Security Systems Ltd"},
	{0x0019BB, "Hewlett Packard"},
	{0x0019BC, "ELECTRO CHANCE SRL"},
	{0x0019BD, "New Media Life"},
	{0x0019BE, "Altai Technologies Limited"},
	{0x0019BF, "Citiway technology Co.,ltd"},
	{0x0019C0, "Motorola Mobile Devices"},
	{0x0019C1, "Alps Electric Co., Ltd"},
	{0x0019C2, "Equustek Solutions, Inc."},
	{0x0019C3, "Qualitrol"},
	{0x0019C4, "Infocrypt Inc."},
	{0x0019C5, "SONY Computer Entertainment inc,"},
	{0x0019C6, "ZTE Corporation"},
	{0x0019C7, "Cambridge Industries(Group) Co.,Ltd."},
	{0x0019C8, "AnyDATA Corporation"},
	{0x0019C9, "S&C ELECTRIC COMPANY"},
	{0x0019CA, "Broadata Communications, Inc"},
	{0x0019CB, "ZyXEL Communications Corporation"},
	{0x0019CC, "RCG (HK) Ltd"},
	{0x0019CD, "Chengdu ethercom information technology Ltd."},
	{0x0019CE, "Progressive Gaming International"},
	{0x0019CF, "SALICRU, S.A."},
	{0x0019D0, "Cathexis"},
	{0x0019D1, "Intel Corporation"},
	{0x0019D2, "Intel Corporation"},
	{0x0019D3, "TRAK Microwave"},
	{0x0019D4, "ICX Technologies"},
	{0x0019D5, "IP Innovations, Inc."},
	{0x0019D6, "LS Cable Ltd."},
	{0x0019D7, "FORTUNETEK CO., LTD"},
	{0x0019D8, "MAXFOR"},
	{0x0019D9, "Zeutschel GmbH"},
	{0x0019DA, "Welltrans O&E Technology Co. , Ltd."},
	{0x0019DB, "MICRO-STAR INTERNATIONAL CO., LTD."},
	{0x0019DC, "ENENSYS Technologies"},
	{0x0019DD, "FEI-Zyfer, Inc."},
	{0x0019DE, "MOBITEK"},
	{0x0019DF, "Thomson Inc."},
	{0x0019E0, "TP-LINK Technologies Co., Ltd."},
	{0x0019E1, "Nortel"},
	{0x0019E2, "Juniper Networks"},
	{0x0019E3, "Apple Computer Inc."},
	{0x0019E4, "2Wire, Inc"},
	{0x0019E5, "Lynx Studio Technology, Inc."},
	{0x0019E6, "TOYO MEDIC CO.,LTD."},
	{0x0019E7, "Cisco Systems"},
	{0x0019E8, "Cisco Systems"},
	{0x0019E9, "S-Information Technolgy, Co., Ltd."},
	{0x0019EA, "TeraMage Technologies Co., Ltd."},
	{0x0019EB, "Pyronix Ltd"},
	{0x0019EC, "Sagamore Systems, Inc."},
	{0x0019ED, "Axesstel Inc."},
	{0x0019EE, "CARLO GAVAZZI CONTROLS SPA-Controls Division"},
	{0x0019EF, "SHENZHEN LINNKING ELECTRONICS CO.,LTD"},
	{0x0019F0, "UNIONMAN TECHNOLOGY CO.,LTD"},
	{0x0019F1, "Star Communication Network Technology Co.,Ltd"},
	{0x0019F2, "Teradyne K.K."},
	{0x0019F3, "Telematrix, Inc"},
	{0x0019F4, "Convergens Oy Ltd"},
	{0x0019F5, "Imagination Technologies Ltd"},
	{0x0019F6, "Acconet (PTE) Ltd"},
	{0x0019F7, "Onset Computer Corporation"},
	{0x0019F8, "Embedded Systems Design, Inc."},
	{0x0019F9, "TDK-Lambda"},
	{0x0019FA, "Cable Vision Electronics CO., LTD."},
	{0x0019FB, "AMSTRAD PLC"},
	{0x0019FC, "PT. Ufoakses Sukses Luarbiasa"},
	{0x0019FD, "Nintendo Co., Ltd."},
	{0x0019FE, "SHENZHEN SEECOMM TECHNOLOGY CO.,LTD."},
	{0x0019FF, "Finnzymes"},
	{0x001A00, "MATRIX INC."},
	{0x001A01, "Smiths Medical"},
	{0x001A02, "SECURE CARE PRODUCTS, INC"},
	{0x001A03, "Angel Electronics Co., Ltd."},
	{0x001A04, "Interay Solutions BV"},
	{0x001A05, "OPTIBASE LTD"},
	{0x001A06, "OpVista, Inc."},
	{0x001A07, "Arecont Vision"},
	{0x001A08, "Dalman Technical Services"},
	{0x001A09, "Wayfarer Transit Systems Ltd"},
	{0x001A0A, "Adaptive Micro-Ware Inc."},
	{0x001A0B, "BONA TECHNOLOGY INC."},
	{0x001A0C, "Swe-Dish Satellite Systems AB"},
	{0x001A0D, "HandHeld entertainment, Inc."},
	{0x001A0E, "Cheng Uei Precision Industry Co.,Ltd"},
	{0x001A0F, "Sistemas Avanzados de Control, S.A."},
	{0x001A10, "LUCENT TRANS ELECTRONICS CO.,LTD"},
	{0x001A11, "Google Inc."},
	{0x001A12, "Essilor"},
	{0x001A13, "Wanlida Group Co., LTD"},
	{0x001A14, "Xin Hua Control Engineering Co.,Ltd."},
	{0x001A15, "gemalto e-Payment"},
	{0x001A16, "Nokia Danmark A/S"},
	{0x001A17, "Teak Technologies, Inc."},
	{0x001A18, "Advanced Simulation Technology inc."},
	{0x001A19, "Computer Engineering Limited"},
	{0x001A1A, "Gentex Corporation/Electro-Acoustic Products"},
	{0x001A1B, "Motorola Mobile Devices"},
	{0x001A1C, "GT&T Engineering Pte Ltd"},
	{0x001A1D, "PChome Online Inc."},
	{0x001A1E, "Aruba Networks"},
	{0x001A1F, "Coastal Environmental Systems"},
	{0x001A20, "CMOTECH Co. Ltd."},
	{0x001A21, "Indac B.V."},
	{0x001A22, "eq-3 GmbH"},
	{0x001A23, "Ice Qube, Inc"},
	{0x001A24, "Galaxy Telecom Technologies Ltd"},
	{0x001A25, "DELTA DORE"},
	{0x001A26, "Deltanode Solutions AB"},
	{0x001A27, "Ubistar"},
	{0x001A28, "ASWT Co., LTD. Taiwan Branch H.K."},
	{0x001A29, "Techsonic Industries d/b/a Humminbird"},
	{0x001A2A, "Arcadyan Technology Corporation"},
	{0x001A2B, "Ayecom Technology Co., Ltd."},
	{0x001A2C, "SATEC Co.,LTD"},
	{0x001A2D, "The Navvo Group"},
	{0x001A2E, "Ziova Coporation"},
	{0x001A2F, "Cisco Systems"},
	{0x001A30, "Cisco Systems"},
	{0x001A31, "SCAN COIN Industries AB"},
	{0x001A32, "ACTIVA MULTIMEDIA"},
	{0x001A33, "ASI Communications, Inc."},
	{0x001A34, "Konka Group Co., Ltd."},
	{0x001A35, "BARTEC GmbH"},
	{0x001A36, "Aipermon GmbH & Co. KG"},
	{0x001A37, "Lear Corporation"},
	{0x001A38, "Sanmina-SCI"},
	{0x001A39, "Merten GmbH&CoKG"},
	{0x001A3A, "Dongahelecomm"},
	{0x001A3B, "Doah Elecom Inc."},
	{0x001A3C, "Technowave Ltd."},
	{0x001A3D, "Ajin Vision Co.,Ltd"},
	{0x001A3E, "Faster Technology LLC"},
	{0x001A3F, "intelbras"},
	{0x001A40, "A-FOUR TECH CO., LTD."},
	{0x001A41, "INOCOVA Co.,Ltd"},
	{0x001A42, "Techcity Technology co., Ltd."},
	{0x001A43, "Logical Link Communications"},
	{0x001A44, "JWTrading Co., Ltd"},
	{0x001A45, "GN Netcom as"},
	{0x001A46, "Digital Multimedia Technology Co., Ltd"},
	{0x001A47, "Agami Systems, Inc."},
	{0x001A48, "Takacom Corporation"},
	{0x001A49, "Micro Vision Co.,LTD"},
	{0x001A4A, "Qumranet Inc."},
	{0x001A4B, "Hewlett Packard"},
	{0x001A4C, "Crossbow Technology, Inc"},
	{0x001A4D, "GIGA-BYTE TECHNOLOGY CO.,LTD."},
	{0x001A4E, "NTI AG / LinMot"},
	{0x001A4F, "AVM GmbH"},
	{0x001A50, "PheeNet Technology Corp."},
	{0x001A51, "Alfred Mann Foundation"},
	{0x001A52, "Meshlinx Wireless Inc."},
	{0x001A53, "Zylaya"},
	{0x001A54, "Hip Shing Electronics Ltd."},
	{0x001A55, "ACA-Digital Corporation"},
	{0x001A56, "ViewTel Co,. Ltd."},
	{0x001A57, "Matrix Design Group, LLC"},
	{0x001A58, "CCV Deutschland GmbH - Celectronic eHealth Div."},
	{0x001A59, "Ircona"},
	{0x001A5A, "Korea Electric Power Data Network  (KDN) Co., Ltd"},
	{0x001A5B, "NetCare Service Co., Ltd."},
	{0x001A5C, "Euchner GmbH+Co. KG"},
	{0x001A5D, "Mobinnova Corp."},
	{0x001A5E, "Thincom Technology Co.,Ltd"},
	{0x001A5F, "KitWorks.fi Ltd."},
	{0x001A60, "Wave Electronics Co.,Ltd."},
	{0x001A61, "PacStar Corp."},
	{0x001A62, "Data Robotics, Incorporated"},
	{0x001A63, "Elster Solutions, LLC,"},
	{0x001A64, "IBM Corp."},
	{0x001A65, "Seluxit"},
	{0x001A66, "Motorola CHS"},
	{0x001A67, "Infinite QL Sdn Bhd"},
	{0x001A68, "Weltec Enterprise Co., Ltd."},
	{0x001A69, "Wuhan Yangtze Optical Technology CO.,Ltd."},
	{0x001A6A, "Tranzas, Inc."},
	{0x001A6B, "USI"},
	{0x001A6C, "Cisco Systems"},
	{0x001A6D, "Cisco Systems"},
	{0x001A6E, "Impro Technologies"},
	{0x001A6F, "MI.TEL s.r.l."},
	{0x001A70, "Cisco-Linksys, LLC"},
	{0x001A71, "Diostech Co., Ltd."},
	{0x001A72, "Mosart Semiconductor Corp."},
	{0x001A73, "Gemtek Technology Co., Ltd."},
	{0x001A74, "Procare International Co"},
	{0x001A75, "Sony Ericsson Mobile Communications"},
	{0x001A76, "SDT information Technology Co.,LTD."},
	{0x001A77, "Motorola Mobile Devices"},
	{0x001A78, "ubtos"},
	{0x001A79, "TELECOMUNICATION TECHNOLOGIES LTD."},
	{0x001A7A, "Lismore Instruments Limited"},
	{0x001A7B, "Teleco, Inc."},
	{0x001A7C, "Hirschmann Automation and Control B.V."},
	{0x001A7D, "cyber-blue(HK)Ltd"},
	{0x001A7E, "LN Srithai Comm Ltd."},
	{0x001A7F, "GCI Science&Technology Co.,Ltd."},
	{0x001A80, "Sony Corporation"},
	{0x001A81, "Zelax"},
	{0x001A82, "PROBA Building Automation Co.,LTD"},
	{0x001A83, "Pegasus Technologies Inc."},
	{0x001A84, "V One Multimedia Pte Ltd"},
	{0x001A85, "NV Michel Van de Wiele"},
	{0x001A86, "AdvancedIO Systems Inc"},
	{0x001A87, "Canhold International Limited"},
	{0x001A88, "Venergy,Co,Ltd"},
	{0x001A89, "Nokia Danmark A/S"},
	{0x001A8A, "Samsung Electronics Co., Ltd."},
	{0x001A8B, "CHUNIL ELECTRIC IND., CO."},
	{0x001A8C, "Astaro AG"},
	{0x001A8D, "AVECS Bergen GmbH"},
	{0x001A8E, "3Way Networks Ltd"},
	{0x001A8F, "Nortel"},
	{0x001A90, "Trpico Sistemas e Telecomunicaes da Amaznia LTDA."},
	{0x001A91, "FusionDynamic Ltd."},
	{0x001A92, "ASUSTek COMPUTER INC."},
	{0x001A93, "ERCO Leuchten GmbH"},
	{0x001A94, "Votronic GmbH"},
	{0x001A95, "Hisense Mobile Communications Technoligy Co.,Ltd."},
	{0x001A96, "ECLER S.A."},
	{0x001A97, "fitivision technology Inc."},
	{0x001A98, "Asotel Communication Limited Taiwan Branch"},
	{0x001A99, "Smarty (HZ) Information Electronics Co., Ltd"},
	{0x001A9A, "Skyworth Digital technology(shenzhen)co.ltd."},
	{0x001A9B, "ADEC & Parter AG"},
	{0x001A9C, "RightHand Technologies, Inc."},
	{0x001A9D, "Skipper Wireless, Inc."},
	{0x001A9E, "ICON Digital International Limited"},
	{0x001A9F, "A-Link Europe Ltd"},
	{0x001AA0, "Dell Inc"},
	{0x001AA1, "Cisco Systems"},
	{0x001AA2, "Cisco Systems"},
	{0x001AA3, "DELORME"},
	{0x001AA4, "Future University-Hakodate"},
	{0x001AA5, "BRN Phoenix"},
	{0x001AA6, "Telefunken Radio Communication Systems GmbH &CO.KG"},
	{0x001AA7, "Torian Wireless"},
	{0x001AA8, "Mamiya Digital Imaging Co., Ltd."},
	{0x001AA9, "FUJIAN STAR-NET COMMUNICATION CO.,LTD"},
	{0x001AAA, "Analogic Corp."},
	{0x001AAB, "eWings s.r.l."},
	{0x001AAC, "Corelatus AB"},
	{0x001AAD, "Motorola CHS"},
	{0x001AAE, "Savant Systems LLC"},
	{0x001AAF, "BLUSENS TECHNOLOGY"},
	{0x001AB0, "Signal Networks Pvt. Ltd.,"},
	{0x001AB1, "Asia Pacific Satellite Industries Co., Ltd."},
	{0x001AB2, "Cyber Solutions Inc."},
	{0x001AB3, "VISIONITE INC."},
	{0x001AB4, "FFEI Ltd."},
	{0x001AB5, "Home Network System"},
	{0x001AB6, "Texas Instruments"},
	{0x001AB7, "Ethos Networks LTD."},
	{0x001AB8, "Anseri Corporation"},
	{0x001AB9, "PMC"},
	{0x001ABA, "Caton Overseas Limited"},
	{0x001ABB, "Fontal Technology Incorporation"},
	{0x001ABC, "U4EA Technologies Ltd"},
	{0x001ABD, "Impatica Inc."},
	{0x001ABE, "COMPUTER HI-TECH INC."},
	{0x001ABF, "TRUMPF Laser Marking Systems AG"},
	{0x001AC0, "JOYBIEN TECHNOLOGIES CO., LTD."},
	{0x001AC1, "3Com Ltd"},
	{0x001AC2, "YEC Co.,Ltd."},
	{0x001AC3, "Scientific-Atlanta, Inc"},
	{0x001AC4, "2Wire, Inc"},
	{0x001AC5, "BreakingPoint Systems, Inc."},
	{0x001AC6, "Micro Control Designs"},
	{0x001AC7, "UNIPOINT"},
	{0x001AC8, "ISL (Instrumentation Scientifique de Laboratoire)"},
	{0x001AC9, "SUZUKEN CO.,LTD"},
	{0x001ACA, "Tilera Corporation"},
	{0x001ACB, "Autocom Products Ltd"},
	{0x001ACC, "Celestial Semiconductor, Ltd"},
	{0x001ACD, "Tidel Engineering LP"},
	{0x001ACE, "YUPITERU CORPORATION"},
	{0x001ACF, "C.T. ELETTRONICA"},
	{0x001AD0, "Albis Technologies AG"},
	{0x001AD1, "FARGO CO., LTD."},
	{0x001AD2, "Eletronica Nitron Ltda"},
	{0x001AD3, "Vamp Ltd."},
	{0x001AD4, "iPOX Technology Co., Ltd."},
	{0x001AD5, "KMC CHAIN INDUSTRIAL CO., LTD."},
	{0x001AD6, "JIAGNSU AETNA ELECTRIC CO.,LTD"},
	{0x001AD7, "Christie Digital Systems, Inc."},
	{0x001AD8, "AlsterAero GmbH"},
	{0x001AD9, "International Broadband Electric Communications, Inc."},
	{0x001ADA, "Biz-2-Me Inc."},
	{0x001ADB, "Motorola Mobile Devices"},
	{0x001ADC, "Nokia Danmark A/S"},
	{0x001ADD, "PePWave Ltd"},
	{0x001ADE, "Motorola CHS"},
	{0x001ADF, "Interactivetv Pty Limited"},
	{0x001AE0, "Mythology Tech Express Inc."},
	{0x001AE1, "EDGE ACCESS INC"},
	{0x001AE2, "Cisco Systems"},
	{0x001AE3, "Cisco Systems"},
	{0x001AE4, "Medicis Technologies Corporation"},
	{0x001AE5, "Mvox Technologies Inc."},
	{0x001AE6, "Atlanta Advanced Communications Holdings Limited"},
	{0x001AE7, "Aztek Networks, Inc."},
	{0x001AE8, "Siemens Enterprise Communications GmbH & Co. KG"},
	{0x001AE9, "Nintendo Co., Ltd."},
	{0x001AEA, "Radio Terminal Systems Pty Ltd"},
	{0x001AEB, "Allied Telesis K.K."},
	{0x001AEC, "Keumbee Electronics Co.,Ltd."},
	{0x001AED, "INCOTEC GmbH"},
	{0x001AEE, "Shenztech Ltd"},
	{0x001AEF, "Loopcomm Technology, Inc."},
	{0x001AF0, "Alcatel - IPD"},
	{0x001AF1, "Embedded Artists AB"},
	{0x001AF2, "Dynavisions Schweiz AG"},
	{0x001AF3, "Samyoung Electronics"},
	{0x001AF4, "Handreamnet"},
	{0x001AF5, "PENTAONE. CO., LTD."},
	{0x001AF6, "Woven Systems, Inc."},
	{0x001AF7, "dataschalt e+a GmbH"},
	{0x001AF8, "Copley Controls Corporation"},
	{0x001AF9, "AeroVIronment (AV Inc)"},
	{0x001AFA, "Welch Allyn, Inc."},
	{0x001AFB, "Joby Inc."},
	{0x001AFC, "ModusLink Corporation"},
	{0x001AFD, "EVOLIS"},
	{0x001AFE, "SOFACREAL"},
	{0x001AFF, "Wizyoung Tech."},
	{0x001B00, "Neopost Technologies"},
	{0x001B01, "Applied Radio Technologies"},
	{0x001B02, "ED Co.Ltd"},
	{0x001B03, "Action Technology (SZ) Co., Ltd"},
	{0x001B04, "Affinity International S.p.a"},
	{0x001B05, "YMC AG"},
	{0x001B06, "Ateliers R. LAUMONIER"},
	{0x001B07, "Mendocino Software"},
	{0x001B08, "Danfoss Drives A/S"},
	{0x001B09, "Matrix Telecom Pvt. Ltd."},
	{0x001B0A, "Intelligent Distributed Controls Ltd"},
	{0x001B0B, "Phidgets Inc."},
	{0x001B0C, "Cisco Systems"},
	{0x001B0D, "Cisco Systems"},
	{0x001B0E, "InoTec GmbH Organisationssysteme"},
	{0x001B0F, "Petratec"},
	{0x001B10, "ShenZhen Kang Hui Technology Co.,ltd"},
	{0x001B11, "D-Link Corporation"},
	{0x001B12, "Apprion"},
	{0x001B13, "Icron Technologies Corporation"},
	{0x001B14, "Carex Lighting Equipment Factory"},
	{0x001B15, "Voxtel, Inc."},
	{0x001B16, "Celtro Ltd."},
	{0x001B17, "Palo Alto Networks"},
	{0x001B18, "Tsuken Electric Ind. Co.,Ltd"},
	{0x001B19, "IEEE 1588 Standard"},
	{0x001B1A, "e-trees Japan, Inc."},
	{0x001B1B, "Siemens AG,"},
	{0x001B1C, "Coherent"},
	{0x001B1D, "Phoenix International Co., Ltd"},
	{0x001B1E, "HART Communication Foundation"},
	{0x001B1F, "DELTA - Danish Electronics, Light & Acoustics"},
	{0x001B20, "TPine Technology"},
	{0x001B21, "Intel Corporate"},
	{0x001B22, "Palit Microsystems ( H.K.) Ltd."},
	{0x001B23, "SimpleComTools"},
	{0x001B24, "Quanta Computer Inc."},
	{0x001B25, "Nortel"},
	{0x001B26, "RON-Telecom ZAO"},
	{0x001B27, "Merlin CSI"},
	{0x001B28, "POLYGON, JSC"},
	{0x001B29, "Avantis.Co.,Ltd"},
	{0x001B2A, "Cisco Systems"},
	{0x001B2B, "Cisco Systems"},
	{0x001B2C, "ATRON electronic GmbH"},
	{0x001B2D, "Med-Eng Systems Inc."},
	{0x001B2E, "Sinkyo Electron Inc"},
	{0x001B2F, "NETGEAR Inc."},
	{0x001B30, "Solitech Inc."},
	{0x001B31, "Neural Image. Co. Ltd."},
	{0x001B32, "QLogic Corporation"},
	{0x001B33, "Nokia Danmark A/S"},
	{0x001B34, "Focus System Inc."},
	{0x001B35, "ChongQing JINOU Science & Technology Development CO.,Ltd"},
	{0x001B36, "Tsubata Engineering Co.,Ltd. (Head Office)"},
	{0x001B37, "Computec Oy"},
	{0x001B38, "COMPAL INFORMATION (KUNSHAN) CO., LTD."},
	{0x001B39, "Proxicast"},
	{0x001B3A, "SIMS Corp."},
	{0x001B3B, "Yi-Qing CO., LTD"},
	{0x001B3C, "Software Technologies Group,Inc."},
	{0x001B3D, "EuroTel Spa"},
	{0x001B3E, "Curtis, Inc."},
	{0x001B3F, "ProCurve Networking by HP"},
	{0x001B40, "Network Automation mxc AB"},
	{0x001B41, "General Infinity Co.,Ltd."},
	{0x001B42, "Wise & Blue"},
	{0x001B43, "Beijing DG Telecommunications equipment Co.,Ltd"},
	{0x001B44, "SanDisk Corporation"},
	{0x001B45, "ABB AS, Division Automation Products"},
	{0x001B46, "Blueone Technology Co.,Ltd"},
	{0x001B47, "Futarque A/S"},
	{0x001B48, "Shenzhen Lantech Electronics Co., Ltd."},
	{0x001B49, "Roberts Radio limited"},
	{0x001B4A, "W&W Communications, Inc."},
	{0x001B4B, "SANION Co., Ltd."},
	{0x001B4C, "Signtech"},
	{0x001B4D, "Areca Technology Corporation"},
	{0x001B4E, "Navman New Zealand"},
	{0x001B4F, "Avaya Inc."},
	{0x001B50, "Nizhny Novgorod Factory named after M.Frunze, FSUE (NZiF)"},
	{0x001B51, "Vector Technology Corp."},
	{0x001B52, "Motorola Mobile Devices"},
	{0x001B53, "Cisco Systems"},
	{0x001B54, "Cisco Systems"},
	{0x001B55, "Hurco Automation Ltd."},
	{0x001B56, "Tehuti Networks Ltd."},
	{0x001B57, "SEMINDIA SYSTEMS PRIVATE LIMITED"},
	{0x001B58, "ACE CAD Enterprise Co., Ltd."},
	{0x001B59, "Sony Ericsson Mobile Communications AB"},
	{0x001B5A, "Apollo Imaging Technologies, Inc."},
	{0x001B5B, "2Wire, Inc."},
	{0x001B5C, "Azuretec Co., Ltd."},
	{0x001B5D, "Vololink Pty Ltd"},
	{0x001B5E, "BPL Limited"},
	{0x001B5F, "Alien Technology"},
	{0x001B60, "NAVIGON AG"},
	{0x001B61, "Digital Acoustics, LLC"},
	{0x001B62, "JHT Optoelectronics Co.,Ltd."},
	{0x001B63, "Apple Computer Inc."},
	{0x001B64, "IsaacLandKorea Co., Ltd,"},
	{0x001B65, "China Gridcom Co., Ltd"},
	{0x001B66, "Sennheiser electronic GmbH & Co. KG"},
	{0x001B67, "Ubiquisys Ltd"},
	{0x001B68, "Modnnet Co., Ltd"},
	{0x001B69, "Equaline Corporation"},
	{0x001B6A, "Powerwave Technologies Sweden AB"},
	{0x001B6B, "Swyx Solutions AG"},
	{0x001B6C, "LookX Digital Media BV"},
	{0x001B6D, "Midtronics, Inc."},
	{0x001B6E, "Anue Systems, Inc."},
	{0x001B6F, "Teletrak Ltd"},
	{0x001B70, "IRI Ubiteq, INC."},
	{0x001B71, "Telular Corp."},
	{0x001B72, "Sicep s.p.a."},
	{0x001B73, "DTL Broadcast Ltd"},
	{0x001B74, "MiraLink Corporation"},
	{0x001B75, "Hypermedia Systems"},
	{0x001B76, "Ripcode, Inc."},
	{0x001B77, "Intel Corporate"},
	{0x001B78, "Hewlett Packard"},
	{0x001B79, "FAIVELEY TRANSPORT"},
	{0x001B7A, "Nintendo Co., Ltd."},
	{0x001B7B, "The Tintometer Ltd"},
	{0x001B7C, "A & R Cambridge"},
	{0x001B7D, "CXR Anderson Jacobson"},
	{0x001B7E, "Beckmann GmbH"},
	{0x001B7F, "TMN Technologies Telecomunicacoes Ltda"},
	{0x001B80, "LORD Corporation"},
	{0x001B81, "DATAQ Instruments, Inc."},
	{0x001B82, "Taiwan Semiconductor Co., Ltd."},
	{0x001B83, "Finsoft Ltd"},
	{0x001B84, "Scan Engineering Telecom"},
	{0x001B85, "MAN Diesel SE"},
	{0x001B86, "Bosch Access Systems GmbH"},
	{0x001B87, "Deepsound Tech. Co., Ltd"},
	{0x001B88, "Divinet Access Technologies Ltd"},
	{0x001B89, "EMZA Visual Sense Ltd."},
	{0x001B8A, "2M Electronic A/S"},
	{0x001B8B, "NEC AccessTechnica,Ltd."},
	{0x001B8C, "JMicron Technology Corp."},
	{0x001B8D, "Electronic Computer Systems, Inc."},
	{0x001B8E, "Hulu Sweden AB"},
	{0x001B8F, "Cisco Systems"},
	{0x001B90, "Cisco Systems"},
	{0x001B91, "EFKON AG"},
	{0x001B92, "l-acoustics"},
	{0x001B93, "JC Decaux SA DNT"},
	{0x001B94, "T.E.M.A. S.p.A."},
	{0x001B95, "VIDEO SYSTEMS SRL"},
	{0x001B96, "Snif Labs, Inc."},
	{0x001B97, "Violin Technologies"},
	{0x001B98, "Samsung Electronics Co., Ltd."},
	{0x001B99, "KS System GmbH"},
	{0x001B9A, "Apollo Fire Detectors Ltd"},
	{0x001B9B, "Hose-McCann Communications"},
	{0x001B9C, "SATEL sp. z o.o."},
	{0x001B9D, "Novus Security Sp. z o.o."},
	{0x001B9E, "ASKEY  COMPUTER  CORP"},
	{0x001B9F, "Calyptech Pty Ltd"},
	{0x001BA0, "Awox"},
	{0x001BA1, "mic AB"},
	{0x001BA2, "IDS Imaging Development Systems GmbH"},
	{0x001BA3, "Flexit Group GmbH"},
	{0x001BA4, "S.A.E Afikim"},
	{0x001BA5, "MyungMin Systems, Inc."},
	{0x001BA6, "intotech inc."},
	{0x001BA7, "Lorica Solutions"},
	{0x001BA8, "UBI&MOBI,.Inc"},
	{0x001BA9, "BROTHER INDUSTRIES, LTD."},
	{0x001BAA, "XenICs nv"},
	{0x001BAB, "Telchemy, Incorporated"},
	{0x001BAC, "Curtiss Wright Controls Embedded Computing"},
	{0x001BAD, "iControl Incorporated"},
	{0x001BAE, "Micro Control Systems, Inc"},
	{0x001BAF, "Nokia Danmark A/S"},
	{0x001BB0, "BHARAT ELECTRONICS"},
	{0x001BB1, "Wistron Neweb Corp."},
	{0x001BB2, "Intellect International NV"},
	{0x001BB3, "Condalo GmbH"},
	{0x001BB4, "Airvod Limited"},
	{0x001BB5, "ZF Electronics GmbH"},
	{0x001BB6, "Bird Electronic Corp."},
	{0x001BB7, "Alta Heights Technology Corp."},
	{0x001BB8, "BLUEWAY ELECTRONIC CO;LTD"},
	{0x001BB9, "Elitegroup Computer System Co."},
	{0x001BBA, "Nortel"},
	{0x001BBB, "RFTech Co.,Ltd"},
	{0x001BBC, "Silver Peak Systems, Inc."},
	{0x001BBD, "FMC Kongsberg Subsea AS"},
	{0x001BBE, "ICOP Digital"},
	{0x001BBF, "SAGEM COMMUNICATION"},
	{0x001BC0, "Juniper Networks"},
	{0x001BC1, "HOLUX Technology, Inc."},
	{0x001BC2, "Integrated Control Technology Limitied"},
	{0x001BC3, "Mobisolution Co.,Ltd"},
	{0x001BC4, "Ultratec, Inc."},
	{0x001BC5, "IEEE Registration Authority"},
	{0x001BC6, "Strato Rechenzentrum AG"},
	{0x001BC7, "StarVedia Technology Inc."},
	{0x001BC8, "MIURA CO.,LTD"},
	{0x001BC9, "FSN DISPLAY INC"},
	{0x001BCA, "Beijing Run Technology LTD. Company"},
	{0x001BCB, "PEMPEK SYSTEMS PTY LTD"},
	{0x001BCC, "KINGTEK CCTV ALLIANCE CO., LTD."},
	{0x001BCD, "DAVISCOMMS (S) PTE LTD"},
	{0x001BCE, "Measurement Devices Ltd"},
	{0x001BCF, "Dataupia Corporation"},
	{0x001BD0, "IDENTEC SOLUTIONS"},
	{0x001BD1, "SOGESTMATIC"},
	{0x001BD2, "ULTRA-X ASIA PACIFIC Inc."},
	{0x001BD3, "Matsushita Electric Panasonic AVC"},
	{0x001BD4, "Cisco Systems"},
	{0x001BD5, "Cisco Systems"},
	{0x001BD6, "Kelvin Hughes Ltd"},
	{0x001BD7, "Scientific Atlanta, A Cisco Company"},
	{0x001BD8, "DVTel LTD"},
	{0x001BD9, "Edgewater Computer Systems"},
	{0x001BDA, "UTStarcom Inc"},
	{0x001BDB, "Valeo VECS"},
	{0x001BDC, "Vencer Co., Ltd."},
	{0x001BDD, "Motorola CHS"},
	{0x001BDE, "Renkus-Heinz, Inc."},
	{0x001BDF, "Iskra MIS"},
	{0x001BE0, "TELENOT ELECTRONIC GmbH"},
	{0x001BE1, "ViaLogy"},
	{0x001BE2, "AhnLab,Inc."},
	{0x001BE3, "Health Hero Network, Inc."},
	{0x001BE4, "TOWNET SRL"},
	{0x001BE5, "802automation Limited"},
	{0x001BE6, "VR AG"},
	{0x001BE7, "Postek Electronics Co., Ltd."},
	{0x001BE8, "Ultratronik GmbH"},
	{0x001BE9, "Broadcom Corporation"},
	{0x001BEA, "Nintendo Co., Ltd."},
	{0x001BEB, "DMP Electronics INC."},
	{0x001BEC, "Netio Technologies Co., Ltd"},
	{0x001BED, "Brocade Communications Systems, Inc"},
	{0x001BEE, "Nokia Danmark A/S"},
	{0x001BEF, "Blossoms Digital Technology Co.,Ltd."},
	{0x001BF0, "Value Platforms Limited"},
	{0x001BF1, "Nanjing SilverNet Software Co., Ltd."},
	{0x001BF2, "KWORLD COMPUTER CO., LTD"},
	{0x001BF3, "TRANSRADIO SenderSysteme Berlin AG"},
	{0x001BF4, "KENWIN INDUSTRIAL(HK) LTD."},
	{0x001BF5, "Tellink Sistemas de Telecomunicacin S.L."},
	{0x001BF6, "CONWISE Technology Corporation Ltd."},
	{0x001BF7, "Lund IP Products AB"},
	{0x001BF8, "Digitrax Inc."},
	{0x001BF9, "Intellitect Water Ltd"},
	{0x001BFA, "G.i.N. mbH"},
	{0x001BFB, "Alps Electric Co., Ltd"},
	{0x001BFC, "ASUSTek COMPUTER INC."},
	{0x001BFD, "Dignsys Inc."},
	{0x001BFE, "Zavio Inc."},
	{0x001BFF, "Millennia Media inc."},
	{0x001C00, "Entry Point, LLC"},
	{0x001C01, "ABB Oy Drives"},
	{0x001C02, "Atto Devices, Inc"},
	{0x001C03, "Betty TV Technology AG"},
	{0x001C04, "Airgain, Inc."},
	{0x001C05, "Nonin Medical Inc."},
	{0x001C06, "Siemens Numerical Control Ltd., Nanjing"},
	{0x001C07, "Cwlinux Limited"},
	{0x001C08, "Anystream, Inc."},
	{0x001C09, "SAE Electronic Co.,Ltd."},
	{0x001C0A, "Shenzhen AEE Technology Co.,Ltd."},
	{0x001C0B, "SmartAnt Telecom"},
	{0x001C0C, "TANITA Corporation"},
	{0x001C0D, "G-Technology, Inc."},
	{0x001C0E, "Cisco Systems"},
	{0x001C0F, "Cisco Systems"},
	{0x001C10, "Cisco-Linksys, LLC"},
	{0x001C11, "Motorola CHS"},
	{0x001C12, "Motorola Mobile Devices"},
	{0x001C13, "OPTSYS TECHNOLOGY CO., LTD."},
	{0x001C14, "VMware, Inc"},
	{0x001C15, "TXP Corporation"},
	{0x001C16, "ThyssenKrupp Elevator"},
	{0x001C17, "Nortel"},
	{0x001C18, "Sicert S.r.L."},
	{0x001C19, "secunet Security Networks AG"},
	{0x001C1A, "Thomas Instrumentation, Inc"},
	{0x001C1B, "Hyperstone GmbH"},
	{0x001C1C, "Center Communication Systems GmbH"},
	{0x001C1D, "CHENZHOU GOSPELL DIGITAL TECHNOLOGY CO.,LTD"},
	{0x001C1E, "emtrion GmbH"},
	{0x001C1F, "Quest Retail Technology Pty Ltd"},
	{0x001C20, "CLB Benelux"},
	{0x001C21, "Nucsafe Inc."},
	{0x001C22, "Aeris Elettronica s.r.l."},
	{0x001C23, "Dell Inc"},
	{0x001C24, "Formosa Wireless Systems Corp."},
	{0x001C25, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x001C26, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x001C27, "Sunell Electronics Co."},
	{0x001C28, "Sphairon Access Systems GmbH"},
	{0x001C29, "CORE DIGITAL ELECTRONICS CO., LTD"},
	{0x001C2A, "Envisacor Technologies Inc."},
	{0x001C2B, "Alertme.com Limited"},
	{0x001C2C, "Synapse"},
	{0x001C2D, "FlexRadio Systems"},
	{0x001C2E, "ProCurve Networking by HP"},
	{0x001C2F, "Pfister GmbH"},
	{0x001C30, "Mode Lighting (UK ) Ltd."},
	{0x001C31, "Mobile XP Technology Co., LTD"},
	{0x001C32, "Telian Corporation"},
	{0x001C33, "Sutron"},
	{0x001C34, "HUEY CHIAO INTERNATIONAL CO., LTD."},
	{0x001C35, "Nokia Danmark A/S"},
	{0x001C36, "iNEWiT NV"},
	{0x001C37, "Callpod, Inc."},
	{0x001C38, "Bio-Rad Laboratories, Inc."},
	{0x001C39, "S Netsystems Inc."},
	{0x001C3A, "Element Labs, Inc."},
	{0x001C3B, "AmRoad Technology Inc."},
	{0x001C3C, "Seon Design Inc."},
	{0x001C3D, "WaveStorm"},
	{0x001C3E, "ECKey Limited"},
	{0x001C3F, "International Police Technologies, Inc."},
	{0x001C40, "VDG-Security bv"},
	{0x001C41, "scemtec Transponder Technology GmbH"},
	{0x001C42, "Parallels, Inc."},
	{0x001C43, "Samsung Electronics Co.,Ltd"},
	{0x001C44, "Bosch Security Systems BV"},
	{0x001C45, "Chenbro Micom Co., Ltd."},
	{0x001C46, "QTUM"},
	{0x001C47, "Hangzhou Hollysys Automation Co., Ltd"},
	{0x001C48, "WiDeFi, Inc."},
	{0x001C49, "Zoltan Technology Inc."},
	{0x001C4A, "AVM GmbH"},
	{0x001C4B, "Gener8, Inc."},
	{0x001C4C, "Petrotest Instruments"},
	{0x001C4D, "Zeetoo, Inc."},
	{0x001C4E, "TASA International Limited"},
	{0x001C4F, "MACAB AB"},
	{0x001C50, "TCL Technoly Electronics(Huizhou)Co.,Ltd"},
	{0x001C51, "Celeno Communications"},
	{0x001C52, "VISIONEE SRL"},
	{0x001C53, "Synergy Lighting Controls"},
	{0x001C54, "Hillstone Networks Inc"},
	{0x001C55, "Shenzhen Kaifa Technology Co."},
	{0x001C56, "Pado Systems, Inc."},
	{0x001C57, "Cisco Systems"},
	{0x001C58, "Cisco Systems"},
	{0x001C59, "DEVON IT"},
	{0x001C5A, "Advanced Relay Corporation"},
	{0x001C5B, "Chubb Electronic Security Systems Ltd"},
	{0x001C5C, "Integrated Medical Systems, Inc."},
	{0x001C5D, "Leica Microsystems"},
	{0x001C5E, "ASTON France"},
	{0x001C5F, "Winland Electronics, Inc."},
	{0x001C60, "CSP Frontier Technologies,Inc."},
	{0x001C61, "Galaxy Technology (HK) Ltd."},
	{0x001C62, "LG Electronics Inc"},
	{0x001C63, "TRUEN"},
	{0x001C64, "Cellnet+Hunt"},
	{0x001C65, "JoeScan, Inc."},
	{0x001C66, "UCAMP CO.,LTD"},
	{0x001C67, "Pumpkin Networks, Inc."},
	{0x001C68, "Anhui Sun Create Electronics Co., Ltd"},
	{0x001C69, "Packet Vision Ltd"},
	{0x001C6A, "Weiss Engineering Ltd."},
	{0x001C6B, "COVAX  Co. Ltd"},
	{0x001C6C, "Jabil Circuit (Guangzhou) Limited"},
	{0x001C6D, "KYOHRITSU ELECTRONIC INDUSTRY CO., LTD."},
	{0x001C6E, "Newbury Networks, Inc."},
	{0x001C6F, "Emfit Ltd"},
	{0x001C70, "NOVACOMM LTDA"},
	{0x001C71, "Emergent Electronics"},
	{0x001C72, "Mayer & Cie GmbH & Co KG"},
	{0x001C73, "Arista Networks, Inc."},
	{0x001C74, "Syswan Technologies Inc."},
	{0x001C75, "RF Systems GmbH"},
	{0x001C76, "The Wandsworth Group Ltd"},
	{0x001C77, "Prodys"},
	{0x001C78, "WYPLAY SAS"},
	{0x001C79, "Cohesive Financial Technologies LLC"},
	{0x001C7A, "Perfectone Netware Company Ltd"},
	{0x001C7B, "Castlenet Technology Inc."},
	{0x001C7C, "PERQ SYSTEMS CORPORATION"},
	{0x001C7D, "Excelpoint Manufacturing Pte Ltd"},
	{0x001C7E, "Toshiba"},
	{0x001C7F, "Check Point Software Technologies"},
	{0x001C80, "New Business Division/Rhea-Information CO., LTD."},
	{0x001C81, "NextGen Venturi LTD"},
	{0x001C82, "Genew Technologies"},
	{0x001C83, "New Level Telecom Co., Ltd."},
	{0x001C84, "STL Solution Co.,Ltd."},
	{0x001C85, "Eunicorn"},
	{0x001C86, "Cranite Systems, Inc."},
	{0x001C87, "Uriver Inc."},
	{0x001C88, "TRANSYSTEM INC."},
	{0x001C89, "Force Communications, Inc."},
	{0x001C8A, "Verari Systems Inc"},
	{0x001C8B, "MJ Innovations Ltd."},
	{0x001C8C, "DIAL TECHNOLOGY LTD."},
	{0x001C8D, "Mesa Imaging"},
	{0x001C8E, "Alcatel-Lucent IPD"},
	{0x001C8F, "Advanced Electronic Design, Inc."},
	{0x001C90, "Empacket Corporation"},
	{0x001C91, "Gefen Inc."},
	{0x001C92, "Tervela"},
	{0x001C93, "ExaDigm Inc"},
	{0x001C94, "LI-COR Biosciences"},
	{0x001C95, "Opticomm Corporation"},
	{0x001C96, "Linkwise Technology Pte Ltd"},
	{0x001C97, "Enzytek Technology Inc.,"},
	{0x001C98, "LUCKY TECHNOLOGY (HK) COMPANY LIMITED"},
	{0x001C99, "Shunra Software Ltd."},
	{0x001C9A, "Nokia Danmark A/S"},
	{0x001C9B, "FEIG ELECTRONIC GmbH"},
	{0x001C9C, "Nortel"},
	{0x001C9D, "Liecthi AG"},
	{0x001C9E, "Dualtech IT AB"},
	{0x001C9F, "Razorstream, LLC"},
	{0x001CA0, "Production Resource Group, LLC"},
	{0x001CA1, "AKAMAI TECHNOLOGIES, INC."},
	{0x001CA2, "PIRELLI BROADBAND SOLUTIONS"},
	{0x001CA3, "Terra"},
	{0x001CA4, "Sony Ericsson Mobile Communications"},
	{0x001CA5, "Zygo Corporation"},
	{0x001CA6, "Win4NET"},
	{0x001CA7, "International Quartz Limited"},
	{0x001CA8, "AirTies Wireless Networks"},
	{0x001CA9, "Audiomatica Srl"},
	{0x001CAA, "Bellon Pty Ltd"},
	{0x001CAB, "Meyer Sound Laboratories, Inc."},
	{0x001CAC, "Qniq Technology Corp."},
	{0x001CAD, "Wuhan Telecommunication Devices Co.,Ltd"},
	{0x001CAE, "WiChorus, Inc."},
	{0x001CAF, "Plato Networks Inc."},
	{0x001CB0, "Cisco Systems"},
	{0x001CB1, "Cisco Systems"},
	{0x001CB2, "BPT SPA"},
	{0x001CB3, "APPLE, INC"},
	{0x001CB4, "Iridium Satellite LLC"},
	{0x001CB5, "Neihua Network Technology Co.,LTD.(NHN)"},
	{0x001CB6, "Duzon CNT Co., Ltd."},
	{0x001CB7, "USC DigiArk Corporation"},
	{0x001CB8, "CBC Co., Ltd"},
	{0x001CB9, "KWANG SUNG ELECTRONICS CO., LTD."},
	{0x001CBA, "VerScient, Inc."},
	{0x001CBB, "MusicianLink"},
	{0x001CBC, "CastGrabber, LLC"},
	{0x001CBD, "Ezze Mobile Tech., Inc."},
	{0x001CBE, "Nintendo Co., Ltd."},
	{0x001CBF, "Intel Corporate"},
	{0x001CC0, "Intel Corporate"},
	{0x001CC1, "Motorola Mobile Devices"},
	{0x001CC2, "Part II Research, Inc."},
	{0x001CC3, "Pace Micro Technology plc"},
	{0x001CC4, "Hewlett Packard"},
	{0x001CC5, "3COM LTD"},
	{0x001CC6, "ProStor Systems"},
	{0x001CC7, "Rembrandt Technologies, LLC d/b/a REMSTREAM"},
	{0x001CC8, "INDUSTRONIC Industrie-Electronic GmbH & Co. KG"},
	{0x001CC9, "Kaise Electronic Technology Co., Ltd."},
	{0x001CCA, "Shanghai Gaozhi Science & Technology Development Co."},
	{0x001CCB, "Forth Corporation Public Company Limited"},
	{0x001CCC, "Research In Motion Limited"},
	{0x001CCD, "Alektrona Corporation"},
	{0x001CCE, "By Techdesign"},
	{0x001CCF, "LIMETEK"},
	{0x001CD0, "Circleone Co.,Ltd."},
	{0x001CD1, "Waves Audio LTD"},
	{0x001CD2, "King Champion (Hong Kong) Limited"},
	{0x001CD3, "ZP Engineering SEL"},
	{0x001CD4, "Nokia Danmark A/S"},
	{0x001CD5, "ZeeVee, Inc."},
	{0x001CD6, "Nokia Danmark A/S"},
	{0x001CD7, "Harman/Becker Automotive Systems GmbH"},
	{0x001CD8, "BlueAnt Wireless"},
	{0x001CD9, "GlobalTop Technology Inc."},
	{0x001CDA, "Exegin Technologies Limited"},
	{0x001CDB, "CARPOINT CO.,LTD"},
	{0x001CDC, "Custom Computer Services, Inc."},
	{0x001CDD, "COWBELL ENGINEERING CO., LTD."},
	{0x001CDE, "Interactive Multimedia eXchange Inc."},
	{0x001CDF, "Belkin International Inc."},
	{0x001CE0, "DASAN TPS"},
	{0x001CE1, "INDRA SISTEMAS, S.A."},
	{0x001CE2, "Attero Tech, LLC."},
	{0x001CE3, "Optimedical Systems"},
	{0x001CE4, "EleSy JSC"},
	{0x001CE5, "MBS Electronic Systems GmbH"},
	{0x001CE6, "INNES"},
	{0x001CE7, "Rocon PLC Research Centre"},
	{0x001CE8, "Cummins Inc"},
	{0x001CE9, "Galaxy Technology Limited"},
	{0x001CEA, "Scientific-Atlanta, Inc"},
	{0x001CEB, "Nortel"},
	{0x001CEC, "Mobilesoft (Aust.) Pty Ltd"},
	{0x001CED, "ENVIRONNEMENT SA"},
	{0x001CEE, "SHARP Corporation"},
	{0x001CEF, "Primax Electronics LTD"},
	{0x001CF0, "D-Link Corporation"},
	{0x001CF1, "SUPoX Technology Co. , LTD."},
	{0x001CF2, "Tenlon Technology Co.,Ltd."},
	{0x001CF3, "EVS BROADCAST EQUIPMENT"},
	{0x001CF4, "Media Technology Systems Inc"},
	{0x001CF5, "Wiseblue Technology Limited"},
	{0x001CF6, "Cisco Systems"},
	{0x001CF7, "AudioScience"},
	{0x001CF8, "Parade Technologies, Ltd."},
	{0x001CF9, "Cisco Systems"},
	{0x001CFA, "Alarm.com"},
	{0x001CFB, "Motorola CHS"},
	{0x001CFC, "Suminet Communication Technologies (Shanghai) Co., Ltd."},
	{0x001CFD, "Universal Electronics"},
	{0x001CFE, "Quartics Inc"},
	{0x001CFF, "Napera Networks Inc"},
	{0x001D00, "Brivo Systems, LLC"},
	{0x001D01, "Neptune Digital"},
	{0x001D02, "Cybertech Telecom Development"},
	{0x001D03, "Design Solutions Inc."},
	{0x001D04, "Zipit Wireless, Inc."},
	{0x001D05, "iLight"},
	{0x001D06, "HM Electronics, Inc."},
	{0x001D07, "Shenzhen Sang Fei Consumer Communications Co.,Ltd"},
	{0x001D08, "JIANGSU YINHE ELECTRONICS CO., LTD"},
	{0x001D09, "Dell Inc"},
	{0x001D0A, "Davis Instruments, Inc."},
	{0x001D0B, "Power Standards Lab"},
	{0x001D0C, "MobileCompia"},
	{0x001D0D, "Sony Computer Entertainment inc."},
	{0x001D0E, "Agapha Technology co., Ltd."},
	{0x001D0F, "TP-LINK Technologies Co., Ltd."},
	{0x001D10, "LightHaus Logic, Inc."},
	{0x001D11, "Analogue & Micro Ltd"},
	{0x001D12, "ROHM CO., LTD."},
	{0x001D13, "NextGTV"},
	{0x001D14, "SPERADTONE INFORMATION TECHNOLOGY LIMITED"},
	{0x001D15, "Shenzhen Dolphin Electronic Co., Ltd"},
	{0x001D16, "Efixo"},
	{0x001D17, "Digital Sky Corporation"},
	{0x001D18, "Power Innovation GmbH"},
	{0x001D19, "Arcadyan Technology Corporation"},
	{0x001D1A, "OvisLink S.A."},
	{0x001D1B, "Sangean Electronics Inc."},
	{0x001D1C, "Gennet s.a."},
	{0x001D1D, "Inter-M Corporation"},
	{0x001D1E, "KYUSHU TEN CO.,LTD"},
	{0x001D1F, "Siauliu Tauro Televizoriai, JSC"},
	{0x001D20, "COMTREND CO."},
	{0x001D21, "Alcad SL"},
	{0x001D22, "Foss Analytical A/S"},
	{0x001D23, "SENSUS "},
	{0x001D24, "Aclara Power-Line Systems Inc."},
	{0x001D25, "Samsung Electronics Co.,Ltd"},
	{0x001D26, "Rockridgesound Technology Co."},
	{0x001D27, "NAC-INTERCOM"},
	{0x001D28, "Sony Ericsson Mobile Communications AB"},
	{0x001D29, "Doro AB"},
	{0x001D2A, "Tideway Electronic LTD"},
	{0x001D2B, "Wuhan Pont Technology CO. , LTD"},
	{0x001D2C, "Wavetrend Technologies (Pty) Limited"},
	{0x001D2D, "Pylone, Inc."},
	{0x001D2E, "Ruckus Wireless"},
	{0x001D2F, "QuantumVision Corporation"},
	{0x001D30, "YX Wireless S.A."},
	{0x001D31, "HIGHPRO INTERNATIONAL R&D CO,.LTD."},
	{0x001D32, "Longkay Communication & Technology (Shanghai) Co. Ltd"},
	{0x001D33, "Maverick Systems Inc."},
	{0x001D34, "SYRIS Technology Corp"},
	{0x001D35, "Viconics Electronics Inc."},
	{0x001D36, "ELECTRONICS CORPORATION OF INDIA LIMITED"},
	{0x001D37, "Thales-Panda Transportation System"},
	{0x001D38, "Seagate Technology"},
	{0x001D39, "MOOHADIGITAL CO., LTD"},
	{0x001D3A, "mh acoustics LLC"},
	{0x001D3B, "Nokia Danmark A/S"},
	{0x001D3C, "Muscle Corporation"},
	{0x001D3D, "Avidyne Corporation"},
	{0x001D3E, "SAKA TECHNO SCIENCE CO.,LTD"},
	{0x001D3F, "Mitron Pty Ltd"},
	{0x001D40, "Living Independently Group, Inc."},
	{0x001D41, "Hardy Instruments"},
	{0x001D42, "Nortel"},
	{0x001D43, "Shenzhen G-link Digital Technology Co., Ltd."},
	{0x001D44, "Krohne"},
	{0x001D45, "Cisco Systems"},
	{0x001D46, "Cisco Systems"},
	{0x001D47, "Covote GmbH & Co KG"},
	{0x001D48, "Sensor-Technik Wiedemann GmbH"},
	{0x001D49, "Innovation Wireless Inc."},
	{0x001D4A, "Carestream Health, Inc."},
	{0x001D4B, "Grid Connect Inc."},
	{0x001D4C, "Alcatel-Lucent"},
	{0x001D4D, "Adaptive Recognition Hungary, Inc"},
	{0x001D4E, "TCM Mobile LLC"},
	{0x001D4F, "Apple Computer Inc."},
	{0x001D50, "SPINETIX SA"},
	{0x001D51, "GE Energy"},
	{0x001D52, "Defzone B.V."},
	{0x001D53, "S&O Electronics (Malaysia) Sdn. Bhd."},
	{0x001D54, "Sunnic Technology & Merchandise INC."},
	{0x001D55, "ZANTAZ, Inc"},
	{0x001D56, "Kramer Electronics Ltd."},
	{0x001D57, "CAETEC Messtechnik"},
	{0x001D58, "CQ Inc"},
	{0x001D59, "Mitra Energy & Infrastructure"},
	{0x001D5A, "2Wire Inc."},
	{0x001D5B, "Tecvan Informatica Ltda"},
	{0x001D5C, "Tom Communication Industrial Co.,Ltd."},
	{0x001D5D, "Control Dynamics Pty. Ltd."},
	{0x001D5E, "COMING MEDIA CORP."},
	{0x001D5F, "OverSpeed SARL"},
	{0x001D60, "ASUSTek COMPUTER INC."},
	{0x001D61, "BIJ Corporation"},
	{0x001D62, "InPhase Technologies"},
	{0x001D63, "Miele & Cie. KG"},
	{0x001D64, "Adam Communications Systems Int Ltd"},
	{0x001D65, "Microwave Radio Communications"},
	{0x001D66, "Hyundai Telecom"},
	{0x001D67, "AMEC"},
	{0x001D68, "Thomson Telecom Belgium"},
	{0x001D69, "Knorr-Bremse AG"},
	{0x001D6A, "Alpha Networks Inc."},
	{0x001D6B, "Motorola (formerly Netopia, Inc"},
	{0x001D6C, "ClariPhy Communications, Inc."},
	{0x001D6D, "Confidant International LLC"},
	{0x001D6E, "Nokia Danmark A/S"},
	{0x001D6F, "Chainzone Technology Co., Ltd"},
	{0x001D70, "Cisco Systems"},
	{0x001D71, "Cisco Systems"},
	{0x001D72, "Wistron Corporation"},
	{0x001D73, "Buffalo Inc."},
	{0x001D74, "Tianjin China-Silicon Microelectronics Co., Ltd."},
	{0x001D75, "Radioscape PLC"},
	{0x001D76, "Eyeheight Ltd."},
	{0x001D77, "NSGate"},
	{0x001D78, "Invengo Information Technology Co.,Ltd"},
	{0x001D79, "SIGNAMAX LLC"},
	{0x001D7A, "Wideband Semiconductor, Inc."},
	{0x001D7B, "Ice Energy, Inc."},
	{0x001D7C, "ABE Elettronica S.p.A."},
	{0x001D7D, "GIGA-BYTE TECHNOLOGY CO.,LTD."},
	{0x001D7E, "Cisco-Linksys, LLC"},
	{0x001D7F, "Tekron International Ltd"},
	{0x001D80, "Beijing Huahuan Eletronics Co.,Ltd"},
	{0x001D81, "GUANGZHOU GATEWAY ELECTRONICS CO., LTD"},
	{0x001D82, "GN A/S (GN Netcom A/S)"},
	{0x001D83, "Emitech Corporation"},
	{0x001D84, "Gateway, Inc."},
	{0x001D85, "Call Direct Cellular Solutions"},
	{0x001D86, "Shinwa Industries(China) Ltd."},
	{0x001D87, "VigTech Labs Sdn Bhd"},
	{0x001D88, "Clearwire"},
	{0x001D89, "VaultStor Corporation"},
	{0x001D8A, "TechTrex Inc"},
	{0x001D8B, "PIRELLI BROADBAND SOLUTIONS"},
	{0x001D8C, "La Crosse Technology LTD"},
	{0x001D8D, "Raytek GmbH"},
	{0x001D8E, "Alereon, Inc."},
	{0x001D8F, "PureWave Networks"},
	{0x001D90, "EMCO Flow Systems"},
	{0x001D91, "Digitize, Inc"},
	{0x001D92, "MICRO-STAR INT'L CO.,LTD."},
	{0x001D93, "Modacom"},
	{0x001D94, "Climax Technology Co., Ltd"},
	{0x001D95, "Flash, Inc."},
	{0x001D96, "WatchGuard Video"},
	{0x001D97, "Alertus Technologies LLC"},
	{0x001D98, "Nokia Danmark A/S"},
	{0x001D99, "Cyan Optic, Inc."},
	{0x001D9A, "GODEX INTERNATIONAL CO., LTD"},
	{0x001D9B, "Hokuyo Automatic Co., Ltd."},
	{0x001D9C, "Rockwell Automation"},
	{0x001D9D, "ARTJOY INTERNATIONAL LIMITED"},
	{0x001D9E, "AXION TECHNOLOGIES"},
	{0x001D9F, "MATT   R.P.Traczynscy Sp.J."},
	{0x001DA0, "Heng Yu Electronic Manufacturing Company Limited"},
	{0x001DA1, "Cisco Systems"},
	{0x001DA2, "Cisco Systems"},
	{0x001DA3, "SabiOso"},
	{0x001DA4, "Hangzhou System Technology CO., LTD"},
	{0x001DA5, "WB Electronics"},
	{0x001DA6, "Media Numerics Limited"},
	{0x001DA7, "Seamless Internet"},
	{0x001DA8, "Takahata Electronics Co.,Ltd"},
	{0x001DA9, "Castles Technology, Co., LTD"},
	{0x001DAA, "DrayTek Corp."},
	{0x001DAB, "SwissQual License AG"},
	{0x001DAC, "Gigamon Systems LLC"},
	{0x001DAD,
	 "Sinotech Engineering Consultants, Inc.  Geotechnical Enginee"},
	{0x001DAE, "CHANG TSENG TECHNOLOGY CO., LTD"},
	{0x001DAF, "Nortel"},
	{0x001DB0, "FuJian HengTong Information Technology Co.,Ltd"},
	{0x001DB1, "Crescendo Networks"},
	{0x001DB2, "HOKKAIDO ELECTRIC ENGINEERING CO.,LTD."},
	{0x001DB3, "ProCurve Networking by HP"},
	{0x001DB4, "KUMHO ENG CO.,LTD"},
	{0x001DB5, "Juniper networks"},
	{0x001DB6, "BestComm Networks, Inc."},
	{0x001DB7, "Tendril Networks, Inc."},
	{0x001DB8, "Intoto Inc."},
	{0x001DB9, "Wellspring Wireless"},
	{0x001DBA, "Sony Corporation"},
	{0x001DBB, "Dynamic System Electronics Corp."},
	{0x001DBC, "Nintendo Co., Ltd."},
	{0x001DBD, "Versamed Inc."},
	{0x001DBE, "Motorola Mobile Devices"},
	{0x001DBF, "Radiient Technologies, Inc."},
	{0x001DC0, "Enphase Energy"},
	{0x001DC1, "Audinate"},
	{0x001DC2, "XORTEC OY"},
	{0x001DC3, "RIKOR TV, Ltd"},
	{0x001DC4, "AIOI Systems Co., Ltd."},
	{0x001DC5, "Beijing Jiaxun Feihong Electricial Co., Ltd."},
	{0x001DC6, "SNR Inc."},
	{0x001DC7, "L-3 Communications Geneva Aerospace"},
	{0x001DC8, "ScadaMetrcs, LLC."},
	{0x001DC9, "GainSpan Corp."},
	{0x001DCA, "PAV Electronics Limited"},
	{0x001DCB, "Exns Development Oy"},
	{0x001DCC, "Hetra Secure Solutions"},
	{0x001DCD, "ARRIS Group, Inc."},
	{0x001DCE, "ARRIS Group, Inc."},
	{0x001DCF, "ARRIS Group, Inc."},
	{0x001DD0, "ARRIS Group, Inc."},
	{0x001DD1, "ARRIS Group, Inc."},
	{0x001DD2, "ARRIS Group, Inc."},
	{0x001DD3, "ARRIS Group, Inc."},
	{0x001DD4, "ARRIS Group, Inc."},
	{0x001DD5, "ARRIS Group, Inc."},
	{0x001DD6, "ARRIS Group, Inc."},
	{0x001DD7, "Algolith"},
	{0x001DD8, "Microsoft Corporation"},
	{0x001DD9, "Hon Hai Precision Ind.Co.,Ltd."},
	{0x001DDA, "Mikroelektronika spol. s r. o."},
	{0x001DDB, "C-BEL Corporation"},
	{0x001DDC, "HangZhou DeChangLong Tech&Info Co.,Ltd"},
	{0x001DDD, "DAT H.K. LIMITED"},
	{0x001DDE, "Zhejiang Broadcast&Television Technology Co.,Ltd."},
	{0x001DDF, "Sunitec Enterprise Co., Ltd."},
	{0x001DE0, "Intel Corporate"},
	{0x001DE1, "Intel Corporate"},
	{0x001DE2, "Radionor Communications"},
	{0x001DE3, "Intuicom"},
	{0x001DE4, "Visioneered Image Systems"},
	{0x001DE5, "Cisco Systems"},
	{0x001DE6, "Cisco Systems"},
	{0x001DE7, "Marine Sonic Technology, Ltd."},
	{0x001DE8, "Nikko Denki Tsushin Company(NDTC)"},
	{0x001DE9, "Nokia Danmark A/S"},
	{0x001DEA, "Commtest Instruments Ltd"},
	{0x001DEB, "DINEC International"},
	{0x001DEC, "Marusys"},
	{0x001DED, "Grid Net, Inc."},
	{0x001DEE, "NEXTVISION SISTEMAS DIGITAIS DE TELEVISO LTDA."},
	{0x001DEF, "TRIMM, INC."},
	{0x001DF0, "Vidient Systems, Inc."},
	{0x001DF1, "Intego Systems, Inc."},
	{0x001DF2, "Netflix, Inc."},
	{0x001DF3, "SBS Science & Technology Co., Ltd"},
	{0x001DF4, "Magellan Technology Pty Limited"},
	{0x001DF5, "Sunshine Co,LTD"},
	{0x001DF6, "Samsung Electronics Co.,Ltd"},
	{0x001DF7, "R. STAHL Schaltgerte GmbH"},
	{0x001DF8, "Webpro Vision Technology Corporation"},
	{0x001DF9, "Cybiotronics (Far East) Limited"},
	{0x001DFA, "Fujian LANDI Commercial Equipment Co.,Ltd"},
	{0x001DFB, "NETCLEUS Systems Corporation"},
	{0x001DFC, "KSIC"},
	{0x001DFD, "Nokia Danmark A/S"},
	{0x001DFE, "Palm, Inc"},
	{0x001DFF, "Network Critical Solutions Ltd"},
	{0x001E00, "Shantou Institute of Ultrasonic Instruments"},
	{0x001E01, "Renesas Technology Sales Co., Ltd."},
	{0x001E02, "Sougou Keikaku Kougyou Co.,Ltd."},
	{0x001E03, "LiComm Co., Ltd."},
	{0x001E04, "Hanson Research Corporation"},
	{0x001E05, "Xseed Technologies & Computing"},
	{0x001E06, "WIBRAIN"},
	{0x001E07, "Winy Technology Co., Ltd."},
	{0x001E08, "Centec Networks Inc"},
	{0x001E09, "ZEFATEK Co.,LTD"},
	{0x001E0A, "Syba Tech Limited"},
	{0x001E0B, "Hewlett Packard"},
	{0x001E0C, "Sherwood Information Partners, Inc."},
	{0x001E0D, "Micran Ltd."},
	{0x001E0E, "MAXI VIEW HOLDINGS LIMITED"},
	{0x001E0F, "Briot International"},
	{0x001E10, "ShenZhen Huawei Communication Technologies Co.,Ltd."},
	{0x001E11, "ELELUX INTERNATIONAL LTD"},
	{0x001E12, "Ecolab"},
	{0x001E13, "Cisco Systems"},
	{0x001E14, "Cisco Systems"},
	{0x001E15, "Beech Hill Electronics"},
	{0x001E16, "Keytronix"},
	{0x001E17, "STN BV"},
	{0x001E18, "Radio Activity srl"},
	{0x001E19, "GTRI"},
	{0x001E1A, "Best Source Taiwan Inc."},
	{0x001E1B, "Digital Stream Technology, Inc."},
	{0x001E1C, "SWS Australia Pty Limited"},
	{0x001E1D, "East Coast Datacom, Inc."},
	{0x001E1E, "Honeywell Life Safety"},
	{0x001E1F, "Nortel"},
	{0x001E20, "Intertain Inc."},
	{0x001E21, "Qisda Co."},
	{0x001E22, "ARVOO Imaging Products BV"},
	{0x001E23, "Electronic Educational Devices, Inc"},
	{0x001E24, "Zhejiang Bell Technology Co.,ltd"},
	{0x001E25, "Intek Digital Inc"},
	{0x001E26, "Digifriends Co. Ltd"},
	{0x001E27, "SBN TECH Co.,Ltd."},
	{0x001E28, "Lumexis Corporation"},
	{0x001E29, "Hypertherm Inc"},
	{0x001E2A, "Netgear Inc."},
	{0x001E2B, "Radio Systems Design, Inc."},
	{0x001E2C, "CyVerse Corporation"},
	{0x001E2D, "STIM"},
	{0x001E2E, "SIRTI S.p.A."},
	{0x001E2F, "DiMoto Pty Ltd"},
	{0x001E30, "Shireen Inc"},
	{0x001E31, "INFOMARK CO.,LTD."},
	{0x001E32, "Zensys"},
	{0x001E33, "Inventec Corporation"},
	{0x001E34, "CryptoMetrics"},
	{0x001E35, "Nintendo Co., Ltd."},
	{0x001E36, "IPTE"},
	{0x001E37, "USI"},
	{0x001E38, "Bluecard Software Technology Co., Ltd."},
	{0x001E39, "Comsys Communication Ltd."},
	{0x001E3A, "Nokia Danmark A/S"},
	{0x001E3B, "Nokia Danmark A/S"},
	{0x001E3C, "Lyngbox Media AB"},
	{0x001E3D, "Alps Electric Co., Ltd"},
	{0x001E3E, "KMW Inc."},
	{0x001E3F, "TrellisWare Technologies, Inc."},
	{0x001E40, "Shanghai DareGlobal Technologies  Co.,Ltd."},
	{0x001E41, "Microwave Communication & Component, Inc."},
	{0x001E42, "Teltonika"},
	{0x001E43, "AISIN AW CO.,LTD."},
	{0x001E44, "SANTEC"},
	{0x001E45, "Sony Ericsson Mobile Communications AB"},
	{0x001E46, "Motorola CHS"},
	{0x001E47, "PT. Hariff Daya Tunggal Engineering"},
	{0x001E48, "Wi-Links"},
	{0x001E49, "Cisco Systems"},
	{0x001E4A, "Cisco Systems"},
	{0x001E4B, "City Theatrical"},
	{0x001E4C, "Hon Hai Precision Ind.Co., Ltd."},
	{0x001E4D, "Welkin Sciences, LLC"},
	{0x001E4E, "DAKO EDV-Ingenieur- und Systemhaus GmbH"},
	{0x001E4F, "Dell Inc."},
	{0x001E50, "BATTISTONI RESEARCH"},
	{0x001E51, "Converter Industry Srl"},
	{0x001E52, "Apple Computer Inc"},
	{0x001E53, "Further Tech Co., LTD"},
	{0x001E54, "TOYO ELECTRIC Corporation"},
	{0x001E55, "COWON SYSTEMS,Inc."},
	{0x001E56, "Bally Wulff Entertainment GmbH"},
	{0x001E57, "ALCOMA, spol. s r.o."},
	{0x001E58, "D-Link Corporation"},
	{0x001E59, "Silicon Turnkey Express, LLC"},
	{0x001E5A, "Motorola CHS"},
	{0x001E5B, "Unitron Company, Inc."},
	{0x001E5C, "RB GeneralEkonomik"},
	{0x001E5D, "Holosys d.o.o."},
	{0x001E5E, "COmputime Ltd."},
	{0x001E5F, "KwikByte, LLC"},
	{0x001E60, "Digital Lighting Systems, Inc"},
	{0x001E61, "ITEC GmbH"},
	{0x001E62, "Siemon"},
	{0x001E63, "Vibro-Meter SA"},
	{0x001E64, "Intel Corporate"},
	{0x001E65, "Intel Corporate"},
	{0x001E66, "RESOL Elektronische Regelungen GmbH"},
	{0x001E67, "Intel Corporate"},
	{0x001E68, "Quanta Computer"},
	{0x001E69, "Thomson Inc."},
	{0x001E6A, "Beijing Bluexon Technology Co.,Ltd"},
	{0x001E6B, "Scientific Atlanta, A Cisco Company"},
	{0x001E6C, "Carbon Mountain LLC"},
	{0x001E6D, "IT R&D Center"},
	{0x001E6E, "Shenzhen First Mile Communications Ltd"},
	{0x001E6F, "Magna-Power Electronics, Inc."},
	{0x001E70, "Cobham Defence Communications Ltd"},
	{0x001E71, "IgeaCare Systems Inc."},
	{0x001E72, "PCS"},
	{0x001E73, "ZTE CORPORATION"},
	{0x001E74, "SAGEM COMMUNICATION"},
	{0x001E75, "LG Electronics"},
	{0x001E76, "Thermo Fisher Scientific"},
	{0x001E77, "Air2App"},
	{0x001E78, "Owitek Technology Ltd.,"},
	{0x001E79, "Cisco Systems"},
	{0x001E7A, "Cisco Systems"},
	{0x001E7B, "R.I.CO. S.r.l."},
	{0x001E7C, "Taiwick Limited"},
	{0x001E7D, "Samsung Electronics Co.,Ltd"},
	{0x001E7E, "Nortel"},
	{0x001E7F, "CBM of America"},
	{0x001E80, "Last Mile Ltd."},
	{0x001E81, "CNB Technology Inc."},
	{0x001E82, "Pliant Technology, Inc."},
	{0x001E83, "LAN/MAN Standards Association (LMSC)"},
	{0x001E84, "Pika Technologies Inc."},
	{0x001E85, "Lagotek Corporation"},
	{0x001E86, "MEL Co.,Ltd."},
	{0x001E87, "Realease Limited"},
	{0x001E88, "ANDOR SYSTEM SUPPORT CO., LTD."},
	{0x001E89, "CRFS Limited"},
	{0x001E8A, "eCopy, Inc"},
	{0x001E8B, "Infra Access Korea Co., Ltd."},
	{0x001E8C, "ASUSTek COMPUTER INC."},
	{0x001E8D, "Motorola Mobile Devices"},
	{0x001E8E, "Hunkeler AG"},
	{0x001E8F, "CANON INC."},
	{0x001E90, "Elitegroup Computer Systems Co"},
	{0x001E91, "KIMIN Electronic Co., Ltd."},
	{0x001E92, "JEULIN S.A."},
	{0x001E93, "CiriTech Systems Inc"},
	{0x001E94, "SUPERCOM TECHNOLOGY CORPORATION"},
	{0x001E95, "SIGMALINK"},
	{0x001E96, "Sepura Plc"},
	{0x001E97, "Medium Link System Technology CO., LTD,"},
	{0x001E98, "GreenLine Communications"},
	{0x001E99, "Vantanol Industrial Corporation"},
	{0x001E9A, "HAMILTON Bonaduz AG"},
	{0x001E9B, "San-Eisha, Ltd."},
	{0x001E9C, "Fidustron INC"},
	{0x001E9D, "Recall Technologies, Inc."},
	{0x001E9E, "ddm hopt + schuler Gmbh + Co. KG"},
	{0x001E9F, "Visioneering Systems, Inc."},
	{0x001EA0, "XLN-t"},
	{0x001EA1, "Brunata a/s"},
	{0x001EA2, "Symx Systems, Inc."},
	{0x001EA3, "Nokia Danmark A/S"},
	{0x001EA4, "Nokia Danmark A/S"},
	{0x001EA5, "ROBOTOUS, Inc."},
	{0x001EA6, "Best IT World (India) Pvt. Ltd."},
	{0x001EA7, "ActionTec Electronics, Inc"},
	{0x001EA8, "Datang Mobile Communications Equipment CO.,LTD"},
	{0x001EA9, "Nintendo Co., Ltd."},
	{0x001EAA, "E-Senza Technologies GmbH"},
	{0x001EAB, "TeleWell Oy"},
	{0x001EAC, "Armadeus Systems"},
	{0x001EAD, "Wingtech Group Limited"},
	{0x001EAE, "Continental Automotive Systems"},
	{0x001EAF, "Ophir Optronics Ltd"},
	{0x001EB0, "ImesD Electronica S.L."},
	{0x001EB1, "Cryptsoft Pty Ltd"},
	{0x001EB2, "LG innotek"},
	{0x001EB3, "Primex Wireless"},
	{0x001EB4, "UNIFAT TECHNOLOGY LTD."},
	{0x001EB5, "Ever Sparkle Technologies Ltd"},
	{0x001EB6, "TAG Heuer SA"},
	{0x001EB7, "TBTech, Co., Ltd."},
	{0x001EB8, "Fortis, Inc."},
	{0x001EB9, "Sing Fai Technology Limited"},
	{0x001EBA, "High Density Devices AS"},
	{0x001EBB, "BLUELIGHT TECHNOLOGY INC."},
	{0x001EBC, "WINTECH AUTOMATION CO.,LTD."},
	{0x001EBD, "Cisco Systems"},
	{0x001EBE, "Cisco Systems"},
	{0x001EBF, "Haas Automation Inc."},
	{0x001EC0, "ZeroG Wireless Inc."},
	{0x001EC1, "3COM EUROPE LTD"},
	{0x001EC2, "Apple, Inc"},
	{0x001EC3, "Kozio, Inc."},
	{0x001EC4, "Celio Corp"},
	{0x001EC5, "Middle Atlantic Products Inc"},
	{0x001EC6, "Obvius Holdings LLC"},
	{0x001EC7, "2Wire"},
	{0x001EC8, "Rapid Mobile (Pty) Ltd"},
	{0x001EC9, "Dell Inc"},
	{0x001ECA, "Nortel"},
	{0x001ECB, "\"RPC \"Energoautomatika\" Ltd"},
	{0x001ECC, "CDVI"},
	{0x001ECD, "KYLAND"},
	{0x001ECE, "BISA Technologies (Hong Kong) Limited"},
	{0x001ECF, "PHILIPS ELECTRONICS UK LTD"},
	{0x001ED0, "CONNEXIUM"},
	{0x001ED1, "Keyprocessor B.V."},
	{0x001ED2, "Ray Shine Video Technology Inc"},
	{0x001ED3, "Dot Technology Int'l Co., Ltd."},
	{0x001ED4, "Doble Engineering"},
	{0x001ED5, "Tekon-Automatics"},
	{0x001ED6, "Alentec & Orion AB"},
	{0x001ED7, "H-Stream Wireless, Inc."},
	{0x001ED8, "Digital United Inc."},
	{0x001ED9, "Mitsubishi Precision Co.,LTd."},
	{0x001EDA, "Wesemann Elektrotechniek B.V."},
	{0x001EDB, "Giken Trastem Co., Ltd."},
	{0x001EDC, "Sony Ericsson Mobile Communications AB"},
	{0x001EDD, "WASKO S.A."},
	{0x001EDE, "BYD COMPANY LIMITED"},
	{0x001EDF, "Master Industrialization Center Kista"},
	{0x001EE0, "Urmet Domus SpA"},
	{0x001EE1, "Samsung Electronics Co.,Ltd"},
	{0x001EE2, "Samsung Electronics Co.,Ltd"},
	{0x001EE3, "T&W Electronics (ShenZhen) Co.,Ltd"},
	{0x001EE4, "ACS Solutions France"},
	{0x001EE5, "Cisco-Linksys, LLC"},
	{0x001EE6, "Shenzhen Advanced Video Info-Tech Co., Ltd."},
	{0x001EE7, "Epic Systems Inc"},
	{0x001EE8, "Mytek"},
	{0x001EE9, "Stoneridge Electronics AB"},
	{0x001EEA, "Sensor Switch, Inc."},
	{0x001EEB, "Talk-A-Phone Co."},
	{0x001EEC, "COMPAL INFORMATION (KUNSHAN) CO., LTD."},
	{0x001EED, "Adventiq Ltd."},
	{0x001EEE, "ETL Systems Ltd"},
	{0x001EEF, "Cantronic International Limited"},
	{0x001EF0, "Gigafin Networks"},
	{0x001EF1, "Servimat"},
	{0x001EF2, "Micro Motion Inc"},
	{0x001EF3, "From2"},
	{0x001EF4, "L-3 Communications Display Systems"},
	{0x001EF5, "Hitek Automated Inc."},
	{0x001EF6, "Cisco Systems"},
	{0x001EF7, "Cisco Systems"},
	{0x001EF8, "Emfinity Inc."},
	{0x001EF9, "Pascom Kommunikations systeme GmbH."},
	{0x001EFA, "PROTEI Ltd."},
	{0x001EFB, "Trio Motion Technology Ltd"},
	{0x001EFC, "JSC \"MASSA-K\""},
	{0x001EFD, "Microbit 2.0 AB"},
	{0x001EFE, "LEVEL s.r.o."},
	{0x001EFF, "Mueller-Elektronik GmbH & Co. KG"},
	{0x001F00, "Nokia Danmark A/S"},
	{0x001F01, "Nokia Danmark A/S"},
	{0x001F02, "Pixelmetrix Corporation Pte Ltd"},
	{0x001F03, "NUM AG"},
	{0x001F04, "Granch Ltd."},
	{0x001F05, "iTAS Technology Corp."},
	{0x001F06, "Integrated Dispatch Solutions"},
	{0x001F07, "AZTEQ Mobile"},
	{0x001F08, "RISCO LTD"},
	{0x001F09, "JASTEC CO., LTD."},
	{0x001F0A, "Nortel"},
	{0x001F0B,
	 "Federal State Unitary Enterprise Industrial Union \"Electropribor\""},
	{0x001F0C, "Intelligent Digital Services GmbH"},
	{0x001F0D, "L3 Communications - Telemetry West"},
	{0x001F0E, "Japan Kyastem Co., Ltd"},
	{0x001F0F, "Select Engineered Systems"},
	{0x001F10, "TOLEDO DO BRASIL INDUSTRIA DE BALANCAS  LTDA"},
	{0x001F11, "OPENMOKO, INC."},
	{0x001F12, "Juniper Networks"},
	{0x001F13, "S.& A.S. Ltd."},
	{0x001F14, "NexG"},
	{0x001F15, "Bioscrypt Inc"},
	{0x001F16, "Wistron Corporation"},
	{0x001F17, "IDX Company, Ltd."},
	{0x001F18, "Hakusan.Mfg.Co,.Ltd"},
	{0x001F19, "BEN-RI ELECTRONICA S.A."},
	{0x001F1A, "Prominvest"},
	{0x001F1B, "RoyalTek Company Ltd."},
	{0x001F1C, "KOBISHI ELECTRIC Co.,Ltd."},
	{0x001F1D, "Atlas Material Testing Technology LLC"},
	{0x001F1E, "Astec Technology Co., Ltd"},
	{0x001F1F, "Edimax Technology Co. Ltd."},
	{0x001F20, "Logitech Europe SA"},
	{0x001F21,
	 "Inner Mongolia Yin An Science & Technology Development Co.,L"},
	{0x001F22, "Fiberxon, Inc."},
	{0x001F23, "Interacoustics"},
	{0x001F24, "DIGITVIEW TECHNOLOGY CO., LTD."},
	{0x001F25, "MBS GmbH"},
	{0x001F26, "Cisco Systems"},
	{0x001F27, "Cisco Systems"},
	{0x001F28, "ProCurve Networking by HP"},
	{0x001F29, "Hewlett Packard"},
	{0x001F2A, "ACCM"},
	{0x001F2B, "Orange Logic"},
	{0x001F2C, "Starbridge Networks"},
	{0x001F2D, "Electro-Optical Imaging, Inc."},
	{0x001F2E, "Triangle Research Int'l Pte Ltd"},
	{0x001F2F, "Berker GmbH & Co. KG"},
	{0x001F30, "Travelping"},
	{0x001F31, "Radiocomp"},
	{0x001F32, "Nintendo Co., Ltd."},
	{0x001F33, "Netgear Inc."},
	{0x001F34, "Lung Hwa Electronics Co., Ltd."},
	{0x001F35, "AIR802 LLC"},
	{0x001F36, "Bellwin Information Co. Ltd.,"},
	{0x001F37, "Genesis I&C"},
	{0x001F38, "POSITRON"},
	{0x001F39, "Construcciones y Auxiliar de Ferrocarriles, S.A."},
	{0x001F3A, "Hon Hai Precision Ind.Co., Ltd."},
	{0x001F3B, "Intel Corporate"},
	{0x001F3C, "Intel Corporate"},
	{0x001F3D, "Qbit GmbH"},
	{0x001F3E, "RP-Technik e.K."},
	{0x001F3F, "AVM GmbH"},
	{0x001F40, "Speakercraft Inc."},
	{0x001F41, "Ruckus Wireless"},
	{0x001F42, "Etherstack Pty Ltd"},
	{0x001F43, "ENTES ELEKTRONIK"},
	{0x001F44, "GE Transportation Systems"},
	{0x001F45, "Enterasys"},
	{0x001F46, "Nortel"},
	{0x001F47, "MCS Logic Inc."},
	{0x001F48, "Mojix Inc."},
	{0x001F49, "Eurosat Distribution Ltd"},
	{0x001F4A, "Albentia Systems S.A."},
	{0x001F4B, "Lineage Power"},
	{0x001F4C, "Roseman Engineering Ltd"},
	{0x001F4D, "Segnetics LLC"},
	{0x001F4E, "ConMed Linvatec"},
	{0x001F4F, "Thinkware Co. Ltd."},
	{0x001F50, "Swissdis AG"},
	{0x001F51, "HD Communications Corp"},
	{0x001F52, "UVT Unternehmensberatung fr Verkehr und Technik GmbH"},
	{0x001F53,
	 "GEMAC Gesellschaft fr Mikroelektronikanwendung Chemnitz mbH"},
	{0x001F54, "Lorex Technology Inc."},
	{0x001F55, "Honeywell Security (China) Co., Ltd."},
	{0x001F56, "DIGITAL FORECAST"},
	{0x001F57, "Phonik Innovation Co.,LTD"},
	{0x001F58, "EMH Energiemesstechnik GmbH"},
	{0x001F59, "Kronback Tracers"},
	{0x001F5A, "Beckwith Electric Co."},
	{0x001F5B, "Apple, Inc."},
	{0x001F5C, "Nokia Danmark A/S"},
	{0x001F5D, "Nokia Danmark A/S"},
	{0x001F5E, "Dyna Technology Co.,Ltd."},
	{0x001F5F, "Blatand GmbH"},
	{0x001F60, "COMPASS SYSTEMS CORP."},
	{0x001F61, "Talent Communication Networks Inc."},
	{0x001F62, "JSC \"Stilsoft\""},
	{0x001F63, "JSC Goodwin-Europa"},
	{0x001F64, "Beijing Autelan Technology Inc."},
	{0x001F65, "KOREA ELECTRIC TERMINAL CO., LTD."},
	{0x001F66, "PLANAR LLC"},
	{0x001F67, "Hitachi,Ltd."},
	{0x001F68, "Martinsson Elektronik AB"},
	{0x001F69, "Pingood Technology Co., Ltd."},
	{0x001F6A, "PacketFlux Technologies, Inc."},
	{0x001F6B, "LG Electronics"},
	{0x001F6C, "Cisco Systems"},
	{0x001F6D, "Cisco Systems"},
	{0x001F6E, "Vtech Engineering Corporation"},
	{0x001F6F, "Fujian Sunnada Communication Co.,Ltd."},
	{0x001F70, "Botik Technologies LTD"},
	{0x001F71, "xG Technology, Inc."},
	{0x001F72, "QingDao Hiphone Technology Co,.Ltd"},
	{0x001F73, "Teraview Technology Co., Ltd."},
	{0x001F74, "Eigen Development"},
	{0x001F75, "GiBahn Media"},
	{0x001F76, "AirLogic Systems Inc."},
	{0x001F77, "HEOL DESIGN"},
	{0x001F78, "Blue Fox Porini Textile"},
	{0x001F79, "Lodam Electronics A/S"},
	{0x001F7A, "WiWide Inc."},
	{0x001F7B, "TechNexion Ltd."},
	{0x001F7C, "Witelcom AS"},
	{0x001F7D, "embedded wireless GmbH"},
	{0x001F7E, "Motorola Mobile Devices"},
	{0x001F7F, "Phabrix Limited"},
	{0x001F80, "Lucas Holding bv"},
	{0x001F81, "Accel Semiconductor Corp"},
	{0x001F82, "Cal-Comp Electronics & Communications Co., Ltd"},
	{0x001F83, "Teleplan Technology Services Sdn Bhd"},
	{0x001F84, "Gigle Semiconductor"},
	{0x001F85, "Apriva ISS, LLC"},
	{0x001F86, "digEcor"},
	{0x001F87, "Skydigital Inc."},
	{0x001F88, "FMS Force Measuring Systems AG"},
	{0x001F89, "Signalion GmbH"},
	{0x001F8A, "Ellion Digital Inc."},
	{0x001F8B, "Storspeed, Inc."},
	{0x001F8C, "CCS Inc."},
	{0x001F8D, "Ingenieurbuero Stark GmbH und Ko. KG"},
	{0x001F8E, "Metris USA Inc."},
	{0x001F8F, "Shanghai Bellmann Digital Source Co.,Ltd."},
	{0x001F90, "Actiontec Electronics, Inc"},
	{0x001F91, "DBS Lodging Technologies, LLC"},
	{0x001F92, "VideoIQ, Inc."},
	{0x001F93, "Xiotech Corporation"},
	{0x001F94, "Lascar Electronics Ltd"},
	{0x001F95, "SAGEM COMMUNICATION"},
	{0x001F96, "APROTECH CO.LTD"},
	{0x001F97, "BERTANA SRL"},
	{0x001F98, "DAIICHI-DENTSU LTD."},
	{0x001F99, "SERONICS co.ltd"},
	{0x001F9A, "Nortel Networks"},
	{0x001F9B, "POSBRO"},
	{0x001F9C, "LEDCO"},
	{0x001F9D, "Cisco Systems"},
	{0x001F9E, "Cisco Systems"},
	{0x001F9F, "Thomson Telecom Belgium"},
	{0x001FA0, "A10 Networks"},
	{0x001FA1, "Gtran Inc"},
	{0x001FA2, "Datron World Communications, Inc."},
	{0x001FA3, "T&W Electronics(Shenzhen)Co.,Ltd."},
	{0x001FA4, "ShenZhen Gongjin Electronics Co.,Ltd"},
	{0x001FA5, "Blue-White Industries"},
	{0x001FA6, "Stilo srl"},
	{0x001FA7, "Sony Computer Entertainment Inc."},
	{0x001FA8, "ANI Technologies Corp."},
	{0x001FA9, "Atlanta DTH, Inc."},
	{0x001FAA, "Taseon, Inc."},
	{0x001FAB, "I.S HIGH TECH.INC"},
	{0x001FAC, "Goodmill Systems Ltd"},
	{0x001FAD, "Brown Innovations, Inc"},
	{0x001FAE, "Blick South Africa (Pty) Ltd"},
	{0x001FAF, "NextIO, Inc."},
	{0x001FB0, "TimeIPS, Inc."},
	{0x001FB1, "Cybertech Inc."},
	{0x001FB2, "Sontheim Industrie Elektronik GmbH"},
	{0x001FB3, "2Wire"},
	{0x001FB4, "SmartShare Systems"},
	{0x001FB5, "I/O Interconnect Inc."},
	{0x001FB6, "Chi Lin Technology Co., Ltd."},
	{0x001FB7, "WiMate Technologies Corp."},
	{0x001FB8, "Universal Remote Control, Inc."},
	{0x001FB9, "Paltronics"},
	{0x001FBA, "BoYoung Tech. & Marketing, Inc."},
	{0x001FBB, "Xenatech Co.,LTD"},
	{0x001FBC, "EVGA Corporation"},
	{0x001FBD, "Kyocera Wireless Corp."},
	{0x001FBE, "Shenzhen Mopnet Industrial Co.,Ltd"},
	{0x001FBF, "Fulhua Microelectronics Corp. Taiwan Branch"},
	{0x001FC0, "Control Express Finland Oy"},
	{0x001FC1, "Hanlong Technology Co.,LTD"},
	{0x001FC2, "Jow Tong Technology Co Ltd"},
	{0x001FC3, "SmartSynch, Inc"},
	{0x001FC4, "Motorola CHS"},
	{0x001FC5, "Nintendo Co., Ltd."},
	{0x001FC6, "ASUSTek COMPUTER INC."},
	{0x001FC7, "Casio Hitachi Mobile Comunications Co., Ltd."},
	{0x001FC8, "Up-Today Industrial Co., Ltd."},
	{0x001FC9, "Cisco Systems"},
	{0x001FCA, "Cisco Systems"},
	{0x001FCB, "NIW Solutions"},
	{0x001FCC, "Samsung Electronics Co.,Ltd"},
	{0x001FCD, "Samsung Electronics"},
	{0x001FCE, "QTECH LLC"},
	{0x001FCF, "MSI Technology GmbH"},
	{0x001FD0, "GIGA-BYTE TECHNOLOGY CO.,LTD."},
	{0x001FD1, "OPTEX CO.,LTD."},
	{0x001FD2, "COMMTECH TECHNOLOGY MACAO COMMERCIAL OFFSHORE LTD."},
	{0x001FD3, "RIVA Networks Inc."},
	{0x001FD4, "4IPNET, INC."},
	{0x001FD5, "MICRORISC s.r.o."},
	{0x001FD6, "Shenzhen Allywll"},
	{0x001FD7, "TELERAD SA"},
	{0x001FD8, "A-TRUST COMPUTER CORPORATION"},
	{0x001FD9, "RSD Communications Ltd"},
	{0x001FDA, "Nortel Networks"},
	{0x001FDB, "Network Supply Corp.,"},
	{0x001FDC, "Mobile Safe Track Ltd"},
	{0x001FDD, "GDI LLC"},
	{0x001FDE, "Nokia Danmark A/S"},
	{0x001FDF, "Nokia Danmark A/S"},
	{0x001FE0, "EdgeVelocity Corp"},
	{0x001FE1, "Hon Hai Precision Ind. Co., Ltd."},
	{0x001FE2, "Hon Hai Precision Ind. Co., Ltd."},
	{0x001FE3, "LG Electronics"},
	{0x001FE4, "Sony Ericsson Mobile Communications"},
	{0x001FE5, "In-Circuit GmbH"},
	{0x001FE6, "Alphion Corporation"},
	{0x001FE7, "Simet"},
	{0x001FE8, "KURUSUGAWA Electronics Industry Inc,."},
	{0x001FE9, "Printrex, Inc."},
	{0x001FEA, "Applied Media Technologies Corporation"},
	{0x001FEB, "Trio Datacom Pty Ltd"},
	{0x001FEC, "Synapse lectronique"},
	{0x001FED, "Tecan Systems Inc."},
	{0x001FEE, "ubisys technologies GmbH"},
	{0x001FEF, "SHINSEI INDUSTRIES CO.,LTD"},
	{0x001FF0, "Audio Partnership"},
	{0x001FF1, "Paradox Hellas S.A."},
	{0x001FF2, "VIA Technologies, Inc."},
	{0x001FF3, "Apple, Inc"},
	{0x001FF4, "Power Monitors, Inc."},
	{0x001FF5, "Kongsberg Defence & Aerospace"},
	{0x001FF6, "PS Audio International"},
	{0x001FF7, "Nakajima All Precision Co., Ltd."},
	{0x001FF8,
	 "Siemens AG, Sector Industry, Drive Technologies, Motion Control Systems"},
	{0x001FF9, "Advanced Knowledge Associates"},
	{0x001FFA, "Coretree, Co, Ltd"},
	{0x001FFB, "Green Packet Bhd"},
	{0x001FFC, "Riccius+Sohn GmbH"},
	{0x001FFD, "Indigo Mobile Technologies Corp."},
	{0x001FFE, "ProCurve Networking by HP"},
	{0x001FFF, "Respironics, Inc."},
	{0x002000, "LEXMARK INTERNATIONAL, INC."},
	{0x002001, "DSP SOLUTIONS, INC."},
	{0x002002, "SERITECH ENTERPRISE CO., LTD."},
	{0x002003, "PIXEL POWER LTD."},
	{0x002004, "YAMATAKE-HONEYWELL CO., LTD."},
	{0x002005, "SIMPLE TECHNOLOGY"},
	{0x002006, "GARRETT COMMUNICATIONS, INC."},
	{0x002007, "SFA, INC."},
	{0x002008, "CABLE & COMPUTER TECHNOLOGY"},
	{0x002009, "PACKARD BELL ELEC., INC."},
	{0x00200A, "SOURCE-COMM CORP."},
	{0x00200B, "OCTAGON SYSTEMS CORP."},
	{0x00200C, "ADASTRA SYSTEMS CORP."},
	{0x00200D, "CARL ZEISS"},
	{0x00200E, "SATELLITE TECHNOLOGY MGMT, INC"},
	{0x00200F, "TANBAC CO., LTD."},
	{0x002010, "JEOL SYSTEM TECHNOLOGY CO. LTD"},
	{0x002011, "CANOPUS CO., LTD."},
	{0x002012, "CAMTRONICS MEDICAL SYSTEMS"},
	{0x002013, "DIVERSIFIED TECHNOLOGY, INC."},
	{0x002014, "GLOBAL VIEW CO., LTD."},
	{0x002015, "ACTIS COMPUTER SA"},
	{0x002016, "SHOWA ELECTRIC WIRE & CABLE CO"},
	{0x002017, "ORBOTECH"},
	{0x002018, "CIS TECHNOLOGY INC."},
	{0x002019, "OHLER GmbH"},
	{0x00201A, "MRV Communications, Inc."},
	{0x00201B, "NORTHERN TELECOM/NETWORK"},
	{0x00201C, "EXCEL, INC."},
	{0x00201D, "KATANA PRODUCTS"},
	{0x00201E, "NETQUEST CORPORATION"},
	{0x00201F, "BEST POWER TECHNOLOGY, INC."},
	{0x002020, "MEGATRON COMPUTER INDUSTRIES PTY, LTD."},
	{0x002021, "ALGORITHMS SOFTWARE PVT. LTD."},
	{0x002022, "NMS Communications"},
	{0x002023, "T.C. TECHNOLOGIES PTY. LTD"},
	{0x002024, "PACIFIC COMMUNICATION SCIENCES"},
	{0x002025, "CONTROL TECHNOLOGY, INC."},
	{0x002026, "AMKLY SYSTEMS, INC."},
	{0x002027, "MING FORTUNE INDUSTRY CO., LTD"},
	{0x002028, "WEST EGG SYSTEMS, INC."},
	{0x002029, "TELEPROCESSING PRODUCTS, INC."},
	{0x00202A, "N.V. DZINE"},
	{0x00202B, "ADVANCED TELECOMMUNICATIONS MODULES, LTD."},
	{0x00202C, "WELLTRONIX CO., LTD."},
	{0x00202D, "TAIYO CORPORATION"},
	{0x00202E, "DAYSTAR DIGITAL"},
	{0x00202F, "ZETA COMMUNICATIONS, LTD."},
	{0x002030, "ANALOG & DIGITAL SYSTEMS"},
	{0x002031, "ERTEC GmbH"},
	{0x002032, "ALCATEL TAISEL"},
	{0x002033, "SYNAPSE TECHNOLOGIES, INC."},
	{0x002034, "ROTEC INDUSTRIEAUTOMATION GMBH"},
	{0x002035, "IBM CORPORATION"},
	{0x002036, "BMC SOFTWARE"},
	{0x002037, "SEAGATE TECHNOLOGY"},
	{0x002038, "VME MICROSYSTEMS INTERNATIONAL CORPORATION"},
	{0x002039, "SCINETS"},
	{0x00203A, "DIGITAL BI0METRICS INC."},
	{0x00203B, "WISDM LTD."},
	{0x00203C, "EUROTIME AB"},
	{0x00203D, "Honeywell ECC"},
	{0x00203E, "LogiCan Technologies, Inc."},
	{0x00203F, "JUKI CORPORATION"},
	{0x002040, "Motorola Broadband Communications Sector"},
	{0x002041, "DATA NET"},
	{0x002042, "DATAMETRICS CORP."},
	{0x002043, "NEURON COMPANY LIMITED"},
	{0x002044, "GENITECH PTY LTD"},
	{0x002045, "ION Networks, Inc."},
	{0x002046, "CIPRICO, INC."},
	{0x002047, "STEINBRECHER CORP."},
	{0x002048, "Marconi Communications"},
	{0x002049, "COMTRON, INC."},
	{0x00204A, "PRONET GMBH"},
	{0x00204B, "AUTOCOMPUTER CO., LTD."},
	{0x00204C, "MITRON COMPUTER PTE LTD."},
	{0x00204D, "INOVIS GMBH"},
	{0x00204E, "NETWORK SECURITY SYSTEMS, INC."},
	{0x00204F, "DEUTSCHE AEROSPACE AG"},
	{0x002050, "KOREA COMPUTER INC."},
	{0x002051, "Verilink Corporation"},
	{0x002052, "RAGULA SYSTEMS"},
	{0x002053, "HUNTSVILLE MICROSYSTEMS, INC."},
	{0x002054, "Sycamore Networks"},
	{0x002055, "ALTECH CO., LTD."},
	{0x002056, "NEOPRODUCTS"},
	{0x002057, "TITZE DATENTECHNIK GmbH"},
	{0x002058, "ALLIED SIGNAL INC."},
	{0x002059, "MIRO COMPUTER PRODUCTS AG"},
	{0x00205A, "COMPUTER IDENTICS"},
	{0x00205B, "Kentrox, LLC"},
	{0x00205C, "InterNet Systems of Florida, Inc."},
	{0x00205D, "NANOMATIC OY"},
	{0x00205E, "CASTLE ROCK, INC."},
	{0x00205F, "GAMMADATA COMPUTER GMBH"},
	{0x002060, "ALCATEL ITALIA S.p.A."},
	{0x002061, "GarrettCom, Inc."},
	{0x002062, "SCORPION LOGIC, LTD."},
	{0x002063, "WIPRO INFOTECH LTD."},
	{0x002064, "PROTEC MICROSYSTEMS, INC."},
	{0x002065, "SUPERNET NETWORKING INC."},
	{0x002066, "GENERAL MAGIC, INC."},
	{0x002068, "ISDYNE"},
	{0x002069, "ISDN SYSTEMS CORPORATION"},
	{0x00206A, "OSAKA COMPUTER CORP."},
	{0x00206B, "KONICA MINOLTA HOLDINGS, INC."},
	{0x00206C, "EVERGREEN TECHNOLOGY CORP."},
	{0x00206D, "DATA RACE, INC."},
	{0x00206E, "XACT, INC."},
	{0x00206F, "FLOWPOINT CORPORATION"},
	{0x002070, "HYNET, LTD."},
	{0x002071, "IBR GMBH"},
	{0x002072, "WORKLINK INNOVATIONS"},
	{0x002073, "FUSION SYSTEMS CORPORATION"},
	{0x002074, "SUNGWOON SYSTEMS"},
	{0x002075, "MOTOROLA COMMUNICATION ISRAEL"},
	{0x002076, "REUDO CORPORATION"},
	{0x002077, "KARDIOS SYSTEMS CORP."},
	{0x002078, "RUNTOP, INC."},
	{0x002079, "MIKRON GMBH"},
	{0x00207A, "WiSE Communications, Inc."},
	{0x00207B, "Intel Corporation"},
	{0x00207C, "AUTEC GmbH"},
	{0x00207D, "ADVANCED COMPUTER APPLICATIONS"},
	{0x00207E, "FINECOM Co., Ltd."},
	{0x00207F, "KYOEI SANGYO CO., LTD."},
	{0x002080, "SYNERGY (UK) LTD."},
	{0x002081, "TITAN ELECTRONICS"},
	{0x002082, "ONEAC CORPORATION"},
	{0x002083, "PRESTICOM INCORPORATED"},
	{0x002084, "OCE PRINTING SYSTEMS, GMBH"},
	{0x002085, "EXIDE ELECTRONICS"},
	{0x002086, "MICROTECH ELECTRONICS LIMITED"},
	{0x002087, "MEMOTEC, INC."},
	{0x002088, "GLOBAL VILLAGE COMMUNICATION"},
	{0x002089, "T3PLUS NETWORKING, INC."},
	{0x00208A, "SONIX COMMUNICATIONS, LTD."},
	{0x00208B, "LAPIS TECHNOLOGIES, INC."},
	{0x00208C, "GALAXY NETWORKS, INC."},
	{0x00208D, "CMD TECHNOLOGY"},
	{0x00208E, "CHEVIN SOFTWARE ENG. LTD."},
	{0x00208F, "ECI TELECOM LTD."},
	{0x002090, "ADVANCED COMPRESSION TECHNOLOGY, INC."},
	{0x002091, "J125, NATIONAL SECURITY AGENCY"},
	{0x002092, "CHESS ENGINEERING B.V."},
	{0x002093, "LANDINGS TECHNOLOGY CORP."},
	{0x002094, "CUBIX CORPORATION"},
	{0x002095, "RIVA ELECTRONICS"},
	{0x002096, "Invensys"},
	{0x002097, "APPLIED SIGNAL TECHNOLOGY"},
	{0x002098, "HECTRONIC AB"},
	{0x002099, "BON ELECTRIC CO., LTD."},
	{0x00209A, "THE 3DO COMPANY"},
	{0x00209B, "ERSAT ELECTRONIC GMBH"},
	{0x00209C, "PRIMARY ACCESS CORP."},
	{0x00209D, "LIPPERT AUTOMATIONSTECHNIK"},
	{0x00209E, "BROWN'S OPERATING SYSTEM SERVICES, LTD."},
	{0x00209F, "MERCURY COMPUTER SYSTEMS, INC."},
	{0x0020A0, "OA LABORATORY CO., LTD."},
	{0x0020A1, "DOVATRON"},
	{0x0020A2, "GALCOM NETWORKING LTD."},
	{0x0020A3, "DIVICOM INC."},
	{0x0020A4, "MULTIPOINT NETWORKS"},
	{0x0020A5, "API ENGINEERING"},
	{0x0020A6, "PROXIM, INC."},
	{0x0020A7, "PAIRGAIN TECHNOLOGIES, INC."},
	{0x0020A8, "SAST TECHNOLOGY CORP."},
	{0x0020A9, "WHITE HORSE INDUSTRIAL"},
	{0x0020AA, "DIGIMEDIA VISION LTD."},
	{0x0020AB, "MICRO INDUSTRIES CORP."},
	{0x0020AC, "INTERFLEX DATENSYSTEME GMBH"},
	{0x0020AD, "LINQ SYSTEMS"},
	{0x0020AE, "ORNET DATA COMMUNICATION TECH."},
	{0x0020AF, "3COM CORPORATION"},
	{0x0020B0, "GATEWAY DEVICES, INC."},
	{0x0020B1, "COMTECH RESEARCH INC."},
	{0x0020B2, "GKD Gesellschaft Fur Kommunikation Und Datentechnik"},
	{0x0020B3, "SCLTEC COMMUNICATIONS SYSTEMS"},
	{0x0020B4, "TERMA ELEKTRONIK AS"},
	{0x0020B5, "YASKAWA ELECTRIC CORPORATION"},
	{0x0020B6, "AGILE NETWORKS, INC."},
	{0x0020B7, "NAMAQUA COMPUTERWARE"},
	{0x0020B8, "PRIME OPTION, INC."},
	{0x0020B9, "METRICOM, INC."},
	{0x0020BA, "CENTER FOR HIGH PERFORMANCE"},
	{0x0020BB, "ZAX CORPORATION"},
	{0x0020BC, "Long Reach Networks Pty Ltd"},
	{0x0020BD, "NIOBRARA R & D CORPORATION"},
	{0x0020BE, "LAN ACCESS CORP."},
	{0x0020BF, "AEHR TEST SYSTEMS"},
	{0x0020C0, "PULSE ELECTRONICS, INC."},
	{0x0020C1, "SAXA, Inc."},
	{0x0020C2, "TEXAS MEMORY SYSTEMS, INC."},
	{0x0020C3, "COUNTER SOLUTIONS LTD."},
	{0x0020C4, "INET,INC."},
	{0x0020C5, "EAGLE TECHNOLOGY"},
	{0x0020C6, "NECTEC"},
	{0x0020C7, "AKAI Professional M.I. Corp."},
	{0x0020C8, "LARSCOM INCORPORATED"},
	{0x0020C9, "VICTRON BV"},
	{0x0020CA, "DIGITAL OCEAN"},
	{0x0020CB, "PRETEC ELECTRONICS CORP."},
	{0x0020CC, "DIGITAL SERVICES, LTD."},
	{0x0020CD, "HYBRID NETWORKS, INC."},
	{0x0020CE, "LOGICAL DESIGN GROUP, INC."},
	{0x0020CF, "TEST & MEASUREMENT SYSTEMS INC"},
	{0x0020D0, "VERSALYNX CORPORATION"},
	{0x0020D1, "MICROCOMPUTER SYSTEMS (M) SDN."},
	{0x0020D2, "RAD DATA COMMUNICATIONS, LTD."},
	{0x0020D3, "OST (OUEST STANDARD TELEMATIQU"},
	{0x0020D4, "CABLETRON - ZEITTNET INC."},
	{0x0020D5, "VIPA GMBH"},
	{0x0020D6, "BREEZECOM"},
	{0x0020D7, "JAPAN MINICOMPUTER SYSTEMS CO., Ltd."},
	{0x0020D8, "Nortel Networks"},
	{0x0020D9, "PANASONIC TECHNOLOGIES, INC./MIECO-US"},
	{0x0020DA, "Alcatel North America ESD"},
	{0x0020DB, "XNET TECHNOLOGY, INC."},
	{0x0020DC, "DENSITRON TAIWAN LTD."},
	{0x0020DD, "Cybertec Pty Ltd"},
	{0x0020DE, "JAPAN DIGITAL LABORAT'Y CO.LTD"},
	{0x0020DF, "KYOSAN ELECTRIC MFG. CO., LTD."},
	{0x0020E0, "Actiontec Electronics, Inc."},
	{0x0020E1, "ALAMAR ELECTRONICS"},
	{0x0020E2, "INFORMATION RESOURCE ENGINEERING"},
	{0x0020E3, "MCD KENCOM CORPORATION"},
	{0x0020E4, "HSING TECH ENTERPRISE CO., LTD"},
	{0x0020E5, "APEX DATA, INC."},
	{0x0020E6, "LIDKOPING MACHINE TOOLS AB"},
	{0x0020E7, "B&W NUCLEAR SERVICE COMPANY"},
	{0x0020E8, "DATATREK CORPORATION"},
	{0x0020E9, "DANTEL"},
	{0x0020EA, "EFFICIENT NETWORKS, INC."},
	{0x0020EB, "CINCINNATI MICROWAVE, INC."},
	{0x0020EC, "TECHWARE SYSTEMS CORP."},
	{0x0020ED, "GIGA-BYTE TECHNOLOGY CO., LTD."},
	{0x0020EE, "GTECH CORPORATION"},
	{0x0020EF, "USC CORPORATION"},
	{0x0020F0, "UNIVERSAL MICROELECTRONICS CO."},
	{0x0020F1, "ALTOS INDIA LIMITED"},
	{0x0020F2, "SUN MICROSYSTEMS, INC."},
	{0x0020F3, "RAYNET CORPORATION"},
	{0x0020F4, "SPECTRIX CORPORATION"},
	{0x0020F5, "PANDATEL AG"},
	{0x0020F6, "NET TEK  AND KARLNET, INC."},
	{0x0020F7, "CYBERDATA"},
	{0x0020F8, "CARRERA COMPUTERS, INC."},
	{0x0020F9, "PARALINK NETWORKS, INC."},
	{0x0020FA, "GDE SYSTEMS, INC."},
	{0x0020FB, "OCTEL COMMUNICATIONS CORP."},
	{0x0020FC, "MATROX"},
	{0x0020FD, "ITV TECHNOLOGIES, INC."},
	{0x0020FE, "TOPWARE INC. / GRAND COMPUTER"},
	{0x0020FF, "SYMMETRICAL TECHNOLOGIES"},
	{0x002100, "GemTek Technology Co., Ltd."},
	{0x002101, "Aplicaciones Electronicas Quasar (AEQ)"},
	{0x002102, "UpdateLogic Inc."},
	{0x002103, "GHI Electronics, LLC"},
	{0x002104, "Gigaset Communications GmbH"},
	{0x002105, "Alcatel-Lucent"},
	{0x002106, "RIM Testing Services"},
	{0x002107, "Seowonintech Co Ltd."},
	{0x002108, "Nokia Danmark A/S"},
	{0x002109, "Nokia Danmark A/S"},
	{0x00210A, "byd:sign Corporation"},
	{0x00210B, "GEMINI TRAZE RFID PVT. LTD."},
	{0x00210C, "Cymtec Systems, Inc."},
	{0x00210D, "SAMSIN INNOTEC"},
	{0x00210E, "Orpak Systems L.T.D."},
	{0x00210F, "Cernium Corp"},
	{0x002110, "Clearbox Systems"},
	{0x002111, "Uniphone Inc."},
	{0x002112, "WISCOM SYSTEM CO.,LTD"},
	{0x002113, "Padtec S/A"},
	{0x002114, "Hylab Technology Inc."},
	{0x002115, "PHYWE Systeme GmbH & Co. KG"},
	{0x002116, "Transcon Electronic Systems, spol. s r. o."},
	{0x002117, "Tellord"},
	{0x002118, "Athena Tech, Inc."},
	{0x002119, "Samsung Electro-Mechanics"},
	{0x00211A, "LInTech Corporation"},
	{0x00211B, "Cisco Systems"},
	{0x00211C, "Cisco Systems"},
	{0x00211D, "Dataline AB"},
	{0x00211E, "Motorola CHS"},
	{0x00211F, "SHINSUNG DELTATECH CO.,LTD."},
	{0x002120, "Sequel Technologies, LLC"},
	{0x002121, "VRmagic GmbH"},
	{0x002122, "Chip-pro Ltd."},
	{0x002123, "Aerosat Avionics"},
	{0x002124, "Optos Plc"},
	{0x002125, "KUK JE TONG SHIN Co.,LTD"},
	{0x002126, "Shenzhen Torch Equipment Co., Ltd."},
	{0x002127, "TP-LINK Technology Co., Ltd."},
	{0x002128, "Sun Microsystems Inc"},
	{0x002129, "Cisco-Linksys, LLC"},
	{0x00212A, "Audiovox Corporation"},
	{0x00212B, "MSA Auer"},
	{0x00212C, "SemIndia System Private Limited"},
	{0x00212D, "SCIMOLEX CORPORATION"},
	{0x00212E, "dresden-elektronik"},
	{0x00212F, "Phoebe Micro Inc."},
	{0x002130, "Keico Hightech Inc."},
	{0x002131, "Blynke Inc."},
	{0x002132, "Masterclock, Inc."},
	{0x002133, "Building B, Inc"},
	{0x002134, "Brandywine Communications"},
	{0x002135, "ALCATEL-LUCENT"},
	{0x002136, "Motorola Mobile Devices business (MDb)"},
	{0x002137, "Bay Controls, LLC"},
	{0x002138, "Cepheid"},
	{0x002139, "Escherlogic Inc."},
	{0x00213A, "Winchester Systems Inc."},
	{0x00213B, "Berkshire Products, Inc"},
	{0x00213C, "AliphCom"},
	{0x00213D, "Cermetek Microelectronics, Inc."},
	{0x00213E, "TomTom"},
	{0x00213F, "A-Team Technology Ltd."},
	{0x002140, "EN Technologies Inc."},
	{0x002141, "RADLIVE"},
	{0x002142, "Advanced Control Systems doo"},
	{0x002143, "Motorola CHS"},
	{0x002144, "SS Telecoms"},
	{0x002145, "Semptian Technologies Ltd."},
	{0x002146, "SCI Technology"},
	{0x002147, "Nintendo Co., Ltd."},
	{0x002148, "Kaco Solar Korea"},
	{0x002149, "China Daheng Group ,Inc."},
	{0x00214A, "Pixel Velocity, Inc"},
	{0x00214B, "Shenzhen HAMP Science & Technology Co.,Ltd"},
	{0x00214C, "SAMSUNG ELECTRONICS CO., LTD."},
	{0x00214D, "Guangzhou Skytone Transmission Technology Com. Ltd."},
	{0x00214E, "GS Yuasa Power Supply Ltd."},
	{0x00214F, "ALPS Electric Co., Ltd"},
	{0x002150, "EYEVIEW ELECTRONICS"},
	{0x002151, "Millinet Co., Ltd."},
	{0x002152, "General Satellite Trading Limited"},
	{0x002153, "SeaMicro Inc."},
	{0x002154, "D-TACQ Solutions Ltd"},
	{0x002155, "Cisco Systems"},
	{0x002156, "Cisco Systems"},
	{0x002157, "National Datacast, Inc."},
	{0x002158, "Style Flying Technology Co."},
	{0x002159, "Juniper Networks"},
	{0x00215A, "Hewlett Packard"},
	{0x00215B, "Inotive"},
	{0x00215C, "Intel Corporate"},
	{0x00215D, "Intel Corporate"},
	{0x00215E, "IBM"},
	{0x00215F, "IHSE GmbH"},
	{0x002160, "Hidea Solutions Co. Ltd."},
	{0x002161, "Yournet Inc."},
	{0x002162, "Nortel"},
	{0x002163, "ASKEY COMPUTER CORP"},
	{0x002164, "Special Design Bureau for Seismic Instrumentation"},
	{0x002165, "Presstek Inc."},
	{0x002166, "NovAtel Inc."},
	{0x002167, "HWA JIN T&I Corp."},
	{0x002168, "iVeia, LLC"},
	{0x002169, "Prologix, LLC."},
	{0x00216A, "Intel Corporate"},
	{0x00216B, "Intel Corporate"},
	{0x00216C, "ODVA"},
	{0x00216D, "Soltech Co., Ltd."},
	{0x00216E, "Function ATI (Huizhou) Telecommunications Co., Ltd."},
	{0x00216F, "SymCom, Inc."},
	{0x002170, "Dell Inc"},
	{0x002171, "Wesung TNC Co., Ltd."},
	{0x002172, "Seoultek Valley"},
	{0x002173, "Ion Torrent Systems, Inc."},
	{0x002174, "AvaLAN Wireless"},
	{0x002175, "Pacific Satellite International Ltd."},
	{0x002176, "YMax Telecom Ltd."},
	{0x002177, "W. L. Gore & Associates"},
	{0x002178, "Matuschek Messtechnik GmbH"},
	{0x002179, "IOGEAR, Inc."},
	{0x00217A, "Sejin Electron, Inc."},
	{0x00217B, "Bastec AB"},
	{0x00217C, "2Wire"},
	{0x00217D, "PYXIS S.R.L."},
	{0x00217E, "Telit Communication s.p.a"},
	{0x00217F, "Intraco Technology Pte Ltd"},
	{0x002180, "Motorola CHS"},
	{0x002181, "Si2 Microsystems Limited"},
	{0x002182, "SandLinks Systems, Ltd."},
	{0x002183, "VATECH HYDRO"},
	{0x002184, "POWERSOFT SRL"},
	{0x002185, "MICRO-STAR INT'L CO.,LTD."},
	{0x002186, "USI"},
	{0x002187, "Imacs GmbH"},
	{0x002188, "Data Domain, Inc."},
	{0x002189, "AppTech, Inc."},
	{0x00218A, "Electronic Design and Manufacturing Company"},
	{0x00218B, "Wescon Technology, Inc."},
	{0x00218C, "TopControl GMBH"},
	{0x00218D, "AP Router Ind. Eletronica LTDA"},
	{0x00218E, "MEKICS CO., LTD."},
	{0x00218F, "Avantgarde Acoustic Lautsprechersysteme GmbH"},
	{0x002190, "Goliath Solutions"},
	{0x002191, "D-Link Corporation"},
	{0x002192, "Baoding Galaxy Electronic Technology  Co.,Ltd"},
	{0x002193, "Videofon MV"},
	{0x002194, "Ping Communication"},
	{0x002195, "GWD Media Limited"},
	{0x002196, "Telsey  S.p.A."},
	{0x002197, "ELITEGROUP COMPUTER SYSTEM"},
	{0x002198, "Thai Radio Co, LTD"},
	{0x002199, "Vacon Plc"},
	{0x00219A, "Cambridge Visual Networks Ltd"},
	{0x00219B, "Dell Inc"},
	{0x00219C, "Honeywld Technology Corp."},
	{0x00219D, "Adesys BV"},
	{0x00219E, "Sony Ericsson Mobile Communications"},
	{0x00219F, "SATEL OY"},
	{0x0021A0, "Cisco Systems"},
	{0x0021A1, "Cisco Systems"},
	{0x0021A2, "EKE-Electronics Ltd."},
	{0x0021A3, "Micromint"},
	{0x0021A4, "Dbii Networks"},
	{0x0021A5, "ERLPhase Power Technologies Ltd."},
	{0x0021A6, "Videotec Spa"},
	{0x0021A7, "Hantle System Co., Ltd."},
	{0x0021A8, "Telephonics Corporation"},
	{0x0021A9, "Mobilink Telecom Co.,Ltd"},
	{0x0021AA, "Nokia Danmark A/S"},
	{0x0021AB, "Nokia Danmark A/S"},
	{0x0021AC, "Infrared Integrated Systems Ltd"},
	{0x0021AD, "Nordic ID Oy"},
	{0x0021AE, "ALCATEL-LUCENT FRANCE - WTD"},
	{0x0021AF, "Radio Frequency Systems"},
	{0x0021B0, "Tyco Telecommunications"},
	{0x0021B1, "DIGITAL SOLUTIONS LTD"},
	{0x0021B2, "Fiberblaze A/S"},
	{0x0021B3, "Ross Controls"},
	{0x0021B4, "APRO MEDIA CO., LTD"},
	{0x0021B5, "Vyro Games Limited"},
	{0x0021B6, "Triacta Power Technologies Inc."},
	{0x0021B7, "Lexmark International Inc."},
	{0x0021B8, "Inphi Corporation"},
	{0x0021B9, "Universal Devices Inc."},
	{0x0021BA, "Texas Instruments"},
	{0x0021BB, "Riken Keiki Co., Ltd."},
	{0x0021BC, "ZALA COMPUTER"},
	{0x0021BD, "Nintendo Co., Ltd."},
	{0x0021BE, "Cisco, Service Provider Video Technology Group"},
	{0x0021BF, "Hitachi High-Tech Control Systems Corporation"},
	{0x0021C0, "Mobile Appliance, Inc."},
	{0x0021C1, "ABB Oy / Distribution Automation"},
	{0x0021C2, "GL Communications Inc"},
	{0x0021C3, "CORNELL Communications, Inc."},
	{0x0021C4, "Consilium AB"},
	{0x0021C5, "3DSP Corp"},
	{0x0021C6, "CSJ Global, Inc."},
	{0x0021C7, "Russound"},
	{0x0021C8, "LOHUIS Networks"},
	{0x0021C9, "Wavecom Asia Pacific Limited"},
	{0x0021CA, "ART System Co., Ltd."},
	{0x0021CB, "SMS TECNOLOGIA ELETRONICA LTDA"},
	{0x0021CC, "Flextronics International"},
	{0x0021CD, "LiveTV"},
	{0x0021CE, "NTC-Metrotek"},
	{0x0021CF, "The Crypto Group"},
	{0x0021D0, "Global Display Solutions Spa"},
	{0x0021D1, "Samsung Electronics Co.,Ltd"},
	{0x0021D2, "Samsung Electronics Co.,Ltd"},
	{0x0021D3, "BOCOM SECURITY(ASIA PACIFIC) LIMITED"},
	{0x0021D4, "Vollmer Werke GmbH"},
	{0x0021D5, "X2E GmbH"},
	{0x0021D6, "LXI Consortium"},
	{0x0021D7, "Cisco Systems"},
	{0x0021D8, "Cisco Systems"},
	{0x0021D9, "SEKONIC CORPORATION"},
	{0x0021DA, "Automation Products Group Inc."},
	{0x0021DB, "Santachi Video Technology (Shenzhen) Co., Ltd."},
	{0x0021DC, "TECNOALARM S.r.l."},
	{0x0021DD, "Northstar Systems Corp"},
	{0x0021DE, "Firepro Wireless"},
	{0x0021DF, "Martin Christ GmbH"},
	{0x0021E0, "CommAgility Ltd"},
	{0x0021E1, "Nortel Networks"},
	{0x0021E2, "Creative Electronic GmbH"},
	{0x0021E3, "SerialTek LLC"},
	{0x0021E4, "I-WIN"},
	{0x0021E5, "Display Solution AG"},
	{0x0021E6, "Starlight Video Limited"},
	{0x0021E7, "Informatics Services Corporation"},
	{0x0021E8, "Murata Manufacturing Co., Ltd."},
	{0x0021E9, "Apple, Inc"},
	{0x0021EA, "Bystronic Laser AG"},
	{0x0021EB, "ESP SYSTEMS, LLC"},
	{0x0021EC, "Solutronic GmbH"},
	{0x0021ED, "Telegesis"},
	{0x0021EE, "Full Spectrum Inc."},
	{0x0021EF, "Kapsys"},
	{0x0021F0, "EW3 Technologies LLC"},
	{0x0021F1, "Tutus Data AB"},
	{0x0021F2, "EASY3CALL Technology Limited"},
	{0x0021F3, "Si14 SpA"},
	{0x0021F4, "INRange Systems, Inc"},
	{0x0021F5, "Western Engravers Supply, Inc."},
	{0x0021F6, "Virtual Iron Software"},
	{0x0021F7, "ProCurve Networking by HP"},
	{0x0021F8, "Enseo, Inc."},
	{0x0021F9, "WIRECOM Technologies"},
	{0x0021FA, "A4SP Technologies Ltd."},
	{0x0021FB, "LG Electronics"},
	{0x0021FC, "Nokia Danmark A/S"},
	{0x0021FD, "DSTA S.L."},
	{0x0021FE, "Nokia Danmark A/S"},
	{0x0021FF, "Cyfrowy Polsat SA"},
	{0x002200, "BLADE Network Technology"},
	{0x002201, "Aksys Networks Inc"},
	{0x002202, "Excito Elektronik i Skne AB"},
	{0x002203, "Glensound Electronics Ltd"},
	{0x002204, "KORATEK"},
	{0x002205, "WeLink Solutions, Inc."},
	{0x002206, "Cyberdyne Inc."},
	{0x002207, "Inteno Broadband Technology AB"},
	{0x002208, "Certicom Corp"},
	{0x002209, "Omron Healthcare Co., Ltd"},
	{0x00220A, "Rearden Labs"},
	{0x00220B, "National Source Coding Center"},
	{0x00220C, "Cisco Systems"},
	{0x00220D, "Cisco Systems"},
	{0x00220E, "Indigo Security Co., Ltd."},
	{0x00220F, "MoCA (Multimedia over Coax Alliance)"},
	{0x002210, "Motorola CHS"},
	{0x002211, "Rohati Systems"},
	{0x002212, "CAI Networks, Inc."},
	{0x002213, "PCI CORPORATION"},
	{0x002214, "RINNAI KOREA"},
	{0x002215, "ASUSTek COMPUTER INC."},
	{0x002216, "SHIBAURA VENDING MACHINE CORPORATION"},
	{0x002217, "Neat Electronics"},
	{0x002218, "Verivue Inc."},
	{0x002219, "Dell Inc"},
	{0x00221A, "Audio Precision"},
	{0x00221B, "Morega Systems"},
	{0x00221D, "Freegene Technology LTD"},
	{0x00221E, "Media Devices Co., Ltd."},
	{0x00221F, "eSang Technologies Co., Ltd."},
	{0x002220, "Mitac Technology Corp"},
	{0x002221, "ITOH DENKI CO,LTD."},
	{0x002222, "Betec Engineering GmbH"},
	{0x002223, "TimeKeeping Systems, Inc."},
	{0x002224, "Good Will Instrument Co., Ltd."},
	{0x002225, "Thales Avionics Ltd"},
	{0x002226, "Avaak, Inc."},
	{0x002227, "uv-electronic GmbH"},
	{0x002228, "Breeze Innovations Ltd."},
	{0x002229, "Compumedics Ltd"},
	{0x00222A, "SoundEar A/S"},
	{0x00222B, "Nucomm, Inc."},
	{0x00222C, "Ceton Corp"},
	{0x00222D, "SMC Networks Inc."},
	{0x00222E, "maintech GmbH"},
	{0x00222F, "Open Grid Computing, Inc."},
	{0x002230, "FutureLogic Inc."},
	{0x002231, "SMT&C Co., Ltd."},
	{0x002232, "Design Design Technology Ltd"},
	{0x002233, "Pirelli Broadband Solutions"},
	{0x002234, "Corventis Inc."},
	{0x002235, "Strukton Systems bv"},
	{0x002236, "VECTOR SP. Z O.O."},
	{0x002237, "Shinhint Group"},
	{0x002238, "LOGIPLUS"},
	{0x002239, "Indiana Life Sciences Incorporated"},
	{0x00223A, "Scientific Atlanta, Cisco SPVT Group"},
	{0x00223B, "Communication Networks, LLC"},
	{0x00223C, "RATIO Entwicklungen GmbH"},
	{0x00223D, "JumpGen Systems, LLC"},
	{0x00223E, "IRTrans GmbH"},
	{0x00223F, "Netgear Inc."},
	{0x002240, "Universal Telecom S/A"},
	{0x002241, "Apple, Inc"},
	{0x002242, "Alacron Inc."},
	{0x002243, "AzureWave Technologies, Inc."},
	{0x002244, "Chengdu Linkon Communications Device Co., Ltd"},
	{0x002245, "Leine & Linde AB"},
	{0x002246, "Evoc Intelligent Technology Co.,Ltd."},
	{0x002247, "DAC ENGINEERING CO., LTD."},
	{0x002248, "Microsoft Corporation"},
	{0x002249, "HOME MULTIENERGY SL"},
	{0x00224A, "RAYLASE AG"},
	{0x00224B, "AIRTECH TECHNOLOGIES, INC."},
	{0x00224C, "Nintendo Co., Ltd."},
	{0x00224D, "MITAC INTERNATIONAL CORP."},
	{0x00224E, "SEEnergy Corp."},
	{0x00224F, "Byzoro Networks Ltd."},
	{0x002250, "Point Six Wireless, LLC"},
	{0x002251, "Lumasense Technologies"},
	{0x002252, "ZOLL Lifecor Corporation"},
	{0x002253, "Entorian Technologies"},
	{0x002254, "Bigelow Aerospace"},
	{0x002255, "Cisco Systems"},
	{0x002256, "Cisco Systems"},
	{0x002257, "3Com Europe Ltd"},
	{0x002258, "Taiyo Yuden Co., Ltd."},
	{0x002259, "Guangzhou New Postcom Equipment Co.,Ltd."},
	{0x00225A, "Garde Security AB"},
	{0x00225B, "Teradici Corporation"},
	{0x00225C, "Multimedia & Communication Technology"},
	{0x00225D, "Digicable Network India Pvt. Ltd."},
	{0x00225E, "Uwin Technologies Co.,LTD"},
	{0x00225F, "Liteon Technology Corporation"},
	{0x002260, "AFREEY Inc."},
	{0x002261, "Frontier Silicon Ltd"},
	{0x002262, "BEP Marine"},
	{0x002263, "Koos Technical Services, Inc."},
	{0x002264, "Hewlett Packard"},
	{0x002265, "Nokia Danmark A/S"},
	{0x002266, "Nokia Danmark A/S"},
	{0x002267, "Nortel Networks"},
	{0x002268, "Hon Hai Precision Ind. Co., Ltd."},
	{0x002269, "Hon Hai Precision Ind. Co., Ltd."},
	{0x00226A, "Honeywell"},
	{0x00226B, "Cisco-Linksys, LLC"},
	{0x00226C, "LinkSprite Technologies, Inc."},
	{0x00226D, "Shenzhen GIEC Electronics Co., Ltd."},
	{0x00226E, "Gowell Electronic Limited"},
	{0x00226F, "3onedata Technology Co. Ltd."},
	{0x002270, "ABK North America, LLC"},
	{0x002271, "Jger Computergesteuerte Messtechnik GmbH"},
	{0x002272, "American Micro-Fuel Device Corp."},
	{0x002273, "Techway"},
	{0x002274, "FamilyPhone AB"},
	{0x002275, "Belkin International, Inc."},
	{0x002276, "Triple EYE B.V."},
	{0x002277, "NEC Australia Pty Ltd"},
	{0x002278, "Shenzhen  Tongfang Multimedia  Technology Co.,Ltd."},
	{0x002279, "Nippon Conlux Co., Ltd."},
	{0x00227A, "Telecom Design"},
	{0x00227B, "Apogee Labs, Inc."},
	{0x00227C, "Woori SMT Co.,ltd"},
	{0x00227D, "YE DATA INC."},
	{0x00227E, "Chengdu 30Kaitian Communication Industry Co.Ltd"},
	{0x00227F, "Ruckus Wireless"},
	{0x002280, "A2B Electronics AB"},
	{0x002281, "Daintree Networks Inc"},
	{0x002282, "8086 Limited"},
	{0x002283, "Juniper Networks"},
	{0x002284, "DESAY A&V SCIENCE AND TECHNOLOGY CO.,LTD"},
	{0x002285, "NOMUS COMM SYSTEMS"},
	{0x002286, "ASTRON"},
	{0x002287, "Titan Wireless LLC"},
	{0x002288, "Sagrad, Inc."},
	{0x002289, "Optosecurity Inc."},
	{0x00228A, "Teratronik elektronische systeme gmbh"},
	{0x00228B, "Kensington Computer Products Group"},
	{0x00228C, "Photon Europe GmbH"},
	{0x00228D, "GBS Laboratories LLC"},
	{0x00228E, "TV-NUMERIC"},
	{0x00228F, "CNRS"},
	{0x002290, "Cisco Systems"},
	{0x002291, "Cisco Systems"},
	{0x002292, "Cinetal"},
	{0x002293, "ZTE Corporation"},
	{0x002294, "Kyocera Corporation"},
	{0x002295, "SGM Technology for lighting spa"},
	{0x002296, "LinoWave Corporation"},
	{0x002297, "XMOS Semiconductor"},
	{0x002298, "Sony Ericsson Mobile Communications"},
	{0x002299, "SeaMicro Inc."},
	{0x00229A, "Lastar, Inc."},
	{0x00229B, "AverLogic Technologies, Inc."},
	{0x00229C, "Verismo Networks Inc"},
	{0x00229D, "PYUNG-HWA IND.CO.,LTD"},
	{0x00229E, "Social Aid Research Co., Ltd."},
	{0x00229F, "Sensys Traffic AB"},
	{0x0022A0, "Delphi Corporation"},
	{0x0022A1, "Huawei Symantec Technologies Co.,Ltd."},
	{0x0022A2, "Xtramus Technologies"},
	{0x0022A3, "California Eastern Laboratories"},
	{0x0022A4, "2Wire"},
	{0x0022A5, "Texas Instruments"},
	{0x0022A6, "Sony Computer Entertainment America"},
	{0x0022A7, "Tyco Electronics AMP GmbH"},
	{0x0022A8, "Ouman Finland Oy"},
	{0x0022A9, "LG Electronics Inc"},
	{0x0022AA, "Nintendo Co., Ltd."},
	{0x0022AB, "Shenzhen Turbosight Technology Ltd"},
	{0x0022AC, "Hangzhou Siyuan Tech. Co., Ltd"},
	{0x0022AD, "TELESIS TECHNOLOGIES, INC."},
	{0x0022AE, "Mattel Inc."},
	{0x0022AF, "Safety Vision"},
	{0x0022B0, "D-Link Corporation"},
	{0x0022B1, "Elbit Systems"},
	{0x0022B2, "4RF Communications Ltd"},
	{0x0022B3, "Sei S.p.A."},
	{0x0022B4, "Motorola Mobile Devices"},
	{0x0022B5, "NOVITA"},
	{0x0022B6, "Superflow Technologies Group"},
	{0x0022B7, "GSS Grundig SAT-Systems GmbH"},
	{0x0022B8, "Norcott"},
	{0x0022B9, "Analogix Seminconductor, Inc"},
	{0x0022BA, "HUTH Elektronik Systeme GmbH"},
	{0x0022BB, "beyerdynamic GmbH & Co. KG"},
	{0x0022BC, "JDSU France SAS"},
	{0x0022BD, "Cisco Systems"},
	{0x0022BE, "Cisco Systems"},
	{0x0022BF, "SieAmp Group of Companies"},
	{0x0022C0, "Shenzhen Forcelink Electronic Co, Ltd"},
	{0x0022C1, "Active Storage Inc."},
	{0x0022C2, "Proview Eletronica do Brasil LTDA"},
	{0x0022C3, "Zeeport Technology Inc."},
	{0x0022C4, "epro GmbH"},
	{0x0022C5, "INFORSON Co,Ltd."},
	{0x0022C6, "Sutus Inc"},
	{0x0022C7, "SEGGER Microcontroller GmbH & Co. KG"},
	{0x0022C8, "Applied Instruments"},
	{0x0022C9, "Lenord, Bauer & Co GmbH"},
	{0x0022CA, "Anviz Biometric Tech. Co., Ltd."},
	{0x0022CB, "IONODES Inc."},
	{0x0022CC, "SciLog, Inc."},
	{0x0022CD, "Ared Technology Co., Ltd."},
	{0x0022CE, "Cisco, Service Provider Video Technology Group"},
	{0x0022CF, "PLANEX Communications INC"},
	{0x0022D0, "Polar Electro Oy"},
	{0x0022D1, "Albrecht Jung GmbH & Co. KG"},
	{0x0022D2, "All Earth Comrcio de Eletrnicos LTDA."},
	{0x0022D3, "Hub-Tech"},
	{0x0022D4, "ComWorth Co., Ltd."},
	{0x0022D5,
	 "Eaton Corp. Electrical Group Data Center Solutions - Pulizzi"},
	{0x0022D6, "Cypak AB"},
	{0x0022D7, "Nintendo Co., Ltd."},
	{0x0022D8, "Shenzhen GST Security and Safety Technology Limited"},
	{0x0022D9, "Fortex Industrial Ltd."},
	{0x0022DA, "ANATEK, LLC"},
	{0x0022DB, "Translogic Corporation"},
	{0x0022DC, "Vigil Health Solutions Inc."},
	{0x0022DD, "Protecta Electronics Ltd"},
	{0x0022DE, "OPPO Digital, Inc."},
	{0x0022DF, "TAMUZ Monitors"},
	{0x0022E0, "Atlantic Software Technologies S.r.L."},
	{0x0022E1, "ZORT Labs, LLC."},
	{0x0022E2, "WABTEC Transit Division"},
	{0x0022E3, "Amerigon"},
	{0x0022E4, "APASS TECHNOLOGY CO., LTD."},
	{0x0022E5, "Fisher-Rosemount Systems Inc."},
	{0x0022E6, "Intelligent Data"},
	{0x0022E7, "WPS Parking Systems"},
	{0x0022E8, "Applition Co., Ltd."},
	{0x0022E9, "ProVision Communications"},
	{0x0022EA, "Rustelcom Inc."},
	{0x0022EB, "Data Respons A/S"},
	{0x0022EC, "IDEALBT TECHNOLOGY CORPORATION"},
	{0x0022ED, "TSI Power Corporation"},
	{0x0022EE, "Algo Communication Products Ltd"},
	{0x0022EF, "Ibis Tek, LLC"},
	{0x0022F0, "3 Greens Aviation Limited"},
	{0x0022F2, "SunPower Corp"},
	{0x0022F3, "SHARP CORPORATION"},
	{0x0022F4, "AMPAK Technology, Inc."},
	{0x0022F5, "Advanced Realtime Tracking GmbH"},
	{0x0022F6, "Syracuse Research Corporation"},
	{0x0022F7, "Conceptronic"},
	{0x0022F8, "PIMA Electronic Systems Ltd."},
	{0x0022F9, "Pollin Electronic GmbH"},
	{0x0022FA, "Intel Corporate"},
	{0x0022FB, "Intel Corporate"},
	{0x0022FC, "Nokia Danmark A/S"},
	{0x0022FD, "Nokia Danmark A/S"},
	{0x0022FE, "Microprocessor Designs Inc"},
	{0x0022FF, "NIVIS LLC"},
	{0x002300, "Cayee Computer Ltd."},
	{0x002301, "Witron Technology Limited"},
	{0x002302, "Cobalt Digital, Inc."},
	{0x002303, "LITE-ON IT Corporation"},
	{0x002304, "Cisco Systems"},
	{0x002305, "Cisco Systems"},
	{0x002306, "ALPS Electric Co., Ltd"},
	{0x002307, "FUTURE INNOVATION TECH CO.,LTD"},
	{0x002308, "Arcadyan Technology Corporation"},
	{0x002309, "Janam Technologies LLC"},
	{0x00230A, "ARBURG GmbH & Co KG"},
	{0x00230B, "Motorola CHS"},
	{0x00230C, "CLOVER ELECTRONICS CO.,LTD."},
	{0x00230D, "Nortel Networks"},
	{0x00230E, "Gorba AG"},
	{0x00230F, "Hirsch Electronics Corporation"},
	{0x002310, "LNC Technology Co., Ltd."},
	{0x002311, "Gloscom Co., Ltd."},
	{0x002312, "Apple, Inc"},
	{0x002313, "Qool Technologies Ltd."},
	{0x002314, "Intel Corporate"},
	{0x002315, "Intel Corporate"},
	{0x002316, "KISAN ELECTRONICS CO"},
	{0x002317, "Lasercraft Inc"},
	{0x002318, "Toshiba"},
	{0x002319, "Sielox LLC"},
	{0x00231A, "ITF Co., Ltd."},
	{0x00231B, "Danaher Motion - Kollmorgen"},
	{0x00231C, "Fourier Systems Ltd."},
	{0x00231D, "Deltacom Electronics Ltd"},
	{0x00231E, "Cezzer Multimedia Technologies"},
	{0x00231F,
	 "Guangda Electronic & Telecommunication Technology Development Co., Ltd."},
	{0x002320, "Nicira Network"},
	{0x002321, "Avitech International Corp"},
	{0x002322, "KISS Teknical Solutions, Inc."},
	{0x002323, "Zylin AS"},
	{0x002324, "G-PRO COMPUTER"},
	{0x002325, "IOLAN Holding"},
	{0x002326, "Fujitsu Limited"},
	{0x002327, "Shouyo Electronics CO., LTD"},
	{0x002328, "ALCON TELECOMMUNICATIONS CO., LTD."},
	{0x002329, "DDRdrive LLC"},
	{0x00232A, "eonas IT-Beratung und -Entwicklung GmbH"},
	{0x00232B, "IRD A/S"},
	{0x00232C, "Senticare"},
	{0x00232D, "SandForce"},
	{0x00232E, "Kedah Electronics Engineering, LLC"},
	{0x00232F, "Advanced Card Systems Ltd."},
	{0x002330, "DIZIPIA, INC."},
	{0x002331, "Nintendo Co., Ltd."},
	{0x002332, "Apple, Inc"},
	{0x002333, "Cisco Systems"},
	{0x002334, "Cisco Systems"},
	{0x002335, "Linkflex Co.,Ltd"},
	{0x002336, "METEL s.r.o."},
	{0x002337, "Global Star Solutions ULC"},
	{0x002338, "OJ-Electronics A/S"},
	{0x002339, "Samsung Electronics"},
	{0x00233A, "Samsung Electronics Co.,Ltd"},
	{0x00233B, "C-Matic Systems Ltd"},
	{0x00233C, "Alflex"},
	{0x00233D, "novero GmbH"},
	{0x00233E, "Alcatel-Lucent-IPD"},
	{0x00233F, "Purechoice Inc"},
	{0x002340, "MiX Telematics"},
	{0x002341,
	 "Siemens Building Technologies Fire & Security Products GmbH & Co. oHG"},
	{0x002342, "Coffee Equipment Company"},
	{0x002343, "TEM AG"},
	{0x002344, "Objective Interface Systems"},
	{0x002345, "Sony Ericsson Mobile Communications"},
	{0x002346, "Vestac"},
	{0x002347, "ProCurve Networking by HP"},
	{0x002348, "SAGEM COMMUNICATION"},
	{0x002349, "Helmholtz Centre Berlin for Material and Energy"},
	{0x00234B, "Inyuan Technology Inc."},
	{0x00234C, "KTC AB"},
	{0x00234D, "Hon Hai Precision Ind. Co., Ltd."},
	{0x00234E, "Hon Hai Precision Ind. Co., Ltd."},
	{0x00234F, "Luminous Power Technologies Pvt. Ltd."},
	{0x002350, "LynTec"},
	{0x002351, "2Wire"},
	{0x002352, "DATASENSOR S.p.A."},
	{0x002353, "F E T Elettronica snc"},
	{0x002354, "ASUSTek COMPUTER INC."},
	{0x002355, "Kinco Automation(Shanghai) Ltd."},
	{0x002356, "Packet Forensics LLC"},
	{0x002357, "Pitronot Technologies and Engineering P.T.E. Ltd."},
	{0x002358, "SYSTEL SA"},
	{0x002359, "Benchmark Electronics ( Thailand ) Public Company Limited"},
	{0x00235A, "COMPAL INFORMATION (KUNSHAN) CO., Ltd."},
	{0x00235B, "Gulfstream"},
	{0x00235C, "Aprius, Inc."},
	{0x00235D, "Cisco Systems"},
	{0x00235E, "Cisco Systems"},
	{0x00235F, "Silicon Micro Sensors GmbH"},
	{0x002360, "Lookit Technology Co., Ltd"},
	{0x002361, "Unigen Corporation"},
	{0x002362, "Goldline Controls"},
	{0x002363, "Zhuhai RaySharp Technology Co., Ltd."},
	{0x002364, "Power Instruments Pte Ltd"},
	{0x002365, "ELKA-Elektronik GmbH"},
	{0x002366, "Beijing Siasun Electronic System Co.,Ltd."},
	{0x002367, "UniControls a.s."},
	{0x002368, "Motorola"},
	{0x002369, "Cisco-Linksys, LLC"},
	{0x00236A, "ClearAccess, Inc."},
	{0x00236B, "Xembedded, Inc."},
	{0x00236C, "Apple, Inc"},
	{0x00236D, "ResMed Ltd"},
	{0x00236E, "Burster GmbH & Co KG"},
	{0x00236F, "DAQ System"},
	{0x002370, "PRO-BEL LIMITED"},
	{0x002371, "SOAM Systel"},
	{0x002372, "MORE STAR INDUSTRIAL GROUP LIMITED"},
	{0x002373, "GridIron Systems, Inc."},
	{0x002374, "Motorola CHS"},
	{0x002375, "Motorola CHS"},
	{0x002376, "HTC Corporation"},
	{0x002377, "Isotek Electronics Ltd"},
	{0x002378, "GN Netcom A/S"},
	{0x002379, "Union Business Machines Co. Ltd."},
	{0x00237A, "RIM"},
	{0x00237B, "WHDI LLC"},
	{0x00237C, "NEOTION"},
	{0x00237D, "Hewlett Packard"},
	{0x00237E, "ELSTER GMBH"},
	{0x00237F, "PLANTRONICS"},
	{0x002380, "Nanoteq"},
	{0x002381, "Lengda Technology(Xiamen) Co.,Ltd."},
	{0x002382, "Lih Rong Electronic Enterprise Co., Ltd."},
	{0x002383, "InMage Systems Inc"},
	{0x002384, "GGH Engineering s.r.l."},
	{0x002385, "ANTIPODE"},
	{0x002386, "Tour & Andersson AB"},
	{0x002387, "ThinkFlood, Inc."},
	{0x002388, "V.T. Telematica S.p.a."},
	{0x002389, "HANGZHOU H3C Technologies Co., Ltd."},
	{0x00238A, "Ciena Corporation"},
	{0x00238B, "Quanta Computer Inc."},
	{0x00238D, "Techno Design Co., Ltd."},
	{0x00238E, "PIRELLI BROADBAND SOLUTIONS"},
	{0x00238F, "NIDEC COPAL CORPORATION"},
	{0x002390, "Algolware Corporation"},
	{0x002391, "Maxian"},
	{0x002392, "Proteus Industries Inc."},
	{0x002393, "AJINEXTEK"},
	{0x002394, "Samjeon"},
	{0x002395, "Motorola CHS"},
	{0x002396, "ANDES TECHNOLOGY CORPORATION"},
	{0x002397, "Westell Technologies Inc."},
	{0x002398, "Sky Control"},
	{0x002399, "VD Division, Samsung Electronics Co."},
	{0x00239A, "EasyData Software GmbH"},
	{0x00239B, "Elster Integrated Solutions"},
	{0x00239C, "Juniper Networks"},
	{0x00239D, "Mapower Electronics Co., Ltd"},
	{0x00239E, "Jiangsu Lemote Technology Corporation Limited"},
	{0x00239F, "Institut fr Prftechnik"},
	{0x0023A0, "Hana CNS Co., LTD."},
	{0x0023A1, "Trend Electronics Ltd"},
	{0x0023A2, "Motorola CHS"},
	{0x0023A3, "Motorola CHS"},
	{0x0023A4, "New Concepts Development Corp."},
	{0x0023A5, "SageTV, LLC"},
	{0x0023A6, "E-Mon"},
	{0x0023A7, "Redpine Signals, Inc."},
	{0x0023A8, "Marshall Electronics"},
	{0x0023A9, "Beijing Detianquan Electromechanical Equipment Co., Ltd"},
	{0x0023AA, "HFR, Inc."},
	{0x0023AB, "Cisco Systems"},
	{0x0023AC, "Cisco Systems"},
	{0x0023AD, "Xmark Corporation"},
	{0x0023AE, "Dell Inc."},
	{0x0023AF, "Motorola Mobile Devices"},
	{0x0023B0, "COMXION Technology Inc."},
	{0x0023B1, "Longcheer Technology (Singapore) Pte Ltd"},
	{0x0023B2, "Intelligent Mechatronic Systems Inc"},
	{0x0023B3, "Lyyn AB"},
	{0x0023B4, "Nokia Danmark A/S"},
	{0x0023B5, "ORTANA LTD"},
	{0x0023B6, "SECURITE COMMUNICATIONS / HONEYWELL"},
	{0x0023B7, "Q-Light Co., Ltd."},
	{0x0023B8, "Sichuan Jiuzhou Electronic Technology Co.,Ltd"},
	{0x0023B9, "EADS Deutschland GmbH"},
	{0x0023BA, "Chroma"},
	{0x0023BB, "Schmitt Industries"},
	{0x0023BC, "EQ-SYS GmbH"},
	{0x0023BD, "Digital Ally, Inc."},
	{0x0023BE, "Cisco SPVTG"},
	{0x0023BF, "Mainpine, Inc."},
	{0x0023C0, "Broadway Networks"},
	{0x0023C1, "Securitas Direct AB"},
	{0x0023C2, "SAMSUNG Electronics. Co. LTD"},
	{0x0023C3, "LogMeIn, Inc."},
	{0x0023C4, "Lux Lumen"},
	{0x0023C5, "Radiation Safety and Control Services Inc"},
	{0x0023C6, "SMC Corporation"},
	{0x0023C7, "AVSystem"},
	{0x0023C8, "TEAM-R"},
	{0x0023C9,
	 "Sichuan Tianyi Information Science & Technology Stock CO.,LTD"},
	{0x0023CA, "Behind The Set, LLC"},
	{0x0023CB, "Shenzhen Full-join Technology Co.,Ltd"},
	{0x0023CC, "Nintendo Co., Ltd."},
	{0x0023CD, "TP-LINK TECHNOLOGIES CO., LTD."},
	{0x0023CE, "KITA DENSHI CORPORATION"},
	{0x0023CF, "CUMMINS-ALLISON CORP."},
	{0x0023D0, "Uniloc USA Inc."},
	{0x0023D1, "TRG"},
	{0x0023D2, "Inhand Electronics, Inc."},
	{0x0023D3, "AirLink WiFi Networking Corp."},
	{0x0023D4, "Texas Instruments"},
	{0x0023D5, "WAREMA electronic GmbH"},
	{0x0023D6, "Samsung Electronics Co.,LTD"},
	{0x0023D7, "Samsung Electronics"},
	{0x0023D8, "Ball-It Oy"},
	{0x0023D9, "Banner Engineering"},
	{0x0023DA, "Industrial Computer Source (Deutschland)GmbH"},
	{0x0023DB, "saxnet gmbh"},
	{0x0023DC, "Benein, Inc"},
	{0x0023DD, "ELGIN S.A."},
	{0x0023DE, "Ansync Inc."},
	{0x0023DF, "Apple, Inc"},
	{0x0023E0, "INO Therapeutics LLC"},
	{0x0023E1, "Cavena Image Products AB"},
	{0x0023E2, "SEA Signalisation"},
	{0x0023E3, "Microtronic AG"},
	{0x0023E4, "IPnect co. ltd."},
	{0x0023E5, "IPaXiom Networks"},
	{0x0023E6, "Pirkus, Inc."},
	{0x0023E7, "Hinke A/S"},
	{0x0023E8, "Demco Corp."},
	{0x0023E9, "F5 Networks, Inc."},
	{0x0023EA, "Cisco Systems"},
	{0x0023EB, "Cisco Systems"},
	{0x0023EC, "Algorithmix GmbH"},
	{0x0023ED, "Motorola CHS"},
	{0x0023EE, "Motorola CHS"},
	{0x0023EF, "Zuend Systemtechnik AG"},
	{0x0023F0, "Shanghai Jinghan Weighing Apparatus Co. Ltd."},
	{0x0023F1, "Sony Ericsson Mobile Communications"},
	{0x0023F2, "TVLogic"},
	{0x0023F3, "Glocom, Inc."},
	{0x0023F4, "Masternaut"},
	{0x0023F5, "WILO SE"},
	{0x0023F6, "Softwell Technology Co., Ltd."},
	{0x0023F8, "ZyXEL Communications Corporation"},
	{0x0023F9, "Double-Take Software, INC."},
	{0x0023FA, "RG Nets, Inc."},
	{0x0023FB, "IP Datatel, Inc."},
	{0x0023FC, "Ultra Stereo Labs, Inc"},
	{0x0023FD, "AFT Atlas Fahrzeugtechnik GmbH"},
	{0x0023FE, "Biodevices, SA"},
	{0x0023FF, "Beijing HTTC Technology Ltd."},
	{0x002400, "Nortel Networks"},
	{0x002401, "D-Link Corporation"},
	{0x002402, "Op-Tection GmbH"},
	{0x002403, "Nokia Danmark A/S"},
	{0x002404, "Nokia Danmark A/S"},
	{0x002405, "Dilog Nordic AB"},
	{0x002406, "Pointmobile"},
	{0x002407, "TELEM SAS"},
	{0x002408, "Pacific Biosciences"},
	{0x002409, "The Toro Company"},
	{0x00240A, "US Beverage Net"},
	{0x00240B, "Virtual Computer Inc."},
	{0x00240C, "DELEC GmbH"},
	{0x00240D, "OnePath Networks LTD."},
	{0x00240E, "Inventec Besta Co., Ltd."},
	{0x00240F, "Ishii Tool & Engineering Corporation"},
	{0x002410, "NUETEQ Technology,Inc."},
	{0x002411, "PharmaSmart LLC"},
	{0x002412, "Benign Technologies Co, Ltd."},
	{0x002413, "Cisco Systems"},
	{0x002414, "Cisco Systems"},
	{0x002415, "Magnetic Autocontrol GmbH"},
	{0x002416, "Any Use"},
	{0x002417, "Thomson Telecom Belgium"},
	{0x002418, "Nextwave Semiconductor"},
	{0x00241A, "Red Beetle Inc."},
	{0x00241B, "iWOW Communications Pte Ltd"},
	{0x00241C, "FuGang Electronic (DG) Co.,Ltd"},
	{0x00241D, "GIGA-BYTE TECHNOLOGY CO.,LTD."},
	{0x00241E, "Nintendo Co., Ltd."},
	{0x00241F, "DCT-Delta GmbH"},
	{0x002420, "NetUP Inc."},
	{0x002421, "MICRO-STAR INT'L CO., LTD."},
	{0x002422, "Knapp Logistik Automation GmbH"},
	{0x002423, "AzureWave Technologies (Shanghai) Inc."},
	{0x002424, "Axis Network Technology"},
	{0x002425, "Shenzhenshi chuangzhicheng Technology Co.,Ltd"},
	{0x002426, "NOHMI BOSAI LTD."},
	{0x002427, "SSI COMPUTER CORP"},
	{0x002428, "EnergyICT"},
	{0x002429, "MK MASTER INC."},
	{0x00242A, "Hittite Microwave Corporation"},
	{0x00242B, "Hon Hai Precision Ind.Co.,Ltd."},
	{0x00242C, "Hon Hai Precision Ind. Co., Ltd."},
	{0x00242E, "Datastrip Inc."},
	{0x00242F, "VirtenSys Inc"},
	{0x002430, "Ruby Tech Corp."},
	{0x002431, "Uni-v co.,ltd"},
	{0x002432, "Neostar Technology Co.,LTD"},
	{0x002433, "Alps Electric Co., Ltd"},
	{0x002434, "Lectrosonics, Inc."},
	{0x002435, "WIDE CORPORATION"},
	{0x002436, "Apple, Inc"},
	{0x002437, "Motorola - BSG"},
	{0x002438, "Brocade Communications Systems, Inc"},
	{0x002439, "Essential Viewing Systems Limited"},
	{0x00243A, "Ludl Electronic Products"},
	{0x00243B, "CSSI (S) Pte Ltd"},
	{0x00243C, "S.A.A.A."},
	{0x00243D, "Emerson Appliance Motors and Controls"},
	{0x00243F, "Storwize, Inc."},
	{0x002440, "Halo Monitoring, Inc."},
	{0x002441, "Wanzl Metallwarenfabrik GmbH"},
	{0x002442, "Axona Limited"},
	{0x002443, "Nortel Networks"},
	{0x002444, "Nintendo Co., Ltd."},
	{0x002445, "LiquidxStream Systems Inc."},
	{0x002446, "MMB Research Inc."},
	{0x002447, "Kaztek Systems"},
	{0x002448, "SpiderCloud Wireless, Inc"},
	{0x002449, "Shen Zhen Lite Star Electronics Technology Co., Ltd"},
	{0x00244A, "Voyant International"},
	{0x00244B, "PERCEPTRON INC"},
	{0x00244C, "Solartron Metrology Ltd"},
	{0x00244D, "Hokkaido Electronics Corporation"},
	{0x00244E, "RadChips, Inc."},
	{0x00244F, "Asantron Technologies Ltd."},
	{0x002450, "Cisco Systems"},
	{0x002451, "Cisco Systems"},
	{0x002452, "Silicon Software GmbH"},
	{0x002453, "Initra d.o.o."},
	{0x002454, "Samsung Electronics Co., LTD"},
	{0x002455, "MuLogic BV"},
	{0x002456, "2Wire"},
	{0x002458, "PA Bastion CC"},
	{0x002459, "ABB STOTZ-KONTAKT GmbH"},
	{0x00245A, "Nanjing Panda Electronics Company Limited"},
	{0x00245B, "RAIDON TECHNOLOGY, INC."},
	{0x00245C, "Design-Com Technologies Pty. Ltd."},
	{0x00245D, "Terberg besturingstechniek B.V."},
	{0x00245E, "Hivision Co.,ltd"},
	{0x00245F, "Vine Telecom CO.,Ltd."},
	{0x002460, "Giaval Science Development Co. Ltd."},
	{0x002461, "Shin Wang Tech."},
	{0x002462, "Rayzone Corporation"},
	{0x002463, "Phybridge Inc"},
	{0x002464, "Bridge Technologies Co AS"},
	{0x002465, "Elentec"},
	{0x002466, "Unitron nv"},
	{0x002467, "AOC International (Europe) GmbH"},
	{0x002468, "Sumavision Technologies Co.,Ltd"},
	{0x002469, "Smart Doorphones"},
	{0x00246A, "Solid Year Co., Ltd."},
	{0x00246B, "Coventive"},
	{0x00246C, "ARUBA NETWORKS, INC."},
	{0x00246D, "Weinzierl Engineering GmbH"},
	{0x00246E, "Phihong USA Corp."},
	{0x00246F, "Onda Communication spa"},
	{0x002470, "AUROTECH ultrasound AS."},
	{0x002471, "Fusion MultiSystems dba Fusion-io"},
	{0x002472, "ReDriven Power Inc."},
	{0x002473, "3Com Europe Ltd"},
	{0x002474, "Autronica Fire And Securirty"},
	{0x002475, "Compass System(Embedded Dept.)"},
	{0x002476, "TAP.tv"},
	{0x002477, "Tibbo Technology"},
	{0x002478, "Mag Tech Electronics Co Limited"},
	{0x002479, "Optec Displays, Inc."},
	{0x00247A, "FU YI CHENG Technology Co., Ltd."},
	{0x00247B, "Actiontec Electronics, Inc"},
	{0x00247C, "Nokia Danmark A/S"},
	{0x00247D, "Nokia Danmark A/S"},
	{0x00247E, "USI"},
	{0x00247F, "Nortel Networks"},
	{0x002480, "Meteocontrol GmbH"},
	{0x002481, "Hewlett Packard"},
	{0x002482, "Ruckus Wireless"},
	{0x002483, "LG Electronics"},
	{0x002484, "Bang and Olufsen Medicom a/s"},
	{0x002485, "ConteXtream Ltd"},
	{0x002486, "DesignArt Networks"},
	{0x002487, "Blackboard Inc."},
	{0x002488, "Centre For Development Of Telematics"},
	{0x002489, "Vodafone Omnitel N.V."},
	{0x00248A, "Kaga Electronics Co., Ltd."},
	{0x00248B, "HYBUS CO., LTD."},
	{0x00248C, "ASUSTek COMPUTER INC."},
	{0x00248D, "Sony Computer Entertainment Inc."},
	{0x00248E, "Infoware ZRt."},
	{0x00248F, "DO-MONIX"},
	{0x002490, "Samsung Electronics Co.,LTD"},
	{0x002491, "Samsung Electronics"},
	{0x002492, "Motorola, Broadband Solutions Group"},
	{0x002493, "Motorola, Inc"},
	{0x002494, "Shenzhen Baoxin Tech CO., Ltd."},
	{0x002495, "Motorola Mobile Devices"},
	{0x002496, "Ginzinger electronic systems"},
	{0x002497, "Cisco Systems"},
	{0x002498, "Cisco Systems"},
	{0x002499, "Aquila Technologies"},
	{0x00249A, "Beijing Zhongchuang Telecommunication Test Co., Ltd."},
	{0x00249B, "Action Star Enterprise Co., Ltd."},
	{0x00249C, "Bimeng Comunication System Co. Ltd"},
	{0x00249D, "NES Technology Inc."},
	{0x00249E, "ADC-Elektronik GmbH"},
	{0x00249F, "RIM Testing Services"},
	{0x0024A0, "Motorola CHS"},
	{0x0024A1, "Motorola CHS"},
	{0x0024A2, "Hong Kong Middleware Technology Limited"},
	{0x0024A3, "Sonim Technologies Inc"},
	{0x0024A4, "Siklu Communication"},
	{0x0024A5, "Buffalo Inc."},
	{0x0024A6, "TELESTAR DIGITAL GmbH"},
	{0x0024A7, "Advanced Video Communications Inc."},
	{0x0024A8, "ProCurve Networking by HP"},
	{0x0024A9, "Ag Leader Technology"},
	{0x0024AA, "Dycor Technologies Ltd."},
	{0x0024AB, "A7 Engineering, Inc."},
	{0x0024AC, "Hangzhou DPtech Technologies Co., Ltd."},
	{0x0024AD, "Adolf Thies Gmbh & Co. KG"},
	{0x0024AE, "SAGEM SECURITE"},
	{0x0024AF, "EchoStar Technologies"},
	{0x0024B0, "ESAB AB"},
	{0x0024B1, "Coulomb Technologies"},
	{0x0024B2, "Netgear"},
	{0x0024B3, "Graf-Syteco GmbH & Co. KG"},
	{0x0024B4, "ESCATRONIC GmbH"},
	{0x0024B5, "Nortel Networks"},
	{0x0024B6, "Seagate Technology"},
	{0x0024B7, "GridPoint, Inc."},
	{0x0024B8, "free alliance sdn bhd"},
	{0x0024B9, "Wuhan Higheasy Electronic Technology Development Co.Ltd"},
	{0x0024BA, "Texas Instruments"},
	{0x0024BB, "CENTRAL Corporation"},
	{0x0024BC, "HuRob Co.,Ltd"},
	{0x0024BD, "Hainzl Industriesysteme GmbH"},
	{0x0024BE, "Sony Corporation"},
	{0x0024BF, "CIAT"},
	{0x0024C0, "NTI COMODO INC"},
	{0x0024C1, "Hangzhou Motorola Technologies LTD."},
	{0x0024C2, "Asumo Co.,Ltd."},
	{0x0024C3, "Cisco Systems"},
	{0x0024C4, "Cisco Systems"},
	{0x0024C5, "Meridian Audio Limited"},
	{0x0024C6, "Hager Electro SAS"},
	{0x0024C7, "Mobilarm Ltd"},
	{0x0024C8, "Broadband Solutions Group"},
	{0x0024C9, "Broadband Solutions Group"},
	{0x0024CA, "Tobii Technology AB"},
	{0x0024CB, "Autonet Mobile"},
	{0x0024CC, "Fascinations Toys and Gifts, Inc."},
	{0x0024CD, "Willow Garage, Inc."},
	{0x0024CE, "Exeltech Inc"},
	{0x0024CF, "Inscape Data Corporation"},
	{0x0024D0, "Shenzhen SOGOOD Industry CO.,LTD."},
	{0x0024D1, "Thomson Inc."},
	{0x0024D2, "Askey Computer"},
	{0x0024D3, "QUALICA Inc."},
	{0x0024D4, "FREEBOX SA"},
	{0x0024D5, "Winward Industrial Limited"},
	{0x0024D6, "Intel Corporate"},
	{0x0024D7, "Intel Corporate"},
	{0x0024D8, "IlSung Precision"},
	{0x0024D9, "BICOM, Inc."},
	{0x0024DA, "Innovar Systems Limited"},
	{0x0024DB, "Alcohol Monitoring Systems"},
	{0x0024DC, "Juniper Networks"},
	{0x0024DD, "Centrak, Inc."},
	{0x0024DE, "GLOBAL Technology Inc."},
	{0x0024DF, "Digitalbox Europe GmbH"},
	{0x0024E0, "DS Tech, LLC"},
	{0x0024E1, "Convey Computer Corp."},
	{0x0024E2, "HASEGAWA ELECTRIC CO.,LTD."},
	{0x0024E3, "CAO Group"},
	{0x0024E4, "Withings"},
	{0x0024E5, "Seer Technology, Inc"},
	{0x0024E6, "In Motion Technology Inc."},
	{0x0024E7, "Plaster Networks"},
	{0x0024E8, "Dell Inc."},
	{0x0024E9, "Samsung Electronics Co., Ltd., Storage System Division"},
	{0x0024EA, "iris-GmbH infrared & intelligent sensors"},
	{0x0024EB, "ClearPath Networks, Inc."},
	{0x0024EC, "United Information Technology Co.,Ltd."},
	{0x0024ED, "YT Elec. Co,.Ltd."},
	{0x0024EE, "Wynmax Inc."},
	{0x0024EF, "Sony Ericsson Mobile Communications"},
	{0x0024F0, "Seanodes"},
	{0x0024F1, "Shenzhen Fanhai Sanjiang Electronics Co., Ltd."},
	{0x0024F2, "Uniphone Telecommunication Co., Ltd."},
	{0x0024F3, "Nintendo Co., Ltd."},
	{0x0024F4, "Kaminario Technologies Ltd."},
	{0x0024F5, "NDS Surgical Imaging"},
	{0x0024F6, "MIYOSHI ELECTRONICS CORPORATION"},
	{0x0024F7, "Cisco Systems"},
	{0x0024F8, "Technical Solutions Company Ltd."},
	{0x0024F9, "Cisco Systems"},
	{0x0024FA, "Hilger u. Kern GMBH"},
	{0x0024FC, "QuoPin Co., Ltd."},
	{0x0024FD, "Prosilient Technologies AB"},
	{0x0024FE, "AVM GmbH"},
	{0x0024FF, "QLogic Corporation"},
	{0x002500, "Apple, Inc"},
	{0x002501, "JSC \"Supertel\""},
	{0x002502, "NaturalPoint"},
	{0x002503, "BLADE Network Technology"},
	{0x002504, "Valiant Communications Limited"},
	{0x002505, "eks Engel GmbH & Co. KG"},
	{0x002506, "A.I. ANTITACCHEGGIO ITALIA SRL"},
	{0x002507, "ASTAK Inc."},
	{0x002508, "Maquet Cardiopulmonary AG"},
	{0x002509, "SHARETRONIC Group LTD"},
	{0x00250A, "Security Expert Co. Ltd"},
	{0x00250B, "CENTROFACTOR  INC"},
	{0x00250C, "Enertrac"},
	{0x00250D, "GZT Telkom-Telmor sp. z o.o."},
	{0x00250E, "gt german telematics gmbh"},
	{0x00250F, "On-Ramp Wireless, Inc."},
	{0x002510, "Pico-Tesla Magnetic Therapies"},
	{0x002511, "ELITEGROUP COMPUTER SYSTEM CO., LTD."},
	{0x002512, "ZTE Corporation"},
	{0x002513, "CXP DIGITAL BV"},
	{0x002514, "PC Worth Int'l Co., Ltd."},
	{0x002515, "SFR"},
	{0x002516, "Integrated Design Tools, Inc."},
	{0x002517, "Venntis, LLC"},
	{0x002518, "Power PLUS Communications AG"},
	{0x002519, "Viaas Inc"},
	{0x00251A, "Psiber Data Systems Inc."},
	{0x00251B, "Philips CareServant"},
	{0x00251C, "EDT"},
	{0x00251D, "DSA Encore, LLC"},
	{0x00251E, "ROTEL TECHNOLOGIES"},
	{0x00251F, "ZYNUS VISION INC."},
	{0x002520, "SMA Railway Technology GmbH"},
	{0x002521, "Logitek Electronic Systems, Inc."},
	{0x002522, "ASRock Incorporation"},
	{0x002523, "OCP Inc."},
	{0x002524, "Lightcomm Technology Co., Ltd"},
	{0x002525, "CTERA Networks Ltd."},
	{0x002526, "Genuine Technologies Co., Ltd."},
	{0x002527, "Bitrode Corp."},
	{0x002528, "Daido Signal Co., Ltd."},
	{0x002529, "COMELIT GROUP S.P.A"},
	{0x00252A, "Chengdu GeeYa Technology Co.,LTD"},
	{0x00252B, "Stirling Energy Systems"},
	{0x00252C, "Entourage Systems, Inc."},
	{0x00252D, "Kiryung Electronics"},
	{0x00252E, "Cisco SPVTG"},
	{0x00252F, "Energy, Inc."},
	{0x002530, "Aetas Systems Inc."},
	{0x002531, "Cloud Engines, Inc."},
	{0x002532, "Digital Recorders"},
	{0x002533, "WITTENSTEIN AG"},
	{0x002535, "Minimax GmbH & Co KG"},
	{0x002536, "Oki Electric Industry Co., Ltd."},
	{0x002537, "Runcom Technologies Ltd."},
	{0x002538, "Samsung Electronics Co., Ltd., Memory Division"},
	{0x002539, "IfTA GmbH"},
	{0x00253A, "CEVA, Ltd."},
	{0x00253B, "din Dietmar Nocker Facilitymanagement GmbH"},
	{0x00253C, "2Wire"},
	{0x00253D, "DRS Consolidated Controls"},
	{0x00253E, "Sensus Metering Systems"},
	{0x002540, "Quasar Technologies, Inc."},
	{0x002541, "Maquet Critical Care AB"},
	{0x002542, "Pittasoft"},
	{0x002543, "MONEYTECH"},
	{0x002544, "LoJack Corporation"},
	{0x002545, "Cisco Systems"},
	{0x002546, "Cisco Systems"},
	{0x002547, "Nokia Danmark A/S"},
	{0x002548, "Nokia Danmark A/S"},
	{0x002549, "Jeorich Tech. Co.,Ltd."},
	{0x00254A, "RingCube Technologies, Inc."},
	{0x00254B, "Apple, Inc"},
	{0x00254C, "Videon Central, Inc."},
	{0x00254D, "Singapore Technologies Electronics Limited"},
	{0x00254E, "Vertex Wireless Co., Ltd."},
	{0x00254F, "ELETTROLAB Srl"},
	{0x002550, "Riverbed Technology"},
	{0x002551, "SE-Elektronic GmbH"},
	{0x002552, "VXI CORPORATION"},
	{0x002553, "PIRELLI BROADBAND SOLUTIONS"},
	{0x002554, "Pixel8 Networks"},
	{0x002555, "Visonic Technologies 1993 Ltd"},
	{0x002556, "Hon Hai Precision Ind. Co., Ltd."},
	{0x002557, "Research In Motion"},
	{0x002558, "MPEDIA"},
	{0x002559, "Syphan Technologies Ltd"},
	{0x00255A, "Tantalus Systems Corp."},
	{0x00255B, "CoachComm, LLC"},
	{0x00255C, "NEC Corporation"},
	{0x00255D, "Morningstar Corporation"},
	{0x00255E, "Shanghai Dare Technologies Co.,Ltd."},
	{0x00255F, "SenTec AG"},
	{0x002560, "Ibridge Networks & Communications Ltd."},
	{0x002561, "ProCurve Networking by HP"},
	{0x002562, "interbro Co. Ltd."},
	{0x002563, "Luxtera Inc"},
	{0x002564, "Dell Inc."},
	{0x002565, "Vizimax Inc."},
	{0x002566, "Samsung Electronics Co.,Ltd"},
	{0x002567, "Samsung Electronics"},
	{0x002568, "Shenzhen Huawei Communication Technologies Co., Ltd"},
	{0x002569, "SAGEM COMMUNICATION"},
	{0x00256A, "inIT - Institut Industrial IT"},
	{0x00256B, "ATENIX E.E. s.r.l."},
	{0x00256C, "\"Azimut\" Production Association JSC"},
	{0x00256D, "Broadband Forum"},
	{0x00256E, "Van Breda B.V."},
	{0x00256F, "Dantherm Power"},
	{0x002570, "Eastern Communications Company Limited"},
	{0x002571, "Zhejiang Tianle Digital Electric Co.,Ltd"},
	{0x002572, "Nemo-Q International AB"},
	{0x002573, "ST Electronics (Info-Security) Pte Ltd"},
	{0x002574, "KUNIMI MEDIA DEVICE Co., Ltd."},
	{0x002575, "FiberPlex Inc"},
	{0x002576, "NELI TECHNOLOGIES"},
	{0x002577, "D-BOX Technologies"},
	{0x002578, "JSC \"Concern \"Sozvezdie\""},
	{0x002579, "J & F Labs"},
	{0x00257A,
	 "CAMCO Produktions- und Vertriebs-GmbH fr Beschallungs- und Beleuchtungsanlagen"},
	{0x00257B, "STJ  ELECTRONICS  PVT  LTD"},
	{0x00257C, "Huachentel Technology Development Co., Ltd"},
	{0x00257D, "PointRed Telecom Private Ltd."},
	{0x00257E, "NEW POS Technology Limited"},
	{0x00257F, "CallTechSolution Co.,Ltd"},
	{0x002580, "Equipson S.A."},
	{0x002581, "x-star networks Inc."},
	{0x002582, "Maksat Technologies (P) Ltd"},
	{0x002583, "Cisco Systems"},
	{0x002584, "Cisco Systems"},
	{0x002585, "KOKUYO S&T Co., Ltd."},
	{0x002586, "TP-LINK Technologies Co., Ltd."},
	{0x002587, "Vitality, Inc."},
	{0x002588, "Genie Industries, Inc."},
	{0x002589, "Hills Industries Limited"},
	{0x00258A, "Pole/Zero Corporation"},
	{0x00258B, "Mellanox Technologies Ltd"},
	{0x00258C, "ESUS ELEKTRONIK SAN. VE DIS. TIC. LTD. STI."},
	{0x00258D, "Haier"},
	{0x00258E, "The Weather Channel"},
	{0x00258F, "Trident Microsystems, Inc."},
	{0x002590, "Super Micro Computer, Inc."},
	{0x002591, "NEXTEK, Inc."},
	{0x002592, "Guangzhou Shirui Electronic Co., Ltd"},
	{0x002593, "DatNet Informatikai Kft."},
	{0x002594, "Eurodesign BG LTD"},
	{0x002595, "Northwest Signal Supply, Inc"},
	{0x002596, "GIGAVISION srl"},
	{0x002597, "Kalki Communication Technologies"},
	{0x002598, "Zhong Shan City Litai Electronic Industrial Co. Ltd"},
	{0x002599, "Hedon e.d. B.V."},
	{0x00259A, "CEStronics GmbH"},
	{0x00259B, "Beijing PKUNITY Microsystems Technology Co., Ltd"},
	{0x00259C, "Cisco-Linksys, LLC"},
	{0x00259E, "Huawei Technologies Co., Ltd."},
	{0x00259F, "TechnoDigital Technologies GmbH"},
	{0x0025A0, "Nintendo Co., Ltd."},
	{0x0025A1, "Enalasys"},
	{0x0025A2, "Alta Definicion LINCEO S.L."},
	{0x0025A3, "Trimax Wireless, Inc."},
	{0x0025A4, "EuroDesign embedded technologies GmbH"},
	{0x0025A5, "Walnut Media Network"},
	{0x0025A6, "Central Network Solution Co., Ltd."},
	{0x0025A7, "Comverge, Inc."},
	{0x0025A8, "Kontron (BeiJing) Technology Co.,Ltd"},
	{0x0025A9, "Shanghai Embedway Information Technologies Co.,Ltd"},
	{0x0025AA, "Beijing Soul Technology Co.,Ltd."},
	{0x0025AB, "AIO LCD PC BU / TPV"},
	{0x0025AC, "I-Tech corporation"},
	{0x0025AD, "Manufacturing Resources International"},
	{0x0025AE, "Microsoft Corporation"},
	{0x0025AF, "COMFILE Technology"},
	{0x0025B0, "Schmartz Inc"},
	{0x0025B1, "Maya-Creation Corporation"},
	{0x0025B2, "LFK-Lenkflugkrpersysteme GmbH"},
	{0x0025B3, "Hewlett Packard"},
	{0x0025B4, "Cisco Systems"},
	{0x0025B5, "Cisco Systems"},
	{0x0025B6, "Telecom FM"},
	{0x0025B7, "Costar  electronics, inc.,"},
	{0x0025B8, "Agile Communications, Inc."},
	{0x0025B9, "Agilink Systems Corp."},
	{0x0025BA, "Alcatel-Lucent IPD"},
	{0x0025BB, "INNERINT Co., Ltd."},
	{0x0025BC, "Apple, Inc"},
	{0x0025BD, "Italdata Ingegneria dell'Idea S.p.A."},
	{0x0025BE, "Tektrap Systems Inc."},
	{0x0025BF, "Wireless Cables Inc."},
	{0x0025C0, "ZillionTV Corporation"},
	{0x0025C1, "Nawoo Korea Corp."},
	{0x0025C2, "RingBell Co.,Ltd."},
	{0x0025C3, "Nortel Networks"},
	{0x0025C4, "Ruckus Wireless"},
	{0x0025C5, "Star Link Communication Pvt. Ltd."},
	{0x0025C6, "kasercorp, ltd"},
	{0x0025C7, "altek Corporation"},
	{0x0025C8, "S-Access GmbH"},
	{0x0025C9, "SHENZHEN HUAPU DIGITAL CO., LTD"},
	{0x0025CA, "LS Research, LLC"},
	{0x0025CB, "Reiner SCT"},
	{0x0025CC, "Mobile Communications Korea Incorporated"},
	{0x0025CD, "Skylane Optics"},
	{0x0025CE, "InnerSpace"},
	{0x0025CF, "Nokia Danmark A/S"},
	{0x0025D0, "Nokia Danmark A/S"},
	{0x0025D1, "Eastech Electronics (Taiwan) Inc."},
	{0x0025D2, "InpegVision Co., Ltd"},
	{0x0025D3, "AzureWave Technologies, Inc"},
	{0x0025D4, "Fortress Technologies"},
	{0x0025D5, "Robonica (Pty) Ltd"},
	{0x0025D6, "The Kroger Co."},
	{0x0025D7, "CEDO"},
	{0x0025D8, "KOREA MAINTENANCE"},
	{0x0025D9, "DataFab Systems Inc."},
	{0x0025DA, "Secura Key"},
	{0x0025DB, "ATI Electronics(Shenzhen) Co., LTD"},
	{0x0025DC, "Sumitomo Electric Networks, Inc"},
	{0x0025DD, "SUNNYTEK INFORMATION CO., LTD."},
	{0x0025DE, "Probits Co., LTD."},
	{0x0025E0, "CeedTec Sdn Bhd"},
	{0x0025E1, "SHANGHAI SEEYOO ELECTRONIC & TECHNOLOGY CO., LTD"},
	{0x0025E2, "Everspring Industry Co., Ltd."},
	{0x0025E3, "Hanshinit Inc."},
	{0x0025E4, "OMNI-WiFi, LLC"},
	{0x0025E5, "LG Electronics Inc"},
	{0x0025E6, "Belgian Monitoring Systems bvba"},
	{0x0025E7, "Sony Ericsson Mobile Communications"},
	{0x0025E8, "Idaho Technology"},
	{0x0025E9, "i-mate Development, Inc."},
	{0x0025EA, "Iphion BV"},
	{0x0025EB, "Reutech Radar Systems (PTY) Ltd"},
	{0x0025EC, "Humanware"},
	{0x0025ED, "NuVo Technologies LLC"},
	{0x0025EE, "Avtex Ltd"},
	{0x0025EF, "I-TEC Co., Ltd."},
	{0x0025F0, "Suga Electronics Limited"},
	{0x0025F1, "Motorola CHS"},
	{0x0025F2, "Motorola CHS"},
	{0x0025F3, "Nordwestdeutsche Zhlerrevision"},
	{0x0025F4, "KoCo Connector AG"},
	{0x0025F5, "DVS Korea, Co., Ltd"},
	{0x0025F6, "netTALK.com, Inc."},
	{0x0025F7, "Ansaldo STS USA"},
	{0x0025F9, "GMK electronic design GmbH"},
	{0x0025FA, "J&M Analytik AG"},
	{0x0025FB, "Tunstall Healthcare A/S"},
	{0x0025FC, "ENDA ENDUSTRIYEL ELEKTRONIK LTD. STI."},
	{0x0025FD, "OBR Centrum Techniki Morskiej S.A."},
	{0x0025FE, "Pilot Electronics Corporation"},
	{0x0025FF, "CreNova Technology GmbH"},
	{0x002600, "TEAC Australia Pty Ltd."},
	{0x002602, "SMART Temps LLC"},
	{0x002603, "Shenzhen Wistar Technology Co., Ltd"},
	{0x002604, "Audio Processing Technology Ltd"},
	{0x002605, "CC Systems AB"},
	{0x002606, "RAUMFELD GmbH"},
	{0x002607, "Enabling Technology Pty Ltd"},
	{0x002608, "Apple, Inc"},
	{0x002609, "Phyllis Co., Ltd."},
	{0x00260A, "Cisco Systems"},
	{0x00260B, "Cisco Systems"},
	{0x00260C, "Dataram"},
	{0x00260D, "Micronetics, Inc."},
	{0x00260E, "Ablaze Systems, LLC"},
	{0x00260F, "Linn Products Ltd"},
	{0x002610, "Apacewave Technologies"},
	{0x002611, "Licera AB"},
	{0x002612, "Space Exploration Technologies"},
	{0x002613, "Engel Axil S.L."},
	{0x002614, "KTNF"},
	{0x002615, "Teracom Limited"},
	{0x002616, "Rosemount Inc."},
	{0x002617, "OEM Worldwide"},
	{0x002618, "ASUSTek COMPUTER INC."},
	{0x002619, "FRC"},
	{0x00261A, "Femtocomm System Technology Corp."},
	{0x00261B, "LAUREL BANK MACHINES CO., LTD."},
	{0x00261C, "NEOVIA INC."},
	{0x00261D, "COP SECURITY SYSTEM CORP."},
	{0x00261E, "QINGBANG ELEC(SZ) CO., LTD"},
	{0x00261F, "SAE Magnetics (H.K.) Ltd."},
	{0x002620, "ISGUS GmbH"},
	{0x002621, "InteliCloud Technology Inc."},
	{0x002622, "COMPAL INFORMATION (KUNSHAN) CO., LTD."},
	{0x002623, "JRD Communication Inc"},
	{0x002624, "Thomson Inc."},
	{0x002625, "MediaSputnik"},
	{0x002626, "Geophysical Survey Systems, Inc."},
	{0x002627, "Truesell"},
	{0x002628, "companytec automao e controle ltda"},
	{0x002629, "Juphoon System Software Inc."},
	{0x00262A, "Proxense, LLC"},
	{0x00262B, "Wongs Electronics Co. Ltd."},
	{0x00262C, "IKT Advanced Technologies s.r.o."},
	{0x00262D, "Wistron Corporation"},
	{0x00262E, "Chengdu Jiuzhou Electronic Technology Inc"},
	{0x00262F, "HAMAMATSU TOA ELECTRONICS"},
	{0x002630, "ACOREL S.A.S"},
	{0x002631, "COMMTACT LTD"},
	{0x002632, "Instrumentation Technologies d.d."},
	{0x002633, "MIR - Medical International Research"},
	{0x002634, "Infineta Systems, Inc"},
	{0x002635, "Bluetechnix GmbH"},
	{0x002636, "Motorola Mobile Devices"},
	{0x002637, "Samsung Electro-Mechanics"},
	{0x002638, "Xia Men Joyatech Co., Ltd."},
	{0x002639, "T.M. Electronics, Inc."},
	{0x00263A, "Digitec Systems"},
	{0x00263B, "Onbnetech"},
	{0x00263C, "Bachmann GmbH & Co. KG"},
	{0x00263D, "MIA Corporation"},
	{0x00263E, "Trapeze Networks"},
	{0x00263F, "LIOS Technology GmbH"},
	{0x002640, "Baustem Broadband Technologies, Ltd."},
	{0x002641, "Motorola, Inc"},
	{0x002642, "Motorola, Inc"},
	{0x002643, "Alps Electric Co., Ltd"},
	{0x002644, "Thomson Telecom Belgium"},
	{0x002645, "Circontrol S.A."},
	{0x002646, "SHENYANG TONGFANG MULTIMEDIA TECHNOLOGY COMPANY LIMITED"},
	{0x002647, "WFE TECHNOLOGY CORP."},
	{0x002648, "Emitech Corp."},
	{0x00264A, "Apple, Inc"},
	{0x00264C, "Shanghai DigiVision Technology Co., Ltd."},
	{0x00264D, "Arcadyan Technology Corporation"},
	{0x00264E, "Rail & Road Protec GmbH"},
	{0x00264F, "Krger&Gothe GmbH"},
	{0x002650, "2Wire"},
	{0x002651, "Cisco Systems"},
	{0x002652, "Cisco Systems"},
	{0x002653, "DaySequerra Corporation"},
	{0x002654, "3Com Corporation"},
	{0x002655, "Hewlett Packard"},
	{0x002656, "Sansonic Electronics USA"},
	{0x002657, "OOO NPP EKRA"},
	{0x002658, "T-Platforms (Cyprus) Limited"},
	{0x002659, "Nintendo Co., Ltd."},
	{0x00265A, "D-Link Corporation"},
	{0x00265B, "Hitron Technologies. Inc"},
	{0x00265C, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x00265D, "Samsung Electronics"},
	{0x00265E, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x00265F, "Samsung Electronics Co.,Ltd"},
	{0x002660, "Logiways"},
	{0x002661, "Irumtek Co., Ltd."},
	{0x002662, "Actiontec Electronics, Inc"},
	{0x002663, "Shenzhen Huitaiwei Tech. Ltd, co."},
	{0x002664, "Core System Japan"},
	{0x002665, "ProtectedLogic Corporation"},
	{0x002666, "EFM Networks"},
	{0x002667, "CARECOM CO.,LTD."},
	{0x002668, "Nokia Danmark A/S"},
	{0x002669, "Nokia Danmark A/S"},
	{0x00266A, "ESSENSIUM NV"},
	{0x00266B, "SHINE UNION ENTERPRISE LIMITED"},
	{0x00266C, "Inventec"},
	{0x00266D, "MobileAccess Networks"},
	{0x00266E, "Nissho-denki Co.,LTD."},
	{0x00266F, "Coordiwise Technology Corp."},
	{0x002670, "Cinch Connectors"},
	{0x002671, "AUTOVISION Co., Ltd"},
	{0x002672, "AAMP of America"},
	{0x002673, "RICOH COMPANY LTD."},
	{0x002674, "Electronic Solutions, Inc."},
	{0x002675, "Aztech Electronics Pte Ltd"},
	{0x002676, "COMMidt AS"},
	{0x002677, "DEIF A/S"},
	{0x002678, "Logic Instrument SA"},
	{0x002679, "Euphonic Technologies, Inc."},
	{0x00267A, "wuhan hongxin telecommunication technologies co.,ltd"},
	{0x00267B, "GSI Helmholtzzentrum fr Schwerionenforschung GmbH"},
	{0x00267C, "Metz-Werke GmbH & Co KG"},
	{0x00267D,
	 "A-Max Technology Macao Commercial Offshore Company Limited"},
	{0x00267E, "Parrot SA"},
	{0x00267F, "Zenterio AB"},
	{0x002680, "Lockie Innovation Pty Ltd"},
	{0x002681, "Interspiro AB"},
	{0x002682, "Gemtek Technology Co., Ltd."},
	{0x002683, "Ajoho Enterprise Co., Ltd."},
	{0x002684, "KISAN SYSTEM"},
	{0x002685, "Digital Innovation"},
	{0x002686, "Quantenna Communcations, Inc."},
	{0x002687, "ALLIED TELESIS, K.K corega division."},
	{0x002688, "Juniper Networks"},
	{0x002689, "General Dynamics Robotic Systems"},
	{0x00268A, "Terrier SC Ltd"},
	{0x00268B, "Guangzhou Escene Computer Technology Limited"},
	{0x00268C, "StarLeaf Ltd."},
	{0x00268D, "CellTel S.p.A."},
	{0x00268E, "Alta Solutions, Inc."},
	{0x00268F, "MTA SpA"},
	{0x002690, "I DO IT"},
	{0x002691, "SAGEM COMMUNICATION"},
	{0x002692, "Mitsubishi Electric Co."},
	{0x002693, "QVidium Technologies, Inc."},
	{0x002694, "Senscient Ltd"},
	{0x002695, "ZT Group Int'l Inc"},
	{0x002696, "NOOLIX Co., Ltd"},
	{0x002697, "Cheetah Technologies, L.P."},
	{0x002698, "Cisco Systems"},
	{0x002699, "Cisco Systems"},
	{0x00269A, "carina system co., ltd."},
	{0x00269B, "SOKRAT Ltd."},
	{0x00269C, "ITUS JAPAN CO. LTD"},
	{0x00269D, "M2Mnet Co., Ltd."},
	{0x00269E, "Quanta Computer Inc"},
	{0x0026A0, "moblic"},
	{0x0026A1, "Megger"},
	{0x0026A2, "Instrumentation Technology Systems"},
	{0x0026A3, "FQ Ingenieria Electronica S.A."},
	{0x0026A4, "Novus Produtos Eletronicos Ltda"},
	{0x0026A5, "MICROROBOT.CO.,LTD"},
	{0x0026A6, "TRIXELL"},
	{0x0026A7, "CONNECT SRL"},
	{0x0026A8, "DAEHAP HYPER-TECH"},
	{0x0026A9, "Strong Technologies Pty Ltd"},
	{0x0026AA, "Kenmec Mechanical Engineering Co., Ltd."},
	{0x0026AB, "SEIKO EPSON CORPORATION"},
	{0x0026AC, "Shanghai LUSTER Teraband photonic Co., Ltd."},
	{0x0026AD, "Arada Systems, Inc."},
	{0x0026AE, "Wireless Measurement Ltd"},
	{0x0026AF, "Duelco A/S"},
	{0x0026B0, "Apple, Inc"},
	{0x0026B1, "Harman/Navis"},
	{0x0026B2, "Setrix AG"},
	{0x0026B3, "Thales Communications Inc"},
	{0x0026B4, "Ford Motor Company"},
	{0x0026B5, "ICOMM Tele Ltd"},
	{0x0026B6, "Askey Computer"},
	{0x0026B7, "Kingston Technology Company, Inc."},
	{0x0026B8, "Actiontec Electronics, Inc"},
	{0x0026B9, "Dell Inc"},
	{0x0026BA, "Motorola Mobile Devices"},
	{0x0026BB, "Apple, Inc"},
	{0x0026BC, "General Jack Technology Ltd."},
	{0x0026BD, "JTEC Card & Communication Co., Ltd."},
	{0x0026BE, "Schoonderbeek Elektronica Systemen B.V."},
	{0x0026BF, "ShenZhen Temobi Science&Tech Development Co.,Ltd"},
	{0x0026C0, "EnergyHub"},
	{0x0026C1, "ARTRAY CO., LTD."},
	{0x0026C2, "SCDI Co. LTD"},
	{0x0026C3, "Insightek Corp."},
	{0x0026C4, "Cadmos microsystems S.r.l."},
	{0x0026C5, "Guangdong Gosun Telecommunications Co.,Ltd"},
	{0x0026C6, "Intel Corporate"},
	{0x0026C7, "Intel Corporate"},
	{0x0026C8, "System Sensor"},
	{0x0026C9, "Proventix Systems, Inc."},
	{0x0026CA, "Cisco Systems"},
	{0x0026CB, "Cisco Systems"},
	{0x0026CC, "Nokia Danmark A/S"},
	{0x0026CD, "PurpleComm, Inc."},
	{0x0026CE, "Kozumi USA Corp."},
	{0x0026CF, "DEKA R&D"},
	{0x0026D0, "Semihalf"},
	{0x0026D1, "S Squared Innovations Inc."},
	{0x0026D2, "Pcube Systems, Inc."},
	{0x0026D3, "Zeno Information System"},
	{0x0026D4, "IRCA SpA"},
	{0x0026D5, "Ory Solucoes em Comercio de Informatica Ltda."},
	{0x0026D6, "Ningbo Andy Optoelectronic Co., Ltd."},
	{0x0026D7, "Xiamen BB Electron & Technology Co., Ltd."},
	{0x0026D8, "Magic Point Inc."},
	{0x0026D9, "Pace Micro Technology plc"},
	{0x0026DA, "Universal Media Corporation /Slovakia/ s.r.o."},
	{0x0026DB, "Ionics EMS Inc."},
	{0x0026DC, "Optical Systems Design"},
	{0x0026DD, "Fival Corporation"},
	{0x0026DE, "FDI MATELEC"},
	{0x0026DF, "TaiDoc Technology Corp."},
	{0x0026E0, "ASITEQ"},
	{0x0026E1, "Stanford University, OpenFlow Group"},
	{0x0026E2, "LG Electronics"},
	{0x0026E3, "DTI"},
	{0x0026E4, "CANAL OVERSEAS"},
	{0x0026E5, "AEG Power Solutions"},
	{0x0026E6, "Visionhitech Co., Ltd."},
	{0x0026E7, "Shanghai ONLAN Communication Tech. Co., Ltd."},
	{0x0026E8, "Murata Manufacturing Co., Ltd."},
	{0x0026E9, "SP Corp"},
	{0x0026EA, "Cheerchip Electronic Technology (ShangHai) Co., Ltd."},
	{0x0026EB, "Advanced Spectrum Technology Co., Ltd."},
	{0x0026EC, "Legrand Home Systems, Inc"},
	{0x0026ED, "zte corporation"},
	{0x0026EE, "TKM GmbH"},
	{0x0026EF, "Technology Advancement Group, Inc."},
	{0x0026F0, "cTrixs International GmbH."},
	{0x0026F1, "ProCurve Networking by HP"},
	{0x0026F2, "Netgear"},
	{0x0026F3, "SMC Networks"},
	{0x0026F4, "Nesslab"},
	{0x0026F5, "XRPLUS Inc."},
	{0x0026F6, "Military Communication Institute"},
	{0x0026F7, "Infosys Technologies Ltd."},
	{0x0026F8, "Golden Highway Industry Development Co., Ltd."},
	{0x0026F9, "S.E.M. srl"},
	{0x0026FA, "BandRich Inc."},
	{0x0026FB, "AirDio Wireless, Inc."},
	{0x0026FC, "AcSiP Technology Corp."},
	{0x0026FD, "Interactive Intelligence"},
	{0x0026FE, "MKD Technology Inc."},
	{0x0026FF, "Research In Motion"},
	{0x002700, "Shenzhen Siglent Technology Co., Ltd."},
	{0x002701, "INCOstartec GmbH"},
	{0x002702, "SolarEdge Technologies"},
	{0x002703, "Testech Electronics Pte Ltd"},
	{0x002704, "Accelerated Concepts, LLC"},
	{0x002705, "Sectronic"},
	{0x002706, "YOISYS"},
	{0x002707, "Lift Complex DS, JSC"},
	{0x002708, "Nordiag ASA"},
	{0x002709, "Nintendo Co., Ltd."},
	{0x00270A, "IEE S.A."},
	{0x00270B, "Adura Technologies"},
	{0x00270C, "Cisco Systems"},
	{0x00270D, "Cisco Systems"},
	{0x00270E, "Intel Corporate"},
	{0x00270F, "Envisionnovation Inc"},
	{0x002710, "Intel Corporate"},
	{0x002711, "LanPro Inc"},
	{0x002712, "MaxVision LLC"},
	{0x002713, "USI"},
	{0x002714, "Grainmustards, Co,ltd."},
	{0x002715, "Rebound Telecom. Co., Ltd"},
	{0x002716, "Adachi-Syokai Co., Ltd."},
	{0x002717, "CE Digital(Zhenjiang)Co.,Ltd"},
	{0x002718, "Suzhou NEW SEAUNION Video Technology Co.,Ltd"},
	{0x002719, "TP-LINK TECHNOLOGIES CO., LTD."},
	{0x00271A, "Geenovo Technology Ltd."},
	{0x00271B, "Alec Sicherheitssysteme GmbH"},
	{0x00271C, "MERCURY CORPORATION"},
	{0x00271D, "Comba Telecom Systems (China) Ltd."},
	{0x00271E, "Xagyl Communications"},
	{0x00271F, "MIPRO Electronics Co., Ltd"},
	{0x002720, "NEW-SOL COM"},
	{0x002721, "Shenzhen Baoan Fenda Industrial Co., Ltd"},
	{0x002722, "Ubiquiti Networks"},
	{0x003000, "ALLWELL TECHNOLOGY CORP."},
	{0x003001, "SMP"},
	{0x003002, "Expand Networks"},
	{0x003003, "Phasys Ltd."},
	{0x003004, "LEADTEK RESEARCH INC."},
	{0x003005, "Fujitsu Siemens Computers"},
	{0x003006, "SUPERPOWER COMPUTER"},
	{0x003007, "OPTI, INC."},
	{0x003008, "AVIO DIGITAL, INC."},
	{0x003009, "Tachion Networks, Inc."},
	{0x00300A, "AZTECH Electronics Pte Ltd"},
	{0x00300B, "mPHASE Technologies, Inc."},
	{0x00300C, "CONGRUENCY, LTD."},
	{0x00300D, "MMC Technology, Inc."},
	{0x00300E, "Klotz Digital AG"},
	{0x00300F, "IMT - Information Management T"},
	{0x003010, "VISIONETICS INTERNATIONAL"},
	{0x003011, "HMS FIELDBUS SYSTEMS AB"},
	{0x003012, "DIGITAL ENGINEERING LTD."},
	{0x003013, "NEC Corporation"},
	{0x003014, "DIVIO, INC."},
	{0x003015, "CP CLARE CORP."},
	{0x003016, "ISHIDA CO., LTD."},
	{0x003017, "BlueArc UK Ltd"},
	{0x003018, "Jetway Information Co., Ltd."},
	{0x003019, "CISCO SYSTEMS, INC."},
	{0x00301A, "SMARTBRIDGES PTE. LTD."},
	{0x00301B, "SHUTTLE, INC."},
	{0x00301C, "ALTVATER AIRDATA SYSTEMS"},
	{0x00301D, "SKYSTREAM, INC."},
	{0x00301E, "3COM Europe Ltd."},
	{0x00301F, "OPTICAL NETWORKS, INC."},
	{0x003020, "TSI, Inc.."},
	{0x003021, "HSING TECH. ENTERPRISE CO.,LTD"},
	{0x003022, "Fong Kai Industrial Co., Ltd."},
	{0x003023, "COGENT COMPUTER SYSTEMS, INC."},
	{0x003024, "CISCO SYSTEMS, INC."},
	{0x003025, "CHECKOUT COMPUTER SYSTEMS, LTD"},
	{0x003026, "HeiTel Digital Video GmbH"},
	{0x003027, "KERBANGO, INC."},
	{0x003028, "FASE Saldatura srl"},
	{0x003029, "OPICOM"},
	{0x00302A, "SOUTHERN INFORMATION"},
	{0x00302B, "INALP NETWORKS, INC."},
	{0x00302C, "SYLANTRO SYSTEMS CORPORATION"},
	{0x00302D, "QUANTUM BRIDGE COMMUNICATIONS"},
	{0x00302E, "Hoft & Wessel AG"},
	{0x00302F, "GE Aviation System"},
	{0x003030, "HARMONIX CORPORATION"},
	{0x003031, "LIGHTWAVE COMMUNICATIONS, INC."},
	{0x003032, "MagicRam, Inc."},
	{0x003033, "ORIENT TELECOM CO., LTD."},
	{0x003034, "SET ENGINEERING"},
	{0x003035, "Corning Incorporated"},
	{0x003036, "RMP ELEKTRONIKSYSTEME GMBH"},
	{0x003037, "Packard Bell Nec Services"},
	{0x003038, "XCP, INC."},
	{0x003039, "SOFTBOOK PRESS"},
	{0x00303A, "MAATEL"},
	{0x00303B, "PowerCom Technology"},
	{0x00303C, "ONNTO CORP."},
	{0x00303D, "IVA CORPORATION"},
	{0x00303E, "Radcom Ltd."},
	{0x00303F, "TurboComm Tech Inc."},
	{0x003040, "CISCO SYSTEMS, INC."},
	{0x003041, "SAEJIN T & M CO., LTD."},
	{0x003042, "DeTeWe-Deutsche Telephonwerke"},
	{0x003043, "IDREAM TECHNOLOGIES, PTE. LTD."},
	{0x003044, "Portsmith LLC"},
	{0x003045, "Village Networks, Inc. (VNI)"},
	{0x003046, "Controlled Electronic Manageme"},
	{0x003047, "NISSEI ELECTRIC CO., LTD."},
	{0x003048, "Supermicro Computer, Inc."},
	{0x003049, "BRYANT TECHNOLOGY, LTD."},
	{0x00304A, "Fraunhofer IPMS"},
	{0x00304B, "ORBACOM SYSTEMS, INC."},
	{0x00304C, "APPIAN COMMUNICATIONS, INC."},
	{0x00304D, "ESI"},
	{0x00304E, "BUSTEC PRODUCTION LTD."},
	{0x00304F, "PLANET Technology Corporation"},
	{0x003050, "Versa Technology"},
	{0x003051, "ORBIT AVIONIC & COMMUNICATION"},
	{0x003052, "ELASTIC NETWORKS"},
	{0x003053, "Basler AG"},
	{0x003054, "CASTLENET TECHNOLOGY, INC."},
	{0x003055, "Renesas Technology America, Inc."},
	{0x003056, "Beck IPC GmbH"},
	{0x003057, "QTelNet, Inc."},
	{0x003058, "API MOTION"},
	{0x003059, "DIGITAL-LOGIC AG"},
	{0x00305A, "TELGEN CORPORATION"},
	{0x00305B, "Toko Inc."},
	{0x00305C, "SMAR Laboratories Corp."},
	{0x00305D, "DIGITRA SYSTEMS, INC."},
	{0x00305E, "Abelko Innovation"},
	{0x00305F, "Hasselblad"},
	{0x003060, "Powerfile, Inc."},
	{0x003061, "MobyTEL"},
	{0x003062, "PATH 1 NETWORK TECHNOL'S INC."},
	{0x003063, "SANTERA SYSTEMS, INC."},
	{0x003064, "ADLINK TECHNOLOGY, INC."},
	{0x003065, "APPLE COMPUTER, INC."},
	{0x003066, "RFM"},
	{0x003067, "BIOSTAR MICROTECH INT'L CORP."},
	{0x003068, "CYBERNETICS TECH. CO., LTD."},
	{0x003069, "IMPACCT TECHNOLOGY CORP."},
	{0x00306A, "PENTA MEDIA CO., LTD."},
	{0x00306B, "CMOS SYSTEMS, INC."},
	{0x00306C, "Hitex Holding GmbH"},
	{0x00306D, "LUCENT TECHNOLOGIES"},
	{0x00306E, "HEWLETT PACKARD"},
	{0x00306F, "SEYEON TECH. CO., LTD."},
	{0x003070, "1Net Corporation"},
	{0x003071, "Cisco Systems, Inc."},
	{0x003072, "Intellibyte Inc."},
	{0x003073, "International Microsystems, In"},
	{0x003074, "EQUIINET LTD."},
	{0x003075, "ADTECH"},
	{0x003076, "Akamba Corporation"},
	{0x003077, "ONPREM NETWORKS"},
	{0x003078, "Cisco Systems, Inc."},
	{0x003079, "CQOS, INC."},
	{0x00307A, "Advanced Technology & Systems"},
	{0x00307B, "Cisco Systems, Inc."},
	{0x00307C, "ADID SA"},
	{0x00307D, "GRE AMERICA, INC."},
	{0x00307E, "Redflex Communication Systems"},
	{0x00307F, "IRLAN LTD."},
	{0x003080, "CISCO SYSTEMS, INC."},
	{0x003081, "ALTOS C&C"},
	{0x003082, "TAIHAN ELECTRIC WIRE CO., LTD."},
	{0x003083, "Ivron Systems"},
	{0x003084, "ALLIED TELESYN INTERNAIONAL"},
	{0x003085, "CISCO SYSTEMS, INC."},
	{0x003086, "Transistor Devices, Inc."},
	{0x003087, "VEGA GRIESHABER KG"},
	{0x003088, "Siara Systems, Inc."},
	{0x003089, "Spectrapoint Wireless, LLC"},
	{0x00308A, "NICOTRA SISTEMI S.P.A"},
	{0x00308B, "Brix Networks"},
	{0x00308C, "Quantum Corporation"},
	{0x00308D, "Pinnacle Systems, Inc."},
	{0x00308E, "CROSS MATCH TECHNOLOGIES, INC."},
	{0x00308F, "MICRILOR, Inc."},
	{0x003090, "CYRA TECHNOLOGIES, INC."},
	{0x003091, "TAIWAN FIRST LINE ELEC. CORP."},
	{0x003092, "ModuNORM GmbH"},
	{0x003093, "Sonnet Technologies, Inc"},
	{0x003094, "Cisco Systems, Inc."},
	{0x003095, "Procomp Informatics, Ltd."},
	{0x003096, "CISCO SYSTEMS, INC."},
	{0x003097, "AB Regin"},
	{0x003098, "Global Converging Technologies"},
	{0x003099, "BOENIG UND KALLENBACH OHG"},
	{0x00309A, "ASTRO TERRA CORP."},
	{0x00309B, "Smartware"},
	{0x00309C, "Timing Applications, Inc."},
	{0x00309D, "Nimble Microsystems, Inc."},
	{0x00309E, "WORKBIT CORPORATION."},
	{0x00309F, "AMBER NETWORKS"},
	{0x0030A0, "TYCO SUBMARINE SYSTEMS, LTD."},
	{0x0030A1, "WEBGATE Inc."},
	{0x0030A2, "Lightner Engineering"},
	{0x0030A3, "CISCO SYSTEMS, INC."},
	{0x0030A4, "Woodwind Communications System"},
	{0x0030A5, "ACTIVE POWER"},
	{0x0030A6, "VIANET TECHNOLOGIES, LTD."},
	{0x0030A7, "SCHWEITZER ENGINEERING"},
	{0x0030A8, "OL'E COMMUNICATIONS, INC."},
	{0x0030A9, "Netiverse, Inc."},
	{0x0030AA, "AXUS MICROSYSTEMS, INC."},
	{0x0030AB, "DELTA NETWORKS, INC."},
	{0x0030AC, "Systeme Lauer GmbH & Co., Ltd."},
	{0x0030AD, "SHANGHAI COMMUNICATION"},
	{0x0030AE, "Times N System, Inc."},
	{0x0030AF, "Honeywell GmbH"},
	{0x0030B0, "Convergenet Technologies"},
	{0x0030B1, "aXess-pro networks GmbH"},
	{0x0030B2, "L-3 Sonoma EO"},
	{0x0030B3, "San Valley Systems, Inc."},
	{0x0030B4, "INTERSIL CORP."},
	{0x0030B5, "Tadiran Microwave Networks"},
	{0x0030B6, "CISCO SYSTEMS, INC."},
	{0x0030B7, "Teletrol Systems, Inc."},
	{0x0030B8, "RiverDelta Networks"},
	{0x0030B9, "ECTEL"},
	{0x0030BA, "AC&T SYSTEM CO., LTD."},
	{0x0030BB, "CacheFlow, Inc."},
	{0x0030BC, "Optronic AG"},
	{0x0030BD, "BELKIN COMPONENTS"},
	{0x0030BE, "City-Net Technology, Inc."},
	{0x0030BF, "MULTIDATA GMBH"},
	{0x0030C0, "Lara Technology, Inc."},
	{0x0030C1, "HEWLETT-PACKARD"},
	{0x0030C2, "COMONE"},
	{0x0030C3, "FLUECKIGER ELEKTRONIK AG"},
	{0x0030C4, "Canon Imaging Systems Inc."},
	{0x0030C5, "CADENCE DESIGN SYSTEMS"},
	{0x0030C6, "CONTROL SOLUTIONS, INC."},
	{0x0030C7, "Macromate Corp."},
	{0x0030C8, "GAD LINE, LTD."},
	{0x0030C9, "LuxN, N"},
	{0x0030CA, "Discovery Com"},
	{0x0030CB, "OMNI FLOW COMPUTERS, INC."},
	{0x0030CC, "Tenor Networks, Inc."},
	{0x0030CD, "CONEXANT SYSTEMS, INC."},
	{0x0030CE, "Zaffire"},
	{0x0030CF, "TWO TECHNOLOGIES, INC."},
	{0x0030D0, "Tellabs"},
	{0x0030D1, "INOVA CORPORATION"},
	{0x0030D2, "WIN TECHNOLOGIES, CO., LTD."},
	{0x0030D3, "Agilent Technologies"},
	{0x0030D4, "AAE Systems, Inc"},
	{0x0030D5, "DResearch GmbH"},
	{0x0030D6, "MSC VERTRIEBS GMBH"},
	{0x0030D7, "Innovative Systems, L.L.C."},
	{0x0030D8, "SITEK"},
	{0x0030D9, "DATACORE SOFTWARE CORP."},
	{0x0030DA, "COMTREND CO."},
	{0x0030DB, "Mindready Solutions, Inc."},
	{0x0030DC, "RIGHTECH CORPORATION"},
	{0x0030DD, "INDIGITA CORPORATION"},
	{0x0030DE, "WAGO Kontakttechnik GmbH"},
	{0x0030DF, "KB/TEL TELECOMUNICACIONES"},
	{0x0030E0, "OXFORD SEMICONDUCTOR LTD."},
	{0x0030E1, "ACROTRON SYSTEMS, INC."},
	{0x0030E2, "GARNET SYSTEMS CO., LTD."},
	{0x0030E3, "SEDONA NETWORKS CORP."},
	{0x0030E4, "CHIYODA SYSTEM RIKEN"},
	{0x0030E5, "Amper Datos S.A."},
	{0x0030E6, "Draeger Medical Systems, Inc."},
	{0x0030E7, "CNF MOBILE SOLUTIONS, INC."},
	{0x0030E8, "ENSIM CORP."},
	{0x0030E9, "GMA COMMUNICATION MANUFACT'G"},
	{0x0030EA, "TeraForce Technology Corporation"},
	{0x0030EB, "TURBONET COMMUNICATIONS, INC."},
	{0x0030EC, "BORGARDT"},
	{0x0030ED, "Expert Magnetics Corp."},
	{0x0030EE, "DSG Technology, Inc."},
	{0x0030EF, "NEON TECHNOLOGY, INC."},
	{0x0030F0, "Uniform Industrial Corp."},
	{0x0030F1, "Accton Technology Corp."},
	{0x0030F2, "CISCO SYSTEMS, INC."},
	{0x0030F3, "At Work Computers"},
	{0x0030F4, "STARDOT TECHNOLOGIES"},
	{0x0030F5, "Wild Lab. Ltd."},
	{0x0030F6, "SECURELOGIX CORPORATION"},
	{0x0030F7, "RAMIX INC."},
	{0x0030F8, "Dynapro Systems, Inc."},
	{0x0030F9, "Sollae Systems Co., Ltd."},
	{0x0030FA, "TELICA, INC."},
	{0x0030FB, "AZS Technology AG"},
	{0x0030FC, "Terawave Communications, Inc."},
	{0x0030FD, "INTEGRATED SYSTEMS DESIGN"},
	{0x0030FE, "DSA GmbH"},
	{0x0030FF, "DATAFAB SYSTEMS, INC."},
	{0x003532, "Electro-Metrics Corporation"},
	{0x003A98, "Cisco Systems"},
	{0x003A99, "Cisco Systems"},
	{0x003A9A, "Cisco Systems"},
	{0x003A9B, "Cisco Systems"},
	{0x003A9C, "Cisco Systems"},
	{0x003A9D, "NEC AccessTechnica, Ltd."},
	{0x003AAF, "BlueBit Ltd."},
	{0x003CC5, "WONWOO Engineering Co., Ltd"},
	{0x003D41, "Hatteland Computer AS"},
	{0x004000, "PCI COMPONENTES DA AMZONIA LTD"},
	{0x004001, "ZYXEL COMMUNICATIONS, INC."},
	{0x004002, "PERLE SYSTEMS LIMITED"},
	{0x004003, "Emerson Process Management Power & Water Solutions, Inc."},
	{0x004004, "ICM CO. LTD."},
	{0x004005, "ANI COMMUNICATIONS INC."},
	{0x004006, "SAMPO TECHNOLOGY CORPORATION"},
	{0x004007, "TELMAT INFORMATIQUE"},
	{0x004008, "A PLUS INFO CORPORATION"},
	{0x004009, "TACHIBANA TECTRON CO., LTD."},
	{0x00400A, "PIVOTAL TECHNOLOGIES, INC."},
	{0x00400B, "CISCO SYSTEMS, INC."},
	{0x00400C, "GENERAL MICRO SYSTEMS, INC."},
	{0x00400D, "LANNET DATA COMMUNICATIONS,LTD"},
	{0x00400E, "MEMOTEC, INC."},
	{0x00400F, "DATACOM TECHNOLOGIES"},
	{0x004010, "SONIC SYSTEMS, INC."},
	{0x004011, "ANDOVER CONTROLS CORPORATION"},
	{0x004012, "WINDATA, INC."},
	{0x004013, "NTT DATA COMM. SYSTEMS CORP."},
	{0x004014, "COMSOFT GMBH"},
	{0x004015, "ASCOM INFRASYS AG"},
	{0x004016, "ADC - Global Connectivity Solutions Division"},
	{0x004017, "Silex Technology America"},
	{0x004018, "ADOBE SYSTEMS, INC."},
	{0x004019, "AEON SYSTEMS, INC."},
	{0x00401A, "FUJI ELECTRIC CO., LTD."},
	{0x00401B, "PRINTER SYSTEMS CORP."},
	{0x00401C, "AST RESEARCH, INC."},
	{0x00401D, "INVISIBLE SOFTWARE, INC."},
	{0x00401E, "ICC"},
	{0x00401F, "COLORGRAPH LTD"},
	{0x004020, "Tyco Electronics (UK) Ltd"},
	{0x004021, "RASTER GRAPHICS"},
	{0x004022, "KLEVER COMPUTERS, INC."},
	{0x004023, "LOGIC CORPORATION"},
	{0x004024, "COMPAC INC."},
	{0x004025, "MOLECULAR DYNAMICS"},
	{0x004026, "Buffalo, Inc"},
	{0x004027, "SMC MASSACHUSETTS, INC."},
	{0x004028, "NETCOMM LIMITED"},
	{0x004029, "COMPEX"},
	{0x00402A, "CANOGA-PERKINS"},
	{0x00402B, "TRIGEM COMPUTER, INC."},
	{0x00402C, "ISIS DISTRIBUTED SYSTEMS, INC."},
	{0x00402D, "HARRIS ADACOM CORPORATION"},
	{0x00402E, "PRECISION SOFTWARE, INC."},
	{0x00402F, "XLNT DESIGNS INC."},
	{0x004030, "GK COMPUTER"},
	{0x004031, "KOKUSAI ELECTRIC CO., LTD"},
	{0x004032, "DIGITAL COMMUNICATIONS"},
	{0x004033, "ADDTRON TECHNOLOGY CO., LTD."},
	{0x004034, "BUSTEK CORPORATION"},
	{0x004035, "OPCOM"},
	{0x004036, "TRIBE COMPUTER WORKS, INC."},
	{0x004037, "SEA-ILAN, INC."},
	{0x004038, "TALENT ELECTRIC INCORPORATED"},
	{0x004039, "OPTEC DAIICHI DENKO CO., LTD."},
	{0x00403A, "IMPACT TECHNOLOGIES"},
	{0x00403B, "SYNERJET INTERNATIONAL CORP."},
	{0x00403C, "FORKS, INC."},
	{0x00403D, "TERADATA"},
	{0x00403E, "RASTER OPS CORPORATION"},
	{0x00403F, "SSANGYONG COMPUTER SYSTEMS"},
	{0x004040, "RING ACCESS, INC."},
	{0x004041, "FUJIKURA LTD."},
	{0x004042, "N.A.T. GMBH"},
	{0x004043, "Nokia Siemens Networks GmbH & Co. KG."},
	{0x004044, "QNIX COMPUTER CO., LTD."},
	{0x004045, "TWINHEAD CORPORATION"},
	{0x004046, "UDC RESEARCH LIMITED"},
	{0x004047, "WIND RIVER SYSTEMS"},
	{0x004048, "SMD INFORMATICA S.A."},
	{0x004049, "TEGIMENTA AG"},
	{0x00404A, "WEST AUSTRALIAN DEPARTMENT"},
	{0x00404B, "MAPLE COMPUTER SYSTEMS"},
	{0x00404C, "HYPERTEC PTY LTD."},
	{0x00404D, "TELECOMMUNICATIONS TECHNIQUES"},
	{0x00404E, "FLUENT, INC."},
	{0x00404F, "SPACE & NAVAL WARFARE SYSTEMS"},
	{0x004050, "IRONICS, INCORPORATED"},
	{0x004051, "GRACILIS, INC."},
	{0x004052, "STAR TECHNOLOGIES, INC."},
	{0x004053, "AMPRO COMPUTERS"},
	{0x004054, "CONNECTION MACHINES SERVICES"},
	{0x004055, "METRONIX GMBH"},
	{0x004056, "MCM JAPAN LTD."},
	{0x004057, "LOCKHEED - SANDERS"},
	{0x004058, "KRONOS, INC."},
	{0x004059, "YOSHIDA KOGYO K. K."},
	{0x00405A, "GOLDSTAR INFORMATION & COMM."},
	{0x00405B, "FUNASSET LIMITED"},
	{0x00405C, "FUTURE SYSTEMS, INC."},
	{0x00405D, "STAR-TEK, INC."},
	{0x00405E, "NORTH HILLS ISRAEL"},
	{0x00405F, "AFE COMPUTERS LTD."},
	{0x004060, "COMENDEC LTD"},
	{0x004061, "DATATECH ENTERPRISES CO., LTD."},
	{0x004062, "E-SYSTEMS, INC./GARLAND DIV."},
	{0x004063, "VIA TECHNOLOGIES, INC."},
	{0x004064, "KLA INSTRUMENTS CORPORATION"},
	{0x004065, "GTE SPACENET"},
	{0x004066, "HITACHI CABLE, LTD."},
	{0x004067, "OMNIBYTE CORPORATION"},
	{0x004068, "EXTENDED SYSTEMS"},
	{0x004069, "LEMCOM SYSTEMS, INC."},
	{0x00406A, "KENTEK INFORMATION SYSTEMS,INC"},
	{0x00406B, "SYSGEN"},
	{0x00406C, "COPERNIQUE"},
	{0x00406D, "LANCO, INC."},
	{0x00406E, "COROLLARY, INC."},
	{0x00406F, "SYNC RESEARCH INC."},
	{0x004070, "INTERWARE CO., LTD."},
	{0x004071, "ATM COMPUTER GMBH"},
	{0x004072, "Applied Innovation Inc."},
	{0x004073, "BASS ASSOCIATES"},
	{0x004074, "CABLE AND WIRELESS"},
	{0x004075, "M-TRADE (UK) LTD"},
	{0x004076, "Sun Conversion Technologies"},
	{0x004077, "MAXTON TECHNOLOGY CORPORATION"},
	{0x004078, "WEARNES AUTOMATION PTE LTD"},
	{0x004079, "JUKO MANUFACTURE COMPANY, LTD."},
	{0x00407A, "SOCIETE D'EXPLOITATION DU CNIT"},
	{0x00407B, "SCIENTIFIC ATLANTA"},
	{0x00407C, "QUME CORPORATION"},
	{0x00407D, "EXTENSION TECHNOLOGY CORP."},
	{0x00407E, "EVERGREEN SYSTEMS, INC."},
	{0x00407F, "FLIR Systems"},
	{0x004080, "ATHENIX CORPORATION"},
	{0x004081, "MANNESMANN SCANGRAPHIC GMBH"},
	{0x004082, "LABORATORY EQUIPMENT CORP."},
	{0x004083, "TDA INDUSTRIA DE PRODUTOS"},
	{0x004084, "HONEYWELL ACS"},
	{0x004085, "SAAB INSTRUMENTS AB"},
	{0x004086, "MICHELS & KLEBERHOFF COMPUTER"},
	{0x004087, "UBITREX CORPORATION"},
	{0x004088, "MOBIUS TECHNOLOGIES, INC."},
	{0x004089, "MEIDENSHA CORPORATION"},
	{0x00408A, "TPS TELEPROCESSING SYS. GMBH"},
	{0x00408B, "RAYLAN CORPORATION"},
	{0x00408C, "AXIS COMMUNICATIONS AB"},
	{0x00408D, "THE GOODYEAR TIRE & RUBBER CO."},
	{0x00408E, "DIGILOG, INC."},
	{0x00408F, "WM-DATA MINFO AB"},
	{0x004090, "ANSEL COMMUNICATIONS"},
	{0x004091, "PROCOMP INDUSTRIA ELETRONICA"},
	{0x004092, "ASP COMPUTER PRODUCTS, INC."},
	{0x004093, "PAXDATA NETWORKS LTD."},
	{0x004094, "SHOGRAPHICS, INC."},
	{0x004095, "R.P.T. INTERGROUPS INT'L LTD."},
	{0x004096, "Cisco Systems, Inc."},
	{0x004097, "DATEX DIVISION OF"},
	{0x004098, "DRESSLER GMBH & CO."},
	{0x004099, "NEWGEN SYSTEMS CORP."},
	{0x00409A, "NETWORK EXPRESS, INC."},
	{0x00409B, "HAL COMPUTER SYSTEMS INC."},
	{0x00409C, "TRANSWARE"},
	{0x00409D, "DIGIBOARD, INC."},
	{0x00409E, "CONCURRENT TECHNOLOGIES  LTD."},
	{0x00409F, "LANCAST/CASAT TECHNOLOGY, INC."},
	{0x0040A0, "GOLDSTAR CO., LTD."},
	{0x0040A1, "ERGO COMPUTING"},
	{0x0040A2, "KINGSTAR TECHNOLOGY INC."},
	{0x0040A3, "MICROUNITY SYSTEMS ENGINEERING"},
	{0x0040A4, "ROSE ELECTRONICS"},
	{0x0040A5, "CLINICOMP INTL."},
	{0x0040A6, "Cray, Inc."},
	{0x0040A7, "ITAUTEC PHILCO S.A."},
	{0x0040A8, "IMF INTERNATIONAL LTD."},
	{0x0040A9, "DATACOM INC."},
	{0x0040AA, "VALMET AUTOMATION INC."},
	{0x0040AB, "ROLAND DG CORPORATION"},
	{0x0040AC, "SUPER WORKSTATION, INC."},
	{0x0040AD, "SMA REGELSYSTEME GMBH"},
	{0x0040AE, "DELTA CONTROLS, INC."},
	{0x0040AF, "DIGITAL PRODUCTS, INC."},
	{0x0040B0, "BYTEX CORPORATION, ENGINEERING"},
	{0x0040B1, "CODONICS INC."},
	{0x0040B2, "SYSTEMFORSCHUNG"},
	{0x0040B3, "PAR MICROSYSTEMS CORPORATION"},
	{0x0040B4, "NEXTCOM K.K."},
	{0x0040B5, "VIDEO TECHNOLOGY COMPUTERS LTD"},
	{0x0040B6, "COMPUTERM  CORPORATION"},
	{0x0040B7, "STEALTH COMPUTER SYSTEMS"},
	{0x0040B8, "IDEA ASSOCIATES"},
	{0x0040B9, "MACQ ELECTRONIQUE SA"},
	{0x0040BA, "ALLIANT COMPUTER SYSTEMS CORP."},
	{0x0040BB, "GOLDSTAR CABLE CO., LTD."},
	{0x0040BC, "ALGORITHMICS LTD."},
	{0x0040BD, "STARLIGHT NETWORKS, INC."},
	{0x0040BE, "BOEING DEFENSE & SPACE"},
	{0x0040BF, "CHANNEL SYSTEMS INTERN'L INC."},
	{0x0040C0, "VISTA CONTROLS CORPORATION"},
	{0x0040C1, "BIZERBA-WERKE WILHEIM KRAUT"},
	{0x0040C2, "APPLIED COMPUTING DEVICES"},
	{0x0040C3, "FISCHER AND PORTER CO."},
	{0x0040C4, "KINKEI SYSTEM CORPORATION"},
	{0x0040C5, "MICOM COMMUNICATIONS INC."},
	{0x0040C6, "FIBERNET RESEARCH, INC."},
	{0x0040C7, "RUBY TECH CORPORATION"},
	{0x0040C8, "MILAN TECHNOLOGY CORPORATION"},
	{0x0040C9, "NCUBE"},
	{0x0040CA, "FIRST INTERNAT'L COMPUTER, INC"},
	{0x0040CB, "LANWAN TECHNOLOGIES"},
	{0x0040CC, "SILCOM MANUF'G TECHNOLOGY INC."},
	{0x0040CD, "TERA MICROSYSTEMS, INC."},
	{0x0040CE, "NET-SOURCE, INC."},
	{0x0040CF, "STRAWBERRY TREE, INC."},
	{0x0040D0, "MITAC INTERNATIONAL CORP."},
	{0x0040D1, "FUKUDA DENSHI CO., LTD."},
	{0x0040D2, "PAGINE CORPORATION"},
	{0x0040D3, "KIMPSION INTERNATIONAL CORP."},
	{0x0040D4, "GAGE TALKER CORP."},
	{0x0040D5, "Sartorius Mechatronics T&H GmbH "},
	{0x0040D6, "LOCAMATION B.V."},
	{0x0040D7, "STUDIO GEN INC."},
	{0x0040D8, "OCEAN OFFICE AUTOMATION LTD."},
	{0x0040D9, "AMERICAN MEGATRENDS INC."},
	{0x0040DA, "TELSPEC LTD"},
	{0x0040DB, "ADVANCED TECHNICAL SOLUTIONS"},
	{0x0040DC, "TRITEC ELECTRONIC GMBH"},
	{0x0040DD, "HONG TECHNOLOGIES"},
	{0x0040DE, "ELETTRONICA SAN GIORGIO"},
	{0x0040DF, "DIGALOG SYSTEMS, INC."},
	{0x0040E0, "ATOMWIDE LTD."},
	{0x0040E1, "MARNER INTERNATIONAL, INC."},
	{0x0040E2, "MESA RIDGE TECHNOLOGIES, INC."},
	{0x0040E3, "QUIN SYSTEMS LTD"},
	{0x0040E4, "E-M TECHNOLOGY, INC."},
	{0x0040E5, "SYBUS CORPORATION"},
	{0x0040E6, "C.A.E.N."},
	{0x0040E7, "ARNOS INSTRUMENTS & COMPUTER"},
	{0x0040E8, "CHARLES RIVER DATA SYSTEMS,INC"},
	{0x0040E9, "ACCORD SYSTEMS, INC."},
	{0x0040EA, "PLAIN TREE SYSTEMS INC"},
	{0x0040EB, "MARTIN MARIETTA CORPORATION"},
	{0x0040EC, "MIKASA SYSTEM ENGINEERING"},
	{0x0040ED, "NETWORK CONTROLS INT'NATL INC."},
	{0x0040EE, "OPTIMEM"},
	{0x0040EF, "HYPERCOM, INC."},
	{0x0040F0, "MICRO SYSTEMS, INC."},
	{0x0040F1, "CHUO ELECTRONICS CO., LTD."},
	{0x0040F2, "JANICH & KLASS COMPUTERTECHNIK"},
	{0x0040F3, "NETCOR"},
	{0x0040F4, "CAMEO COMMUNICATIONS, INC."},
	{0x0040F5, "OEM ENGINES"},
	{0x0040F6, "KATRON COMPUTERS INC."},
	{0x0040F7, "Polaroid Corporation"},
	{0x0040F8, "SYSTEMHAUS DISCOM"},
	{0x0040F9, "COMBINET"},
	{0x0040FA, "MICROBOARDS, INC."},
	{0x0040FB, "CASCADE COMMUNICATIONS CORP."},
	{0x0040FC, "IBR COMPUTER TECHNIK GMBH"},
	{0x0040FD, "LXE"},
	{0x0040FE, "SYMPLEX COMMUNICATIONS"},
	{0x0040FF, "TELEBIT CORPORATION"},
	{0x004252, "RLX Technologies"},
	{0x004501, "Versus Technology, Inc."},
	{0x005000, "NEXO COMMUNICATIONS, INC."},
	{0x005001, "YAMASHITA SYSTEMS CORP."},
	{0x005002, "OMNISEC AG"},
	{0x005003, "GRETAG MACBETH AG"},
	{0x005004, "3COM CORPORATION"},
	{0x005006, "TAC AB"},
	{0x005007, "SIEMENS TELECOMMUNICATION SYSTEMS LIMITED"},
	{0x005008, "TIVA MICROCOMPUTER CORP. (TMC)"},
	{0x005009, "PHILIPS BROADBAND NETWORKS"},
	{0x00500A, "IRIS TECHNOLOGIES, INC."},
	{0x00500B, "CISCO SYSTEMS, INC."},
	{0x00500C, "e-Tek Labs, Inc."},
	{0x00500D, "SATORI ELECTORIC CO., LTD."},
	{0x00500E, "CHROMATIS NETWORKS, INC."},
	{0x00500F, "CISCO SYSTEMS, INC."},
	{0x005010, "NovaNET Learning, Inc."},
	{0x005012, "CBL - GMBH"},
	{0x005013, "Chaparral Network Storage"},
	{0x005014, "CISCO SYSTEMS, INC."},
	{0x005015, "BRIGHT STAR ENGINEERING"},
	{0x005016, "SST/WOODHEAD INDUSTRIES"},
	{0x005017, "RSR S.R.L."},
	{0x005018, "AMIT, Inc."},
	{0x005019, "SPRING TIDE NETWORKS, INC."},
	{0x00501A, "IQinVision"},
	{0x00501B, "ABL CANADA, INC."},
	{0x00501C, "JATOM SYSTEMS, INC."},
	{0x00501E, "Miranda Technologies, Inc."},
	{0x00501F, "MRG SYSTEMS, LTD."},
	{0x005020, "MEDIASTAR CO., LTD."},
	{0x005021, "EIS INTERNATIONAL, INC."},
	{0x005022, "ZONET TECHNOLOGY, INC."},
	{0x005023, "PG DESIGN ELECTRONICS, INC."},
	{0x005024, "NAVIC SYSTEMS, INC."},
	{0x005026, "COSYSTEMS, INC."},
	{0x005027, "GENICOM CORPORATION"},
	{0x005028, "AVAL COMMUNICATIONS"},
	{0x005029, "1394 PRINTER WORKING GROUP"},
	{0x00502A, "CISCO SYSTEMS, INC."},
	{0x00502B, "GENRAD LTD."},
	{0x00502C, "SOYO COMPUTER, INC."},
	{0x00502D, "ACCEL, INC."},
	{0x00502E, "CAMBEX CORPORATION"},
	{0x00502F, "TollBridge Technologies, Inc."},
	{0x005030, "FUTURE PLUS SYSTEMS"},
	{0x005031, "AEROFLEX LABORATORIES, INC."},
	{0x005032, "PICAZO COMMUNICATIONS, INC."},
	{0x005033, "MAYAN NETWORKS"},
	{0x005036, "NETCAM, LTD."},
	{0x005037, "KOGA ELECTRONICS CO."},
	{0x005038, "DAIN TELECOM CO., LTD."},
	{0x005039, "MARINER NETWORKS"},
	{0x00503A, "DATONG ELECTRONICS LTD."},
	{0x00503B, "MEDIAFIRE CORPORATION"},
	{0x00503C, "TSINGHUA NOVEL ELECTRONICS"},
	{0x00503E, "CISCO SYSTEMS, INC."},
	{0x00503F, "ANCHOR GAMES"},
	{0x005040, "Panasonic Electric Works Co., Ltd."},
	{0x005041, "Coretronic Corporation"},
	{0x005042, "SCI MANUFACTURING SINGAPORE PTE, LTD."},
	{0x005043, "MARVELL SEMICONDUCTOR, INC."},
	{0x005044, "ASACA CORPORATION"},
	{0x005045, "RIOWORKS SOLUTIONS, INC."},
	{0x005046, "MENICX INTERNATIONAL CO., LTD."},
	{0x005048, "INFOLIBRIA"},
	{0x005049, "Arbor Networks Inc"},
	{0x00504A, "ELTECO A.S."},
	{0x00504B, "BARCONET N.V."},
	{0x00504C, "Galil Motion Control"},
	{0x00504D, "Tokyo Electron Device Limited"},
	{0x00504E, "SIERRA MONITOR CORP."},
	{0x00504F, "OLENCOM ELECTRONICS"},
	{0x005050, "CISCO SYSTEMS, INC."},
	{0x005051, "IWATSU ELECTRIC CO., LTD."},
	{0x005052, "TIARA NETWORKS, INC."},
	{0x005053, "CISCO SYSTEMS, INC."},
	{0x005054, "CISCO SYSTEMS, INC."},
	{0x005055, "DOMS A/S"},
	{0x005056, "VMware, Inc."},
	{0x005057, "BROADBAND ACCESS SYSTEMS"},
	{0x005058, "VegaStream Group Limted"},
	{0x005059, "iBAHN"},
	{0x00505A, "NETWORK ALCHEMY, INC."},
	{0x00505B, "KAWASAKI LSI U.S.A., INC."},
	{0x00505C, "TUNDO CORPORATION"},
	{0x00505E, "DIGITEK MICROLOGIC S.A."},
	{0x00505F, "BRAND INNOVATORS"},
	{0x005060, "TANDBERG TELECOM AS"},
	{0x005062, "KOUWELL ELECTRONICS CORP.  **"},
	{0x005063, "OY COMSEL SYSTEM AB"},
	{0x005064, "CAE ELECTRONICS"},
	{0x005065, "TDK-Lambda Corporation"},
	{0x005066, "AtecoM GmbH advanced telecomunication modules"},
	{0x005067, "AEROCOMM, INC."},
	{0x005068, "ELECTRONIC INDUSTRIES ASSOCIATION"},
	{0x005069, "PixStream Incorporated"},
	{0x00506A, "EDEVA, INC."},
	{0x00506B, "SPX-ATEG"},
	{0x00506C, "Beijer Electronics Products AB"},
	{0x00506D, "VIDEOJET SYSTEMS"},
	{0x00506E, "CORDER ENGINEERING CORPORATION"},
	{0x00506F, "G-CONNECT"},
	{0x005070, "CHAINTECH COMPUTER CO., LTD."},
	{0x005071, "AIWA CO., LTD."},
	{0x005072, "CORVIS CORPORATION"},
	{0x005073, "CISCO SYSTEMS, INC."},
	{0x005074, "ADVANCED HI-TECH CORP."},
	{0x005075, "KESTREL SOLUTIONS"},
	{0x005076, "IBM"},
	{0x005077, "PROLIFIC TECHNOLOGY, INC."},
	{0x005078, "MEGATON HOUSE, LTD."},
	{0x00507A, "XPEED, INC."},
	{0x00507B, "MERLOT COMMUNICATIONS"},
	{0x00507C, "VIDEOCON AG"},
	{0x00507D, "IFP"},
	{0x00507E, "NEWER TECHNOLOGY"},
	{0x00507F, "DrayTek Corp."},
	{0x005080, "CISCO SYSTEMS, INC."},
	{0x005081, "MURATA MACHINERY, LTD."},
	{0x005082, "FORESSON CORPORATION"},
	{0x005083, "GILBARCO, INC."},
	{0x005084, "ATL PRODUCTS"},
	{0x005086, "TELKOM SA, LTD."},
	{0x005087, "TERASAKI ELECTRIC CO., LTD."},
	{0x005088, "AMANO CORPORATION"},
	{0x005089, "SAFETY MANAGEMENT SYSTEMS"},
	{0x00508B, "Hewlett Packard"},
	{0x00508C, "RSI SYSTEMS"},
	{0x00508D, "ABIT COMPUTER CORPORATION"},
	{0x00508E, "OPTIMATION, INC."},
	{0x00508F, "ASITA TECHNOLOGIES INT'L LTD."},
	{0x005090, "DCTRI"},
	{0x005091, "NETACCESS, INC."},
	{0x005092, "RIGAKU INDUSTRIAL CORPORATION"},
	{0x005093, "BOEING"},
	{0x005094, "PACE MICRO TECHNOLOGY PLC"},
	{0x005095, "PERACOM NETWORKS"},
	{0x005096, "SALIX TECHNOLOGIES, INC."},
	{0x005097, "MMC-EMBEDDED COMPUTERTECHNIK GmbH"},
	{0x005098, "GLOBALOOP, LTD."},
	{0x005099, "3COM EUROPE, LTD."},
	{0x00509A, "TAG ELECTRONIC SYSTEMS"},
	{0x00509B, "SWITCHCORE AB"},
	{0x00509C, "BETA RESEARCH"},
	{0x00509D, "THE INDUSTREE B.V."},
	{0x00509E, "Les Technologies SoftAcoustik Inc."},
	{0x00509F, "HORIZON COMPUTER"},
	{0x0050A0, "DELTA COMPUTER SYSTEMS, INC."},
	{0x0050A1, "CARLO GAVAZZI, INC."},
	{0x0050A2, "CISCO SYSTEMS, INC."},
	{0x0050A3, "TransMedia Communications, Inc."},
	{0x0050A4, "IO TECH, INC."},
	{0x0050A5, "CAPITOL BUSINESS SYSTEMS, LTD."},
	{0x0050A6, "OPTRONICS"},
	{0x0050A7, "CISCO SYSTEMS, INC."},
	{0x0050A8, "OpenCon Systems, Inc."},
	{0x0050A9, "MOLDAT WIRELESS TECHNOLGIES"},
	{0x0050AA, "KONICA MINOLTA HOLDINGS, INC."},
	{0x0050AB, "NALTEC, Inc."},
	{0x0050AC, "MAPLE COMPUTER CORPORATION"},
	{0x0050AD, "CommUnique Wireless Corp."},
	{0x0050AE, "IWAKI ELECTRONICS CO., LTD."},
	{0x0050AF, "INTERGON, INC."},
	{0x0050B0, "TECHNOLOGY ATLANTA CORPORATION"},
	{0x0050B1, "GIDDINGS & LEWIS"},
	{0x0050B2, "BRODEL AUTOMATION"},
	{0x0050B3, "VOICEBOARD CORPORATION"},
	{0x0050B4, "SATCHWELL CONTROL SYSTEMS, LTD"},
	{0x0050B5, "FICHET-BAUCHE"},
	{0x0050B6, "GOOD WAY IND. CO., LTD."},
	{0x0050B7, "BOSER TECHNOLOGY CO., LTD."},
	{0x0050B8, "INOVA COMPUTERS GMBH & CO. KG"},
	{0x0050B9, "XITRON TECHNOLOGIES, INC."},
	{0x0050BA, "D-LINK"},
	{0x0050BB, "CMS TECHNOLOGIES"},
	{0x0050BC, "HAMMER STORAGE SOLUTIONS"},
	{0x0050BD, "CISCO SYSTEMS, INC."},
	{0x0050BE, "FAST MULTIMEDIA AG"},
	{0x0050BF, "MOTOTECH INC."},
	{0x0050C0, "GATAN, INC."},
	{0x0050C1, "GEMFLEX NETWORKS, LTD."},
	{0x0050C2, "IEEE REGISTRATION AUTHORITY"},
	{0x0050C4, "IMD"},
	{0x0050C5, "ADS Technologies, Inc"},
	{0x0050C6, "LOOP TELECOMMUNICATION INTERNATIONAL, INC."},
	{0x0050C8, "ADDONICS COMMUNICATIONS, INC."},
	{0x0050C9, "MASPRO DENKOH CORP."},
	{0x0050CA, "NET TO NET TECHNOLOGIES"},
	{0x0050CB, "JETTER"},
	{0x0050CC, "XYRATEX"},
	{0x0050CD, "DIGIANSWER A/S"},
	{0x0050CE, "LG INTERNATIONAL CORP."},
	{0x0050CF, "VANLINK COMMUNICATION TECHNOLOGY RESEARCH INSTITUTE"},
	{0x0050D0, "MINERVA SYSTEMS"},
	{0x0050D1, "CISCO SYSTEMS, INC."},
	{0x0050D2, "CMC Electronics Inc"},
	{0x0050D3, "DIGITAL AUDIO PROCESSING PTY. LTD."},
	{0x0050D4, "JOOHONG INFORMATION &"},
	{0x0050D5, "AD SYSTEMS CORP."},
	{0x0050D6, "ATLAS COPCO TOOLS AB"},
	{0x0050D7, "TELSTRAT"},
	{0x0050D8, "UNICORN COMPUTER CORP."},
	{0x0050D9, "ENGETRON-ENGENHARIA ELETRONICA IND. e COM. LTDA"},
	{0x0050DA, "3COM CORPORATION"},
	{0x0050DB, "CONTEMPORARY CONTROL"},
	{0x0050DC, "TAS TELEFONBAU A. SCHWABE GMBH & CO. KG"},
	{0x0050DD, "SERRA SOLDADURA, S.A."},
	{0x0050DE, "SIGNUM SYSTEMS CORP."},
	{0x0050DF, "AirFiber, Inc."},
	{0x0050E1, "NS TECH ELECTRONICS SDN BHD"},
	{0x0050E2, "CISCO SYSTEMS, INC."},
	{0x0050E3, "Motorola, Inc."},
	{0x0050E4, "APPLE COMPUTER, INC."},
	{0x0050E6, "HAKUSAN CORPORATION"},
	{0x0050E7, "PARADISE INNOVATIONS (ASIA)"},
	{0x0050E8, "NOMADIX INC."},
	{0x0050EA, "XEL COMMUNICATIONS, INC."},
	{0x0050EB, "ALPHA-TOP CORPORATION"},
	{0x0050EC, "OLICOM A/S"},
	{0x0050ED, "ANDA NETWORKS"},
	{0x0050EE, "TEK DIGITEL CORPORATION"},
	{0x0050EF, "SPE Systemhaus GmbH"},
	{0x0050F0, "CISCO SYSTEMS, INC."},
	{0x0050F1, "LIBIT SIGNAL PROCESSING, LTD."},
	{0x0050F2, "MICROSOFT CORP."},
	{0x0050F3, "GLOBAL NET INFORMATION CO., Ltd."},
	{0x0050F4, "SIGMATEK GMBH & CO. KG"},
	{0x0050F6, "PAN-INTERNATIONAL INDUSTRIAL CORP."},
	{0x0050F7, "VENTURE MANUFACTURING (SINGAPORE) LTD."},
	{0x0050F8, "ENTREGA TECHNOLOGIES, INC."},
	{0x0050F9, "SENSORMATIC ACD"},
	{0x0050FA, "OXTEL, LTD."},
	{0x0050FB, "VSK ELECTRONICS"},
	{0x0050FC, "EDIMAX TECHNOLOGY CO., LTD."},
	{0x0050FD, "VISIONCOMM CO., LTD."},
	{0x0050FE, "PCTVnet ASA"},
	{0x0050FF, "HAKKO ELECTRONICS CO., LTD."},
	{0x005218, "Wuxi Keboda Electron Co.Ltd"},
	{0x006000, "XYCOM INC."},
	{0x006001, "InnoSys, Inc."},
	{0x006002, "SCREEN SUBTITLING SYSTEMS, LTD"},
	{0x006003, "TERAOKA WEIGH SYSTEM PTE, LTD."},
	{0x006004, "COMPUTADORES MODULARES SA"},
	{0x006005, "FEEDBACK DATA LTD."},
	{0x006006, "SOTEC CO., LTD"},
	{0x006007, "ACRES GAMING, INC."},
	{0x006008, "3COM CORPORATION"},
	{0x006009, "CISCO SYSTEMS, INC."},
	{0x00600A, "SORD COMPUTER CORPORATION"},
	{0x00600B, "LOGWARE GmbH"},
	{0x00600C, "APPLIED DATA SYSTEMS, INC."},
	{0x00600D, "Digital Logic GmbH"},
	{0x00600E, "WAVENET INTERNATIONAL, INC."},
	{0x00600F, "WESTELL, INC."},
	{0x006010, "NETWORK MACHINES, INC."},
	{0x006011, "CRYSTAL SEMICONDUCTOR CORP."},
	{0x006012, "POWER COMPUTING CORPORATION"},
	{0x006013, "NETSTAL MASCHINEN AG"},
	{0x006014, "EDEC CO., LTD."},
	{0x006015, "NET2NET CORPORATION"},
	{0x006016, "CLARIION"},
	{0x006017, "TOKIMEC INC."},
	{0x006018, "STELLAR ONE CORPORATION"},
	{0x006019, "Roche Diagnostics"},
	{0x00601A, "KEITHLEY INSTRUMENTS"},
	{0x00601B, "MESA ELECTRONICS"},
	{0x00601C, "TELXON CORPORATION"},
	{0x00601D, "LUCENT TECHNOLOGIES"},
	{0x00601E, "SOFTLAB, INC."},
	{0x00601F, "STALLION TECHNOLOGIES"},
	{0x006020, "PIVOTAL NETWORKING, INC."},
	{0x006021, "DSC CORPORATION"},
	{0x006022, "VICOM SYSTEMS, INC."},
	{0x006023, "PERICOM SEMICONDUCTOR CORP."},
	{0x006024, "GRADIENT TECHNOLOGIES, INC."},
	{0x006025, "ACTIVE IMAGING PLC"},
	{0x006026, "VIKING COMPONENTS, INC."},
	{0x006027, "Superior Modular Products"},
	{0x006028, "MACROVISION CORPORATION"},
	{0x006029, "CARY PERIPHERALS INC."},
	{0x00602A, "SYMICRON COMPUTER COMMUNICATIONS, LTD."},
	{0x00602B, "PEAK AUDIO"},
	{0x00602C, "LINX Data Terminals, Inc."},
	{0x00602D, "ALERTON TECHNOLOGIES, INC."},
	{0x00602E, "CYCLADES CORPORATION"},
	{0x00602F, "CISCO SYSTEMS, INC."},
	{0x006030, "VILLAGE TRONIC ENTWICKLUNG"},
	{0x006031, "HRK SYSTEMS"},
	{0x006032, "I-CUBE, INC."},
	{0x006033, "ACUITY IMAGING, INC."},
	{0x006034, "ROBERT BOSCH GmbH"},
	{0x006035, "DALLAS SEMICONDUCTOR, INC."},
	{0x006036, "AIT Austrian Institute of Technology GmbH"},
	{0x006037, "NXP Semiconductors"},
	{0x006038, "Nortel Networks"},
	{0x006039, "SanCom Technology, Inc."},
	{0x00603A, "QUICK CONTROLS LTD."},
	{0x00603B, "AMTEC spa"},
	{0x00603C, "HAGIWARA SYS-COM CO., LTD."},
	{0x00603D, "3CX"},
	{0x00603E, "CISCO SYSTEMS, INC."},
	{0x00603F, "PATAPSCO DESIGNS"},
	{0x006040, "NETRO CORP."},
	{0x006041, "Yokogawa Electric Corporation"},
	{0x006042, "TKS (USA), INC."},
	{0x006043, "iDirect, INC."},
	{0x006044, "LITTON/POLY-SCIENTIFIC"},
	{0x006045, "PATHLIGHT TECHNOLOGIES"},
	{0x006046, "VMETRO, INC."},
	{0x006047, "CISCO SYSTEMS, INC."},
	{0x006048, "EMC CORPORATION"},
	{0x006049, "VINA TECHNOLOGIES"},
	{0x00604A, "SAIC IDEAS GROUP"},
	{0x00604B, "Safe-com GmbH & Co. KG"},
	{0x00604C, "SAGEM COMMUNICATION"},
	{0x00604D, "MMC NETWORKS, INC."},
	{0x00604E, "CYCLE COMPUTER CORPORATION, INC."},
	{0x00604F, "SUZUKI MFG. CO., LTD."},
	{0x006050, "INTERNIX INC."},
	{0x006051, "QUALITY SEMICONDUCTOR"},
	{0x006052, "PERIPHERALS ENTERPRISE CO., Ltd."},
	{0x006053, "TOYODA MACHINE WORKS, LTD."},
	{0x006054, "CONTROLWARE GMBH"},
	{0x006055, "CORNELL UNIVERSITY"},
	{0x006056, "NETWORK TOOLS, INC."},
	{0x006057, "MURATA MANUFACTURING CO., LTD."},
	{0x006058, "COPPER MOUNTAIN COMMUNICATIONS, INC."},
	{0x006059, "TECHNICAL COMMUNICATIONS CORP."},
	{0x00605A, "CELCORE, INC."},
	{0x00605B, "IntraServer Technology, Inc."},
	{0x00605C, "CISCO SYSTEMS, INC."},
	{0x00605D, "SCANIVALVE CORP."},
	{0x00605E, "LIBERTY TECHNOLOGY NETWORKING"},
	{0x00605F, "NIPPON UNISOFT CORPORATION"},
	{0x006060, "DAWNING TECHNOLOGIES, INC."},
	{0x006061, "WHISTLE COMMUNICATIONS CORP."},
	{0x006062, "TELESYNC, INC."},
	{0x006063, "PSION DACOM PLC."},
	{0x006064, "NETCOMM LIMITED"},
	{0x006065, "BERNECKER & RAINER INDUSTRIE-ELEKTRONIC GmbH"},
	{0x006066, "LACROIX TECHNOLGIE"},
	{0x006067, "ACER NETXUS INC."},
	{0x006068, "Dialogic Corporation"},
	{0x006069, "Brocade Communications Systems, Inc."},
	{0x00606A, "MITSUBISHI WIRELESS COMMUNICATIONS. INC."},
	{0x00606B, "Synclayer Inc."},
	{0x00606C, "ARESCOM"},
	{0x00606D, "DIGITAL EQUIPMENT CORP."},
	{0x00606E, "DAVICOM SEMICONDUCTOR, INC."},
	{0x00606F, "CLARION CORPORATION OF AMERICA"},
	{0x006070, "CISCO SYSTEMS, INC."},
	{0x006071, "MIDAS LAB, INC."},
	{0x006072, "VXL INSTRUMENTS, LIMITED"},
	{0x006073, "REDCREEK COMMUNICATIONS, INC."},
	{0x006074, "QSC AUDIO PRODUCTS"},
	{0x006075, "PENTEK, INC."},
	{0x006076, "SCHLUMBERGER TECHNOLOGIES RETAIL PETROLEUM SYSTEMS"},
	{0x006077, "PRISA NETWORKS"},
	{0x006078, "POWER MEASUREMENT LTD."},
	{0x006079, "Mainstream Data, Inc."},
	{0x00607A, "DVS GmbH"},
	{0x00607B, "FORE SYSTEMS, INC."},
	{0x00607C, "WaveAccess, Ltd."},
	{0x00607D, "SENTIENT NETWORKS INC."},
	{0x00607E, "GIGALABS, INC."},
	{0x00607F, "AURORA TECHNOLOGIES, INC."},
	{0x006080, "MICROTRONIX DATACOM LTD."},
	{0x006081, "TV/COM INTERNATIONAL"},
	{0x006082, "NOVALINK TECHNOLOGIES, INC."},
	{0x006083, "CISCO SYSTEMS, INC."},
	{0x006084, "DIGITAL VIDEO"},
	{0x006085, "Storage Concepts"},
	{0x006086, "LOGIC REPLACEMENT TECH. LTD."},
	{0x006087, "KANSAI ELECTRIC CO., LTD."},
	{0x006088, "WHITE MOUNTAIN DSP, INC."},
	{0x006089, "XATA"},
	{0x00608A, "CITADEL COMPUTER"},
	{0x00608B, "ConferTech International"},
	{0x00608C, "3COM CORPORATION"},
	{0x00608D, "UNIPULSE CORP."},
	{0x00608E, "HE ELECTRONICS, TECHNOLOGIE & SYSTEMTECHNIK GmbH"},
	{0x00608F, "TEKRAM TECHNOLOGY CO., LTD."},
	{0x006090, "ABLE COMMUNICATIONS, INC."},
	{0x006091, "FIRST PACIFIC NETWORKS, INC."},
	{0x006092, "MICRO/SYS, INC."},
	{0x006093, "VARIAN"},
	{0x006094, "IBM CORP."},
	{0x006095, "ACCU-TIME SYSTEMS, INC."},
	{0x006096, "T.S. MICROTECH INC."},
	{0x006097, "3COM CORPORATION"},
	{0x006098, "HT COMMUNICATIONS"},
	{0x006099, "SBE, Inc."},
	{0x00609A, "NJK TECHNO CO."},
	{0x00609B, "ASTRO-MED, INC."},
	{0x00609C, "Perkin-Elmer Incorporated"},
	{0x00609D, "PMI FOOD EQUIPMENT GROUP"},
	{0x00609E, "ASC X3 - INFORMATION TECHNOLOGY STANDARDS SECRETARIATS"},
	{0x00609F, "PHAST CORPORATION"},
	{0x0060A0, "SWITCHED NETWORK TECHNOLOGIES, INC."},
	{0x0060A1, "VPNet, Inc."},
	{0x0060A2, "NIHON UNISYS LIMITED CO."},
	{0x0060A3, "CONTINUUM TECHNOLOGY CORP."},
	{0x0060A4, "GRINAKER SYSTEM TECHNOLOGIES"},
	{0x0060A5, "PERFORMANCE TELECOM CORP."},
	{0x0060A6, "PARTICLE MEASURING SYSTEMS"},
	{0x0060A7, "MICROSENS GmbH & CO. KG"},
	{0x0060A8, "TIDOMAT AB"},
	{0x0060A9, "GESYTEC MbH"},
	{0x0060AA, "INTELLIGENT DEVICES INC. (IDI)"},
	{0x0060AB, "LARSCOM INCORPORATED"},
	{0x0060AC, "RESILIENCE CORPORATION"},
	{0x0060AD, "MegaChips Corporation"},
	{0x0060AE, "TRIO INFORMATION SYSTEMS AB"},
	{0x0060AF, "PACIFIC MICRO DATA, INC."},
	{0x0060B0, "HEWLETT-PACKARD CO."},
	{0x0060B1, "INPUT/OUTPUT, INC."},
	{0x0060B2, "PROCESS CONTROL CORP."},
	{0x0060B3, "Z-COM, INC."},
	{0x0060B4, "GLENAYRE R&D INC."},
	{0x0060B5, "KEBA GmbH"},
	{0x0060B6, "LAND COMPUTER CO., LTD."},
	{0x0060B7, "CHANNELMATIC, INC."},
	{0x0060B8, "CORELIS Inc."},
	{0x0060B9, "NEC Infrontia Corporation"},
	{0x0060BA, "SAHARA NETWORKS, INC."},
	{0x0060BB, "CABLETRON - NETLINK, INC."},
	{0x0060BC, "KeunYoung Electronics & Communication Co., Ltd."},
	{0x0060BD, "HUBBELL-PULSECOM"},
	{0x0060BE, "WEBTRONICS"},
	{0x0060BF, "MACRAIGOR SYSTEMS, INC."},
	{0x0060C0, "Nera Networks AS"},
	{0x0060C1, "WaveSpan Corporation"},
	{0x0060C2, "MPL AG"},
	{0x0060C3, "NETVISION CORPORATION"},
	{0x0060C4, "SOLITON SYSTEMS K.K."},
	{0x0060C5, "ANCOT CORP."},
	{0x0060C6, "DCS AG"},
	{0x0060C7, "AMATI COMMUNICATIONS CORP."},
	{0x0060C8, "KUKA WELDING SYSTEMS & ROBOTS"},
	{0x0060C9, "ControlNet, Inc."},
	{0x0060CA, "HARMONIC SYSTEMS INCORPORATED"},
	{0x0060CB, "HITACHI ZOSEN CORPORATION"},
	{0x0060CC, "EMTRAK, INCORPORATED"},
	{0x0060CD, "VideoServer, Inc."},
	{0x0060CE, "ACCLAIM COMMUNICATIONS"},
	{0x0060CF, "ALTEON NETWORKS, INC."},
	{0x0060D0, "SNMP RESEARCH INCORPORATED"},
	{0x0060D1, "CASCADE COMMUNICATIONS"},
	{0x0060D2, "LUCENT TECHNOLOGIES TAIWAN TELECOMMUNICATIONS CO., LTD."},
	{0x0060D3, "AT&T"},
	{0x0060D4, "ELDAT COMMUNICATION LTD."},
	{0x0060D5, "MIYACHI TECHNOS CORP."},
	{0x0060D6, "NovAtel Wireless Technologies Ltd."},
	{0x0060D7, "ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE (EPFL)"},
	{0x0060D8, "ELMIC SYSTEMS, INC."},
	{0x0060D9, "TRANSYS NETWORKS INC."},
	{0x0060DA, "JBM ELECTRONICS CO."},
	{0x0060DB, "NTP ELEKTRONIK A/S"},
	{0x0060DC, "Toyo Network Systems  & System Integration Co. LTD"},
	{0x0060DD, "MYRICOM, INC."},
	{0x0060DE, "Kayser-Threde GmbH"},
	{0x0060DF, "Brocade Communications Systems, Inc."},
	{0x0060E0, "AXIOM TECHNOLOGY CO., LTD."},
	{0x0060E1, "ORCKIT COMMUNICATIONS LTD."},
	{0x0060E2, "QUEST ENGINEERING & DEVELOPMENT"},
	{0x0060E3, "ARBIN INSTRUMENTS"},
	{0x0060E4, "COMPUSERVE, INC."},
	{0x0060E5, "FUJI AUTOMATION CO., LTD."},
	{0x0060E6, "SHOMITI SYSTEMS INCORPORATED"},
	{0x0060E7, "RANDATA"},
	{0x0060E8, "HITACHI COMPUTER PRODUCTS (AMERICA), INC."},
	{0x0060E9, "ATOP TECHNOLOGIES, INC."},
	{0x0060EA, "StreamLogic"},
	{0x0060EB, "FOURTHTRACK SYSTEMS"},
	{0x0060EC, "HERMARY OPTO ELECTRONICS INC."},
	{0x0060ED, "RICARDO TEST AUTOMATION LTD."},
	{0x0060EE, "APOLLO"},
	{0x0060EF, "FLYTECH TECHNOLOGY CO., LTD."},
	{0x0060F0, "JOHNSON & JOHNSON MEDICAL, INC"},
	{0x0060F1, "EXP COMPUTER, INC."},
	{0x0060F2, "LASERGRAPHICS, INC."},
	{0x0060F3, "Performance Analysis Broadband, Spirent plc"},
	{0x0060F4, "ADVANCED COMPUTER SOLUTIONS, Inc."},
	{0x0060F5, "ICON WEST, INC."},
	{0x0060F6, "NEXTEST COMMUNICATIONS PRODUCTS, INC."},
	{0x0060F7, "DATAFUSION SYSTEMS"},
	{0x0060F8, "Loran International Technologies Inc."},
	{0x0060F9, "DIAMOND LANE COMMUNICATIONS"},
	{0x0060FA, "EDUCATIONAL TECHNOLOGY RESOURCES, INC."},
	{0x0060FB, "PACKETEER, INC."},
	{0x0060FC, "CONSERVATION THROUGH INNOVATION LTD."},
	{0x0060FD, "NetICs, Inc."},
	{0x0060FE, "LYNX SYSTEM DEVELOPERS, INC."},
	{0x0060FF, "QuVis, Inc."},
	{0x006440, "Cisco Systems"},
	{0x0070B0, "M/A-COM INC. COMPANIES"},
	{0x0070B3, "DATA RECALL LTD."},
	{0x008000, "MULTITECH SYSTEMS, INC."},
	{0x008001, "PERIPHONICS CORPORATION"},
	{0x008002, "SATELCOM (UK) LTD"},
	{0x008003, "HYTEC ELECTRONICS LTD."},
	{0x008004, "ANTLOW COMMUNICATIONS, LTD."},
	{0x008005, "CACTUS COMPUTER INC."},
	{0x008006, "COMPUADD CORPORATION"},
	{0x008007, "DLOG NC-SYSTEME"},
	{0x008008, "DYNATECH COMPUTER SYSTEMS"},
	{0x008009, "JUPITER SYSTEMS, INC."},
	{0x00800A, "JAPAN COMPUTER CORP."},
	{0x00800B, "CSK CORPORATION"},
	{0x00800C, "VIDECOM LIMITED"},
	{0x00800D, "VOSSWINKEL F.U."},
	{0x00800E, "ATLANTIX CORPORATION"},
	{0x00800F, "STANDARD MICROSYSTEMS"},
	{0x008010, "COMMODORE INTERNATIONAL"},
	{0x008011, "DIGITAL SYSTEMS INT'L. INC."},
	{0x008012, "INTEGRATED MEASUREMENT SYSTEMS"},
	{0x008013, "THOMAS-CONRAD CORPORATION"},
	{0x008014, "ESPRIT SYSTEMS"},
	{0x008015, "SEIKO SYSTEMS, INC."},
	{0x008016, "WANDEL AND GOLTERMANN"},
	{0x008017, "PFU LIMITED"},
	{0x008018, "KOBE STEEL, LTD."},
	{0x008019, "DAYNA COMMUNICATIONS, INC."},
	{0x00801A, "BELL ATLANTIC"},
	{0x00801B, "KODIAK TECHNOLOGY"},
	{0x00801C, "NEWPORT SYSTEMS SOLUTIONS"},
	{0x00801D, "INTEGRATED INFERENCE MACHINES"},
	{0x00801E, "XINETRON, INC."},
	{0x00801F, "KRUPP ATLAS ELECTRONIK GMBH"},
	{0x008020, "NETWORK PRODUCTS"},
	{0x008021, "Alcatel Canada Inc."},
	{0x008022, "SCAN-OPTICS"},
	{0x008023, "INTEGRATED BUSINESS NETWORKS"},
	{0x008024, "KALPANA, INC."},
	{0x008025, "STOLLMANN GMBH"},
	{0x008026, "NETWORK PRODUCTS CORPORATION"},
	{0x008027, "ADAPTIVE SYSTEMS, INC."},
	{0x008028, "TRADPOST (HK) LTD"},
	{0x008029, "EAGLE TECHNOLOGY, INC."},
	{0x00802A, "TEST SYSTEMS & SIMULATIONS INC"},
	{0x00802B, "INTEGRATED MARKETING CO"},
	{0x00802C, "THE SAGE GROUP PLC"},
	{0x00802D, "XYLOGICS INC"},
	{0x00802E, "CASTLE ROCK COMPUTING"},
	{0x00802F, "NATIONAL INSTRUMENTS CORP."},
	{0x008030, "NEXUS ELECTRONICS"},
	{0x008031, "BASYS, CORP."},
	{0x008032, "ACCESS CO., LTD."},
	{0x008033, "FORMATION, INC."},
	{0x008034, "SMT GOUPIL"},
	{0x008035, "TECHNOLOGY WORKS, INC."},
	{0x008036, "REFLEX MANUFACTURING SYSTEMS"},
	{0x008037, "Ericsson Group"},
	{0x008038, "DATA RESEARCH & APPLICATIONS"},
	{0x008039, "ALCATEL STC AUSTRALIA"},
	{0x00803A, "VARITYPER, INC."},
	{0x00803B, "APT COMMUNICATIONS, INC."},
	{0x00803C, "TVS ELECTRONICS LTD"},
	{0x00803D, "SURIGIKEN CO.,  LTD."},
	{0x00803E, "SYNERNETICS"},
	{0x00803F, "TATUNG COMPANY"},
	{0x008040, "JOHN FLUKE MANUFACTURING CO."},
	{0x008041, "VEB KOMBINAT ROBOTRON"},
	{0x008042, "Emerson Network Power"},
	{0x008043, "NETWORLD, INC."},
	{0x008044, "SYSTECH COMPUTER CORP."},
	{0x008045, "MATSUSHITA ELECTRIC IND. CO"},
	{0x008046, "UNIVERSITY OF TORONTO"},
	{0x008047, "IN-NET CORP."},
	{0x008048, "COMPEX INCORPORATED"},
	{0x008049, "NISSIN ELECTRIC CO., LTD."},
	{0x00804A, "PRO-LOG"},
	{0x00804B, "EAGLE TECHNOLOGIES PTY.LTD."},
	{0x00804C, "CONTEC CO., LTD."},
	{0x00804D, "CYCLONE MICROSYSTEMS, INC."},
	{0x00804E, "APEX COMPUTER COMPANY"},
	{0x00804F, "DAIKIN INDUSTRIES, LTD."},
	{0x008050, "ZIATECH CORPORATION"},
	{0x008051, "FIBERMUX"},
	{0x008052, "TECHNICALLY ELITE CONCEPTS"},
	{0x008053, "INTELLICOM, INC."},
	{0x008054, "FRONTIER TECHNOLOGIES CORP."},
	{0x008055, "FERMILAB"},
	{0x008056, "SPHINX ELEKTRONIK GMBH"},
	{0x008057, "ADSOFT, LTD."},
	{0x008058, "PRINTER SYSTEMS CORPORATION"},
	{0x008059, "STANLEY ELECTRIC CO., LTD"},
	{0x00805A, "TULIP COMPUTERS INTERNAT'L B.V"},
	{0x00805B, "CONDOR SYSTEMS, INC."},
	{0x00805C, "AGILIS CORPORATION"},
	{0x00805D, "CANSTAR"},
	{0x00805E, "LSI LOGIC CORPORATION"},
	{0x00805F, "Hewlett Packard"},
	{0x008060, "NETWORK INTERFACE CORPORATION"},
	{0x008061, "LITTON SYSTEMS, INC."},
	{0x008062, "INTERFACE  CO."},
	{0x008063, "RICHARD HIRSCHMANN GMBH & CO."},
	{0x008064, "WYSE TECHNOLOGY"},
	{0x008065, "CYBERGRAPHIC SYSTEMS PTY LTD."},
	{0x008066, "ARCOM CONTROL SYSTEMS, LTD."},
	{0x008067, "SQUARE D COMPANY"},
	{0x008068, "YAMATECH SCIENTIFIC LTD."},
	{0x008069, "COMPUTONE SYSTEMS"},
	{0x00806A, "ERI (EMPAC RESEARCH INC.)"},
	{0x00806B, "SCHMID TELECOMMUNICATION"},
	{0x00806C, "CEGELEC PROJECTS LTD"},
	{0x00806D, "CENTURY SYSTEMS CORP."},
	{0x00806E, "NIPPON STEEL CORPORATION"},
	{0x00806F, "ONELAN LTD."},
	{0x008070, "COMPUTADORAS MICRON"},
	{0x008071, "SAI TECHNOLOGY"},
	{0x008072, "MICROPLEX SYSTEMS LTD."},
	{0x008073, "DWB ASSOCIATES"},
	{0x008074, "FISHER CONTROLS"},
	{0x008075, "PARSYTEC GMBH"},
	{0x008076, "MCNC"},
	{0x008077, "BROTHER INDUSTRIES, LTD."},
	{0x008078, "PRACTICAL PERIPHERALS, INC."},
	{0x008079, "MICROBUS DESIGNS LTD."},
	{0x00807A, "AITECH SYSTEMS LTD."},
	{0x00807B, "ARTEL COMMUNICATIONS CORP."},
	{0x00807C, "FIBERCOM, INC."},
	{0x00807D, "EQUINOX SYSTEMS INC."},
	{0x00807E, "SOUTHERN PACIFIC LTD."},
	{0x00807F, "DY-4 INCORPORATED"},
	{0x008080, "DATAMEDIA CORPORATION"},
	{0x008081, "KENDALL SQUARE RESEARCH CORP."},
	{0x008082, "PEP MODULAR COMPUTERS GMBH"},
	{0x008083, "AMDAHL"},
	{0x008084, "THE CLOUD INC."},
	{0x008085, "H-THREE SYSTEMS CORPORATION"},
	{0x008086, "COMPUTER GENERATION INC."},
	{0x008087, "OKI ELECTRIC INDUSTRY CO., LTD"},
	{0x008088, "VICTOR COMPANY OF JAPAN, LTD."},
	{0x008089, "TECNETICS (PTY) LTD."},
	{0x00808A, "SUMMIT MICROSYSTEMS CORP."},
	{0x00808B, "DACOLL LIMITED"},
	{0x00808C, "NetScout Systems, Inc."},
	{0x00808D, "WESTCOAST TECHNOLOGY B.V."},
	{0x00808E, "RADSTONE TECHNOLOGY"},
	{0x00808F, "C. ITOH ELECTRONICS, INC."},
	{0x008090, "MICROTEK INTERNATIONAL, INC."},
	{0x008091, "TOKYO ELECTRIC CO.,LTD"},
	{0x008092, "Silex Technology, Inc."},
	{0x008093, "XYRON CORPORATION"},
	{0x008094, "ALFA LAVAL AUTOMATION AB"},
	{0x008095, "BASIC MERTON HANDELSGES.M.B.H."},
	{0x008096, "HUMAN DESIGNED SYSTEMS, INC."},
	{0x008097, "CENTRALP AUTOMATISMES"},
	{0x008098, "TDK CORPORATION"},
	{0x008099, "KLOCKNER MOELLER IPC"},
	{0x00809A, "NOVUS NETWORKS LTD"},
	{0x00809B, "JUSTSYSTEM CORPORATION"},
	{0x00809C, "LUXCOM, INC."},
	{0x00809D, "Commscraft Ltd."},
	{0x00809E, "DATUS GMBH"},
	{0x00809F, "ALCATEL BUSINESS SYSTEMS"},
	{0x0080A0, "EDISA HEWLETT PACKARD S/A"},
	{0x0080A1, "MICROTEST, INC."},
	{0x0080A2, "CREATIVE ELECTRONIC SYSTEMS"},
	{0x0080A3, "Lantronix"},
	{0x0080A4, "LIBERTY ELECTRONICS"},
	{0x0080A5, "SPEED INTERNATIONAL"},
	{0x0080A6, "REPUBLIC TECHNOLOGY, INC."},
	{0x0080A7, "MEASUREX CORP."},
	{0x0080A8, "VITACOM CORPORATION"},
	{0x0080A9, "CLEARPOINT RESEARCH"},
	{0x0080AA, "MAXPEED"},
	{0x0080AB, "DUKANE NETWORK INTEGRATION"},
	{0x0080AC, "IMLOGIX, DIVISION OF GENESYS"},
	{0x0080AD, "CNET TECHNOLOGY, INC."},
	{0x0080AE, "HUGHES NETWORK SYSTEMS"},
	{0x0080AF, "ALLUMER CO., LTD."},
	{0x0080B0, "ADVANCED INFORMATION"},
	{0x0080B1, "SOFTCOM A/S"},
	{0x0080B2, "NETWORK EQUIPMENT TECHNOLOGIES"},
	{0x0080B3, "AVAL DATA CORPORATION"},
	{0x0080B4, "SOPHIA SYSTEMS"},
	{0x0080B5, "UNITED NETWORKS INC."},
	{0x0080B6, "THEMIS COMPUTER"},
	{0x0080B7, "STELLAR COMPUTER"},
	{0x0080B8, "BUG, INCORPORATED"},
	{0x0080B9, "ARCHE TECHNOLIGIES INC."},
	{0x0080BA, "SPECIALIX (ASIA) PTE, LTD"},
	{0x0080BB, "HUGHES LAN SYSTEMS"},
	{0x0080BC, "HITACHI ENGINEERING CO., LTD"},
	{0x0080BD, "THE FURUKAWA ELECTRIC CO., LTD"},
	{0x0080BE, "ARIES RESEARCH"},
	{0x0080BF, "TAKAOKA ELECTRIC MFG. CO. LTD."},
	{0x0080C0, "PENRIL DATACOMM"},
	{0x0080C1, "LANEX CORPORATION"},
	{0x0080C2, "IEEE 802.1 COMMITTEE"},
	{0x0080C3, "BICC INFORMATION SYSTEMS & SVC"},
	{0x0080C4, "DOCUMENT TECHNOLOGIES, INC."},
	{0x0080C5, "NOVELLCO DE MEXICO"},
	{0x0080C6, "NATIONAL DATACOMM CORPORATION"},
	{0x0080C7, "XIRCOM"},
	{0x0080C8, "D-LINK SYSTEMS, INC."},
	{0x0080C9, "ALBERTA MICROELECTRONIC CENTRE"},
	{0x0080CA, "NETCOM RESEARCH INCORPORATED"},
	{0x0080CB, "FALCO DATA PRODUCTS"},
	{0x0080CC, "MICROWAVE BYPASS SYSTEMS"},
	{0x0080CD, "MICRONICS COMPUTER, INC."},
	{0x0080CE, "BROADCAST TELEVISION SYSTEMS"},
	{0x0080CF, "EMBEDDED PERFORMANCE INC."},
	{0x0080D0, "COMPUTER PERIPHERALS, INC."},
	{0x0080D1, "KIMTRON CORPORATION"},
	{0x0080D2, "SHINNIHONDENKO CO., LTD."},
	{0x0080D3, "SHIVA CORP."},
	{0x0080D4, "CHASE RESEARCH LTD."},
	{0x0080D5, "CADRE TECHNOLOGIES"},
	{0x0080D6, "NUVOTECH, INC."},
	{0x0080D7, "Fantum Engineering"},
	{0x0080D8, "NETWORK PERIPHERALS INC."},
	{0x0080D9, "EMK Elektronik GmbH & Co. KG"},
	{0x0080DA, "BRUEL & KJAER"},
	{0x0080DB, "GRAPHON CORPORATION"},
	{0x0080DC, "PICKER INTERNATIONAL"},
	{0x0080DD, "GMX INC/GIMIX"},
	{0x0080DE, "GIPSI S.A."},
	{0x0080DF, "ADC CODENOLL TECHNOLOGY CORP."},
	{0x0080E0, "XTP SYSTEMS, INC."},
	{0x0080E1, "STMICROELECTRONICS"},
	{0x0080E2, "T.D.I. CO., LTD."},
	{0x0080E3, "CORAL NETWORK CORPORATION"},
	{0x0080E4, "NORTHWEST DIGITAL SYSTEMS, INC"},
	{0x0080E5, "LSI Logic Corporation"},
	{0x0080E6, "PEER NETWORKS, INC."},
	{0x0080E7, "LYNWOOD SCIENTIFIC DEV. LTD."},
	{0x0080E8, "CUMULUS CORPORATIION"},
	{0x0080E9, "Madge Ltd."},
	{0x0080EA, "ADVA Optical Networking Ltd."},
	{0x0080EB, "COMPCONTROL B.V."},
	{0x0080EC, "SUPERCOMPUTING SOLUTIONS, INC."},
	{0x0080ED, "IQ TECHNOLOGIES, INC."},
	{0x0080EE, "THOMSON CSF"},
	{0x0080EF, "RATIONAL"},
	{0x0080F0, "Panasonic Communications Co., Ltd."},
	{0x0080F1, "OPUS SYSTEMS"},
	{0x0080F2, "RAYCOM SYSTEMS INC"},
	{0x0080F3, "SUN ELECTRONICS CORP."},
	{0x0080F4, "TELEMECANIQUE ELECTRIQUE"},
	{0x0080F5, "Quantel Ltd"},
	{0x0080F6, "SYNERGY MICROSYSTEMS"},
	{0x0080F7, "ZENITH ELECTRONICS"},
	{0x0080F8, "MIZAR, INC."},
	{0x0080F9, "HEURIKON CORPORATION"},
	{0x0080FA, "RWT GMBH"},
	{0x0080FB, "BVM LIMITED"},
	{0x0080FC, "AVATAR CORPORATION"},
	{0x0080FD, "EXSCEED CORPRATION"},
	{0x0080FE, "AZURE TECHNOLOGIES, INC."},
	{0x0080FF, "SOC. DE TELEINFORMATIQUE RTC"},
	{0x008CFA, "Inventec Corporation"},
	{0x009000, "DIAMOND MULTIMEDIA"},
	{0x009001, "NISHIMU ELECTRONICS INDUSTRIES CO., LTD."},
	{0x009002, "ALLGON AB"},
	{0x009003, "APLIO"},
	{0x009004, "3COM EUROPE LTD."},
	{0x009005, "PROTECH SYSTEMS CO., LTD."},
	{0x009006, "HAMAMATSU PHOTONICS K.K."},
	{0x009007, "DOMEX TECHNOLOGY CORP."},
	{0x009008, "HanA Systems Inc."},
	{0x009009, "i Controls, Inc."},
	{0x00900A, "PROTON ELECTRONIC INDUSTRIAL CO., LTD."},
	{0x00900B, "LANNER ELECTRONICS, INC."},
	{0x00900C, "CISCO SYSTEMS, INC."},
	{0x00900D, "Overland Storage Inc."},
	{0x00900E, "HANDLINK TECHNOLOGIES, INC."},
	{0x00900F, "KAWASAKI HEAVY INDUSTRIES, LTD"},
	{0x009010, "SIMULATION LABORATORIES, INC."},
	{0x009011, "WAVTrace, Inc."},
	{0x009012, "GLOBESPAN SEMICONDUCTOR, INC."},
	{0x009013, "SAMSAN CORP."},
	{0x009014, "ROTORK INSTRUMENTS, LTD."},
	{0x009015, "CENTIGRAM COMMUNICATIONS CORP."},
	{0x009016, "ZAC"},
	{0x009017, "Zypcom, Inc"},
	{0x009018, "ITO ELECTRIC INDUSTRY CO, LTD."},
	{0x009019, "HERMES ELECTRONICS CO., LTD."},
	{0x00901A, "UNISPHERE SOLUTIONS"},
	{0x00901B, "DIGITAL CONTROLS"},
	{0x00901C, "mps Software Gmbh"},
	{0x00901D, "PEC (NZ) LTD."},
	{0x00901E, "Selesta Ingegneria S.p.A."},
	{0x00901F, "ADTEC PRODUCTIONS, INC."},
	{0x009020, "PHILIPS ANALYTICAL X-RAY B.V."},
	{0x009021, "CISCO SYSTEMS, INC."},
	{0x009022, "IVEX"},
	{0x009023, "ZILOG INC."},
	{0x009024, "PIPELINKS, INC."},
	{0x009025, "BAE Systems Australia (Electronic Systems) Pty Ltd"},
	{0x009026, "ADVANCED SWITCHING COMMUNICATIONS, INC."},
	{0x009027, "INTEL CORPORATION"},
	{0x009028, "NIPPON SIGNAL CO., LTD."},
	{0x009029, "CRYPTO AG"},
	{0x00902A, "COMMUNICATION DEVICES, INC."},
	{0x00902B, "CISCO SYSTEMS, INC."},
	{0x00902C, "DATA & CONTROL EQUIPMENT LTD."},
	{0x00902D, "DATA ELECTRONICS (AUST.) PTY, LTD."},
	{0x00902E, "NAMCO LIMITED"},
	{0x00902F, "NETCORE SYSTEMS, INC."},
	{0x009030, "HONEYWELL-DATING"},
	{0x009031, "MYSTICOM, LTD."},
	{0x009032, "PELCOMBE GROUP LTD."},
	{0x009033, "INNOVAPHONE AG"},
	{0x009034, "IMAGIC, INC."},
	{0x009035, "ALPHA TELECOM, INC."},
	{0x009036, "ens, inc."},
	{0x009037, "ACUCOMM, INC."},
	{0x009038, "FOUNTAIN TECHNOLOGIES, INC."},
	{0x009039, "SHASTA NETWORKS"},
	{0x00903A, "NIHON MEDIA TOOL INC."},
	{0x00903B, "TriEMS Research Lab, Inc."},
	{0x00903C, "ATLANTIC NETWORK SYSTEMS"},
	{0x00903D, "BIOPAC SYSTEMS, INC."},
	{0x00903E, "N.V. PHILIPS INDUSTRIAL ACTIVITIES"},
	{0x00903F, "AZTEC RADIOMEDIA"},
	{0x009040, "Siemens Network Convergence LLC"},
	{0x009041, "APPLIED DIGITAL ACCESS"},
	{0x009042, "ECCS, Inc."},
	{0x009043, "NICHIBEI DENSHI CO., LTD."},
	{0x009044, "ASSURED DIGITAL, INC."},
	{0x009045, "Marconi Communications"},
	{0x009046, "DEXDYNE, LTD."},
	{0x009047, "GIGA FAST E. LTD."},
	{0x009048, "ZEAL CORPORATION"},
	{0x009049, "ENTRIDIA CORPORATION"},
	{0x00904A, "CONCUR SYSTEM TECHNOLOGIES"},
	{0x00904B, "GemTek Technology Co., Ltd."},
	{0x00904C, "EPIGRAM, INC."},
	{0x00904D, "SPEC S.A."},
	{0x00904E, "DELEM BV"},
	{0x00904F, "ABB POWER T&D COMPANY, INC."},
	{0x009050, "TELESTE OY"},
	{0x009051, "ULTIMATE TECHNOLOGY CORP."},
	{0x009052, "SELCOM ELETTRONICA S.R.L."},
	{0x009053, "DAEWOO ELECTRONICS CO., LTD."},
	{0x009054, "INNOVATIVE SEMICONDUCTORS, INC"},
	{0x009055, "PARKER HANNIFIN CORPORATION COMPUMOTOR DIVISION"},
	{0x009056, "TELESTREAM, INC."},
	{0x009057, "AANetcom, Inc."},
	{0x009058, "Ultra Electronics Ltd., Command and Control Systems"},
	{0x009059, "TELECOM DEVICE K.K."},
	{0x00905A, "DEARBORN GROUP, INC."},
	{0x00905B, "RAYMOND AND LAE ENGINEERING"},
	{0x00905C, "EDMI"},
	{0x00905D, "NETCOM SICHERHEITSTECHNIK GmbH"},
	{0x00905E, "RAULAND-BORG CORPORATION"},
	{0x00905F, "CISCO SYSTEMS, INC."},
	{0x009060, "SYSTEM CREATE CORP."},
	{0x009061, "PACIFIC RESEARCH & ENGINEERING CORPORATION"},
	{0x009062, "ICP VORTEX COMPUTERSYSTEME GmbH"},
	{0x009063, "COHERENT COMMUNICATIONS SYSTEMS CORPORATION"},
	{0x009064, "Thomson Inc."},
	{0x009065, "FINISAR CORPORATION"},
	{0x009066, "Troika Networks, Inc."},
	{0x009067, "WalkAbout Computers, Inc."},
	{0x009068, "DVT CORP."},
	{0x009069, "JUNIPER NETWORKS, INC."},
	{0x00906A, "TURNSTONE SYSTEMS, INC."},
	{0x00906B, "APPLIED RESOURCES, INC."},
	{0x00906C, "Sartorius Hamburg GmbH"},
	{0x00906D, "CISCO SYSTEMS, INC."},
	{0x00906E, "PRAXON, INC."},
	{0x00906F, "CISCO SYSTEMS, INC."},
	{0x009070, "NEO NETWORKS, INC."},
	{0x009071, "Applied Innovation Inc."},
	{0x009072, "SIMRAD AS"},
	{0x009073, "GAIO TECHNOLOGY"},
	{0x009074, "ARGON NETWORKS, INC."},
	{0x009075, "NEC DO BRASIL S.A."},
	{0x009076, "FMT AIRCRAFT GATE SUPPORT SYSTEMS AB"},
	{0x009077, "ADVANCED FIBRE COMMUNICATIONS"},
	{0x009078, "MER TELEMANAGEMENT SOLUTIONS, LTD."},
	{0x009079, "ClearOne, Inc."},
	{0x00907A, "Polycom, Inc."},
	{0x00907B, "E-TECH, INC."},
	{0x00907C, "DIGITALCAST, INC."},
	{0x00907D, "Lake Communications"},
	{0x00907E, "VETRONIX CORP."},
	{0x00907F, "WatchGuard Technologies, Inc."},
	{0x009080, "NOT LIMITED, INC."},
	{0x009081, "ALOHA NETWORKS, INC."},
	{0x009082, "FORCE INSTITUTE"},
	{0x009083, "TURBO COMMUNICATION, INC."},
	{0x009084, "ATECH SYSTEM"},
	{0x009085, "GOLDEN ENTERPRISES, INC."},
	{0x009086, "CISCO SYSTEMS, INC."},
	{0x009087, "ITIS"},
	{0x009088, "BAXALL SECURITY LTD."},
	{0x009089, "SOFTCOM MICROSYSTEMS, INC."},
	{0x00908A, "BAYLY COMMUNICATIONS, INC."},
	{0x00908B, "PFU Systems, Inc."},
	{0x00908C, "ETREND ELECTRONICS, INC."},
	{0x00908D, "VICKERS ELECTRONICS SYSTEMS"},
	{0x00908E, "Nortel Networks Broadband Access"},
	{0x00908F, "AUDIO CODES LTD."},
	{0x009090, "I-BUS"},
	{0x009091, "DigitalScape, Inc."},
	{0x009092, "CISCO SYSTEMS, INC."},
	{0x009093, "NANAO CORPORATION"},
	{0x009094, "OSPREY TECHNOLOGIES, INC."},
	{0x009095, "UNIVERSAL AVIONICS"},
	{0x009096, "ASKEY COMPUTER CORP."},
	{0x009097, "Sycamore Networks"},
	{0x009098, "SBC DESIGNS, INC."},
	{0x009099, "ALLIED TELESIS, K.K."},
	{0x00909A, "ONE WORLD SYSTEMS, INC."},
	{0x00909B, "IMAJE"},
	{0x00909C, "Motorola, Inc."},
	{0x00909D, "NovaTech Process Solutions, LLC"},
	{0x00909E, "Critical IO, LLC"},
	{0x00909F, "DIGI-DATA CORPORATION"},
	{0x0090A0, "8X8 INC."},
	{0x0090A1, "Flying Pig Systems/High End Systems Inc."},
	{0x0090A2, "CYBERTAN TECHNOLOGY, INC."},
	{0x0090A3, "Corecess Inc."},
	{0x0090A4, "ALTIGA NETWORKS"},
	{0x0090A5, "SPECTRA LOGIC"},
	{0x0090A6, "CISCO SYSTEMS, INC."},
	{0x0090A7, "CLIENTEC CORPORATION"},
	{0x0090A8, "NineTiles Networks, Ltd."},
	{0x0090A9, "WESTERN DIGITAL"},
	{0x0090AA, "INDIGO ACTIVE VISION SYSTEMS LIMITED"},
	{0x0090AB, "CISCO SYSTEMS, INC."},
	{0x0090AC, "OPTIVISION, INC."},
	{0x0090AD, "ASPECT ELECTRONICS, INC."},
	{0x0090AE, "ITALTEL S.p.A."},
	{0x0090AF, "J. MORITA MFG. CORP."},
	{0x0090B0, "VADEM"},
	{0x0090B1, "CISCO SYSTEMS, INC."},
	{0x0090B2, "AVICI SYSTEMS INC."},
	{0x0090B3, "AGRANAT SYSTEMS"},
	{0x0090B4, "WILLOWBROOK TECHNOLOGIES"},
	{0x0090B5, "NIKON CORPORATION"},
	{0x0090B6, "FIBEX SYSTEMS"},
	{0x0090B7, "DIGITAL LIGHTWAVE, INC."},
	{0x0090B8, "ROHDE & SCHWARZ GMBH & CO. KG"},
	{0x0090B9, "BERAN INSTRUMENTS LTD."},
	{0x0090BA, "VALID NETWORKS, INC."},
	{0x0090BB, "TAINET COMMUNICATION SYSTEM Corp."},
	{0x0090BC, "TELEMANN CO., LTD."},
	{0x0090BD, "OMNIA COMMUNICATIONS, INC."},
	{0x0090BE, "IBC/INTEGRATED BUSINESS COMPUTERS"},
	{0x0090BF, "CISCO SYSTEMS, INC."},
	{0x0090C0, "K.J. LAW ENGINEERS, INC."},
	{0x0090C1, "Peco II, Inc."},
	{0x0090C2, "JK microsystems, Inc."},
	{0x0090C3, "TOPIC SEMICONDUCTOR CORP."},
	{0x0090C4, "JAVELIN SYSTEMS, INC."},
	{0x0090C5, "INTERNET MAGIC, INC."},
	{0x0090C6, "OPTIM SYSTEMS, INC."},
	{0x0090C7, "ICOM INC."},
	{0x0090C8, "WAVERIDER COMMUNICATIONS (CANADA) INC."},
	{0x0090C9, "DPAC Technologies"},
	{0x0090CA, "ACCORD VIDEO TELECOMMUNICATIONS, LTD."},
	{0x0090CB, "Wireless OnLine, Inc."},
	{0x0090CC, "Planex Communications"},
	{0x0090CD, "ENT-EMPRESA NACIONAL DE TELECOMMUNICACOES, S.A."},
	{0x0090CE, "TETRA GmbH"},
	{0x0090CF, "NORTEL"},
	{0x0090D0, "Thomson Telecom Belgium"},
	{0x0090D1, "LEICHU ENTERPRISE CO., LTD."},
	{0x0090D2, "ARTEL VIDEO SYSTEMS"},
	{0x0090D3, "GIESECKE & DEVRIENT GmbH"},
	{0x0090D4, "BindView Development Corp."},
	{0x0090D5, "EUPHONIX, INC."},
	{0x0090D6, "CRYSTAL GROUP"},
	{0x0090D7, "NetBoost Corp."},
	{0x0090D8, "WHITECROSS SYSTEMS"},
	{0x0090D9, "CISCO SYSTEMS, INC."},
	{0x0090DA, "DYNARC, INC."},
	{0x0090DB, "NEXT LEVEL COMMUNICATIONS"},
	{0x0090DC, "TECO INFORMATION SYSTEMS"},
	{0x0090DD, "THE MIHARU COMMUNICATIONS CO., LTD."},
	{0x0090DE, "CARDKEY SYSTEMS, INC."},
	{0x0090DF, "MITSUBISHI CHEMICAL AMERICA, INC."},
	{0x0090E0, "SYSTRAN CORP."},
	{0x0090E1, "TELENA S.P.A."},
	{0x0090E2, "DISTRIBUTED PROCESSING TECHNOLOGY"},
	{0x0090E3, "AVEX ELECTRONICS INC."},
	{0x0090E4, "NEC AMERICA, INC."},
	{0x0090E5, "TEKNEMA, INC."},
	{0x0090E6, "ALi Corporation"},
	{0x0090E7, "HORSCH ELEKTRONIK AG"},
	{0x0090E8, "MOXA TECHNOLOGIES CORP., LTD."},
	{0x0090E9, "JANZ COMPUTER AG"},
	{0x0090EA, "ALPHA TECHNOLOGIES, INC."},
	{0x0090EB, "SENTRY TELECOM SYSTEMS"},
	{0x0090EC, "PYRESCOM"},
	{0x0090ED, "CENTRAL SYSTEM RESEARCH CO., LTD."},
	{0x0090EE, "PERSONAL COMMUNICATIONS TECHNOLOGIES"},
	{0x0090EF, "INTEGRIX, INC."},
	{0x0090F0, "Harmonic Video Systems Ltd."},
	{0x0090F1, "DOT HILL SYSTEMS CORPORATION"},
	{0x0090F2, "CISCO SYSTEMS, INC."},
	{0x0090F3, "ASPECT COMMUNICATIONS"},
	{0x0090F4, "LIGHTNING INSTRUMENTATION"},
	{0x0090F5, "CLEVO CO."},
	{0x0090F6, "ESCALATE NETWORKS, INC."},
	{0x0090F7, "NBASE COMMUNICATIONS LTD."},
	{0x0090F8, "MEDIATRIX TELECOM"},
	{0x0090F9, "LEITCH"},
	{0x0090FA, "EMULEX Corp"},
	{0x0090FB, "PORTWELL, INC."},
	{0x0090FC, "NETWORK COMPUTING DEVICES"},
	{0x0090FD, "CopperCom, Inc."},
	{0x0090FE, "ELECOM CO., LTD.  (LANEED DIV.)"},
	{0x0090FF, "TELLUS TECHNOLOGY INC."},
	{0x0091D6, "Crystal Group, Inc."},
	{0x009363, "Uni-Link Technology Co., Ltd."},
	{0x009D8E, "CARDIAC RECORDERS, INC."},
	{0x00A000, "CENTILLION NETWORKS, INC."},
	{0x00A001, "DRS Signal Solutions"},
	{0x00A002, "LEEDS & NORTHRUP AUSTRALIA PTY LTD"},
	{0x00A003, "Siemens Switzerland Ltd., I B T HVP"},
	{0x00A004, "NETPOWER, INC."},
	{0x00A005, "DANIEL INSTRUMENTS, LTD."},
	{0x00A006, "IMAGE DATA PROCESSING SYSTEM GROUP"},
	{0x00A007, "APEXX TECHNOLOGY, INC."},
	{0x00A008, "NETCORP"},
	{0x00A009, "WHITETREE NETWORK"},
	{0x00A00A, "Airspan"},
	{0x00A00B, "COMPUTEX CO., LTD."},
	{0x00A00C, "KINGMAX TECHNOLOGY, INC."},
	{0x00A00D, "THE PANDA PROJECT"},
	{0x00A00E, "VISUAL NETWORKS, INC."},
	{0x00A00F, "Broadband Technologies"},
	{0x00A010, "SYSLOGIC DATENTECHNIK AG"},
	{0x00A011, "MUTOH INDUSTRIES LTD."},
	{0x00A012, "B.A.T.M. ADVANCED TECHNOLOGIES"},
	{0x00A013, "TELTREND LTD."},
	{0x00A014, "CSIR"},
	{0x00A015, "WYLE"},
	{0x00A016, "MICROPOLIS CORP."},
	{0x00A017, "J B M CORPORATION"},
	{0x00A018, "CREATIVE CONTROLLERS, INC."},
	{0x00A019, "NEBULA CONSULTANTS, INC."},
	{0x00A01A, "BINAR ELEKTRONIK AB"},
	{0x00A01B, "PREMISYS COMMUNICATIONS, INC."},
	{0x00A01C, "NASCENT NETWORKS CORPORATION"},
	{0x00A01D, "SIXNET"},
	{0x00A01E, "EST CORPORATION"},
	{0x00A01F, "TRICORD SYSTEMS, INC."},
	{0x00A020, "CITICORP/TTI"},
	{0x00A021, "General Dynamics"},
	{0x00A022, "CENTRE FOR DEVELOPMENT OF ADVANCED COMPUTING"},
	{0x00A023, "APPLIED CREATIVE TECHNOLOGY, INC."},
	{0x00A024, "3COM CORPORATION"},
	{0x00A025, "REDCOM LABS INC."},
	{0x00A026, "TELDAT, S.A."},
	{0x00A027, "FIREPOWER SYSTEMS, INC."},
	{0x00A028, "CONNER PERIPHERALS"},
	{0x00A029, "COULTER CORPORATION"},
	{0x00A02A, "TRANCELL SYSTEMS"},
	{0x00A02B, "TRANSITIONS RESEARCH CORP."},
	{0x00A02C, "interWAVE Communications"},
	{0x00A02D, "1394 Trade Association"},
	{0x00A02E, "BRAND COMMUNICATIONS, LTD."},
	{0x00A02F, "PIRELLI CAVI"},
	{0x00A030, "CAPTOR NV/SA"},
	{0x00A031, "HAZELTINE CORPORATION, MS 1-17"},
	{0x00A032, "GES SINGAPORE PTE. LTD."},
	{0x00A033, "imc MeBsysteme GmbH"},
	{0x00A034, "AXEL"},
	{0x00A035, "CYLINK CORPORATION"},
	{0x00A036, "APPLIED NETWORK TECHNOLOGY"},
	{0x00A037, "Mindray DS USA, Inc."},
	{0x00A038, "EMAIL ELECTRONICS"},
	{0x00A039, "ROSS TECHNOLOGY, INC."},
	{0x00A03A, "KUBOTEK CORPORATION"},
	{0x00A03B, "TOSHIN ELECTRIC CO., LTD."},
	{0x00A03C, "EG&G NUCLEAR INSTRUMENTS"},
	{0x00A03D, "OPTO-22"},
	{0x00A03E, "ATM FORUM"},
	{0x00A03F,
	 "COMPUTER SOCIETY MICROPROCESSOR & MICROPROCESSOR STANDARDS C"},
	{0x00A040, "APPLE COMPUTER"},
	{0x00A041, "INFICON"},
	{0x00A042, "SPUR PRODUCTS CORP."},
	{0x00A043, "AMERICAN TECHNOLOGY LABS, INC."},
	{0x00A044, "NTT IT CO., LTD."},
	{0x00A045, "PHOENIX CONTACT GMBH & CO."},
	{0x00A046, "SCITEX CORP. LTD."},
	{0x00A047, "INTEGRATED FITNESS CORP."},
	{0x00A048, "QUESTECH, LTD."},
	{0x00A049, "DIGITECH INDUSTRIES, INC."},
	{0x00A04A, "NISSHIN ELECTRIC CO., LTD."},
	{0x00A04B, "TFL LAN INC."},
	{0x00A04C, "INNOVATIVE SYSTEMS & TECHNOLOGIES, INC."},
	{0x00A04D, "EDA INSTRUMENTS, INC."},
	{0x00A04E, "VOELKER TECHNOLOGIES, INC."},
	{0x00A04F, "AMERITEC CORP."},
	{0x00A050, "CYPRESS SEMICONDUCTOR"},
	{0x00A051, "ANGIA COMMUNICATIONS. INC."},
	{0x00A052, "STANILITE ELECTRONICS PTY. LTD"},
	{0x00A053, "COMPACT DEVICES, INC."},
	{0x00A055, "Data Device Corporation"},
	{0x00A056, "MICROPROSS"},
	{0x00A057, "LANCOM Systems GmbH"},
	{0x00A058, "GLORY, LTD."},
	{0x00A059, "HAMILTON HALLMARK"},
	{0x00A05A, "KOFAX IMAGE PRODUCTS"},
	{0x00A05B, "MARQUIP, INC."},
	{0x00A05C, "INVENTORY CONVERSION, INC./"},
	{0x00A05D, "CS COMPUTER SYSTEME GmbH"},
	{0x00A05E, "MYRIAD LOGIC INC."},
	{0x00A05F, "BTG Electronics Design BV"},
	{0x00A060, "ACER PERIPHERALS, INC."},
	{0x00A061, "PURITAN BENNETT"},
	{0x00A062, "AES PRODATA"},
	{0x00A063, "JRL SYSTEMS, INC."},
	{0x00A064, "KVB/ANALECT"},
	{0x00A065, "Symantec Corporation"},
	{0x00A066, "ISA CO., LTD."},
	{0x00A067, "NETWORK SERVICES GROUP"},
	{0x00A068, "BHP LIMITED"},
	{0x00A069, "Symmetricom, Inc."},
	{0x00A06A, "Verilink Corporation"},
	{0x00A06B, "DMS DORSCH MIKROSYSTEM GMBH"},
	{0x00A06C, "SHINDENGEN ELECTRIC MFG. CO., LTD."},
	{0x00A06D, "MANNESMANN TALLY CORPORATION"},
	{0x00A06E, "AUSTRON, INC."},
	{0x00A06F, "THE APPCON GROUP, INC."},
	{0x00A070, "COASTCOM"},
	{0x00A071, "VIDEO LOTTERY TECHNOLOGIES,INC"},
	{0x00A072, "OVATION SYSTEMS LTD."},
	{0x00A073, "COM21, INC."},
	{0x00A074, "PERCEPTION TECHNOLOGY"},
	{0x00A075, "MICRON TECHNOLOGY, INC."},
	{0x00A076, "CARDWARE LAB, INC."},
	{0x00A077, "FUJITSU NEXION, INC."},
	{0x00A078, "Marconi Communications"},
	{0x00A079, "ALPS ELECTRIC (USA), INC."},
	{0x00A07A, "ADVANCED PERIPHERALS TECHNOLOGIES, INC."},
	{0x00A07B, "DAWN COMPUTER INCORPORATION"},
	{0x00A07C, "TONYANG NYLON CO., LTD."},
	{0x00A07D, "SEEQ TECHNOLOGY, INC."},
	{0x00A07E, "AVID TECHNOLOGY, INC."},
	{0x00A07F, "GSM-SYNTEL, LTD."},
	{0x00A080, "SBE, Inc."},
	{0x00A081, "ALCATEL DATA NETWORKS"},
	{0x00A082, "NKT ELEKTRONIK A/S"},
	{0x00A083, "ASIMMPHONY TURKEY"},
	{0x00A084, "Dataplex Pty Ltd"},
	{0x00A086, "AMBER WAVE SYSTEMS, INC."},
	{0x00A087, "Zarlink Semiconductor Ltd."},
	{0x00A088, "ESSENTIAL COMMUNICATIONS"},
	{0x00A089, "XPOINT TECHNOLOGIES, INC."},
	{0x00A08A, "BROOKTROUT TECHNOLOGY, INC."},
	{0x00A08B, "ASTON ELECTRONIC DESIGNS LTD."},
	{0x00A08C, "MultiMedia LANs, Inc."},
	{0x00A08D, "JACOMO CORPORATION"},
	{0x00A08E, "Nokia Internet Communications"},
	{0x00A08F, "DESKNET SYSTEMS, INC."},
	{0x00A090, "TimeStep Corporation"},
	{0x00A091, "APPLICOM INTERNATIONAL"},
	{0x00A092, "H. BOLLMANN MANUFACTURERS, LTD"},
	{0x00A093, "B/E AEROSPACE, Inc."},
	{0x00A094, "COMSAT CORPORATION"},
	{0x00A095, "ACACIA NETWORKS, INC."},
	{0x00A096, "MITUMI ELECTRIC CO., LTD."},
	{0x00A097, "JC INFORMATION SYSTEMS"},
	{0x00A098, "NetApp"},
	{0x00A099, "K-NET LTD."},
	{0x00A09A, "NIHON KOHDEN AMERICA"},
	{0x00A09B, "QPSX COMMUNICATIONS, LTD."},
	{0x00A09C, "Xyplex, Inc."},
	{0x00A09D, "JOHNATHON FREEMAN TECHNOLOGIES"},
	{0x00A09E, "ICTV"},
	{0x00A09F, "COMMVISION CORP."},
	{0x00A0A0, "COMPACT DATA, LTD."},
	{0x00A0A1, "EPIC DATA INC."},
	{0x00A0A2, "DIGICOM S.P.A."},
	{0x00A0A3, "RELIABLE POWER METERS"},
	{0x00A0A4, "MICROS SYSTEMS, INC."},
	{0x00A0A5, "TEKNOR MICROSYSTEME, INC."},
	{0x00A0A6, "M.I. SYSTEMS, K.K."},
	{0x00A0A7, "VORAX CORPORATION"},
	{0x00A0A8, "RENEX CORPORATION"},
	{0x00A0A9, "NAVTEL COMMUNICATIONS INC."},
	{0x00A0AA, "SPACELABS MEDICAL"},
	{0x00A0AB, "NETCS INFORMATIONSTECHNIK GMBH"},
	{0x00A0AC, "GILAT SATELLITE NETWORKS, LTD."},
	{0x00A0AD, "MARCONI SPA"},
	{0x00A0AE, "NUCOM SYSTEMS, INC."},
	{0x00A0AF, "WMS INDUSTRIES"},
	{0x00A0B0, "I-O DATA DEVICE, INC."},
	{0x00A0B1, "FIRST VIRTUAL CORPORATION"},
	{0x00A0B2, "SHIMA SEIKI"},
	{0x00A0B3, "ZYKRONIX"},
	{0x00A0B4, "TEXAS MICROSYSTEMS, INC."},
	{0x00A0B5, "3H TECHNOLOGY"},
	{0x00A0B6, "SANRITZ AUTOMATION CO., LTD."},
	{0x00A0B7, "CORDANT, INC."},
	{0x00A0B8, "SYMBIOS LOGIC INC."},
	{0x00A0B9, "EAGLE TECHNOLOGY, INC."},
	{0x00A0BA, "PATTON ELECTRONICS CO."},
	{0x00A0BB, "HILAN GMBH"},
	{0x00A0BC, "VIASAT, INCORPORATED"},
	{0x00A0BD, "I-TECH CORP."},
	{0x00A0BE, "INTEGRATED CIRCUIT SYSTEMS, INC. COMMUNICATIONS GROUP"},
	{0x00A0BF, "WIRELESS DATA GROUP MOTOROLA"},
	{0x00A0C0, "DIGITAL LINK CORP."},
	{0x00A0C1, "ORTIVUS MEDICAL AB"},
	{0x00A0C2, "R.A. SYSTEMS CO., LTD."},
	{0x00A0C3, "UNICOMPUTER GMBH"},
	{0x00A0C4, "CRISTIE ELECTRONICS LTD."},
	{0x00A0C5, "ZYXEL COMMUNICATION"},
	{0x00A0C6, "QUALCOMM INCORPORATED"},
	{0x00A0C7, "TADIRAN TELECOMMUNICATIONS"},
	{0x00A0C8, "ADTRAN INC."},
	{0x00A0C9, "INTEL CORPORATION - HF1-06"},
	{0x00A0CA, "FUJITSU DENSO LTD."},
	{0x00A0CB, "ARK TELECOMMUNICATIONS, INC."},
	{0x00A0CC, "LITE-ON COMMUNICATIONS, INC."},
	{0x00A0CD, "DR. JOHANNES HEIDENHAIN GmbH"},
	{0x00A0CE, "ASTROCOM CORPORATION"},
	{0x00A0CF, "SOTAS, INC."},
	{0x00A0D0, "TEN X TECHNOLOGY, INC."},
	{0x00A0D1, "INVENTEC CORPORATION"},
	{0x00A0D2, "ALLIED TELESIS INTERNATIONAL CORPORATION"},
	{0x00A0D3, "INSTEM COMPUTER SYSTEMS, LTD."},
	{0x00A0D4, "RADIOLAN,  INC."},
	{0x00A0D5, "SIERRA WIRELESS INC."},
	{0x00A0D6, "SBE, INC."},
	{0x00A0D7, "KASTEN CHASE APPLIED RESEARCH"},
	{0x00A0D8, "SPECTRA - TEK"},
	{0x00A0D9, "CONVEX COMPUTER CORPORATION"},
	{0x00A0DA, "INTEGRATED SYSTEMS Technology, Inc."},
	{0x00A0DB, "FISHER & PAYKEL PRODUCTION"},
	{0x00A0DC, "O.N. ELECTRONIC CO., LTD."},
	{0x00A0DD, "AZONIX CORPORATION"},
	{0x00A0DE, "YAMAHA CORPORATION"},
	{0x00A0DF, "STS TECHNOLOGIES, INC."},
	{0x00A0E0, "TENNYSON TECHNOLOGIES PTY LTD"},
	{0x00A0E1, "WESTPORT RESEARCH ASSOCIATES, INC."},
	{0x00A0E2, "Keisokugiken Corporation"},
	{0x00A0E3, "XKL SYSTEMS CORP."},
	{0x00A0E4, "OPTIQUEST"},
	{0x00A0E5, "NHC COMMUNICATIONS"},
	{0x00A0E6, "DIALOGIC CORPORATION"},
	{0x00A0E7, "CENTRAL DATA CORPORATION"},
	{0x00A0E8, "REUTERS HOLDINGS PLC"},
	{0x00A0E9, "ELECTRONIC RETAILING SYSTEMS INTERNATIONAL"},
	{0x00A0EA, "ETHERCOM CORP."},
	{0x00A0EB, "Encore Networks, Inc."},
	{0x00A0EC, "TRANSMITTON LTD."},
	{0x00A0ED, "Brooks Automation, Inc."},
	{0x00A0EE, "NASHOBA NETWORKS"},
	{0x00A0EF, "LUCIDATA LTD."},
	{0x00A0F0, "TORONTO MICROELECTRONICS INC."},
	{0x00A0F1, "MTI"},
	{0x00A0F2, "INFOTEK COMMUNICATIONS, INC."},
	{0x00A0F3, "STAUBLI"},
	{0x00A0F4, "GE"},
	{0x00A0F5, "RADGUARD LTD."},
	{0x00A0F6, "AutoGas Systems Inc."},
	{0x00A0F7, "V.I COMPUTER CORP."},
	{0x00A0F8, "SYMBOL TECHNOLOGIES, INC."},
	{0x00A0F9, "BINTEC COMMUNICATIONS GMBH"},
	{0x00A0FA, "Marconi Communication GmbH"},
	{0x00A0FB, "TORAY ENGINEERING CO., LTD."},
	{0x00A0FC, "IMAGE SCIENCES, INC."},
	{0x00A0FD, "SCITEX DIGITAL PRINTING, INC."},
	{0x00A0FE, "BOSTON TECHNOLOGY, INC."},
	{0x00A0FF, "TELLABS OPERATIONS, INC."},
	{0x00A2DA, "INAT GmbH"},
	{0x00AA00, "INTEL CORPORATION"},
	{0x00AA01, "INTEL CORPORATION"},
	{0x00AA02, "INTEL CORPORATION"},
	{0x00AA3C, "OLIVETTI TELECOM SPA (OLTECO)"},
	{0x00B009, "Grass Valley Group"},
	{0x00B017, "InfoGear Technology Corp."},
	{0x00B019, "Casi-Rusco"},
	{0x00B01C, "Westport Technologies"},
	{0x00B01E, "Rantic Labs, Inc."},
	{0x00B02A, "ORSYS GmbH"},
	{0x00B02D, "ViaGate Technologies, Inc."},
	{0x00B03B, "HiQ Networks"},
	{0x00B048, "Marconi Communications Inc."},
	{0x00B04A, "Cisco Systems, Inc."},
	{0x00B052, "Intellon Corporation"},
	{0x00B064, "Cisco Systems, Inc."},
	{0x00B069, "Honewell Oy"},
	{0x00B06D, "Jones Futurex Inc."},
	{0x00B080, "Mannesmann Ipulsys B.V."},
	{0x00B086, "LocSoft Limited"},
	{0x00B08E, "Cisco Systems, Inc."},
	{0x00B091, "Transmeta Corp."},
	{0x00B094, "Alaris, Inc."},
	{0x00B09A, "Morrow Technologies Corp."},
	{0x00B09D, "Point Grey Research Inc."},
	{0x00B0AC, "SIAE-Microelettronica S.p.A."},
	{0x00B0AE, "Symmetricom"},
	{0x00B0B3, "Xstreamis PLC"},
	{0x00B0C2, "Cisco Systems, Inc."},
	{0x00B0C7, "Tellabs Operations, Inc."},
	{0x00B0CE, "TECHNOLOGY RESCUE"},
	{0x00B0D0, "Dell Computer Corp."},
	{0x00B0DB, "Nextcell, Inc."},
	{0x00B0DF, "RELDATA Inc"},
	{0x00B0E7, "British Federal Ltd."},
	{0x00B0EC, "EACEM"},
	{0x00B0EE, "Ajile Systems, Inc."},
	{0x00B0F0, "CALY NETWORKS"},
	{0x00B0F5, "NetWorth Technologies, Inc."},
	{0x00BAC0, "Biometric Access Company"},
	{0x00BB01, "OCTOTHORPE CORP."},
	{0x00BBF0, "UNGERMANN-BASS INC."},
	{0x00BD3A, "Nokia Corporation"},
	{0x00C000, "LANOPTICS, LTD."},
	{0x00C001, "DIATEK PATIENT MANAGMENT"},
	{0x00C002, "SERCOMM CORPORATION"},
	{0x00C003, "GLOBALNET COMMUNICATIONS"},
	{0x00C004, "JAPAN BUSINESS COMPUTER CO.LTD"},
	{0x00C005, "LIVINGSTON ENTERPRISES, INC."},
	{0x00C006, "NIPPON AVIONICS CO., LTD."},
	{0x00C007, "PINNACLE DATA SYSTEMS, INC."},
	{0x00C008, "SECO SRL"},
	{0x00C009, "KT TECHNOLOGY (S) PTE LTD"},
	{0x00C00A, "MICRO CRAFT"},
	{0x00C00B, "NORCONTROL A.S."},
	{0x00C00C, "RELIA TECHNOLGIES"},
	{0x00C00D, "ADVANCED LOGIC RESEARCH, INC."},
	{0x00C00E, "PSITECH, INC."},
	{0x00C00F, "QUANTUM SOFTWARE SYSTEMS LTD."},
	{0x00C010, "HIRAKAWA HEWTECH CORP."},
	{0x00C011, "INTERACTIVE COMPUTING DEVICES"},
	{0x00C012, "NETSPAN CORPORATION"},
	{0x00C013, "NETRIX"},
	{0x00C014, "TELEMATICS CALABASAS INT'L,INC"},
	{0x00C015, "NEW MEDIA CORPORATION"},
	{0x00C016, "ELECTRONIC THEATRE CONTROLS"},
	{0x00C017, "Fluke Corporation"},
	{0x00C018, "LANART CORPORATION"},
	{0x00C019, "LEAP TECHNOLOGY, INC."},
	{0x00C01A, "COROMETRICS MEDICAL SYSTEMS"},
	{0x00C01B, "SOCKET COMMUNICATIONS, INC."},
	{0x00C01C, "INTERLINK COMMUNICATIONS LTD."},
	{0x00C01D, "GRAND JUNCTION NETWORKS, INC."},
	{0x00C01E, "LA FRANCAISE DES JEUX"},
	{0x00C01F, "S.E.R.C.E.L."},
	{0x00C020, "ARCO ELECTRONIC, CONTROL LTD."},
	{0x00C021, "NETEXPRESS"},
	{0x00C022, "LASERMASTER TECHNOLOGIES, INC."},
	{0x00C023, "TUTANKHAMON ELECTRONICS"},
	{0x00C024, "EDEN SISTEMAS DE COMPUTACAO SA"},
	{0x00C025, "DATAPRODUCTS CORPORATION"},
	{0x00C026, "LANS TECHNOLOGY CO., LTD."},
	{0x00C027, "CIPHER SYSTEMS, INC."},
	{0x00C028, "JASCO CORPORATION"},
	{0x00C029, "Nexans Deutschland GmbH - ANS"},
	{0x00C02A, "OHKURA ELECTRIC CO., LTD."},
	{0x00C02B, "GERLOFF GESELLSCHAFT FUR"},
	{0x00C02C, "CENTRUM COMMUNICATIONS, INC."},
	{0x00C02D, "FUJI PHOTO FILM CO., LTD."},
	{0x00C02E, "NETWIZ"},
	{0x00C02F, "OKUMA CORPORATION"},
	{0x00C030, "INTEGRATED ENGINEERING B. V."},
	{0x00C031, "DESIGN RESEARCH SYSTEMS, INC."},
	{0x00C032, "I-CUBED LIMITED"},
	{0x00C033, "TELEBIT COMMUNICATIONS APS"},
	{0x00C034, "TRANSACTION NETWORK"},
	{0x00C035, "QUINTAR COMPANY"},
	{0x00C036, "RAYTECH ELECTRONIC CORP."},
	{0x00C037, "DYNATEM"},
	{0x00C038, "RASTER IMAGE PROCESSING SYSTEM"},
	{0x00C039, "Teridian Semiconductor Corporation"},
	{0x00C03A, "MEN-MIKRO ELEKTRONIK GMBH"},
	{0x00C03B, "MULTIACCESS COMPUTING CORP."},
	{0x00C03C, "TOWER TECH S.R.L."},
	{0x00C03D, "WIESEMANN & THEIS GMBH"},
	{0x00C03E, "FA. GEBR. HELLER GMBH"},
	{0x00C03F, "STORES AUTOMATED SYSTEMS, INC."},
	{0x00C040, "ECCI"},
	{0x00C041, "DIGITAL TRANSMISSION SYSTEMS"},
	{0x00C042, "DATALUX CORP."},
	{0x00C043, "STRATACOM"},
	{0x00C044, "EMCOM CORPORATION"},
	{0x00C045, "ISOLATION SYSTEMS, LTD."},
	{0x00C046, "Blue Chip Technology Ltd"},
	{0x00C047, "UNIMICRO SYSTEMS, INC."},
	{0x00C048, "BAY TECHNICAL ASSOCIATES"},
	{0x00C049, "U.S. ROBOTICS, INC."},
	{0x00C04A, "GROUP 2000 AG"},
	{0x00C04B, "CREATIVE MICROSYSTEMS"},
	{0x00C04C, "DEPARTMENT OF FOREIGN AFFAIRS"},
	{0x00C04D, "MITEC, INC."},
	{0x00C04E, "COMTROL CORPORATION"},
	{0x00C04F, "DELL COMPUTER CORPORATION"},
	{0x00C050, "TOYO DENKI SEIZO K.K."},
	{0x00C051, "ADVANCED INTEGRATION RESEARCH"},
	{0x00C052, "BURR-BROWN"},
	{0x00C053, "Aspect Software Inc."},
	{0x00C054, "NETWORK PERIPHERALS, LTD."},
	{0x00C055, "MODULAR COMPUTING TECHNOLOGIES"},
	{0x00C056, "SOMELEC"},
	{0x00C057, "MYCO ELECTRONICS"},
	{0x00C058, "DATAEXPERT CORP."},
	{0x00C059, "DENSO CORPORATION"},
	{0x00C05A, "SEMAPHORE COMMUNICATIONS CORP."},
	{0x00C05B, "NETWORKS NORTHWEST, INC."},
	{0x00C05C, "ELONEX PLC"},
	{0x00C05D, "L&N TECHNOLOGIES"},
	{0x00C05E, "VARI-LITE, INC."},
	{0x00C05F, "FINE-PAL COMPANY LIMITED"},
	{0x00C060, "ID SCANDINAVIA AS"},
	{0x00C061, "SOLECTEK CORPORATION"},
	{0x00C062, "IMPULSE TECHNOLOGY"},
	{0x00C063, "MORNING STAR TECHNOLOGIES, INC"},
	{0x00C064, "GENERAL DATACOMM IND. INC."},
	{0x00C065, "SCOPE COMMUNICATIONS, INC."},
	{0x00C066, "DOCUPOINT, INC."},
	{0x00C067, "UNITED BARCODE INDUSTRIES"},
	{0x00C068, "PHILIP DRAKE ELECTRONICS LTD."},
	{0x00C069, "Axxcelera Broadband Wireless"},
	{0x00C06A, "ZAHNER-ELEKTRIK GMBH & CO. KG"},
	{0x00C06B, "OSI PLUS CORPORATION"},
	{0x00C06C, "SVEC COMPUTER CORP."},
	{0x00C06D, "BOCA RESEARCH, INC."},
	{0x00C06E, "HAFT TECHNOLOGY, INC."},
	{0x00C06F, "KOMATSU LTD."},
	{0x00C070, "SECTRA SECURE-TRANSMISSION AB"},
	{0x00C071, "AREANEX COMMUNICATIONS, INC."},
	{0x00C072, "KNX LTD."},
	{0x00C073, "XEDIA CORPORATION"},
	{0x00C074, "TOYODA AUTOMATIC LOOM"},
	{0x00C075, "XANTE CORPORATION"},
	{0x00C076, "I-DATA INTERNATIONAL A-S"},
	{0x00C077, "DAEWOO TELECOM LTD."},
	{0x00C078, "COMPUTER SYSTEMS ENGINEERING"},
	{0x00C079, "FONSYS CO.,LTD."},
	{0x00C07A, "PRIVA B.V."},
	{0x00C07B, "ASCEND COMMUNICATIONS, INC."},
	{0x00C07C, "HIGHTECH INFORMATION"},
	{0x00C07D, "RISC DEVELOPMENTS LTD."},
	{0x00C07E, "KUBOTA CORPORATION ELECTRONIC"},
	{0x00C07F, "NUPON COMPUTING CORP."},
	{0x00C080, "NETSTAR, INC."},
	{0x00C081, "METRODATA LTD."},
	{0x00C082, "MOORE PRODUCTS CO."},
	{0x00C083, "TRACE MOUNTAIN PRODUCTS, INC."},
	{0x00C084, "DATA LINK CORP. LTD."},
	{0x00C085, "ELECTRONICS FOR IMAGING, INC."},
	{0x00C086, "THE LYNK CORPORATION"},
	{0x00C087, "UUNET TECHNOLOGIES, INC."},
	{0x00C088, "EKF ELEKTRONIK GMBH"},
	{0x00C089, "TELINDUS DISTRIBUTION"},
	{0x00C08A, "Lauterbach GmbH"},
	{0x00C08B, "RISQ MODULAR SYSTEMS, INC."},
	{0x00C08C, "PERFORMANCE TECHNOLOGIES, INC."},
	{0x00C08D, "TRONIX PRODUCT DEVELOPMENT"},
	{0x00C08E, "NETWORK INFORMATION TECHNOLOGY"},
	{0x00C08F, "Panasonic Electric Works Co., Ltd."},
	{0x00C090, "PRAIM S.R.L."},
	{0x00C091, "JABIL CIRCUIT, INC."},
	{0x00C092, "MENNEN MEDICAL INC."},
	{0x00C093, "ALTA RESEARCH CORP."},
	{0x00C094, "VMX INC."},
	{0x00C095, "ZNYX"},
	{0x00C096, "TAMURA CORPORATION"},
	{0x00C097, "ARCHIPEL SA"},
	{0x00C098, "CHUNTEX ELECTRONIC CO., LTD."},
	{0x00C099, "YOSHIKI INDUSTRIAL CO.,LTD."},
	{0x00C09A, "PHOTONICS CORPORATION"},
	{0x00C09B, "RELIANCE COMM/TEC, R-TEC"},
	{0x00C09C, "HIOKI E.E. CORPORATION"},
	{0x00C09D, "DISTRIBUTED SYSTEMS INT'L, INC"},
	{0x00C09E, "CACHE COMPUTERS, INC."},
	{0x00C09F, "QUANTA COMPUTER, INC."},
	{0x00C0A0, "ADVANCE MICRO RESEARCH, INC."},
	{0x00C0A1, "TOKYO DENSHI SEKEI CO."},
	{0x00C0A2, "INTERMEDIUM A/S"},
	{0x00C0A3, "DUAL ENTERPRISES CORPORATION"},
	{0x00C0A4, "UNIGRAF OY"},
	{0x00C0A5, "DICKENS DATA SYSTEMS"},
	{0x00C0A6, "EXICOM AUSTRALIA PTY. LTD"},
	{0x00C0A7, "SEEL LTD."},
	{0x00C0A8, "GVC CORPORATION"},
	{0x00C0A9, "BARRON MCCANN LTD."},
	{0x00C0AA, "SILICON VALLEY COMPUTER"},
	{0x00C0AB, "Telco Systems, Inc."},
	{0x00C0AC, "GAMBIT COMPUTER COMMUNICATIONS"},
	{0x00C0AD, "MARBEN COMMUNICATION SYSTEMS"},
	{0x00C0AE, "TOWERCOM CO. INC. DBA PC HOUSE"},
	{0x00C0AF, "TEKLOGIX INC."},
	{0x00C0B0, "GCC TECHNOLOGIES,INC."},
	{0x00C0B1, "GENIUS NET CO."},
	{0x00C0B2, "NORAND CORPORATION"},
	{0x00C0B3, "COMSTAT DATACOMM CORPORATION"},
	{0x00C0B4, "MYSON TECHNOLOGY, INC."},
	{0x00C0B5, "CORPORATE NETWORK SYSTEMS,INC."},
	{0x00C0B6, "Overland Storage, Inc."},
	{0x00C0B7, "AMERICAN POWER CONVERSION CORP"},
	{0x00C0B8, "FRASER'S HILL LTD."},
	{0x00C0B9, "FUNK SOFTWARE, INC."},
	{0x00C0BA, "NETVANTAGE"},
	{0x00C0BB, "FORVAL CREATIVE, INC."},
	{0x00C0BC, "TELECOM AUSTRALIA/CSSC"},
	{0x00C0BD, "INEX TECHNOLOGIES, INC."},
	{0x00C0BE, "ALCATEL - SEL"},
	{0x00C0BF, "TECHNOLOGY CONCEPTS, LTD."},
	{0x00C0C0, "SHORE MICROSYSTEMS, INC."},
	{0x00C0C1, "QUAD/GRAPHICS, INC."},
	{0x00C0C2, "INFINITE NETWORKS LTD."},
	{0x00C0C3, "ACUSON COMPUTED SONOGRAPHY"},
	{0x00C0C4, "COMPUTER OPERATIONAL"},
	{0x00C0C5, "SID INFORMATICA"},
	{0x00C0C6, "PERSONAL MEDIA CORP."},
	{0x00C0C7, "SPARKTRUM MICROSYSTEMS, INC."},
	{0x00C0C8, "MICRO BYTE PTY. LTD."},
	{0x00C0C9, "ELSAG BAILEY PROCESS"},
	{0x00C0CA, "ALFA, INC."},
	{0x00C0CB, "CONTROL TECHNOLOGY CORPORATION"},
	{0x00C0CC, "TELESCIENCES CO SYSTEMS, INC."},
	{0x00C0CD, "COMELTA, S.A."},
	{0x00C0CE, "CEI SYSTEMS & ENGINEERING PTE"},
	{0x00C0CF, "IMATRAN VOIMA OY"},
	{0x00C0D0, "RATOC SYSTEM INC."},
	{0x00C0D1, "COMTREE TECHNOLOGY CORPORATION"},
	{0x00C0D2, "SYNTELLECT, INC."},
	{0x00C0D3, "OLYMPUS IMAGE SYSTEMS, INC."},
	{0x00C0D4, "AXON NETWORKS, INC."},
	{0x00C0D5, "Werbeagentur Jrgen Siebert"},
	{0x00C0D6, "J1 SYSTEMS, INC."},
	{0x00C0D7, "TAIWAN TRADING CENTER DBA"},
	{0x00C0D8, "UNIVERSAL DATA SYSTEMS"},
	{0x00C0D9, "QUINTE NETWORK CONFIDENTIALITY"},
	{0x00C0DA, "NICE SYSTEMS LTD."},
	{0x00C0DB, "IPC CORPORATION (PTE) LTD."},
	{0x00C0DC, "EOS TECHNOLOGIES, INC."},
	{0x00C0DD, "QLogic Corporation"},
	{0x00C0DE, "ZCOMM, INC."},
	{0x00C0DF, "KYE Systems Corp."},
	{0x00C0E0, "DSC COMMUNICATION CORP."},
	{0x00C0E1, "SONIC SOLUTIONS"},
	{0x00C0E2, "CALCOMP, INC."},
	{0x00C0E3, "OSITECH COMMUNICATIONS, INC."},
	{0x00C0E4, "SIEMENS BUILDING"},
	{0x00C0E5, "GESPAC, S.A."},
	{0x00C0E6, "Verilink Corporation"},
	{0x00C0E7, "FIBERDATA AB"},
	{0x00C0E8, "PLEXCOM, INC."},
	{0x00C0E9, "OAK SOLUTIONS, LTD."},
	{0x00C0EA, "ARRAY TECHNOLOGY LTD."},
	{0x00C0EB, "SEH COMPUTERTECHNIK GMBH"},
	{0x00C0EC, "DAUPHIN TECHNOLOGY"},
	{0x00C0ED, "US ARMY ELECTRONIC"},
	{0x00C0EE, "KYOCERA CORPORATION"},
	{0x00C0EF, "ABIT CORPORATION"},
	{0x00C0F0, "KINGSTON TECHNOLOGY CORP."},
	{0x00C0F1, "SHINKO ELECTRIC CO., LTD."},
	{0x00C0F2, "TRANSITION NETWORKS"},
	{0x00C0F3, "NETWORK COMMUNICATIONS CORP."},
	{0x00C0F4, "INTERLINK SYSTEM CO., LTD."},
	{0x00C0F5, "METACOMP, INC."},
	{0x00C0F6, "CELAN TECHNOLOGY INC."},
	{0x00C0F7, "ENGAGE COMMUNICATION, INC."},
	{0x00C0F8, "ABOUT COMPUTING INC."},
	{0x00C0F9, "Motorola Embedded Computing Group"},
	{0x00C0FA, "CANARY COMMUNICATIONS, INC."},
	{0x00C0FB, "ADVANCED TECHNOLOGY LABS"},
	{0x00C0FC, "ELASTIC REALITY, INC."},
	{0x00C0FD, "PROSUM"},
	{0x00C0FE, "APTEC COMPUTER SYSTEMS, INC."},
	{0x00C0FF, "DOT HILL SYSTEMS CORPORATION"},
	{0x00CBBD, "Cambridge Broadband Networks Ltd."},
	{0x00CF1C, "COMMUNICATION MACHINERY CORP."},
	{0x00D000, "FERRAN SCIENTIFIC, INC."},
	{0x00D001, "VST TECHNOLOGIES, INC."},
	{0x00D002, "DITECH CORPORATION"},
	{0x00D003, "COMDA ENTERPRISES CORP."},
	{0x00D004, "PENTACOM LTD."},
	{0x00D005, "ZHS ZEITMANAGEMENTSYSTEME"},
	{0x00D006, "CISCO SYSTEMS, INC."},
	{0x00D007, "MIC ASSOCIATES, INC."},
	{0x00D008, "MACTELL CORPORATION"},
	{0x00D009, "HSING TECH. ENTERPRISE CO. LTD"},
	{0x00D00A, "LANACCESS TELECOM S.A."},
	{0x00D00B, "RHK TECHNOLOGY, INC."},
	{0x00D00C, "SNIJDER MICRO SYSTEMS"},
	{0x00D00D, "MICROMERITICS INSTRUMENT"},
	{0x00D00E, "PLURIS, INC."},
	{0x00D00F, "SPEECH DESIGN GMBH"},
	{0x00D010, "CONVERGENT NETWORKS, INC."},
	{0x00D011, "PRISM VIDEO, INC."},
	{0x00D012, "GATEWORKS CORP."},
	{0x00D013, "PRIMEX AEROSPACE COMPANY"},
	{0x00D014, "ROOT, INC."},
	{0x00D015, "UNIVEX MICROTECHNOLOGY CORP."},
	{0x00D016, "SCM MICROSYSTEMS, INC."},
	{0x00D017, "SYNTECH INFORMATION CO., LTD."},
	{0x00D018, "QWES. COM, INC."},
	{0x00D019, "DAINIPPON SCREEN CORPORATE"},
	{0x00D01A, "URMET  TLC S.P.A."},
	{0x00D01B, "MIMAKI ENGINEERING CO., LTD."},
	{0x00D01C, "SBS TECHNOLOGIES,"},
	{0x00D01D, "FURUNO ELECTRIC CO., LTD."},
	{0x00D01E, "PINGTEL CORP."},
	{0x00D01F, "CTAM PTY. LTD."},
	{0x00D020, "AIM SYSTEM, INC."},
	{0x00D021, "REGENT ELECTRONICS CORP."},
	{0x00D022, "INCREDIBLE TECHNOLOGIES, INC."},
	{0x00D023, "INFORTREND TECHNOLOGY, INC."},
	{0x00D024, "Cognex Corporation"},
	{0x00D025, "XROSSTECH, INC."},
	{0x00D026, "HIRSCHMANN AUSTRIA GMBH"},
	{0x00D027, "APPLIED AUTOMATION, INC."},
	{0x00D028, "OMNEON VIDEO NETWORKS"},
	{0x00D029, "WAKEFERN FOOD CORPORATION"},
	{0x00D02A, "Voxent Systems Ltd."},
	{0x00D02B, "JETCELL, INC."},
	{0x00D02C, "CAMPBELL SCIENTIFIC, INC."},
	{0x00D02D, "ADEMCO"},
	{0x00D02E, "COMMUNICATION AUTOMATION CORP."},
	{0x00D02F, "VLSI TECHNOLOGY INC."},
	{0x00D030, "Safetran Systems Corp"},
	{0x00D031, "INDUSTRIAL LOGIC CORPORATION"},
	{0x00D032, "YANO ELECTRIC CO., LTD."},
	{0x00D033, "DALIAN DAXIAN NETWORK"},
	{0x00D034, "ORMEC SYSTEMS CORP."},
	{0x00D035, "BEHAVIOR TECH. COMPUTER CORP."},
	{0x00D036, "TECHNOLOGY ATLANTA CORP."},
	{0x00D037, "Pace France"},
	{0x00D038, "FIVEMERE, LTD."},
	{0x00D039, "UTILICOM, INC."},
	{0x00D03A, "ZONEWORX, INC."},
	{0x00D03B, "VISION PRODUCTS PTY. LTD."},
	{0x00D03C, "Vieo, Inc."},
	{0x00D03D, "GALILEO TECHNOLOGY, LTD."},
	{0x00D03E, "ROCKETCHIPS, INC."},
	{0x00D03F, "AMERICAN COMMUNICATION"},
	{0x00D040, "SYSMATE CO., LTD."},
	{0x00D041, "AMIGO TECHNOLOGY CO., LTD."},
	{0x00D042, "MAHLO GMBH & CO. UG"},
	{0x00D043, "ZONAL RETAIL DATA SYSTEMS"},
	{0x00D044, "ALIDIAN NETWORKS, INC."},
	{0x00D045, "KVASER AB"},
	{0x00D046, "DOLBY LABORATORIES, INC."},
	{0x00D047, "XN TECHNOLOGIES"},
	{0x00D048, "ECTON, INC."},
	{0x00D049, "IMPRESSTEK CO., LTD."},
	{0x00D04A, "PRESENCE TECHNOLOGY GMBH"},
	{0x00D04B, "LA CIE GROUP S.A."},
	{0x00D04C, "EUROTEL TELECOM LTD."},
	{0x00D04D, "DIV OF RESEARCH & STATISTICS"},
	{0x00D04E, "LOGIBAG"},
	{0x00D04F, "BITRONICS, INC."},
	{0x00D050, "ISKRATEL"},
	{0x00D051, "O2 MICRO, INC."},
	{0x00D052, "ASCEND COMMUNICATIONS, INC."},
	{0x00D053, "CONNECTED SYSTEMS"},
	{0x00D054, "SAS INSTITUTE INC."},
	{0x00D055, "KATHREIN-WERKE KG"},
	{0x00D056, "SOMAT CORPORATION"},
	{0x00D057, "ULTRAK, INC."},
	{0x00D058, "CISCO SYSTEMS, INC."},
	{0x00D059, "AMBIT MICROSYSTEMS CORP."},
	{0x00D05A, "SYMBIONICS, LTD."},
	{0x00D05B, "ACROLOOP MOTION CONTROL"},
	{0x00D05C, "TECHNOTREND SYSTEMTECHNIK GMBH"},
	{0x00D05D, "INTELLIWORXX, INC."},
	{0x00D05E, "STRATABEAM TECHNOLOGY, INC."},
	{0x00D05F, "VALCOM, INC."},
	{0x00D060, "Panasonic Europe Ltd."},
	{0x00D061, "TREMON ENTERPRISES CO., LTD."},
	{0x00D062, "DIGIGRAM"},
	{0x00D063, "CISCO SYSTEMS, INC."},
	{0x00D064, "MULTITEL"},
	{0x00D065, "TOKO ELECTRIC"},
	{0x00D066, "WINTRISS ENGINEERING CORP."},
	{0x00D067, "CAMPIO COMMUNICATIONS"},
	{0x00D068, "IWILL CORPORATION"},
	{0x00D069, "TECHNOLOGIC SYSTEMS"},
	{0x00D06A, "LINKUP SYSTEMS CORPORATION"},
	{0x00D06B, "SR TELECOM INC."},
	{0x00D06C, "SHAREWAVE, INC."},
	{0x00D06D, "ACRISON, INC."},
	{0x00D06E, "TRENDVIEW RECORDERS LTD."},
	{0x00D06F, "KMC CONTROLS"},
	{0x00D070, "LONG WELL ELECTRONICS CORP."},
	{0x00D071, "ECHELON CORP."},
	{0x00D072, "BROADLOGIC"},
	{0x00D073, "ACN ADVANCED COMMUNICATIONS"},
	{0x00D074, "TAQUA SYSTEMS, INC."},
	{0x00D075, "ALARIS MEDICAL SYSTEMS, INC."},
	{0x00D076, "Merrill Lynch & Co., Inc."},
	{0x00D077, "LUCENT TECHNOLOGIES"},
	{0x00D078, "Eltex of Sweden AB"},
	{0x00D079, "CISCO SYSTEMS, INC."},
	{0x00D07A, "AMAQUEST COMPUTER CORP."},
	{0x00D07B, "COMCAM INTERNATIONAL INC"},
	{0x00D07C, "KOYO ELECTRONICS INC. CO.,LTD."},
	{0x00D07D, "COSINE COMMUNICATIONS"},
	{0x00D07E, "KEYCORP LTD."},
	{0x00D07F, "STRATEGY & TECHNOLOGY, LIMITED"},
	{0x00D080, "EXABYTE CORPORATION"},
	{0x00D081, "RTD Embedded Technologies, Inc."},
	{0x00D082, "IOWAVE INC."},
	{0x00D083, "INVERTEX, INC."},
	{0x00D084, "NEXCOMM SYSTEMS, INC."},
	{0x00D085, "OTIS ELEVATOR COMPANY"},
	{0x00D086, "FOVEON, INC."},
	{0x00D087, "MICROFIRST INC."},
	{0x00D088, "Motorola, Inc."},
	{0x00D089, "DYNACOLOR, INC."},
	{0x00D08A, "PHOTRON USA"},
	{0x00D08B, "ADVA Optical Networking Ltd"},
	{0x00D08C, "GENOA TECHNOLOGY, INC."},
	{0x00D08D, "PHOENIX GROUP, INC."},
	{0x00D08E, "NVISION INC."},
	{0x00D08F, "ARDENT TECHNOLOGIES, INC."},
	{0x00D090, "CISCO SYSTEMS, INC."},
	{0x00D091, "SMARTSAN SYSTEMS, INC."},
	{0x00D092, "GLENAYRE WESTERN MULTIPLEX"},
	{0x00D093, "TQ - COMPONENTS GMBH"},
	{0x00D094, "TIMELINE VISTA, INC."},
	{0x00D095, "Alcatel-Lucent, Enterprise Business Group"},
	{0x00D096, "3COM EUROPE LTD."},
	{0x00D097, "CISCO SYSTEMS, INC."},
	{0x00D098, "Photon Dynamics Canada Inc."},
	{0x00D099, "ELCARD OY"},
	{0x00D09A, "FILANET CORPORATION"},
	{0x00D09B, "SPECTEL LTD."},
	{0x00D09C, "KAPADIA COMMUNICATIONS"},
	{0x00D09D, "VERIS INDUSTRIES"},
	{0x00D09E, "2WIRE, INC."},
	{0x00D09F, "NOVTEK TEST SYSTEMS"},
	{0x00D0A0, "MIPS DENMARK"},
	{0x00D0A1, "OSKAR VIERLING GMBH + CO. KG"},
	{0x00D0A2, "INTEGRATED DEVICE"},
	{0x00D0A3, "VOCAL DATA, INC."},
	{0x00D0A4, "ALANTRO COMMUNICATIONS"},
	{0x00D0A5, "AMERICAN ARIUM"},
	{0x00D0A6, "LANBIRD TECHNOLOGY CO., LTD."},
	{0x00D0A7, "TOKYO SOKKI KENKYUJO CO., LTD."},
	{0x00D0A8, "NETWORK ENGINES, INC."},
	{0x00D0A9, "SHINANO KENSHI CO., LTD."},
	{0x00D0AA, "CHASE COMMUNICATIONS"},
	{0x00D0AB, "DELTAKABEL TELECOM CV"},
	{0x00D0AC, "GRAYSON WIRELESS"},
	{0x00D0AD, "TL INDUSTRIES"},
	{0x00D0AE, "ORESIS COMMUNICATIONS, INC."},
	{0x00D0AF, "CUTLER-HAMMER, INC."},
	{0x00D0B0, "BITSWITCH LTD."},
	{0x00D0B1, "OMEGA ELECTRONICS SA"},
	{0x00D0B2, "XIOTECH CORPORATION"},
	{0x00D0B3, "DRS FLIGHT SAFETY AND"},
	{0x00D0B4, "KATSUJIMA CO., LTD."},
	{0x00D0B5, "IPricot formerly DotCom"},
	{0x00D0B6, "CRESCENT NETWORKS, INC."},
	{0x00D0B7, "INTEL CORPORATION"},
	{0x00D0B8, "Iomega Corporation"},
	{0x00D0B9, "MICROTEK INTERNATIONAL, INC."},
	{0x00D0BA, "CISCO SYSTEMS, INC."},
	{0x00D0BB, "CISCO SYSTEMS, INC."},
	{0x00D0BC, "CISCO SYSTEMS, INC."},
	{0x00D0BD, "Silicon Image GmbH"},
	{0x00D0BE, "EMUTEC INC."},
	{0x00D0BF, "PIVOTAL TECHNOLOGIES"},
	{0x00D0C0, "CISCO SYSTEMS, INC."},
	{0x00D0C1, "HARMONIC DATA SYSTEMS, LTD."},
	{0x00D0C2, "BALTHAZAR TECHNOLOGY AB"},
	{0x00D0C3, "VIVID TECHNOLOGY PTE, LTD."},
	{0x00D0C4, "TERATECH CORPORATION"},
	{0x00D0C5, "COMPUTATIONAL SYSTEMS, INC."},
	{0x00D0C6, "THOMAS & BETTS CORP."},
	{0x00D0C7, "PATHWAY, INC."},
	{0x00D0C8, "Prevas A/S"},
	{0x00D0C9, "ADVANTECH CO., LTD."},
	{0x00D0CA, "Intrinsyc Software International Inc."},
	{0x00D0CB, "DASAN CO., LTD."},
	{0x00D0CC, "TECHNOLOGIES LYRE INC."},
	{0x00D0CD, "ATAN TECHNOLOGY INC."},
	{0x00D0CE, "ASYST ELECTRONIC"},
	{0x00D0CF, "MORETON BAY"},
	{0x00D0D0, "ZHONGXING TELECOM LTD."},
	{0x00D0D1, "Sycamore Networks"},
	{0x00D0D2, "EPILOG CORPORATION"},
	{0x00D0D3, "CISCO SYSTEMS, INC."},
	{0x00D0D4, "V-BITS, INC."},
	{0x00D0D5, "GRUNDIG AG"},
	{0x00D0D6, "AETHRA TELECOMUNICAZIONI"},
	{0x00D0D7, "B2C2, INC."},
	{0x00D0D8, "3Com Corporation"},
	{0x00D0D9, "DEDICATED MICROCOMPUTERS"},
	{0x00D0DA, "TAICOM DATA SYSTEMS CO., LTD."},
	{0x00D0DB, "MCQUAY INTERNATIONAL"},
	{0x00D0DC, "MODULAR MINING SYSTEMS, INC."},
	{0x00D0DD, "SUNRISE TELECOM, INC."},
	{0x00D0DE, "PHILIPS MULTIMEDIA NETWORK"},
	{0x00D0DF, "KUZUMI ELECTRONICS, INC."},
	{0x00D0E0, "DOOIN ELECTRONICS CO."},
	{0x00D0E1, "AVIONITEK ISRAEL INC."},
	{0x00D0E2, "MRT MICRO, INC."},
	{0x00D0E3, "ELE-CHEM ENGINEERING CO., LTD."},
	{0x00D0E4, "CISCO SYSTEMS, INC."},
	{0x00D0E5, "SOLIDUM SYSTEMS CORP."},
	{0x00D0E6, "IBOND INC."},
	{0x00D0E7, "VCON TELECOMMUNICATION LTD."},
	{0x00D0E8, "MAC SYSTEM CO., LTD."},
	{0x00D0E9, "Advantage Century Telecommunication Corp."},
	{0x00D0EA, "NEXTONE COMMUNICATIONS, INC."},
	{0x00D0EB, "LIGHTERA NETWORKS, INC."},
	{0x00D0EC, "NAKAYO TELECOMMUNICATIONS, INC"},
	{0x00D0ED, "XIOX"},
	{0x00D0EE, "DICTAPHONE CORPORATION"},
	{0x00D0EF, "IGT"},
	{0x00D0F0, "CONVISION TECHNOLOGY GMBH"},
	{0x00D0F1, "SEGA ENTERPRISES, LTD."},
	{0x00D0F2, "MONTEREY NETWORKS"},
	{0x00D0F3, "SOLARI DI UDINE SPA"},
	{0x00D0F4, "CARINTHIAN TECH INSTITUTE"},
	{0x00D0F5, "ORANGE MICRO, INC."},
	{0x00D0F6, "Alcatel Canada"},
	{0x00D0F7, "NEXT NETS CORPORATION"},
	{0x00D0F8, "FUJIAN STAR TERMINAL"},
	{0x00D0F9, "ACUTE COMMUNICATIONS CORP."},
	{0x00D0FA, "Thales e-Security Ltd."},
	{0x00D0FB, "TEK MICROSYSTEMS, INCORPORATED"},
	{0x00D0FC, "GRANITE MICROSYSTEMS"},
	{0x00D0FD, "OPTIMA TELE.COM, INC."},
	{0x00D0FE, "ASTRAL POINT"},
	{0x00D0FF, "CISCO SYSTEMS, INC."},
	{0x00D11C, "ACETEL"},
	{0x00DB45, "THAMWAY CO.,LTD."},
	{0x00DD00, "UNGERMANN-BASS INC."},
	{0x00DD01, "UNGERMANN-BASS INC."},
	{0x00DD02, "UNGERMANN-BASS INC."},
	{0x00DD03, "UNGERMANN-BASS INC."},
	{0x00DD04, "UNGERMANN-BASS INC."},
	{0x00DD05, "UNGERMANN-BASS INC."},
	{0x00DD06, "UNGERMANN-BASS INC."},
	{0x00DD07, "UNGERMANN-BASS INC."},
	{0x00DD08, "UNGERMANN-BASS INC."},
	{0x00DD09, "UNGERMANN-BASS INC."},
	{0x00DD0A, "UNGERMANN-BASS INC."},
	{0x00DD0B, "UNGERMANN-BASS INC."},
	{0x00DD0C, "UNGERMANN-BASS INC."},
	{0x00DD0D, "UNGERMANN-BASS INC."},
	{0x00DD0E, "UNGERMANN-BASS INC."},
	{0x00DD0F, "UNGERMANN-BASS INC."},
	{0x00E000, "Fujitsu Limited"},
	{0x00E001, "STRAND LIGHTING LIMITED"},
	{0x00E002, "CROSSROADS SYSTEMS, INC."},
	{0x00E003, "NOKIA WIRELESS BUSINESS COMMUN"},
	{0x00E004, "PMC-SIERRA, INC."},
	{0x00E005, "TECHNICAL CORP."},
	{0x00E006, "SILICON INTEGRATED SYS. CORP."},
	{0x00E007, "Avaya ECS Ltd"},
	{0x00E008, "AMAZING CONTROLS! INC."},
	{0x00E009, "MARATHON TECHNOLOGIES CORP."},
	{0x00E00A, "DIBA, INC."},
	{0x00E00B, "ROOFTOP COMMUNICATIONS CORP."},
	{0x00E00C, "MOTOROLA"},
	{0x00E00D, "RADIANT SYSTEMS"},
	{0x00E00E, "AVALON IMAGING SYSTEMS, INC."},
	{0x00E00F, "SHANGHAI BAUD DATA"},
	{0x00E010, "HESS SB-AUTOMATENBAU GmbH"},
	{0x00E011, "Uniden Corporation"},
	{0x00E012, "PLUTO TECHNOLOGIES INTERNATIONAL INC."},
	{0x00E013, "EASTERN ELECTRONIC CO., LTD."},
	{0x00E014, "CISCO SYSTEMS, INC."},
	{0x00E015, "HEIWA CORPORATION"},
	{0x00E016, "RAPID CITY COMMUNICATIONS"},
	{0x00E017, "EXXACT GmbH"},
	{0x00E018, "ASUSTEK COMPUTER INC."},
	{0x00E019, "ING. GIORDANO ELETTRONICA"},
	{0x00E01A, "COMTEC SYSTEMS. CO., LTD."},
	{0x00E01B, "SPHERE COMMUNICATIONS, INC."},
	{0x00E01C, "Cradlepoint, Inc"},
	{0x00E01D, "WebTV NETWORKS, INC."},
	{0x00E01E, "CISCO SYSTEMS, INC."},
	{0x00E01F, "AVIDIA Systems, Inc."},
	{0x00E020, "TECNOMEN OY"},
	{0x00E021, "FREEGATE CORP."},
	{0x00E022, "Analog Devices Inc."},
	{0x00E023, "TELRAD"},
	{0x00E024, "GADZOOX NETWORKS"},
	{0x00E025, "dit Co., Ltd."},
	{0x00E026, "Redlake MASD LLC"},
	{0x00E027, "DUX, INC."},
	{0x00E028, "APTIX CORPORATION"},
	{0x00E029, "STANDARD MICROSYSTEMS CORP."},
	{0x00E02A, "TANDBERG TELEVISION AS"},
	{0x00E02B, "EXTREME NETWORKS"},
	{0x00E02C, "AST COMPUTER"},
	{0x00E02D, "InnoMediaLogic, Inc."},
	{0x00E02E, "SPC ELECTRONICS CORPORATION"},
	{0x00E02F, "MCNS HOLDINGS, L.P."},
	{0x00E030, "MELITA INTERNATIONAL CORP."},
	{0x00E031, "HAGIWARA ELECTRIC CO., LTD."},
	{0x00E032, "MISYS FINANCIAL SYSTEMS, LTD."},
	{0x00E033, "E.E.P.D. GmbH"},
	{0x00E034, "CISCO SYSTEMS, INC."},
	{0x00E035, "Emerson Network Power"},
	{0x00E036, "PIONEER CORPORATION"},
	{0x00E037, "CENTURY CORPORATION"},
	{0x00E038, "PROXIMA CORPORATION"},
	{0x00E039, "PARADYNE CORP."},
	{0x00E03A, "CABLETRON SYSTEMS, INC."},
	{0x00E03B, "PROMINET CORPORATION"},
	{0x00E03C, "AdvanSys"},
	{0x00E03D, "FOCON ELECTRONIC SYSTEMS A/S"},
	{0x00E03E, "ALFATECH, INC."},
	{0x00E03F, "JATON CORPORATION"},
	{0x00E040, "DeskStation Technology, Inc."},
	{0x00E041, "CSPI"},
	{0x00E042, "Pacom Systems Ltd."},
	{0x00E043, "VitalCom"},
	{0x00E044, "LSICS CORPORATION"},
	{0x00E045, "TOUCHWAVE, INC."},
	{0x00E046, "BENTLY NEVADA CORP."},
	{0x00E047, "InFocus Corporation"},
	{0x00E048, "SDL COMMUNICATIONS, INC."},
	{0x00E049, "MICROWI ELECTRONIC GmbH"},
	{0x00E04A, "ENHANCED MESSAGING SYSTEMS, INC"},
	{0x00E04B, "JUMP INDUSTRIELLE COMPUTERTECHNIK GmbH"},
	{0x00E04C, "REALTEK SEMICONDUCTOR CORP."},
	{0x00E04D, "INTERNET INITIATIVE JAPAN, INC"},
	{0x00E04E, "SANYO DENKI CO., LTD."},
	{0x00E04F, "CISCO SYSTEMS, INC."},
	{0x00E050, "EXECUTONE INFORMATION SYSTEMS, INC."},
	{0x00E051, "TALX CORPORATION"},
	{0x00E052, "Brocade Communications Systems, Inc"},
	{0x00E053, "CELLPORT LABS, INC."},
	{0x00E054, "KODAI HITEC CO., LTD."},
	{0x00E055, "INGENIERIA ELECTRONICA COMERCIAL INELCOM S.A."},
	{0x00E056, "HOLONTECH CORPORATION"},
	{0x00E057, "HAN MICROTELECOM. CO., LTD."},
	{0x00E058, "PHASE ONE DENMARK A/S"},
	{0x00E059, "CONTROLLED ENVIRONMENTS, LTD."},
	{0x00E05A, "GALEA NETWORK SECURITY"},
	{0x00E05B, "WEST END SYSTEMS CORP."},
	{0x00E05C, "MATSUSHITA KOTOBUKI ELECTRONICS INDUSTRIES, LTD."},
	{0x00E05D, "UNITEC CO., LTD."},
	{0x00E05E, "JAPAN AVIATION ELECTRONICS INDUSTRY, LTD."},
	{0x00E05F, "e-Net, Inc."},
	{0x00E060, "SHERWOOD"},
	{0x00E061, "EdgePoint Networks, Inc."},
	{0x00E062, "HOST ENGINEERING"},
	{0x00E063, "CABLETRON - YAGO SYSTEMS, INC."},
	{0x00E064, "SAMSUNG ELECTRONICS"},
	{0x00E065, "OPTICAL ACCESS INTERNATIONAL"},
	{0x00E066, "ProMax Systems, Inc."},
	{0x00E067, "eac AUTOMATION-CONSULTING GmbH"},
	{0x00E068, "MERRIMAC SYSTEMS INC."},
	{0x00E069, "JAYCOR"},
	{0x00E06A, "KAPSCH AG"},
	{0x00E06B, "W&G SPECIAL PRODUCTS"},
	{0x00E06C, "AEP Systems International Ltd"},
	{0x00E06D, "COMPUWARE CORPORATION"},
	{0x00E06E, "FAR SYSTEMS S.p.A."},
	{0x00E06F, "Motorola, Inc."},
	{0x00E070, "DH TECHNOLOGY"},
	{0x00E071, "EPIS MICROCOMPUTER"},
	{0x00E072, "LYNK"},
	{0x00E073, "NATIONAL AMUSEMENT NETWORK, INC."},
	{0x00E074, "TIERNAN COMMUNICATIONS, INC."},
	{0x00E075, "Verilink Corporation"},
	{0x00E076, "DEVELOPMENT CONCEPTS, INC."},
	{0x00E077, "WEBGEAR, INC."},
	{0x00E078, "BERKELEY NETWORKS"},
	{0x00E079, "A.T.N.R."},
	{0x00E07A, "MIKRODIDAKT AB"},
	{0x00E07B, "BAY NETWORKS"},
	{0x00E07C, "METTLER-TOLEDO, INC."},
	{0x00E07D, "NETRONIX, INC."},
	{0x00E07E, "WALT DISNEY IMAGINEERING"},
	{0x00E07F, "LOGISTISTEM s.r.l."},
	{0x00E080, "CONTROL RESOURCES CORPORATION"},
	{0x00E081, "TYAN COMPUTER CORP."},
	{0x00E082, "ANERMA"},
	{0x00E083, "JATO TECHNOLOGIES, INC."},
	{0x00E084, "COMPULITE R&D"},
	{0x00E085, "GLOBAL MAINTECH, INC."},
	{0x00E086, "CYBEX COMPUTER PRODUCTS"},
	{0x00E087, "LeCroy - Networking Productions Division"},
	{0x00E088, "LTX CORPORATION"},
	{0x00E089, "ION Networks, Inc."},
	{0x00E08A, "GEC AVERY, LTD."},
	{0x00E08B, "QLogic Corp."},
	{0x00E08C, "NEOPARADIGM LABS, INC."},
	{0x00E08D, "PRESSURE SYSTEMS, INC."},
	{0x00E08E, "UTSTARCOM"},
	{0x00E08F, "CISCO SYSTEMS, INC."},
	{0x00E090, "BECKMAN LAB. AUTOMATION DIV."},
	{0x00E091, "LG ELECTRONICS, INC."},
	{0x00E092, "ADMTEK INCORPORATED"},
	{0x00E093, "ACKFIN NETWORKS"},
	{0x00E094, "OSAI SRL"},
	{0x00E095, "ADVANCED-VISION TECHNOLGIES CORP."},
	{0x00E096, "SHIMADZU CORPORATION"},
	{0x00E097, "CARRIER ACCESS CORPORATION"},
	{0x00E098, "AboCom Systems, Inc."},
	{0x00E099, "SAMSON AG"},
	{0x00E09A, "Positron Inc."},
	{0x00E09B, "ENGAGE NETWORKS, INC."},
	{0x00E09C, "MII"},
	{0x00E09D, "SARNOFF CORPORATION"},
	{0x00E09E, "QUANTUM CORPORATION"},
	{0x00E09F, "PIXEL VISION"},
	{0x00E0A0, "WILTRON CO."},
	{0x00E0A1, "HIMA PAUL HILDEBRANDT GmbH Co. KG"},
	{0x00E0A2, "MICROSLATE INC."},
	{0x00E0A3, "CISCO SYSTEMS, INC."},
	{0x00E0A4, "ESAOTE S.p.A."},
	{0x00E0A5, "ComCore Semiconductor, Inc."},
	{0x00E0A6, "TELOGY NETWORKS, INC."},
	{0x00E0A7, "IPC INFORMATION SYSTEMS, INC."},
	{0x00E0A8, "SAT GmbH & Co."},
	{0x00E0A9, "FUNAI ELECTRIC CO., LTD."},
	{0x00E0AA, "ELECTROSONIC LTD."},
	{0x00E0AB, "DIMAT S.A."},
	{0x00E0AC, "MIDSCO, INC."},
	{0x00E0AD, "EES TECHNOLOGY, LTD."},
	{0x00E0AE, "XAQTI CORPORATION"},
	{0x00E0AF, "GENERAL DYNAMICS INFORMATION SYSTEMS"},
	{0x00E0B0, "CISCO SYSTEMS, INC."},
	{0x00E0B1, "Alcatel-Lucent, Enterprise Business Group"},
	{0x00E0B2, "TELMAX COMMUNICATIONS CORP."},
	{0x00E0B3, "EtherWAN Systems, Inc."},
	{0x00E0B4, "TECHNO SCOPE CO., LTD."},
	{0x00E0B5, "ARDENT COMMUNICATIONS CORP."},
	{0x00E0B6, "Entrada Networks"},
	{0x00E0B7, "PI GROUP, LTD."},
	{0x00E0B8, "GATEWAY 2000"},
	{0x00E0B9, "BYAS SYSTEMS"},
	{0x00E0BA, "BERGHOF AUTOMATIONSTECHNIK GmbH"},
	{0x00E0BB, "NBX CORPORATION"},
	{0x00E0BC, "SYMON COMMUNICATIONS, INC."},
	{0x00E0BD, "INTERFACE SYSTEMS, INC."},
	{0x00E0BE, "GENROCO INTERNATIONAL, INC."},
	{0x00E0BF, "TORRENT NETWORKING TECHNOLOGIES CORP."},
	{0x00E0C0, "SEIWA ELECTRIC MFG. CO., LTD."},
	{0x00E0C1, "MEMOREX TELEX JAPAN, LTD."},
	{0x00E0C2, "NECSY S.p.A."},
	{0x00E0C3, "SAKAI SYSTEM DEVELOPMENT CORP."},
	{0x00E0C4, "HORNER ELECTRIC, INC."},
	{0x00E0C5, "BCOM ELECTRONICS INC."},
	{0x00E0C6, "LINK2IT, L.L.C."},
	{0x00E0C7, "EUROTECH SRL"},
	{0x00E0C8, "VIRTUAL ACCESS, LTD."},
	{0x00E0C9, "AutomatedLogic Corporation"},
	{0x00E0CA, "BEST DATA PRODUCTS"},
	{0x00E0CB, "RESON, INC."},
	{0x00E0CC, "HERO SYSTEMS, LTD."},
	{0x00E0CD, "SENSIS CORPORATION"},
	{0x00E0CE, "ARN"},
	{0x00E0CF, "INTEGRATED DEVICE TECHNOLOGY, INC."},
	{0x00E0D0, "NETSPEED, INC."},
	{0x00E0D1, "TELSIS LIMITED"},
	{0x00E0D2, "VERSANET COMMUNICATIONS, INC."},
	{0x00E0D3, "DATENTECHNIK GmbH"},
	{0x00E0D4, "EXCELLENT COMPUTER"},
	{0x00E0D5, "Emulex Corporation"},
	{0x00E0D6, "COMPUTER & COMMUNICATION RESEARCH LAB."},
	{0x00E0D7, "SUNSHINE ELECTRONICS, INC."},
	{0x00E0D8, "LANBit Computer, Inc."},
	{0x00E0D9, "TAZMO CO., LTD."},
	{0x00E0DA, "Alcatel North America ESD"},
	{0x00E0DB, "ViaVideo Communications, Inc."},
	{0x00E0DC, "NEXWARE CORP."},
	{0x00E0DD, "ZENITH ELECTRONICS CORPORATION"},
	{0x00E0DE, "DATAX NV"},
	{0x00E0DF, "KEYMILE GmbH"},
	{0x00E0E0, "SI ELECTRONICS, LTD."},
	{0x00E0E1, "G2 NETWORKS, INC."},
	{0x00E0E2, "INNOVA CORP."},
	{0x00E0E3, "SK-ELEKTRONIK GmbH"},
	{0x00E0E4, "FANUC ROBOTICS NORTH AMERICA, Inc."},
	{0x00E0E5, "CINCO NETWORKS, INC."},
	{0x00E0E6, "INCAA DATACOM B.V."},
	{0x00E0E7, "RAYTHEON E-SYSTEMS, INC."},
	{0x00E0E8, "GRETACODER Data Systems AG"},
	{0x00E0E9, "DATA LABS, INC."},
	{0x00E0EA, "INNOVAT COMMUNICATIONS, INC."},
	{0x00E0EB, "DIGICOM SYSTEMS, INCORPORATED"},
	{0x00E0EC, "CELESTICA INC."},
	{0x00E0ED, "SILICOM, LTD."},
	{0x00E0EE, "MAREL HF"},
	{0x00E0EF, "DIONEX"},
	{0x00E0F0, "ABLER TECHNOLOGY, INC."},
	{0x00E0F1, "THAT CORPORATION"},
	{0x00E0F2, "ARLOTTO COMNET, INC."},
	{0x00E0F3, "WebSprint Communications, Inc."},
	{0x00E0F4, "INSIDE Technology A/S"},
	{0x00E0F5, "TELES AG"},
	{0x00E0F6, "DECISION EUROPE"},
	{0x00E0F7, "CISCO SYSTEMS, INC."},
	{0x00E0F8, "DICNA CONTROL AB"},
	{0x00E0F9, "CISCO SYSTEMS, INC."},
	{0x00E0FA, "TRL TECHNOLOGY, LTD."},
	{0x00E0FB, "LEIGHTRONIX, INC."},
	{0x00E0FC, "HUAWEI TECHNOLOGIES CO., LTD."},
	{0x00E0FD, "A-TREND TECHNOLOGY CO., LTD."},
	{0x00E0FE, "CISCO SYSTEMS, INC."},
	{0x00E0FF, "SECURITY DYNAMICS TECHNOLOGIES, Inc."},
	{0x00E6D3, "NIXDORF COMPUTER CORP."},
	{0x020701, "RACAL-DATACOM"},
	{0x021C7C, "PERQ SYSTEMS CORPORATION"},
	{0x026086, "LOGIC REPLACEMENT TECH. LTD."},
	{0x02608C, "3COM CORPORATION"},
	{0x027001, "RACAL-DATACOM"},
	{0x0270B0, "M/A-COM INC. COMPANIES"},
	{0x0270B3, "DATA RECALL LTD"},
	{0x029D8E, "CARDIAC RECORDERS INC."},
	{0x02AA3C, "OLIVETTI TELECOMM SPA (OLTECO)"},
	{0x02BB01, "OCTOTHORPE CORP."},
	{0x02C08C, "3COM CORPORATION"},
	{0x02CF1C, "COMMUNICATION MACHINERY CORP."},
	{0x02E6D3, "NIXDORF COMPUTER CORPORATION"},
	{0x040AE0, "XMIT AG COMPUTER NETWORKS"},
	{0x040EC2, "ViewSonic Mobile China Limited"},
	{0x041E64, "Apple, Inc"},
	{0x042234, "Wireless Standard Extensions"},
	{0x042BBB, "PicoCELA, Inc."},
	{0x042F56, "ATOCS (Shenzhen) LTD"},
	{0x044FAA, "Ruckus Wireless"},
	{0x04766E, "ALPS Co,. Ltd."},
	{0x0494A1, "CATCH THE WIND INC"},
	{0x049F81, "Simena, LLC"},
	{0x04B3B6, "Seamap (UK) Ltd"},
	{0x04B466, "BSP Co., Ltd."},
	{0x04C05B, "Tigo Energy"},
	{0x04C880, "Samtec Inc"},
	{0x04E0C4, "TRIUMPH-ADLER AG"},
	{0x04FE7F, "Cisco Systems"},
	{0x080001, "COMPUTERVISION CORPORATION"},
	{0x080002, "BRIDGE COMMUNICATIONS INC."},
	{0x080003, "ADVANCED COMPUTER COMM."},
	{0x080004, "CROMEMCO INCORPORATED"},
	{0x080005, "SYMBOLICS INC."},
	{0x080006, "SIEMENS AG"},
	{0x080007, "APPLE COMPUTER INC."},
	{0x080008, "BOLT BERANEK AND NEWMAN INC."},
	{0x080009, "HEWLETT PACKARD"},
	{0x08000A, "NESTAR SYSTEMS INCORPORATED"},
	{0x08000B, "UNISYS CORPORATION"},
	{0x08000C, "MIKLYN DEVELOPMENT CO."},
	{0x08000D, "INTERNATIONAL COMPUTERS LTD."},
	{0x08000E, "NCR CORPORATION"},
	{0x08000F, "MITEL CORPORATION"},
	{0x080011, "TEKTRONIX INC."},
	{0x080012, "BELL ATLANTIC INTEGRATED SYST."},
	{0x080013, "EXXON"},
	{0x080014, "EXCELAN"},
	{0x080015, "STC BUSINESS SYSTEMS"},
	{0x080016, "BARRISTER INFO SYS CORP"},
	{0x080017, "NATIONAL SEMICONDUCTOR"},
	{0x080018, "PIRELLI FOCOM NETWORKS"},
	{0x080019, "GENERAL ELECTRIC CORPORATION"},
	{0x08001A, "TIARA/ 10NET"},
	{0x08001B, "EMC Corporation"},
	{0x08001C, "KDD-KOKUSAI DEBNSIN DENWA CO."},
	{0x08001D, "ABLE COMMUNICATIONS INC."},
	{0x08001E, "APOLLO COMPUTER INC."},
	{0x08001F, "SHARP CORPORATION"},
	{0x080020, "SUN MICROSYSTEMS INC."},
	{0x080021, "3M COMPANY"},
	{0x080022, "NBI INC."},
	{0x080023, "Panasonic Communications Co., Ltd."},
	{0x080024, "10NET COMMUNICATIONS/DCA"},
	{0x080025, "CONTROL DATA"},
	{0x080026, "NORSK DATA A.S."},
	{0x080027, "CADMUS COMPUTER SYSTEMS"},
	{0x080028, "Texas Instruments"},
	{0x080029, "MEGATEK CORPORATION"},
	{0x08002A, "MOSAIC TECHNOLOGIES INC."},
	{0x08002B, "DIGITAL EQUIPMENT CORPORATION"},
	{0x08002C, "BRITTON LEE INC."},
	{0x08002D, "LAN-TEC INC."},
	{0x08002E, "METAPHOR COMPUTER SYSTEMS"},
	{0x08002F, "PRIME COMPUTER INC."},
	{0x080030, "NETWORK RESEARCH CORPORATION"},
	{0x080030, "CERN"},
	{0x080030, "ROYAL MELBOURNE INST OF TECH"},
	{0x080031, "LITTLE MACHINES INC."},
	{0x080032, "TIGAN INCORPORATED"},
	{0x080033, "BAUSCH & LOMB"},
	{0x080034, "FILENET CORPORATION"},
	{0x080035, "MICROFIVE CORPORATION"},
	{0x080036, "INTERGRAPH CORPORATION"},
	{0x080037, "FUJI-XEROX CO. LTD."},
	{0x080038, "CII HONEYWELL BULL"},
	{0x080039, "SPIDER SYSTEMS LIMITED"},
	{0x08003A, "ORCATECH INC."},
	{0x08003B, "TORUS SYSTEMS LIMITED"},
	{0x08003C, "SCHLUMBERGER WELL SERVICES"},
	{0x08003D, "CADNETIX CORPORATIONS"},
	{0x08003E, "CODEX CORPORATION"},
	{0x08003F, "FRED KOSCHARA ENTERPRISES"},
	{0x080040, "FERRANTI COMPUTER SYS. LIMITED"},
	{0x080041, "RACAL-MILGO INFORMATION SYS.."},
	{0x080042, "JAPAN MACNICS CORP."},
	{0x080043, "PIXEL COMPUTER INC."},
	{0x080044, "DAVID SYSTEMS INC."},
	{0x080045, "CONCURRENT COMPUTER CORP."},
	{0x080046, "Sony Corporation"},
	{0x080047, "SEQUENT COMPUTER SYSTEMS INC."},
	{0x080048, "EUROTHERM GAUGING SYSTEMS"},
	{0x080049, "UNIVATION"},
	{0x08004A, "BANYAN SYSTEMS INC."},
	{0x08004B, "PLANNING RESEARCH CORP."},
	{0x08004C, "HYDRA COMPUTER SYSTEMS INC."},
	{0x08004D, "CORVUS SYSTEMS INC."},
	{0x08004E, "3COM EUROPE LTD."},
	{0x08004F, "CYGNET SYSTEMS"},
	{0x080050, "DAISY SYSTEMS CORP."},
	{0x080051, "EXPERDATA"},
	{0x080052, "INSYSTEC"},
	{0x080053, "MIDDLE EAST TECH. UNIVERSITY"},
	{0x080055, "STANFORD TELECOMM. INC."},
	{0x080056, "STANFORD LINEAR ACCEL. CENTER"},
	{0x080057, "EVANS & SUTHERLAND"},
	{0x080058, "SYSTEMS CONCEPTS"},
	{0x080059, "A/S MYCRON"},
	{0x08005A, "IBM CORPORATION"},
	{0x08005B, "VTA TECHNOLOGIES INC."},
	{0x08005C, "FOUR PHASE SYSTEMS"},
	{0x08005D, "GOULD INC."},
	{0x08005E, "COUNTERPOINT COMPUTER INC."},
	{0x08005F, "SABER TECHNOLOGY CORP."},
	{0x080060, "INDUSTRIAL NETWORKING INC."},
	{0x080061, "JAROGATE LTD."},
	{0x080062, "GENERAL DYNAMICS"},
	{0x080063, "PLESSEY"},
	{0x080064, "AUTOPHON AG"},
	{0x080065, "GENRAD INC."},
	{0x080066, "AGFA CORPORATION"},
	{0x080067, "COMDESIGN"},
	{0x080068, "RIDGE COMPUTERS"},
	{0x080069, "SILICON GRAPHICS INC."},
	{0x08006A, "ATT BELL LABORATORIES"},
	{0x08006B, "ACCEL TECHNOLOGIES INC."},
	{0x08006C, "SUNTEK TECHNOLOGY INT'L"},
	{0x08006D, "WHITECHAPEL COMPUTER WORKS"},
	{0x08006E, "MASSCOMP"},
	{0x08006F, "PHILIPS APELDOORN B.V."},
	{0x080070, "MITSUBISHI ELECTRIC CORP."},
	{0x080071, "MATRA (DSIE)"},
	{0x080072, "XEROX CORP UNIV GRANT PROGRAM"},
	{0x080073, "TECMAR INC."},
	{0x080074, "CASIO COMPUTER CO. LTD."},
	{0x080075, "DANSK DATA ELECTRONIK"},
	{0x080076, "PC LAN TECHNOLOGIES"},
	{0x080077, "TSL COMMUNICATIONS LTD."},
	{0x080078, "ACCELL CORPORATION"},
	{0x080079, "THE DROID WORKS"},
	{0x08007A, "INDATA"},
	{0x08007B, "SANYO ELECTRIC CO. LTD."},
	{0x08007C, "VITALINK COMMUNICATIONS CORP."},
	{0x08007E, "AMALGAMATED WIRELESS(AUS) LTD"},
	{0x08007F, "CARNEGIE-MELLON UNIVERSITY"},
	{0x080080, "AES DATA INC."},
	{0x080081, ",ASTECH INC."},
	{0x080082, "VERITAS SOFTWARE"},
	{0x080083, "Seiko Instruments Inc."},
	{0x080084, "TOMEN ELECTRONICS CORP."},
	{0x080085, "ELXSI"},
	{0x080086, "KONICA MINOLTA HOLDINGS, INC."},
	{0x080087, "XYPLEX"},
	{0x080088, "Brocade Communications Systems, Inc."},
	{0x080089, "KINETICS"},
	{0x08008A, "PERFORMANCE TECHNOLOGY"},
	{0x08008B, "PYRAMID TECHNOLOGY CORP."},
	{0x08008C, "NETWORK RESEARCH CORPORATION"},
	{0x08008D, "XYVISION INC."},
	{0x08008E, "TANDEM COMPUTERS"},
	{0x08008F, "CHIPCOM CORPORATION"},
	{0x080090, "SONOMA SYSTEMS"},
	{0x081443, "UNIBRAIN S.A."},
	{0x081651, "Shenzhen Sea Star Technology Co.,Ltd"},
	{0x08184C, "A. S. Thomas, Inc."},
	{0x081FF3, "Cisco Systems"},
	{0x082AD0, "SRD Innovations Inc."},
	{0x084E1C, "H2A Systems, LLC"},
	{0x087618, "ViE Technologies Sdn. Bhd."},
	{0x087695, "Auto Industrial Co., Ltd."},
	{0x08BBCC, "AK-NORD EDV VERTRIEBSGES. mbH"},
	{0x08F2F4, "Net One Partners Co.,Ltd."},
	{0x0C17F1, "TELECSYS"},
	{0x0C2755, "Valuable Techologies Limited"},
	{0x0C6076, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x0C7D7C, "Kexiang Information Technology Co, Ltd."},
	{0x0C8230, "SHENZHEN MAGNUS TECHNOLOGIES CO.,LTD"},
	{0x0C8411, "A.O. Smith Water Products"},
	{0x0CA42A, "OB Telecom Electronic Technology Co., Ltd"},
	{0x0CC3A7, "Meritec"},
	{0x0CC9C6, "Samwin Hong Kong Limited"},
	{0x0CD502, "Westell"},
	{0x0CD7C2, "Axium Technologies, Inc."},
	{0x0CE709, "Fox Crypto B.V."},
	{0x0CE936, "ELIMOS srl"},
	{0x0CEEE6, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x0CEF7C, "AnaCom Inc"},
	{0x10005A, "IBM CORPORATION"},
	{0x1000E8, "NATIONAL SEMICONDUCTOR"},
	{0x1010B6, "McCain Inc"},
	{0x10189E, "Elmo Motion Control"},
	{0x102D96, "Looxcie Inc."},
	{0x104369, "Soundmax Electronic Limited "},
	{0x10445A, "Shaanxi Hitech Electronic Co., LTD"},
	{0x1045F8, "LNT-Automation GmbH"},
	{0x1056CA, "Peplink International Ltd."},
	{0x1062C9, "Adatis GmbH & Co. KG"},
	{0x1065A3, "Panamax Inc."},
	{0x10880F, "DARUMA TELECOMUNICAES E INFORMTICA S/A"},
	{0x10B7F6, "Plastoform Industries Ltd."},
	{0x10BAA5, "GANA I&C CO., LTD"},
	{0x10C73F, "Midas Klark Teknik Ltd"},
	{0x10CA81, "PRECIA"},
	{0x10E6AE, "Source Technologies, LLC"},
	{0x147373, "TUBITAK UEKAE"},
	{0x14A62C, "S.M. Dezac S.A."},
	{0x14A86B, "ShenZhen Telacom Science&Technology Co., Ltd"},
	{0x1801E3, "Elektrobit Wireless Communications Ltd"},
	{0x181714, "DAEWOOIS"},
	{0x183BD2, "BYD Precision Manufacture Company Ltd."},
	{0x1886AC, "Nokia Danmark A/S"},
	{0x18A905, "Hewlett Packard"},
	{0x18C086, "Broadcom Corporation"},
	{0x18FC9F, "Changhe Electronics Co., Ltd."},
	{0x1C0FCF, "Sypro Optics GmbH"},
	{0x1C129D, "IEEE PES PSRC/SUB     "},
	{0x1C4BD6, "AzureWave"},
	{0x1C8F8A, "Phase Motion Control SpA"},
	{0x1CAFF7, "D-LINK INTERNATIONAL PTE LIMITED"},
	{0x1CBDB9, "D-LINK INTERNATIONAL PTE LIMITED"},
	{0x1CF061, "SCAPS GmbH"},
	{0x201257, "Most Lucky Trading Ltd"},
	{0x2021A5, "LG Electronics Inc"},
	{0x202CB7, "Kong Yue Electronics & Information Industry (Xinhui) Ltd."},
	{0x20415A, "Smarteh d.o.o."},
	{0x2046F9, "Advanced Network Devices (dba:AND)"},
	{0x204E6B, "Axxana(israel) ltd"},
	{0x2059A0, "Paragon Technologies Inc."},
	{0x207C8F, "Quanta Microsystems,Inc."},
	{0x20BFDB, "DVL"},
	{0x2421AB, "Sony Ericsson Mobile Communications"},
	{0x243C20, "Dynamode Group"},
	{0x24828A, "Prowave Technologies Ltd."},
	{0x24CF21, "Shenzhen State Micro Technology Co., Ltd"},
	{0x24D2CC, "SmartDrive Systems Inc."},
	{0x24DBAD, "ShopperTrak RCT Corporation"},
	{0x286ED4, "HUAWEI TECHNOLOGIES CO.,LTD"},
	{0x2872C5, "Smartmatic Corp"},
	{0x28E794, "Microtime Computer Inc."},
	{0x28FBD3, "Shanghai RagenTek Communication Technology Co.,Ltd."},
	{0x2C0623, "Win Leader Inc."},
	{0x2C1984, "IDN Telecom, Inc."},
	{0x2C3427, "ERCO &amp; GENER"},
	{0x2C3A28, "Fagor Electr�nica"},
	{0x2C3F3E, "Alge-Timing GmbH"},
	{0x2C6BF5, "Juniper networks"},
	{0x2C8158, "Hon Hai Precision Ind. Co.,Ltd"},
	{0x2C9127, "Eintechno Corporation"},
	{0x2CA780, "True Technologies Inc."},
	{0x2CA835, "RIM"},
	{0x2CCD27, "Precor Inc"},
	{0x3032D4, "Hanilstm Co., Ltd."},
	{0x3037A6, "Cisco Systems"},
	{0x304174, "ALTEC LANSING LLC"},
	{0x30469A, "NETGEAR"},
	{0x30525A, "NST Co., LTD"},
	{0x307C30, "RIM"},
	{0x30EFD1, "Alstom Strongwish (Shenzhen) Co., Ltd."},
	{0x34159E, "Apple, Inc"},
	{0x347E39, "Nokia Danmark A/S"},
	{0x34862A, "Heinz Lackmann GmbH & Co KG"},
	{0x34C3AC, "Samsung Electronics"},
	{0x34C69A, "Enecsys Ltd"},
	{0x34CE94, "Parsec (Pty) Ltd"},
	{0x34EF44, "2Wire"},
	{0x34EF8B, "NTT Communications Corporation"},
	{0x38229D, "PIRELLI BROADBAND SOLUTIONS "},
	{0x3863F6, "3NOD MULTIMEDIA(SHENZHEN)CO.,LTD"},
	{0x389F83, "OTN Systems N.V."},
	{0x38BB23, "OzVision America LLC"},
	{0x38E7D8, "HTC Corporation"},
	{0x38E8DF, "b gmbh medien + datenbanken"},
	{0x38E98C, "Reco S.p.A."},
	{0x3C05AB, "Product Creation Studio"},
	{0x3C1CBE, "JADAK LLC"},
	{0x3C2DB7, "Texas Instruments"},
	{0x3C39C3, "JW Electronics Co., Ltd."},
	{0x3C4C69, "Infinity System S.L."},
	{0x3CB17F, "Wattwatchers Pty Ld"},
	{0x3CDF1E, "Cisco Systems"},
	{0x3CE5A6, "Hangzhou H3C Technologies Co., Ltd."},
	{0x3CF52C, "DSPECIALISTS GmbH"},
	{0x3CF72A, "Nokia Corporation"},
	{0x4001C6, "3COM EUROPE LTD"},
	{0x4012E4, "Compass-EOS"},
	{0x401597, "Protect America, Inc."},
	{0x4025C2, "Intel Corporate"},
	{0x402BA1, "Sony Ericsson Mobile Communications AB"},
	{0x404A03, "ZyXEL Communications Corporation"},
	{0x406186, "MICRO-STAR INT'L CO.,LTD"},
	{0x408A9A, "TITENG CO., Ltd."},
	{0x409558, "Aisino Corporation"},
	{0x4097D1, "BK Electronics cc"},
	{0x40A6A4, "PassivSystems Ltd"},
	{0x40D32D, "Apple, Inc"},
	{0x40ECF8, "Siemens AG"},
	{0x40EF4C, "Fihonest communication co.,Ltd"},
	{0x40F52E, "Leica Microsystems (Schweiz) AG"},
	{0x44376F, "Young Electric Sign Co"},
	{0x444E1A, "Samsung Electronics Co.,Ltd"},
	{0x44568D, "PNC Technologies  Co., Ltd."},
	{0x4456B7, "Spawn Labs, Inc"},
	{0x446C24, "Reallin Electronic Co.,Ltd"},
	{0x448312, "Star-Net"},
	{0x4487FC, "ELITEGROUP COMPUTER SYSTEM CO., LTD."},
	{0x448E81, "VIG"},
	{0x44A42D, "TCT Mobile Limited"},
	{0x44A8C2, "SEWOO TECH CO., LTD"},
	{0x44C233, "Guangzhou Comet Technology Development Co.Ltd"},
	{0x44C9A2, "Greenwald Industries"},
	{0x44E49A, "OMNITRONICS PTY LTD"},
	{0x44F459, "Samsung Electronics"},
	{0x481BD2, "Intron Scientific co., ltd."},
	{0x48343D, "IEP GmbH"},
	{0x484487, "Cisco SPVTG"},
	{0x485B39, "ASUSTek COMPUTER INC."},
	{0x486FD2, "StorSimple Inc"},
	{0x487119, "SGB GROUP LTD."},
	{0x48AA5D, "Store Electronic Systems"},
	{0x48EB30, "ETERNA TECHNOLOGY, INC."},
	{0x4C322D, "TELEDATA NETWORKS"},
	{0x4C4B68, "Mobile Device, Inc. "},
	{0x4C63EB, "Application Solutions (Electronics and Vision) Ltd"},
	{0x4C9EE4, "Hanyang Navicom Co.,Ltd."},
	{0x4CC452, "Shang Hai Tyd. Electon Technology Ltd."},
	{0x4CC602, "Radios, Inc."},
	{0x50252B, "Nethra Imaging Incorporated"},
	{0x502A7E, "Smart electronic GmbH"},
	{0x502A8B, "Telekom Research and Development Sdn Bhd"},
	{0x502DA2, "Intel Corporate"},
	{0x502DF4, "Phytec Messtechnik GmbH"},
	{0x506313, "Hon Hai Precision Ind. Co.,Ltd. "},
	{0x50934F, "Gradual Tecnologia Ltda."},
	{0x50A6E3, "David Clark Company"},
	{0x50F003, "Open Stack, Inc."},
	{0x5403F5, "EBN Technology Corp."},
	{0x544249, "Sony Corporation"},
	{0x545FA9, "Teracom Limited"},
	{0x547FEE, "Cisco Systems"},
	{0x5492BE, "Samsung Electronics Co.,Ltd"},
	{0x549A16, "Uzushio Electric Co.,Ltd."},
	{0x54B620, "SUHDOL E&C Co.Ltd."},
	{0x54D46F, "Cisco SPVTG"},
	{0x580556, "Elettronica GF S.r.L."},
	{0x583CC6, "Omneality Ltd."},
	{0x5849BA, "Chitai Electronic Corp."},
	{0x584CEE, "Digital One Technologies, Limited"},
	{0x5850E6, "Best Buy Corporation"},
	{0x58B035, "Apple, Inc"},
	{0x58F67B, "Xia Men UnionCore Technology LTD."},
	{0x5C1437, "Thyssenkrupp Aufzugswerke GmbH"},
	{0x5C338E, "Alpha Networkc Inc."},
	{0x5C35DA, "There Corporation Oy"},
	{0x5C57C8, "Nokia Corporation"},
	{0x5C8778, "Cybertelbridge co.,ltd"},
	{0x5CE223, "Delphin Technology AG"},
	{0x5CE286, "Nortel Networks"},
	{0x5CFF35, "Wistron Corporation"},
	{0x601283, "Soluciones Tecnologicas para la Salud y el Bienestar SA"},
	{0x601D0F, "Midnite Solar"},
	{0x60380E, "Alps Electric Co.,"},
	{0x60391F, "ABB Ltd"},
	{0x6089B7,
	 "KAEL M�HENDISLIK ELEKTRONIK TICARET SANAYI Limited �irketi"},
	{0x608D17, "Sentrus Government Systems Division, Inc"},
	{0x609F9D, "CloudSwitch"},
	{0x60B3C4, "Elber Srl"},
	{0x60D0A9, "Samsung Electronics Co.,Ltd"},
	{0x60D30A, "Quatius Limited"},
	{0x60F13D, "JABLOCOM s.r.o."},
	{0x60FB42, "Apple, Inc"},
	{0x64168D, "Cisco Systems"},
	{0x6416F0, "Shehzhen Huawei Communication Technologies Co., Ltd."},
	{0x644BC3, "Shanghai WOASiS Telecommunications Ltd., Co."},
	{0x644F74, "LENUS Co., Ltd."},
	{0x6465C0, "Nuvon, Inc"},
	{0x64680C, "COMTREND"},
	{0x646E6C, "Radio Datacom LLC"},
	{0x647D81, "YOKOTA INDUSTRIAL CO,.LTD"},
	{0x64A837, "Juni Korea Co., Ltd"},
	{0x64B9E8, "Apple, Inc"},
	{0x64BC11, "CombiQ AB"},
	{0x64C6AF, "AXERRA Networks Ltd"},
	{0x64D4DA, "Intel Corporate"},
	{0x64DB18, "OpenPattern"},
	{0x64ED57, "Motorola MDb/Broadband"},
	{0x64F970, "Kenade Electronics Technology Co.,LTD."},
	{0x681FD8, "Advanced Telemetry"},
	{0x687924, "ELS-GmbH & Co. KG"},
	{0x687F74, "Cisco-Linksys, LLC"},
	{0x688540, "IGI Mobile, Inc."},
	{0x68A1B7, "Honghao Mingchuan Technology (Beijing) CO.,Ltd."},
	{0x68AAD2, "DATECS LTD.,"},
	{0x68CC9C, "Mine Site Technologies"},
	{0x68EFBD, "Cisco Systems"},
	{0x6C0E0D, "Sony Ericsson Mobile Communications AB"},
	{0x6C0F6A, "JDC Tech Co., Ltd."},
	{0x6C1811, "Decatur Electronics"},
	{0x6C32DE, "Indieon Technologies Pvt. Ltd."},
	{0x6C3E9C, "KE Knestel Elektronik GmbH"},
	{0x6C5E7A, "Ubiquitous Internet Telecom Co., Ltd"},
	{0x6C6F18, "Stereotaxis, Inc."},
	{0x6C8CDB, "Otus Technologies Ltd"},
	{0x6CAC60, "Venetex Corp"},
	{0x6CBEE9, "Alcatel-Lucent-IPD"},
	{0x6CD68A, "LG Electronics Inc"},
	{0x6CF049, "GIGA-BYTE TECHNOLOGY CO.,LTD."},
	{0x6CFDB9, "Proware Technologies Co Ltd."},
	{0x6CFFBE, "MPB Communications Inc."},
	{0x701A04, "Liteon Tech Corp."},
	{0x701AED, "ADVAS CO., LTD."},
	{0x702B1D, "E-Domus International Limited"},
	{0x702F97, "Aava Mobile Oy"},
	{0x703C39, "SEAWING Kft"},
	{0x705812, "Panasonic AVC Networks Company"},
	{0x705AB6, "COMPAL INFORMATION (KUNSHAN) CO., LTD. "},
	{0x7071BC, "PEGATRON CORPORATION"},
	{0x7072CF, "EdgeCore Networks"},
	{0x70828E, "OleumTech Corporation"},
	{0x70D5E7, "Wellcore Corporation"},
	{0x70D880, "Upos System sp. z o.o."},
	{0x70F1A1, "Liteon Technology Corporation"},
	{0x743256, "NT-ware Systemprg GmbH"},
	{0x746B82, "MOVEK "},
	{0x747E1A, "Red Embedded Design Limited"},
	{0x748EF8, "Brocade Communications Systems, Inc."},
	{0x74D850, "Evrisko Systems"},
	{0x74E537, "RADSPIN"},
	{0x74F07D, "BnCOM Co.,Ltd"},
	{0x74F726, "Neuron Robotics"},
	{0x781185, "NBS Payment Solutions Inc."},
	{0x7812B8, "ORANTEK LIMITED"},
	{0x78192E, "NASCENT Technology"},
	{0x781DBA, "HUAWEI TECHNOLOGIES CO.,LTD"},
	{0x7825AD, "SAMSUNG ELECTRONICS CO., LTD."},
	{0x7830E1, "UltraClenz, LLC"},
	{0x784476, "Zioncom technology co.,ltd"},
	{0x785C72, "Hioso Technology Co., Ltd."},
	{0x787F62, "GiK mbH"},
	{0x7884EE, "INDRA ESPACIO S.A."},
	{0x78929C, "Intel Corporate"},
	{0x78998F, "MEDILINE ITALIA SRL"},
	{0x78B81A, "INTER SALES A/S"},
	{0x78C40E, "H&D Wireless "},
	{0x78DD08, "Hon Hai Precision Ind. Co.,Ltd. "},
	{0x78E7D1, "Hewlett Packard"},
	{0x7C08D9,
	 "Shanghai Engineering Research Center for Broadband Technologies and Applications"},
	{0x7C1476, "AE Partners S.a.s"},
	{0x7C1EB3, "2N TELEKOMUNIKACE a.s."},
	{0x7C2064, "Alcatel Lucent IPD"},
	{0x7C2CF3, "Secure Electrans Ltd"},
	{0x7C2F80, "Gigaset Communications GmbH"},
	{0x7C3BD5, "Imago Group"},
	{0x7C6C8F, "AMS NEVE LTD"},
	{0x7C6D62, "Apple, Inc"},
	{0x7C6F06, "Caterpillar Trimble Control Technologies"},
	{0x7C7673, "ENMAS GmbH"},
	{0x7C7BE4, "Z&#39;SEDAI KENKYUSHO CORPORATION"},
	{0x7CCB0D, "Aaxeon Technologies Inc."},
	{0x7CCFCF, "Shanghai SEARI Intelligent System Co., Ltd"},
	{0x800010, "ATT BELL LABORATORIES"},
	{0x80177D, "Nortel Networks"},
	{0x8038FD, "LeapFrog Enterprises, Inc."},
	{0x803B9A, "ghe-ces electronic ag"},
	{0x80711F, "Juniper Networks"},
	{0x8081A5, "TONGQING COMMUNICATION EQUIPMENT (SHENZHEN) Co.,Ltd"},
	{0x80912A, "Lih Rong electronic Enterprise Co., Ltd."},
	{0x80B289, "Forworld Electronics Ltd."},
	{0x80BAAC, "TeleAdapt Ltd"},
	{0x80C862, "Openpeak, Inc"},
	{0x80F593, "IRCO Sistemas de Telecomunicaci�n S.A."},
	{0x842141, "Shenzhen Ginwave Technologies Ltd."},
	{0x844823, "WOXTER TECHNOLOGY Co. Ltd"},
	{0x849000, "Arnold &amp; Richter Cine Technik"},
	{0x8843E1, "Cisco Systems"},
	{0x884B39, "Siemens AG, Healthcare Sector"},
	{0x8891DD, "Racktivity"},
	{0x8894F9, "Gemicom Technology, Inc."},
	{0x889821, "TERAON"},
	{0x88A5BD, "QPCOM INC."},
	{0x88B627, "Gembird Europe BV"},
	{0x88BA7F, "Qfiednet Co., Ltd."},
	{0x88ED1C, "Cudo Communication Co., Ltd."},
	{0x88FD15, "LINEEYE CO., LTD"},
	{0x8C53F7, "A&D ENGINEERING CO., LTD."},
	{0x8C541D, "LGE "},
	{0x8C56C5, "Nintendo Co., Ltd."},
	{0x8C598B, "C Technologies AB"},
	{0x8C640B, "BS Storitve d.o.o."},
	{0x8C736E, "Fujitsu Limited"},
	{0x8C9236, "Aus.Linx Technology Co., Ltd."},
	{0x8CA982, "Intel Corporate"},
	{0x8CD628, "Ikor Metering"},
	{0x9018AE, "Shanghai Meridian Technologies, Co. Ltd."},
	{0x903D6B, "Zicon Technology Corp."},
	{0x904716, "RORZE CORPORATION"},
	{0x904CE5, "Hon Hai Precision Ind. Co.,Ltd."},
	{0x906DC8, "DLG Automao Industrial Ltda"},
	{0x907F61, "Chicony Electronics Co., Ltd."},
	{0x90840D, "Apple, Inc"},
	{0x90A2DA, "GHEO SA"},
	{0x90A7C1, "Pakedge Device and Software Inc."},
	{0x90E6BA, "ASUSTek COMPUTER INC."},
	{0x90FBA6, "Hon Hai Precision Ind.Co.Ltd"},
	{0x940C6D, "TP-LINK Technologies Co.,Ltd."},
	{0x94236E, "Shenzhen Junlan Electronic Ltd"},
	{0x942E63, "Finscur"},
	{0x944452, "Belkin International, Inc."},
	{0x94592D, "EKE Building Technology Systems Ltd"},
	{0x94BA31, "Visiontec da Amaznia Ltda."},
	{0x94C4E9, "PowerLayer Microsystems HongKong Limited"},
	{0x94F692, "Geminico co.,Ltd."},
	{0x982D56, "Resolution Audio"},
	{0x986DC8,
	 "TOSHIBA MITSUBISHI-ELECTRIC INDUSTRIAL SYSTEMS CORPORATION"},
	{0x9889ED, "Anadem Information Inc."},
	{0x988B5D, "SAGEM COMMUNICATION"},
	{0x98BC99, "Edeltech Co.,Ltd."},
	{0x98D88C, "Nortel Networks"},
	{0x98DCD9, "UNITEC Co., Ltd."},
	{0x9C1874, "Nokia Danmark A/S"},
	{0x9C4E8E, "ALT Systems Ltd"},
	{0x9C55B4, "I.S.E. S.r.l."},
	{0x9C5B96, "NMR Corporation"},
	{0x9C5E73, "Calibre UK Ltd"},
	{0x9CAFCA, "Cisco Systems"},
	{0x9CB206, "PROCENTEC"},
	{0x9CC077, "PrintCounts, LLC"},
	{0x9CCD82, "CHENG UEI PRECISION INDUSTRY CO.,LTD"},
	{0x9CEBE8, "BizLink (Kunshan) Co.,Ltd"},
	{0xA00798, "Samsung Electronics"},
	{0xA01859, "Shenzhen Yidashi Electronics Co Ltd"},
	{0xA0231B, "TeleComp R&amp;D Corp."},
	{0xA02EF3, "United Integrated Services Co., Led."},
	{0xA03A75, "PSS Belgium N.V."},
	{0xA04025, "Actioncable, Inc."},
	{0xA055DE, "Pace Micro Technology plc"},
	{0xA0593A, "V.D.S. Video Display Systems srl"},
	{0xA05DC1, "TMCT Co., LTD."},
	{0xA05DE7, "DIRECTV, Inc."},
	{0xA06986, "Wellav Technologies Ltd"},
	{0xA06A00, "Verilink Corporation"},
	{0xA07332, "Cashmaster International Limited"},
	{0xA09805, "OpenVox Communication Co Ltd"},
	{0xA098ED,
	 "Shandong Intelligent Optical Communication Development Co., Ltd."},
	{0xA09A5A, "Time Domain"},
	{0xA0B9ED, "Skytap"},
	{0xA0BFA5, "CORESYS"},
	{0xA438FC, "Plastic Logic"},
	{0xA479E4, "KLINFO Corp"},
	{0xA4AD00, "Ragsdale Technology"},
	{0xA4ADB8, "Vitec Group, Camera Dynamics Ltd"},
	{0xA4B121, "Arantia 2010 S.L."},
	{0xA4B1EE, "H. ZANDER GmbH & Co. KG"},
	{0xA4BADB, "Dell Inc."},
	{0xA4C2AB, "Hangzhou LEAD-IT Information & Technology Co.,Ltd"},
	{0xA4DA3F, "Bionics Corp."},
	{0xA4DE50, "Total Walther GmbH"},
	{0xA4E7E4, "Connex GmbH"},
	{0xA4ED4E, "Motorola Mobile Devices"},
	{0xA863DF, "DISPL�AIRE CORPORATION"},
	{0xA870A5, "UniComm Inc."},
	{0xA87B39, "Nokia Corporation"},
	{0xA87E33, "Nokia Danmark A/S"},
	{0xA893E6,
	 "JIANGXI JINGGANGSHAN CKING COMMUNICATION TECHNOLOGY CO.,LTD"},
	{0xA8995C, "aizo ag"},
	{0xA8C222, "TM-Research Inc."},
	{0xA8CB95, "EAST BEST CO., LTD."},
	{0xA8CE90, "CVC"},
	{0xA8E3EE, "Sony Computer Entertainment Inc."},
	{0xA8F274, "Samsung Electronics"},
	{0xA8F470,
	 "Fujian Newland Communication Science Technologies Co.,Ltd."},
	{0xA8F94B, "Eltex Enterprise Ltd."},
	{0xAA0000, "DIGITAL EQUIPMENT CORPORATION"},
	{0xAA0001, "DIGITAL EQUIPMENT CORPORATION"},
	{0xAA0002, "DIGITAL EQUIPMENT CORPORATION"},
	{0xAA0003, "DIGITAL EQUIPMENT CORPORATION"},
	{0xAA0004, "DIGITAL EQUIPMENT CORPORATION"},
	{0xAC44F2, "Revolabs Inc"},
	{0xAC583B, "Human Assembler, Inc."},
	{0xAC6706, "Ruckus Wireless"},
	{0xAC8317, "Shenzhen Furtunetel Communication Co., Ltd"},
	{0xAC867E, "Create New Technology (HK) Limited Company"},
	{0xACBEB6, "Visualedge Technology Co., Ltd."},
	{0xACCE8F, "HWA YAO TECHNOLOGIES CO., LTD"},
	{0xACD180, "Crexendo Business Solutions, Inc."},
	{0xACE348, "MadgeTech, Inc"},
	{0xACE9AA, "Hay Systems Ltd"},
	{0xACEA6A, "GENIX INFOCOMM CO., LTD."},
	{0xB05B1F, "THERMO FISHER SCIENTIFIC S.P.A."},
	{0xB09074, "Fulan Electronics Limited"},
	{0xB09134, "Taleo"},
	{0xB0973A, "E-Fuel Corporation"},
	{0xB0AA36, "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD."},
	{0xB0C69A, "Juniper Networks"},
	{0xB0C8AD, "People Power Company"},
	{0xB0E754, "2Wire"},
	{0xB0E97E, "Advanced Micro Peripherals"},
	{0xB40832, "TC Communications"},
	{0xB42CBE, "Direct Payment Solutions Limited"},
	{0xB4417A, "ShenZhen Gongjin Electronics Co.,Ltd"},
	{0xB45861, "CRemote, LLC"},
	{0xB482FE, "Askey Computer Corp"},
	{0xB4B5AF, "Minsung Electronics"},
	{0xB4ED54, "Wohler Technologies"},
	{0xB86491, "CK Telecom Ltd"},
	{0xB8653B, "Bolymin, Inc."},
	{0xB894D2, "Retail Innovation HTT AB"},
	{0xB8A3E0, "BenRui Technology Co.,Ltd"},
	{0xB8AC6F, "Dell Inc"},
	{0xB8B1C7, "BT&COM CO.,LTD"},
	{0xB8F732, "Aryaka Networks Inc"},
	{0xBC0543, "AVM GmbH"},
	{0xBC4E3C, "CORE STAFF CO., LTD."},
	{0xBC6A16, "tdvine"},
	{0xBC9DA5, "DASCOM Europe GmbH"},
	{0xBCB181, "SHARP CORPORATION"},
	{0xBCD5B6, "d2d technologies"},
	{0xC01E9B, "Pixavi AS"},
	{0xC038F9, "Nokia Danmark A/S"},
	{0xC03F0E, "NETGEAR"},
	{0xC06C0F, "Dobbs Stanford"},
	{0xC09134, "ProCurve Networking by HP"},
	{0xC09C92, "COBY"},
	{0xC0BAE6, "Application Solutions (Safety and Security) Ltd"},
	{0xC0CFA3, "Creative Electronics &amp; Software, Inc."},
	{0xC0E422, "Texas Instruments"},
	{0xC417FE, "Hon Hai Precision Ind. Co.,Ltd."},
	{0xC4198B, "Dominion Voting Systems Corporation"},
	{0xC41ECE, "HMI Sources Ltd."},
	{0xC45976, "Fugoo"},
	{0xC47D4F, "Cisco Systems"},
	{0xC4AAA1, "SUMMIT DEVELOPMENT, spol.s r.o."},
	{0xC4E17C, "U2S co."},
	{0xC4FCE4, "DishTV NZ Ltd"},
	{0xC80AA9, "Quanta Computer Inc."},
	{0xC82E94, "Halfa Enterprise Co., Ltd."},
	{0xC835B8, "Ericsson, EAB/RWI/K"},
	{0xC83A35, "Tenda Technology Co., Ltd."},
	{0xC86C1E, "Display Systems Ltd"},
	{0xC86CB6, "Optcom Co., Ltd."},
	{0xC87248, "Aplicom Oy"},
	{0xC87E75, "Samsung Electronics Co.,Ltd"},
	{0xC8873B, "Net Optics"},
	{0xC8979F, "Nokia Corporation"},
	{0xC8C13C, "RuggedTek Hangzhou Co., Ltd"},
	{0xC8D1D1, "AGAiT Technology Corporation"},
	{0xC8D2C1, "Jetlun (Shenzhen) Corporation"},
	{0xC8EF2E, "Beijing Gefei Tech. Co., Ltd "},
	{0xCC0080, "TRUST SYSTEM Co.,"},
	{0xCC2218, "InnoDigital Co., Ltd."},
	{0xCC5076, "Ocom Communications, Inc."},
	{0xCC5459, "OnTime Networks AS"},
	{0xCC69B0, "Global Traffic Technologies, LLC"},
	{0xCCB888, "AnB Securite s.a."},
	{0xCCCC4E, "Sun Fountainhead USA. Corp "},
	{0xCCEA1C, "DCONWORKS  Co., Ltd"},
	{0xD03761, "Texas Instruments"},
	{0xD05875, "Active Control Technology Inc."},
	{0xD0B33F, "SHENZHEN TINNO MOBILE TECHNOLOGY CO.,LTD."},
	{0xD0D286, "Beckman Coulter Biomedical K.K."},
	{0xD0E40B, "Wearable Inc."},
	{0xD0F0DB, "Ericsson"},
	{0xD411D6, "ShotSpotter, Inc."},
	{0xD41F0C, "TVI Vision Oy"},
	{0xD44CA7, "Informtekhnika & Communication, LLC"},
	{0xD46CBF, "Goodrich ISR"},
	{0xD4823E, "Argosy Technologies, Ltd."},
	{0xD49A20, "Apple, Inc"},
	{0xD49C28, "JayBird Gear LLC"},
	{0xD4AAFF, "MICRO WORLD "},
	{0xD4C766, "Acentic GmbH"},
	{0xD4F143, "IPROAD.,Inc"},
	{0xD81BFE, "TWINLINX CORPORATION"},
	{0xD828C9, "General Electric Consumer and Industrial"},
	{0xD83062, "Apple, Inc"},
	{0xD842AC, "FreeComm Data Communication Co.,Ltd."},
	{0xD8543A, "Texas Instruments"},
	{0xD8AE90, "Itibia Technologies"},
	{0xD8C3FB, "DETRACOM"},
	{0xD8D385, "Hewlett Packard"},
	{0xD8D67E, "GSK CNC EQUIPMENT CO.,LTD"},
	{0xD8E72B, "OnPATH Technologies"},
	{0xDC0265, "Meditech Kft"},
	{0xDC1D9F, "U & B tech"},
	{0xDC2C26, "Iton Technology Limited"},
	{0xDC3350, "TechSAT GmbH"},
	{0xDC49C9, "CASCO SIGNAL LTD"},
	{0xDCA971, "Intel Corporate"},
	{0xDCE2AC, "Lumens Digital Optics Inc."},
	{0xDCE71C, "AUG Elektronik GmbH"},
	{0xE02630, "Intrigue Technologies, Inc."},
	{0xE02636, "Nortel Networks"},
	{0xE064BB, "DigiView S.r.l."},
	{0xE08FEC, "REPOTEC CO., LTD."},
	{0xE09153, "XAVi Technologies Corp."},
	{0xE0ABFE, "Orb Networks, Inc."},
	{0xE0BC43, "C2 Microsystems, Inc."},
	{0xE0CA4D, "Shenzhen Unistar Communication Co.,LTD"},
	{0xE0CB4E, "ASUSTek COMPUTER INC."},
	{0xE0E751, "Nintendo Co., Ltd."},
	{0xE41F13, "IBM"},
	{0xE43593, "Hangzhou GoTo technology Co.Ltd"},
	{0xE4751E, "Getinge Sterilization AB"},
	{0xE497F0, "Shanghai VLC Technologies Ltd. Co."},
	{0xE4FFDD, "ELECTRON INDIA"},
	{0xE8056D, "Nortel Networks"},
	{0xE80B13, "Akib Systems Taiwan, INC"},
	{0xE83A97, "OCZ Technology Group"},
	{0xE84ECE, "Nintendo Co., Ltd."},
	{0xE85E53, "Infratec Datentechnik GmbH"},
	{0xE89D87, "Toshiba"},
	{0xE8A4C1, "Deep Sea Electronics PLC"},
	{0xE8DAAA, "VideoHome Technology Corp."},
	{0xE8DFF2, "PRF Co., Ltd."},
	{0xE8E1E2, "Energotest"},
	{0xE8E776, "Shenzhen Kootion Technology Co., Ltd"},
	{0xEC3091, "Cisco Systems"},
	{0xEC43E6, "AWCER Ltd."},
	{0xEC4476, "Cisco Systems"},
	{0xEC6C9F, "Chengdu Volans Technology CO.,LTD"},
	{0xEC8EAD, "DLX"},
	{0xEC9B5B, "Nokia Corporation"},
	{0xECC882, "Cisco Systems"},
	{0xECCD6D, "Allied Telesis, Inc."},
	{0xECD00E, "MiraeRecognition Co., Ltd."},
	{0xECDE3D, "Lamprey Networks, Inc."},
	{0xECE09B, "Samsung electronics CO., LTD"},
	{0xECE9F8, "Guang Zhou TRI-SUN Electronics Technology  Co., Ltd"},
	{0xF02408, "Talaris (Sweden) AB"},
	{0xF0264C, "Dr. Sigrist AG"},
	{0xF02FD8, "Bi2-Vision"},
	{0xF04335, "DVN(Shanghai)Ltd."},
	{0xF04BF2, "JTECH Communications, Inc."},
	{0xF06281, "ProCurve Networking by HP"},
	{0xF06853, "Integrated Corporation"},
	{0xF077D0, "Xcellen"},
	{0xF07BCB, "Hon Hai Precision Ind. Co.,Ltd. "},
	{0xF0B6EB, "Poslab Technology Co., Ltd."},
	{0xF0BCC8, "MaxID (Pty) Ltd"},
	{0xF0C24C, "Zhejiang FeiYue Digital Technology Co., Ltd"},
	{0xF0DE71, "Shanghai EDO Technologies Co.,Ltd."},
	{0xF0EC39, "Essec"},
	{0xF40B93, "Research In Motion"},
	{0xF445ED, "Portable Innovation Technology Ltd."},
	{0xF45FF7, "DQ Technology Inc."},
	{0xF46349, "Diffon Corporation"},
	{0xF47626, "Viltechmeda UAB "},
	{0xF4ACC1, "Cisco Systems"},
	{0xF4CE46, "Hewlett Packard"},
	{0xF4FC32, "Texas Instruments"},
	{0xF81EDF, "Apple, Inc"},
	{0xF8472D, "X2gen Digital Corp. Ltd"},
	{0xF852DF, "VNL Europe AB"},
	{0xF871FE, "The Goldman Sachs Group, Inc."},
	{0xF8811A, "S2IH"},
	{0xF88DEF, "Tenebraex"},
	{0xF8912A, "GLP German Light Products GmbH"},
	{0xF89D0D, "Control Technology Inc."},
	{0xF8DC7A, "Variscite LTD"},
	{0xF8E968, "Egker Kft."},
	{0xFC0877, "Prentke Romich Company"},
	{0xFC4463, "Universal Audio"},
	{0xFC6198, "NEC Personal Products, Ltd"},
	{0xFC683E, "Directed Perception, Inc"},
	{0xFCCCE4, "Ascon Ltd."},
	{0xFCCF62, "BLADE Network Technology"},
	{0xFCE192, "Sichuan Jinwangtong Electronic Science&Technology Co,.Ltd"},
	{0xFCFAF7, "Shanghai Baud Data Communication Co.,Ltd."},
	{0xFCFBFB, "Cisco Systems"},
	/* Some additional, unofficial Vendor IDs (partly taken from Nmap project) */
	{0x525400, "QEMU Virtual NIC"},
	{0xB0C420, "Bochs Virtual NIC"},
	{0xDEADCA, "PearPC Virtual NIC"},
	{0x00FFD1, "Cooperative Linux Virtual NIC"},
	{0x0180C2, "Spanning tree (for bridges)"},
	{0xAB0003, "DEC Local Area Transport"},
	{0xCF0000, "Ethernet Configuration Test protocol (Loopback)"},
};

char vendor_unknown[] = "Unknown";

#endif				/* _NET_OUI_H_ */
